@@ -32,7 +32,7 @@
 #include <string.h>
 #include <glib.h>
 
-#include <libedataserver/e-url.h> 
+#include <libedataserver/e-url.h>
 #include <libedataserver/e-flag.h>
 #include <libedataserver/e-proxy.h>
 #include <libebook/e-contact.h>
@@ -58,13 +58,13 @@
 static EBookBackendClass *parent_class;
 
 struct _EBookBackendWebdavPrivate {
-	int                mode;
+	gint                mode;
 	gboolean           marked_for_offline;
 	SoupSession       *session;
 	EProxy		  *proxy;
 	gchar             *uri;
-	char              *username;
-	char              *password;
+	gchar              *username;
+	gchar              *password;
 
 	EBookBackendCache *cache;
 };
@@ -107,14 +107,14 @@ static EContact*
 download_contact(EBookBackendWebdav *webdav, const gchar *uri)
 {
 	SoupMessage *message;
-	const char  *content_type;
-	const char  *etag;
+	const gchar  *content_type;
+	const gchar  *etag;
 	EContact    *contact;
 	guint        status;
-	
+
 	message = soup_message_new(SOUP_METHOD_GET, uri);
 	soup_message_headers_append(message->request_headers,
-	                            "User-Agent", USERAGENT);
+				    "User-Agent", USERAGENT);
 
 	status = soup_session_send_message(webdav->priv->session, message);
 	if (status != 200) {
@@ -126,10 +126,10 @@ download_contact(EBookBackendWebdav *webdav, const gchar *uri)
 	 * DECIDE: should we also accept text/plain for webdav servers that
 	 * don't know about text/x-vcard?*/
 	content_type = soup_message_headers_get(message->response_headers,
-	                                        "Content-Type");
+						"Content-Type");
 	if (content_type != NULL && strstr(content_type, "text/x-vcard") == NULL) {
 		g_message("'%s' doesn't have mime-type text/x-vcard but '%s'", uri,
-		          content_type);
+			  content_type);
 		g_object_unref(message);
 		return NULL;
 	}
@@ -150,9 +150,9 @@ download_contact(EBookBackendWebdav *webdav, const gchar *uri)
 
 	/* we use our URI as UID
 	 * the etag is rememebered in the revision field */
-	e_contact_set(contact, E_CONTACT_UID, (const gpointer) uri);
+	e_contact_set(contact, E_CONTACT_UID, (gconstpointer) uri);
 	if (etag != NULL) {
-		e_contact_set(contact, E_CONTACT_REV, (const gpointer) etag);
+		e_contact_set(contact, E_CONTACT_REV, (gconstpointer) etag);
 	}
 
 	g_object_unref(message);
@@ -166,10 +166,10 @@ upload_contact(EBookBackendWebdav *webdav, EContact *contact)
 	SoupMessage *message;
 	gchar       *uri;
 	gchar       *etag;
-	const char  *new_etag;
-	char        *request;
+	const gchar  *new_etag;
+	gchar        *request;
 	guint        status;
-	const char  *property;
+	const gchar  *property;
 	gboolean     avoid_ifmatch;
 
 	uri = e_contact_get(contact, E_CONTACT_UID);
@@ -180,7 +180,7 @@ upload_contact(EBookBackendWebdav *webdav, EContact *contact)
 
 	message = soup_message_new(SOUP_METHOD_PUT, uri);
 	soup_message_headers_append(message->request_headers,
-	                            "User-Agent", USERAGENT);
+				    "User-Agent", USERAGENT);
 
 	property = e_source_get_property(source, "avoid_ifmatch");
 	if (property != NULL && strcmp(property, "1") == 0) {
@@ -196,12 +196,12 @@ upload_contact(EBookBackendWebdav *webdav, EContact *contact)
 		etag = e_contact_get(contact, E_CONTACT_REV);
 		if (etag == NULL) {
 			soup_message_headers_append(message->request_headers,
-			                            "If-None-Match", "*");
+						    "If-None-Match", "*");
 		} else if (etag[0] == 'W' && etag[1] == '/') {
 			g_warning("we only have a weak ETag, don't use If-Match synchronisation");
 		} else {
 			soup_message_headers_append(message->request_headers,
-			                            "If-Match", etag);
+						    "If-Match", etag);
 			g_free(etag);
 		}
 	}
@@ -212,13 +212,13 @@ upload_contact(EBookBackendWebdav *webdav, EContact *contact)
 	e_contact_set(contact, E_CONTACT_REV, NULL);
 	request = e_vcard_to_string(E_VCARD(contact), EVC_FORMAT_VCARD_30);
 	soup_message_set_request(message, "text/x-vcard", SOUP_MEMORY_TEMPORARY,
-	                         request, strlen(request));
-	
+				 request, strlen(request));
+
 	status   = soup_session_send_message(webdav->priv->session, message);
 	new_etag = soup_message_headers_get(message->response_headers, "ETag");
 
 	/* set UID and REV fields */
-	e_contact_set(contact, E_CONTACT_REV, (const gpointer) new_etag);
+	e_contact_set(contact, E_CONTACT_REV, (gconstpointer) new_etag);
 	e_contact_set(contact, E_CONTACT_UID, uri);
 
 	g_object_unref(message);
@@ -247,7 +247,7 @@ e_book_backend_handle_auth_request(EBookBackendWebdav *webdav)
 
 static void
 e_book_backend_webdav_create_contact(EBookBackend *backend,
-	   	EDataBook *book, guint32 opid, const char *vcard)
+		EDataBook *book, guint32 opid, const gchar *vcard)
 {
 	EBookBackendWebdav        *webdav = E_BOOK_BACKEND_WEBDAV (backend);
 	EBookBackendWebdavPrivate *priv   = webdav->priv;
@@ -266,7 +266,7 @@ e_book_backend_webdav_create_contact(EBookBackend *backend,
 	/* do 3 rand() calls to construct a unique ID... poor way but should be
 	 * good enough for us */
 	uid = g_strdup_printf("%s%08X-%08X-%08X.vcf", priv->uri, rand(), rand(),
-	                      rand());
+			      rand());
 	e_contact_set(contact, E_CONTACT_UID, uid);
 
 	/* kill revision field (might have been set by some other backend) */
@@ -281,7 +281,7 @@ e_book_backend_webdav_create_contact(EBookBackend *backend,
 			e_data_book_respond_create(book, opid, res, NULL);
 		} else {
 			g_warning("create resource '%s' failed with http status: %d",
-			          uid, status);
+				  uid, status);
 			e_data_book_respond_create(book, opid,
 					GNOME_Evolution_Addressbook_OtherError, NULL);
 		}
@@ -315,15 +315,15 @@ e_book_backend_webdav_create_contact(EBookBackend *backend,
 }
 
 static guint
-delete_contact(EBookBackendWebdav *webdav, const char *uri)
+delete_contact(EBookBackendWebdav *webdav, const gchar *uri)
 {
 	SoupMessage *message;
 	guint        status;
-	
+
 	message = soup_message_new(SOUP_METHOD_DELETE, uri);
 	soup_message_headers_append(message->request_headers,
-	                            "User-Agent", USERAGENT);
-	
+				    "User-Agent", USERAGENT);
+
 	status = soup_session_send_message(webdav->priv->session, message);
 	g_object_unref(message);
 
@@ -338,7 +338,7 @@ e_book_backend_webdav_remove_contacts(EBookBackend *backend,
 	EBookBackendWebdavPrivate *priv        = webdav->priv;
 	GList                     *deleted_ids = NULL;
 	GList                     *list;
-	
+
 	if (priv->mode == GNOME_Evolution_Addressbook_MODE_LOCAL) {
 		e_data_book_respond_create(book, opid,
 				GNOME_Evolution_Addressbook_RepositoryOffline, NULL);
@@ -346,7 +346,7 @@ e_book_backend_webdav_remove_contacts(EBookBackend *backend,
 	}
 
 	for (list = id_list; list != NULL; list = list->next) {
-		const char *uid = (const char*) list->data;
+		const gchar *uid = (const gchar *) list->data;
 		guint       status;
 
 		status = delete_contact(webdav, uid);
@@ -355,7 +355,7 @@ e_book_backend_webdav_remove_contacts(EBookBackend *backend,
 				GNOME_Evolution_Addressbook_CallStatus res
 					= e_book_backend_handle_auth_request(webdav);
 				e_data_book_respond_remove_contacts(book, opid, res,
-				                                    deleted_ids);
+								    deleted_ids);
 			} else {
 				g_warning("DELETE failed with http status %d", status);
 			}
@@ -371,13 +371,13 @@ e_book_backend_webdav_remove_contacts(EBookBackend *backend,
 
 static void
 e_book_backend_webdav_modify_contact(EBookBackend *backend,
- 		EDataBook *book, guint32 opid, const char *vcard)
+		EDataBook *book, guint32 opid, const gchar *vcard)
 {
 	EBookBackendWebdav        *webdav  = E_BOOK_BACKEND_WEBDAV(backend);
 	EBookBackendWebdavPrivate *priv    = webdav->priv;
 	EContact                  *contact = e_contact_new_from_vcard(vcard);
-	const char                *uid;
-	const char                *etag;
+	const gchar                *uid;
+	const gchar                *etag;
 	guint status;
 
 	if (priv->mode == GNOME_Evolution_Addressbook_MODE_LOCAL) {
@@ -437,12 +437,12 @@ e_book_backend_webdav_modify_contact(EBookBackend *backend,
 
 static void
 e_book_backend_webdav_get_contact(EBookBackend *backend, EDataBook *book,
-		guint32 opid, const char *uid)
+		guint32 opid, const gchar *uid)
 {
 	EBookBackendWebdav        *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 	EBookBackendWebdavPrivate *priv   = webdav->priv;
 	EContact                  *contact;
-	char                      *vcard;
+	gchar                      *vcard;
 
 	if (priv->mode == GNOME_Evolution_Addressbook_MODE_LOCAL) {
 		contact = e_book_backend_cache_get_contact(priv->cache, uid);
@@ -490,7 +490,7 @@ parse_response_tag(const parser_strings_t *strings, xmlTextReaderPtr reader)
 {
 	xmlChar            *href  = NULL;
 	xmlChar            *etag  = NULL;
-	int                 depth = xmlTextReaderDepth(reader);
+	gint                 depth = xmlTextReaderDepth(reader);
 	response_element_t *element;
 
 	while (xmlTextReaderRead(reader) && xmlTextReaderDepth(reader) > depth) {
@@ -510,10 +510,10 @@ parse_response_tag(const parser_strings_t *strings, xmlTextReaderPtr reader)
 			href = xmlTextReaderReadString(reader);
 		} else if (tag_name == strings->propstat) {
 			/* find <propstat><prop><getetag> hierarchy */
-			int depth2 = xmlTextReaderDepth(reader);
-			while (xmlTextReaderRead(reader) 
+			gint depth2 = xmlTextReaderDepth(reader);
+			while (xmlTextReaderRead(reader)
 					&& xmlTextReaderDepth(reader) > depth2) {
-				int depth3;
+				gint depth3;
 				if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT)
 					continue;
 
@@ -528,7 +528,7 @@ parse_response_tag(const parser_strings_t *strings, xmlTextReaderPtr reader)
 						continue;
 
 					if (xmlTextReaderConstNamespaceUri(reader) != strings->dav
-							|| xmlTextReaderConstLocalName(reader) 
+							|| xmlTextReaderConstLocalName(reader)
 							!= strings->getetag)
 						continue;
 
@@ -562,8 +562,8 @@ parse_propfind_response(xmlTextReaderPtr reader)
 
 	/* get internalized versions of some strings to avoid strcmp while
 	 * parsing */
-	strings.multistatus 
-	   	= xmlTextReaderConstString(reader, BAD_CAST "multistatus");
+	strings.multistatus
+		= xmlTextReaderConstString(reader, BAD_CAST "multistatus");
 	strings.dav         = xmlTextReaderConstString(reader, BAD_CAST "DAV:");
 	strings.href        = xmlTextReaderConstString(reader, BAD_CAST "href");
 	strings.response    = xmlTextReaderConstString(reader, BAD_CAST "response");
@@ -571,7 +571,7 @@ parse_propfind_response(xmlTextReaderPtr reader)
 	strings.prop        = xmlTextReaderConstString(reader, BAD_CAST "prop");
 	strings.getetag     = xmlTextReaderConstString(reader, BAD_CAST "getetag");
 
-	while (xmlTextReaderRead(reader) 
+	while (xmlTextReaderRead(reader)
 			&& xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
 	}
 
@@ -613,13 +613,13 @@ send_propfind(EBookBackendWebdav *webdav)
 	const gchar               *request =
 		"<?xml version=\"1.0\" encoding=\"utf-8\"?>"
 		"<propfind xmlns=\"DAV:\"><prop><getetag/></prop></propfind>";
-	
+
 	message = soup_message_new(SOUP_METHOD_PROPFIND, priv->uri);
 	soup_message_headers_append(message->request_headers,
-	                            "User-Agent", USERAGENT);
+				    "User-Agent", USERAGENT);
 	soup_message_headers_append(message->request_headers, "Depth", "1");
 	soup_message_set_request(message, "text/xml", SOUP_MEMORY_TEMPORARY,
-			(gchar*) request, strlen(request));
+			(gchar *) request, strlen(request));
 
 	soup_session_send_message(priv->session, message);
 
@@ -637,8 +637,8 @@ download_contacts(EBookBackendWebdav *webdav, EFlag *running,
 	response_element_t        *elements;
 	response_element_t        *element;
 	response_element_t        *next;
-	int                        count;
-	int                        i;
+	gint                        count;
+	gint                        i;
 
 	if (book_view != NULL) {
 		e_data_book_view_notify_status_message(book_view,
@@ -670,8 +670,8 @@ download_contacts(EBookBackendWebdav *webdav, EFlag *running,
 
 	/* parse response */
 	reader = xmlReaderForMemory(message->response_body->data,
-	                            message->response_body->length, NULL, NULL,
-	                            XML_PARSE_NOWARNING);
+				    message->response_body->length, NULL, NULL,
+				    XML_PARSE_NOWARNING);
 
 	elements = parse_propfind_response(reader);
 
@@ -684,7 +684,7 @@ download_contacts(EBookBackendWebdav *webdav, EFlag *running,
 	/* download contacts */
 	i = 0;
 	for (element = elements; element != NULL; element = element->next, ++i) {
-		const char  *uri;
+		const gchar  *uri;
 		const gchar *etag;
 		EContact    *contact;
 		gchar *complete_uri;
@@ -694,14 +694,14 @@ download_contacts(EBookBackendWebdav *webdav, EFlag *running,
 			break;
 
 		if (book_view != NULL) {
-			float percent = 100.0 / count * i;
-			char buf[100];
-			snprintf(buf, sizeof(buf), "Loading Contacts (%d%%)", (int)percent);
+			gfloat percent = 100.0 / count * i;
+			gchar buf[100];
+			snprintf(buf, sizeof(buf), "Loading Contacts (%d%%)", (gint)percent);
 			e_data_book_view_notify_status_message(book_view, buf);
 		}
 
 		/* skip collections */
-		uri = (const char *) element->href;
+		uri = (const gchar *) element->href;
 		if (uri[strlen(uri)-1] == '/')
 			continue;
 
@@ -716,11 +716,11 @@ download_contacts(EBookBackendWebdav *webdav, EFlag *running,
 			complete_uri = g_strdup(uri);
 		}
 
-		etag = (const gchar*) element->etag;
+		etag = (const gchar *) element->etag;
 
 		contact = e_book_backend_cache_get_contact(priv->cache, complete_uri);
 		/* download contact if it is not cached or its ETag changed */
-		if (contact == NULL || 
+		if (contact == NULL || etag == NULL ||
 				strcmp(e_contact_get_const(contact, E_CONTACT_REV),etag) != 0) {
 			contact = download_contact(webdav, complete_uri);
 			if (contact != NULL) {
@@ -775,22 +775,22 @@ book_view_thread(gpointer data)
 }
 
 static void
-e_book_backend_webdav_start_book_view(EBookBackend *backend, 
+e_book_backend_webdav_start_book_view(EBookBackend *backend,
                                       EDataBookView *book_view)
 {
 	EBookBackendWebdav        *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 	EBookBackendWebdavPrivate *priv   = webdav->priv;
 
 	if (priv->mode == GNOME_Evolution_Addressbook_MODE_REMOTE) {
-		WebdavBackendSearchClosure *closure 
+		WebdavBackendSearchClosure *closure
 			= init_closure(book_view, E_BOOK_BACKEND_WEBDAV(backend));
 
-		closure->thread 
+		closure->thread
 			= g_thread_create(book_view_thread, book_view, TRUE, NULL);
 
 		e_flag_wait(closure->running);
 	} else {
-		const char *query = e_data_book_view_get_card_query(book_view);
+		const gchar *query = e_data_book_view_get_card_query(book_view);
 		GList *contacts = e_book_backend_cache_get_contacts(priv->cache, query);
 		GList *l;
 
@@ -830,7 +830,7 @@ e_book_backend_webdav_stop_book_view(EBookBackend *backend,
 
 static void
 e_book_backend_webdav_get_contact_list(EBookBackend *backend, EDataBook *book,
-		guint32 opid, const char *query)
+		guint32 opid, const gchar *query)
 {
 	EBookBackendWebdav        *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 	EBookBackendWebdavPrivate *priv   = webdav->priv;
@@ -854,7 +854,7 @@ e_book_backend_webdav_get_contact_list(EBookBackend *backend, EDataBook *book,
 	vcard_list   = NULL;
 	for (c = contact_list; c != NULL; c = g_list_next(c)) {
 		EContact *contact = c->data;
-		char     *vcard   
+		gchar     *vcard
 			= e_vcard_to_string(E_VCARD(contact), EVC_FORMAT_VCARD_30);
 		vcard_list = g_list_append(vcard_list, vcard);
 		g_object_unref(contact);
@@ -867,8 +867,8 @@ e_book_backend_webdav_get_contact_list(EBookBackend *backend, EDataBook *book,
 
 static void
 e_book_backend_webdav_authenticate_user(EBookBackend *backend, EDataBook *book,
-		guint32 opid, const char *user, const char *password,
-		const char *auth_method)
+		guint32 opid, const gchar *user, const gchar *password,
+		const gchar *auth_method)
 {
 	EBookBackendWebdav        *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 	EBookBackendWebdavPrivate *priv   = webdav->priv;
@@ -894,7 +894,7 @@ e_book_backend_webdav_authenticate_user(EBookBackend *backend, EDataBook *book,
 				GNOME_Evolution_Addressbook_AuthenticationFailed);
 	} else {
 		e_data_book_respond_authenticate_user(book, opid,
-				GNOME_Evolution_Addressbook_Success); 
+				GNOME_Evolution_Addressbook_Success);
 	}
 }
 
@@ -903,13 +903,13 @@ e_book_backend_webdav_get_supported_fields(EBookBackend *backend,
 		EDataBook *book, guint32 opid)
 {
 	GList *fields = NULL;
-	int    i;
+	gint    i;
 
 	/* we support everything */
 	for (i = 1; i < E_CONTACT_FIELD_LAST; ++i) {
 		fields = g_list_append(fields, g_strdup(e_contact_field_name(i)));
 	}
-	
+
 	e_data_book_respond_get_supported_fields(book, opid,
 			GNOME_Evolution_Addressbook_Success, fields);
 	g_list_foreach(fields, (GFunc) g_free, NULL);
@@ -940,7 +940,7 @@ e_book_backend_webdav_get_required_fields(EBookBackend *backend,
 
 	field_name = e_contact_field_name(E_CONTACT_FILE_AS);
 	fields     = g_list_append(fields , g_strdup(field_name));
-	
+
 	e_data_book_respond_get_supported_fields(book, opid,
 			GNOME_Evolution_Addressbook_Success, fields);
 	g_list_free (fields);
@@ -958,7 +958,7 @@ static void soup_authenticate(SoupSession *session, SoupMessage *message,
 
 	if (priv->username != NULL) {
 		soup_auth_authenticate(auth, g_strdup(priv->username),
-		                       g_strdup(priv->password));
+				       g_strdup(priv->password));
 	}
 }
 
@@ -986,11 +986,11 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 	EBookBackendWebdav        *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 	EBookBackendWebdavPrivate *priv   = webdav->priv;
 	const gchar               *uri;
-	const char                *offline;
-	const char                *uri_without_protocol;
-	const char                *protocol;
-	const char                *use_ssl;
-	const char                *suffix;
+	const gchar                *offline;
+	const gchar                *uri_without_protocol;
+	const gchar                *protocol;
+	const gchar                *use_ssl;
+	const gchar                *suffix;
 	SoupSession               *session;
 
 	uri = e_source_get_uri(source);
@@ -1002,12 +1002,12 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 	offline = e_source_get_property(source, "offline_sync");
 	if (offline && g_str_equal(offline, "1"))
 		priv->marked_for_offline = TRUE;
-	
-	if (priv->mode == GNOME_Evolution_Addressbook_MODE_LOCAL 
+
+	if (priv->mode == GNOME_Evolution_Addressbook_MODE_LOCAL
 			&& !priv->marked_for_offline ) {
 		return GNOME_Evolution_Addressbook_OfflineUnavailable;
 	}
-	
+
 	if (strncmp(uri, "webdav://", 9) != 0) {
 		/* the book is not for us */
 		return GNOME_Evolution_Addressbook_OtherError;
@@ -1026,14 +1026,14 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 	if (uri_without_protocol[strlen(uri_without_protocol) - 1] != '/')
 		suffix = "/";
 
-	priv->uri 
+	priv->uri
 		= g_strdup_printf("%s%s%s", protocol, uri_without_protocol, suffix);
 
 	priv->cache = e_book_backend_cache_new(priv->uri);
 
 	session = soup_session_sync_new();
 	g_signal_connect(session, "authenticate", G_CALLBACK(soup_authenticate),
-	                 webdav);
+			 webdav);
 
 	priv->session = session;
 	priv->proxy = e_proxy_new ();
@@ -1044,8 +1044,8 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 	e_book_backend_notify_auth_required(backend);
 	e_book_backend_set_is_loaded(backend, TRUE);
 	e_book_backend_notify_connection_status(backend, TRUE);
-	e_book_backend_set_is_writable(backend, TRUE);  
-  	e_book_backend_notify_writable(backend, TRUE);
+	e_book_backend_set_is_writable(backend, TRUE);
+	e_book_backend_notify_writable(backend, TRUE);
 
 	return GNOME_Evolution_Addressbook_Success;
 }
@@ -1057,8 +1057,8 @@ e_book_backend_webdav_remove(EBookBackend *backend,	EDataBook *book,
 	e_data_book_respond_remove(book, opid, GNOME_Evolution_Addressbook_Success);
 }
 
-static void 
-e_book_backend_webdav_set_mode(EBookBackend *backend, int mode)
+static void
+e_book_backend_webdav_set_mode(EBookBackend *backend, gint mode)
 {
 	EBookBackendWebdav *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 
@@ -1079,7 +1079,7 @@ e_book_backend_webdav_set_mode(EBookBackend *backend, int mode)
 	}
 }
 
-static char *
+static gchar *
 e_book_backend_webdav_get_static_capabilities(EBookBackend *backend)
 {
 	return g_strdup("net,do-initial-query,contact-lists");
@@ -1094,12 +1094,12 @@ e_book_backend_webdav_cancel_operation(EBookBackend *backend, EDataBook *book)
 EBookBackend *
 e_book_backend_webdav_new(void)
 {
-	EBookBackendWebdav *backend 
+	EBookBackendWebdav *backend
 		= g_object_new(E_TYPE_BOOK_BACKEND_WEBDAV, NULL);
 
 	g_assert(backend != NULL);
 	g_assert(E_IS_BOOK_BACKEND_WEBDAV(backend));
-	
+
 	if (!e_book_backend_construct(E_BOOK_BACKEND(backend))) {
 		g_object_unref(backend);
 		return NULL;
@@ -1121,7 +1121,7 @@ e_book_backend_webdav_dispose(GObject *object)
 	g_free(priv->username);
 	g_free(priv->password);
 
-	G_OBJECT_CLASS(parent_class)->dispose(object);	
+	G_OBJECT_CLASS(parent_class)->dispose(object);
 }
 
 static void
@@ -1137,7 +1137,7 @@ e_book_backend_webdav_class_init(EBookBackendWebdavClass *klass)
 	/* Set the virtual methods. */
 	backend_class->load_source                = e_book_backend_webdav_load_source;
 	backend_class->get_static_capabilities    = e_book_backend_webdav_get_static_capabilities;
- 
+
 	backend_class->create_contact             = e_book_backend_webdav_create_contact;
 	backend_class->remove_contacts            = e_book_backend_webdav_remove_contacts;
 	backend_class->modify_contact             = e_book_backend_webdav_modify_contact;
@@ -1152,7 +1152,7 @@ e_book_backend_webdav_class_init(EBookBackendWebdavClass *klass)
 	backend_class->get_supported_auth_methods = e_book_backend_webdav_get_supported_auth_methods;
 	backend_class->remove                     = e_book_backend_webdav_remove;
 	backend_class->set_mode                   = e_book_backend_webdav_set_mode;
-	
+
 	object_class->dispose                     = e_book_backend_webdav_dispose;
 
 	g_type_class_add_private(object_class, sizeof(EBookBackendWebdavPrivate));
