@@ -1,6 +1,6 @@
 /* Miscellaneous time-related utilities
  *
- * Copyright (C) 2000, 2001 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Federico Mena <federico@ximian.com>
  *          Miguel de Icaza <miguel@ximian.com>
@@ -26,11 +26,12 @@
 #define MISSING_DAYS 11		/* They corrected out 11 days */
 #define THURSDAY 4		/* First day of reformation */
 #define SATURDAY 6		/* Offset value; 1 Jan 1 was a Saturday */
+#define ISODATE_LENGTH 17 /* 4+2+2+1+2+2+2+1 + 1 */
 
 
 /* Number of days in a month, using 0 (Jan) to 11 (Dec). For leap years,
    add 1 to February (month 1). */
-static const int days_in_month[12] = {
+static const gint days_in_month[12] = {
 	31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
 };
 
@@ -60,7 +61,7 @@ static const int days_in_month[12] = {
  * Return value: a time_t value containing @time plus the days added.
  */
 time_t
-time_add_day (time_t time, int days)
+time_add_day (time_t time, gint days)
 {
 	struct tm *tm;
 
@@ -81,7 +82,7 @@ time_add_day (time_t time, int days)
  * Return value: a time_t value containing @time plus the weeks added.
  */
 time_t
-time_add_week (time_t time, int weeks)
+time_add_week (time_t time, gint weeks)
 {
 	return time_add_day (time, weeks * 7);
 }
@@ -152,7 +153,7 @@ time_day_end (time_t t)
  * Return value: a time_t value containing @time plus the days added.
  */
 time_t
-time_add_day_with_zone (time_t time, int days, icaltimezone *zone)
+time_add_day_with_zone (time_t time, gint days, icaltimezone *zone)
 {
 	struct icaltimetype tt;
 
@@ -182,7 +183,7 @@ time_add_day_with_zone (time_t time, int days, icaltimezone *zone)
  * Return value: a time_t value containing @time plus the weeks added.
  */
 time_t
-time_add_week_with_zone (time_t time, int weeks, icaltimezone *zone)
+time_add_week_with_zone (time_t time, gint weeks, icaltimezone *zone)
 {
 	return time_add_day_with_zone (time, weeks * 7, zone);
 }
@@ -208,10 +209,10 @@ time_add_week_with_zone (time_t time, int weeks, icaltimezone *zone)
  * Return value: a time_t value containing @time plus the months added.
  */
 time_t
-time_add_month_with_zone (time_t time, int months, icaltimezone *zone)
+time_add_month_with_zone (time_t time, gint months, icaltimezone *zone)
 {
 	struct icaltimetype tt;
-	int day, days_in_month;
+	gint day, days_in_month;
 
 	/* Convert to an icaltimetype. */
 	tt = icaltime_from_timet_with_zone (time, FALSE, zone);
@@ -320,10 +321,10 @@ time_month_begin_with_zone (time_t time, icaltimezone *zone)
  * Return value: the beginning of the week.
  */
 time_t
-time_week_begin_with_zone (time_t time, int week_start_day, icaltimezone *zone)
+time_week_begin_with_zone (time_t time, gint week_start_day, icaltimezone *zone)
 {
 	struct icaltimetype tt;
-	int weekday, offset;
+	gint weekday, offset;
 
 	/* Convert to an icaltimetype. */
 	tt = icaltime_from_timet_with_zone (time, FALSE, zone);
@@ -419,7 +420,7 @@ time_day_end_with_zone (time_t time, icaltimezone *zone)
  * @time: A time value.
  * @zone: Desired timezone for destination @date, or NULL if the UTC timezone
  * is desired.
- * 
+ *
  * Converts a time_t value to a #GDate structure using the specified timezone.
  * This is analogous to g_date_set_time() but takes the timezone into account.
  **/
@@ -453,10 +454,10 @@ time_to_gdate_with_zone (GDate *date, time_t time, icaltimezone *zone)
  *
  * Return value: number of days in the given month/year.
  */
-int
-time_days_in_month (int year, int month)
+gint
+time_days_in_month (gint year, gint month)
 {
-	int days;
+	gint days;
 
 	g_return_val_if_fail (year >= 1900, 0);
 	g_return_val_if_fail ((month >= 0) && (month < 12), 0);
@@ -480,10 +481,10 @@ time_days_in_month (int year, int month)
  *
  * Return value: the day of the year.
  */
-int
-time_day_of_year (int day, int month, int year)
+gint
+time_day_of_year (gint day, gint month, gint year)
 {
-	int i;
+	gint i;
 
 	for (i = 0; i < month; i++) {
 		day += days_in_month[i];
@@ -508,10 +509,10 @@ time_day_of_year (int day, int month, int year)
  *
  * Return value: the day of the week for the given date.
  */
-int
-time_day_of_week (int day, int month, int year)
+gint
+time_day_of_week (gint day, gint month, gint year)
 {
-	int n;
+	gint n;
 
 	n = (year - 1) * 365 + time_leap_years_up_to (year - 1)
 	  + time_day_of_year (day, month, year);
@@ -536,7 +537,7 @@ time_day_of_week (int day, int month, int year)
  * Return value: TRUE if the year is leap, FALSE if not.
  */
 gboolean
-time_is_leap_year (int year)
+time_is_leap_year (gint year)
 {
 	if (year <= 1752)
 		return !(year % 4);
@@ -554,8 +555,8 @@ time_is_leap_year (int year)
  *
  * Return value: number of leap years.
  */
-int
-time_leap_years_up_to (int year)
+gint
+time_leap_years_up_to (gint year)
 {
 	/* There is normally a leap year every 4 years, except at the turn of
 	   centuries since 1700. But there is a leap year on centuries since 1700
@@ -569,20 +570,21 @@ time_leap_years_up_to (int year)
 /**
  * isodate_from_time_t:
  * @t: A time value.
- * 
+ *
  * Creates an ISO 8601 UTC representation from a time value.
- * 
+ *
  * Return value: String with the ISO 8601 representation of the UTC time.
  **/
-char *
+gchar *
 isodate_from_time_t (time_t t)
 {
 	gchar *ret;
 	struct tm stm;
+	const gchar fmt[] = "%04d%02d%02dT%02d%02d%02dZ";
 
 	gmtime_r (&t, &stm);
-	ret = g_malloc (17); /* 4+2+2+1+2+2+2+1 + 1 */
-	strftime (ret, 17, "%Y%m%dT%H%M%SZ", &stm);
+	ret = g_malloc (ISODATE_LENGTH);
+	g_snprintf (ret, ISODATE_LENGTH, fmt, (stm.tm_year+1900), (stm.tm_mon+1), stm.tm_mday, stm.tm_hour, stm.tm_min, stm.tm_sec);
 
 	return ret;
 }
@@ -590,18 +592,18 @@ isodate_from_time_t (time_t t)
 /**
  * time_from_isodate:
  * @str: Date/time value in ISO 8601 format.
- * 
+ *
  * Converts an ISO 8601 UTC time string into a time_t value.
- * 
+ *
  * Return value: Time_t corresponding to the specified ISO string.
  * Note that we only allow UTC times at present.
  **/
 time_t
-time_from_isodate (const char *str)
+time_from_isodate (const gchar *str)
 {
 	struct icaltimetype tt = icaltime_null_time ();
 	icaltimezone *utc_zone;
-	int len, i;
+	gint len, i;
 
 	g_return_val_if_fail (str != NULL, -1);
 
@@ -658,7 +660,7 @@ struct tm
 icaltimetype_to_tm (struct icaltimetype *itt)
 {
 	struct tm tm;
-	
+
 	memset (&tm, 0, sizeof (struct tm));
 
 	if (!itt->is_date) {
@@ -672,7 +674,7 @@ icaltimetype_to_tm (struct icaltimetype *itt)
 	tm.tm_year = itt->year - 1900;
 	tm.tm_wday = time_day_of_week (itt->day, itt->month - 1, itt->year);
 	tm.tm_isdst = -1;
-	
+
 	return tm;
 }
 
@@ -681,10 +683,10 @@ icaltimetype_to_tm (struct icaltimetype *itt)
  * @itt: A time value.
  * @from_zone: Source timezone.
  * @to_zone: Destination timezone.
- * 
+ *
  * Converts a time value from one timezone to another, and returns a struct tm
  * representation of the time.
- * 
+ *
  * Return value: The converted time as a struct tm. All fields will be
  * set properly except for tm.tm_yday.
  **/
@@ -734,10 +736,10 @@ tm_to_icaltimetype (struct tm *tm, gboolean is_date)
 	itt.day = tm->tm_mday;
 	itt.month = tm->tm_mon + 1;
 	itt.year = tm->tm_year+ 1900;
-    
+
 	itt.is_utc = 0;
-	itt.is_date = is_date; 
-	
+	itt.is_date = is_date;
+
 	return itt;
 }
 
