@@ -1,14 +1,14 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; -*- */
-/* 
+/*
  * Authors:
  *   Michael Zucchi <notzed@ximian.com>
  *   Jeffrey Stedfast <fejj@ximian.com>
  *   Dan Winship <danw@ximian.com>
  *
- * Copyright 2000-2003 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -59,9 +59,9 @@
 #ifdef BUILD_MAP
 
 static struct {
-	char *name;        /* charset name */
-	int multibyte;     /* charset type */
-	unsigned int bit;  /* assigned bit */
+	gchar *name;        /* charset name */
+	gint multibyte;     /* charset type */
+	guint bit;  /* assigned bit */
 } tables[] = {
 	/* These are the 8bit character sets (other than iso-8859-1,
 	 * which is special-cased) which are supported by both other
@@ -83,7 +83,7 @@ static struct {
 				    * programs that support this support UTF8
 				    */
 	{ "windows-1251", 0, 0 },  /* Russian */
-	
+
 	/* These are the multibyte character sets which are commonly
 	 * supported by other mail clients. Note: order for multibyte
 	 * charsets does not affect priority unlike the 8bit charsets
@@ -100,7 +100,7 @@ static struct {
 	{ NULL,           0, 0 }
 };
 
-unsigned int encoding_map[256 * 256];
+guint encoding_map[256 * 256];
 
 #if G_BYTE_ORDER == G_BIG_ENDIAN
 #define UCS "UCS-4BE"
@@ -111,47 +111,47 @@ unsigned int encoding_map[256 * 256];
 static guint
 block_hash (gconstpointer v)
 {
-	const signed char *p = v;
+	const gchar *p = v;
 	guint32 h = *p++;
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < 256; i++)
 		h = (h << 5) - h + *p++;
-	
+
 	return h;
 }
 
-static int
+static gint
 block_equal (gconstpointer v1, gconstpointer v2)
 {
 	return !memcmp (v1, v2, 256);
 }
 
-int main (int argc, char **argv)
+gint main (gint argc, gchar **argv)
 {
-	unsigned char *block = NULL;
-	unsigned int bit = 0x01;
+	guchar *block = NULL;
+	guint bit = 0x01;
 	GHashTable *table_hash;
-	size_t inleft, outleft;
-	char *inbuf, *outbuf;
+	gsize inleft, outleft;
+	gchar *inbuf, *outbuf;
 	guint32 out[128], c;
-	char in[128];
-	int i, j, k;
-	int bytes;
+	gchar in[128];
+	gint i, j, k;
+	gint bytes;
 	iconv_t cd;
-	
+
 	/* dont count the terminator */
 	bytes = ((sizeof (tables) / sizeof (tables[0])) + 7 - 1) / 8;
 	g_assert (bytes <= 4);
-	
+
 	for (i = 0; i < 128; i++)
 		in[i] = i + 128;
-	
+
 	for (j = 0; tables[j].name && !tables[j].multibyte; j++) {
 		cd = iconv_open (UCS, tables[j].name);
 		inbuf = in;
 		inleft = sizeof (in);
-		outbuf = (char *) out;
+		outbuf = (gchar *) out;
 		outleft = sizeof (out);
 		while (iconv (cd, &inbuf, &inleft, &outbuf, &outleft) == -1) {
 			if (errno == EILSEQ) {
@@ -165,29 +165,29 @@ int main (int argc, char **argv)
 			}
 		}
 		iconv_close (cd);
-		
+
 		for (i = 0; i < 128 - outleft / 4; i++) {
 			encoding_map[i] |= bit;
 			encoding_map[out[i]] |= bit;
 		}
-		
+
 		tables[j].bit = bit;
 		bit <<= 1;
 	}
-	
+
 	/* Mutibyte tables */
-	for ( ; tables[j].name && tables[j].multibyte; j++) {
+	for (; tables[j].name && tables[j].multibyte; j++) {
 		cd = iconv_open (tables[j].name, UCS);
 		if (cd == (iconv_t) -1)
 			continue;
-		
+
 		for (c = 128, i = 0; c < 65535 && i < 65535; c++) {
-			inbuf = (char *) &c;
+			inbuf = (gchar *) &c;
 			inleft = sizeof (c);
 			outbuf = in;
 			outleft = sizeof (in);
-			
-			if (iconv (cd, &inbuf, &inleft, &outbuf, &outleft) != (size_t) -1) {
+
+			if (iconv (cd, &inbuf, &inleft, &outbuf, &outleft) != (gsize) -1) {
 				/* this is a legal character in charset table[j].name */
 				iconv (cd, NULL, NULL, &outbuf, &outleft);
 				encoding_map[i++] |= bit;
@@ -197,66 +197,66 @@ int main (int argc, char **argv)
 				iconv (cd, NULL, NULL, NULL, NULL);
 			}
 		}
-		
+
 		iconv_close (cd);
-		
+
 		tables[j].bit = bit;
 		bit <<= 1;
 	}
-	
+
 	printf ("/* This file is automatically generated: DO NOT EDIT */\n\n");
-	
+
 	table_hash = g_hash_table_new_full (block_hash, block_equal, g_free, g_free);
-	
+
 	for (i = 0; i < 256; i++) {
 		for (k = 0; k < bytes; k++) {
-			char name[32], *alias;
-			int has_bits = FALSE;
-			
+			gchar name[32], *alias;
+			gint has_bits = FALSE;
+
 			if (!block) {
 				/* we reuse malloc'd blocks that are not added to the
 				 * hash table to avoid unnecessary malloc/free's */
 				block = g_malloc (256);
 			}
-			
+
 			for (j = 0; j < 256; j++) {
 				if ((block[j] = (encoding_map[i * 256 + j] >> (k * 8)) & 0xff))
 					has_bits = TRUE;
 			}
-			
+
 			if (!has_bits)
 				continue;
-			
+
 			sprintf (name, "m%02x%x", i, k);
-			
+
 			if ((alias = g_hash_table_lookup (table_hash, block))) {
 				/* this block is identical to an earlier block, just alias it */
 				printf ("#define %s %s\n\n", name, alias);
 			} else {
 				/* unique block, dump it */
 				g_hash_table_insert (table_hash, block, g_strdup (name));
-				
-				printf ("static unsigned char %s[256] = {\n\t", name);
+
+				printf ("static guchar %s[256] = {\n\t", name);
 				for (j = 0; j < 256; j++) {
 					printf ("0x%02x, ", block[j]);
 					if (((j + 1) & 7) == 0 && j < 255)
 						printf ("\n\t");
 				}
 				printf ("\n};\n\n");
-				
+
 				/* force the next loop to malloc a new block */
 				block = NULL;
 			}
 		}
 	}
-	
+
 	g_hash_table_destroy (table_hash);
 	g_free (block);
-	
+
 	printf ("static const struct {\n");
 	for (k = 0; k < bytes; k++)
-		printf ("\tconst unsigned char *bits%d;\n", k);
-	
+		printf ("\tconst guchar *bits%d;\n", k);
+
 	printf ("} camel_charmap[256] = {\n\t");
 	for (i = 0; i < 256; i++) {
 		printf ("{ ");
@@ -265,39 +265,39 @@ int main (int argc, char **argv)
 				if ((encoding_map[i * 256 + j] & (0xff << (k * 8))) != 0)
 					break;
 			}
-			
+
 			if (j < 256)
 				printf ("m%02x%x, ", i, k);
 			else
 				printf ("NULL, ");
 		}
-		
+
 		printf ("}, ");
 		if (((i + 1) & 3) == 0 && i < 255)
 			printf ("\n\t");
 	}
 	printf ("\n};\n\n");
-	
-	printf ("static const struct {\n\tconst char *name;\n\tunsigned int bit;\n} camel_charinfo[] = {\n");
+
+	printf ("static const struct {\n\tconst gchar *name;\n\tguint bit;\n} camel_charinfo[] = {\n");
 	for (j = 0; tables[j].name; j++)
 		printf ("\t{ \"%s\", 0x%08x },\n", tables[j].name, tables[j].bit);
 	printf ("};\n\n");
-	
+
 	printf ("#define charset_mask(x) \\\n");
 	for (k = 0; k < bytes; k++) {
 		if (k != 0)
 			printf ("\t| ");
 		else
 			printf ("\t");
-		
+
 		printf ("(camel_charmap[(x) >> 8].bits%d ? camel_charmap[(x) >> 8].bits%d[(x) & 0xff] << %d : 0)",
 			k, k, k * 8);
-		
+
 		if (k < bytes - 1)
 			printf ("\t\\\n");
 	}
 	printf ("\n\n");
-	
+
 	return 0;
 }
 
@@ -310,27 +310,27 @@ int main (int argc, char **argv)
 void
 camel_charset_init (CamelCharset *c)
 {
-	c->mask = (unsigned int) ~0;
+	c->mask = (guint) ~0;
 	c->level = 0;
 }
 
 void
-camel_charset_step (CamelCharset *cc, const char *in, int len)
+camel_charset_step (CamelCharset *cc, const gchar *in, gint len)
 {
-	const unsigned char *inptr = (const unsigned char *) in;
-	const unsigned char *inend = inptr + len;
-	register unsigned int mask;
-	register int level;
+	const guchar *inptr = (const guchar *) in;
+	const guchar *inend = inptr + len;
+	register guint mask;
+	register gint level;
 	register guint32 c;
-	
+
 	mask = cc->mask;
 	level = cc->level;
-	
+
 	/* check what charset a given string will fit in */
 	while ((c = camel_utf8_getc_limit(&inptr, inend)) != 0xffff) {
 		if (c < 0xffff) {
 			mask &= charset_mask(c);
-			
+
 			if (c>=128 && c<256)
 				level = MAX(level, 1);
 			else if (c>=256)
@@ -341,32 +341,32 @@ camel_charset_step (CamelCharset *cc, const char *in, int len)
 			break;
 		}
 	}
-	
+
 	cc->mask = mask;
 	cc->level = level;
 }
 
 /* gets the best charset from the mask of chars in it */
-static const char *
-camel_charset_best_mask(unsigned int mask)
+static const gchar *
+camel_charset_best_mask(guint mask)
 {
-	const char *locale_lang, *lang;
-	int i;
-	
+	const gchar *locale_lang, *lang;
+	gint i;
+
 	locale_lang = camel_iconv_locale_language ();
 	for (i = 0; i < G_N_ELEMENTS (camel_charinfo); i++) {
 		if (camel_charinfo[i].bit & mask) {
 			lang = camel_iconv_charset_language (camel_charinfo[i].name);
-			
+
 			if (!locale_lang || (lang && !strncmp (locale_lang, lang, 2)))
 				return camel_charinfo[i].name;
 		}
 	}
-	
+
 	return "UTF-8";
 }
 
-const char *
+const gchar *
 camel_charset_best_name (CamelCharset *charset)
 {
 	if (charset->level == 1)
@@ -378,8 +378,8 @@ camel_charset_best_name (CamelCharset *charset)
 }
 
 /* finds the minimum charset for this string NULL means US-ASCII */
-const char *
-camel_charset_best (const char *in, int len)
+const gchar *
+camel_charset_best (const gchar *in, gint len)
 {
 	CamelCharset charset;
 
@@ -393,10 +393,10 @@ camel_charset_best (const char *in, int len)
  * camel_charset_iso_to_windows:
  * @isocharset: a canonicalised ISO charset
  *
- * Returns the equivalent Windows charset.
+ * Returns: the equivalent Windows charset.
  **/
-const char *
-camel_charset_iso_to_windows (const char *isocharset)
+const gchar *
+camel_charset_iso_to_windows (const gchar *isocharset)
 {
 	/* According to http://czyborra.com/charsets/codepages.html,
 	 * the charset mapping is as follows:
@@ -421,7 +421,7 @@ camel_charset_iso_to_windows (const char *isocharset)
 	 *    iso-8859-13 are Baltic that it also maps to
 	 *    windows-cp1257.
 	 */
-	
+
 	if (!g_ascii_strcasecmp (isocharset, "iso-8859-1") || !g_ascii_strcasecmp (isocharset, "us-ascii"))
 		return "windows-cp1252";
 	else if (!g_ascii_strcasecmp (isocharset, "iso-8859-2"))
@@ -440,7 +440,7 @@ camel_charset_iso_to_windows (const char *isocharset)
 		return "windows-cp1254";
 	else if (!g_ascii_strcasecmp (isocharset, "iso-8859-13"))
 		return "windows-cp1257";
-	
+
 	return isocharset;
 }
 
