@@ -2,10 +2,10 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001-2003 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -24,12 +24,11 @@
 #include <config.h>
 #endif
 
-#include <pthread.h>
 #include <string.h>
 
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 
-#include "camel-i18n.h"
 #include "camel-cipher-context.h"
 #include "camel-stream.h"
 #include "camel-operation.h"
@@ -67,14 +66,14 @@ CamelCipherContext *
 camel_cipher_context_new (CamelSession *session)
 {
 	CamelCipherContext *context;
-	
+
 	g_return_val_if_fail (session != NULL, NULL);
-	
+
 	context = CAMEL_CIPHER_CONTEXT (camel_object_new (CAMEL_CIPHER_CONTEXT_TYPE));
-	
+
 	camel_object_ref (session);
 	context->session = session;
-	
+
 	return context;
 }
 
@@ -90,13 +89,13 @@ camel_cipher_context_construct (CamelCipherContext *context, CamelSession *sessi
 {
 	g_return_if_fail (CAMEL_IS_CIPHER_CONTEXT (context));
 	g_return_if_fail (CAMEL_IS_SESSION (session));
-	
+
 	camel_object_ref (session);
 	context->session = session;
 }
 
-static int
-cipher_sign (CamelCipherContext *ctx, const char *userid, CamelCipherHash hash,
+static gint
+cipher_sign (CamelCipherContext *ctx, const gchar *userid, CamelCipherHash hash,
 	     struct _CamelMimePart *ipart, struct _CamelMimePart *opart, CamelException *ex)
 {
 	camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
@@ -118,20 +117,20 @@ cipher_sign (CamelCipherContext *ctx, const char *userid, CamelCipherHash hash,
  *
  * Return value: 0 for success or -1 for failure.
  **/
-int
-camel_cipher_sign (CamelCipherContext *context, const char *userid, CamelCipherHash hash,
+gint
+camel_cipher_sign (CamelCipherContext *context, const gchar *userid, CamelCipherHash hash,
 		   struct _CamelMimePart *ipart, struct _CamelMimePart *opart, CamelException *ex)
 {
-	int retval;
-	
+	gint retval;
+
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), -1);
 
 	camel_operation_start(NULL, _("Signing message"));
 
 	CIPHER_LOCK(context);
-	
+
 	retval = CCC_CLASS (context)->sign (context, userid, hash, ipart, opart, ex);
-	
+
 	CIPHER_UNLOCK(context);
 
 	camel_operation_end(NULL);
@@ -166,24 +165,24 @@ CamelCipherValidity *
 camel_cipher_verify (CamelCipherContext *context, struct _CamelMimePart *ipart, CamelException *ex)
 {
 	CamelCipherValidity *valid;
-	
+
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), NULL);
-	
+
 	camel_operation_start(NULL, _("Verifying message"));
 
 	CIPHER_LOCK(context);
-	
+
 	valid = CCC_CLASS (context)->verify (context, ipart, ex);
-	
+
 	CIPHER_UNLOCK(context);
 
 	camel_operation_end(NULL);
-	
+
 	return valid;
 }
 
-static int
-cipher_encrypt (CamelCipherContext *context, const char *userid, GPtrArray *recipients,
+static gint
+cipher_encrypt (CamelCipherContext *context, const gchar *userid, GPtrArray *recipients,
 		struct _CamelMimePart *ipart, struct _CamelMimePart *opart, CamelException *ex)
 {
 	camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
@@ -196,8 +195,8 @@ cipher_encrypt (CamelCipherContext *context, const char *userid, GPtrArray *reci
  * @context: Cipher Context
  * @userid: key id (or email address) to use when signing, or NULL to not sign.
  * @recipients: an array of recipient key ids and/or email addresses
- * @istream: cleartext input stream
- * @ostream: ciphertext output stream
+ * @ipart: cleartext input stream
+ * @opart: ciphertext output stream
  * @ex: exception
  *
  * Encrypts (and optionally signs) the cleartext input stream and
@@ -205,24 +204,24 @@ cipher_encrypt (CamelCipherContext *context, const char *userid, GPtrArray *reci
  *
  * Return value: 0 for success or -1 for failure.
  **/
-int
-camel_cipher_encrypt (CamelCipherContext *context, const char *userid, GPtrArray *recipients,
+gint
+camel_cipher_encrypt (CamelCipherContext *context, const gchar *userid, GPtrArray *recipients,
 		      struct _CamelMimePart *ipart, struct _CamelMimePart *opart, CamelException *ex)
 {
-	int retval;
-	
+	gint retval;
+
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), -1);
 
 	camel_operation_start(NULL, _("Encrypting message"));
-	
+
 	CIPHER_LOCK(context);
-	
+
 	retval = CCC_CLASS (context)->encrypt (context, userid, recipients, ipart, opart, ex);
-	
+
 	CIPHER_UNLOCK(context);
 
 	camel_operation_end(NULL);
-	
+
 	return retval;
 }
 
@@ -236,13 +235,13 @@ cipher_decrypt(CamelCipherContext *context, struct _CamelMimePart *ipart, struct
 
 /**
  * camel_cipher_decrypt:
- * @context: 
- * @ipart: 
- * @opart: 
- * @ex: 
- * 
+ * @context:
+ * @ipart:
+ * @opart:
+ * @ex:
+ *
  * Decrypts @ipart into @opart.
- * 
+ *
  * Return value: A validity/encryption status.
  **/
 CamelCipherValidity *
@@ -253,60 +252,60 @@ camel_cipher_decrypt(CamelCipherContext *context, struct _CamelMimePart *ipart,
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), NULL);
 
 	camel_operation_start(NULL, _("Decrypting message"));
-	
+
 	CIPHER_LOCK(context);
-	
+
 	valid = CCC_CLASS (context)->decrypt (context, ipart, opart, ex);
-	
+
 	CIPHER_UNLOCK(context);
 
 	camel_operation_end(NULL);
-	
+
 	return valid;
 }
 
-static int
+static gint
 cipher_import_keys (CamelCipherContext *context, struct _CamelStream *istream, CamelException *ex)
 {
 	camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 			     _("You may not import keys with this cipher"));
-	
+
 	return -1;
 }
 
 /**
  * camel_cipher_import_keys:
- * @ctx: Cipher Context
+ * @context: Cipher Context
  * @istream: input stream (containing keys)
  * @ex: exception
  *
  * Imports a stream of keys/certificates contained within @istream
  * into the key/certificate database controlled by @ctx.
  *
- * Returns 0 on success or -1 on fail.
+ * Returns: 0 on success or -1 on fail.
  **/
-int
+gint
 camel_cipher_import_keys (CamelCipherContext *context, struct _CamelStream *istream, CamelException *ex)
 {
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), -1);
 	g_return_val_if_fail (CAMEL_IS_STREAM (istream), -1);
-	
+
 	return CCC_CLASS (context)->import_keys (context, istream, ex);
 }
 
-static int
+static gint
 cipher_export_keys (CamelCipherContext *context, GPtrArray *keys,
 		    struct _CamelStream *ostream, CamelException *ex)
 {
 	camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 			     _("You may not export keys with this cipher"));
-	
+
 	return -1;
 }
 
 /**
  * camel_cipher_export_keys:
- * @ctx: Cipher Context
+ * @context: Cipher Context
  * @keys: an array of key ids
  * @ostream: output stream
  * @ex: exception
@@ -314,45 +313,45 @@ cipher_export_keys (CamelCipherContext *context, GPtrArray *keys,
  * Exports the keys/certificates in @keys to the stream @ostream from
  * the key/certificate database controlled by @ctx.
  *
- * Returns 0 on success or -1 on fail.
+ * Returns: 0 on success or -1 on fail.
  **/
-int
+gint
 camel_cipher_export_keys (CamelCipherContext *context, GPtrArray *keys,
 			  struct _CamelStream *ostream, CamelException *ex)
 {
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), -1);
 	g_return_val_if_fail (CAMEL_IS_STREAM (ostream), -1);
 	g_return_val_if_fail (keys != NULL, -1);
-	
+
 	return CCC_CLASS (context)->export_keys (context, keys, ostream, ex);
 }
 
 static CamelCipherHash
-cipher_id_to_hash(CamelCipherContext *context, const char *id)
+cipher_id_to_hash(CamelCipherContext *context, const gchar *id)
 {
 	return CAMEL_CIPHER_HASH_DEFAULT;
 }
 
 /* a couple of util functions */
 CamelCipherHash
-camel_cipher_id_to_hash(CamelCipherContext *context, const char *id)
+camel_cipher_id_to_hash(CamelCipherContext *context, const gchar *id)
 {
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), CAMEL_CIPHER_HASH_DEFAULT);
-	
+
 	return CCC_CLASS (context)->id_to_hash (context, id);
 }
 
-static const char *
+static const gchar *
 cipher_hash_to_id(CamelCipherContext *context, CamelCipherHash hash)
 {
 	return NULL;
 }
 
-const char *
+const gchar *
 camel_cipher_hash_to_id(CamelCipherContext *context, CamelCipherHash hash)
 {
 	g_return_val_if_fail (CAMEL_IS_CIPHER_CONTEXT (context), NULL);
-	
+
 	return CCC_CLASS (context)->hash_to_id (context, hash);
 }
 
@@ -369,7 +368,7 @@ CamelCipherValidity *
 camel_cipher_validity_new (void)
 {
 	CamelCipherValidity *validity;
-	
+
 	validity = g_malloc(sizeof(*validity));
 	camel_cipher_validity_init(validity);
 
@@ -382,9 +381,9 @@ camel_cipher_validity_init (CamelCipherValidity *validity)
 	g_assert (validity != NULL);
 
 	memset(validity, 0, sizeof(*validity));
-	e_dlist_init(&validity->children);
-	e_dlist_init(&validity->sign.signers);
-	e_dlist_init(&validity->encrypt.encrypters);
+	camel_dlist_init(&validity->children);
+	camel_dlist_init(&validity->sign.signers);
+	camel_dlist_init(&validity->encrypt.encrypters);
 }
 
 gboolean
@@ -398,7 +397,7 @@ void
 camel_cipher_validity_set_valid (CamelCipherValidity *validity, gboolean valid)
 {
 	g_assert (validity != NULL);
-	
+
 	validity->sign.status = valid?CAMEL_CIPHER_VALIDITY_SIGN_GOOD:CAMEL_CIPHER_VALIDITY_SIGN_BAD;
 }
 
@@ -407,7 +406,7 @@ camel_cipher_validity_get_description (CamelCipherValidity *validity)
 {
 	if (validity == NULL)
 		return NULL;
-	
+
 	return validity->sign.description;
 }
 
@@ -415,7 +414,7 @@ void
 camel_cipher_validity_set_description (CamelCipherValidity *validity, const gchar *description)
 {
 	g_assert (validity != NULL);
-	
+
 	g_free(validity->sign.description);
 	validity->sign.description = g_strdup(description);
 }
@@ -460,34 +459,34 @@ camel_cipher_validity_clone(CamelCipherValidity *vin)
 
 /**
  * camel_cipher_validity_add_certinfo:
- * @vin: 
- * @mode: 
- * @name: 
- * @email: 
- * 
+ * @vin:
+ * @mode:
+ * @name:
+ * @email:
+ *
  * Add a cert info to the signer or encrypter info.
  **/
 void
-camel_cipher_validity_add_certinfo(CamelCipherValidity *vin, enum _camel_cipher_validity_mode_t mode, const char *name, const char *email)
+camel_cipher_validity_add_certinfo(CamelCipherValidity *vin, enum _camel_cipher_validity_mode_t mode, const gchar *name, const gchar *email)
 {
 	CamelCipherCertInfo *info;
-	EDList *list;
+	CamelDList *list;
 
 	info = g_malloc0(sizeof(*info));
 	info->name = g_strdup(name);
 	info->email = g_strdup(email);
 
 	list = (mode==CAMEL_CIPHER_VALIDITY_SIGN)?&vin->sign.signers:&vin->encrypt.encrypters;
-	e_dlist_addtail(list, (EDListNode *)info);
+	camel_dlist_addtail(list, (CamelDListNode *)info);
 
 	printf("adding certinfo %s <%s>\n", name?name:"unset", email?email:"unset");
 }
 
 /**
  * camel_cipher_validity_envelope:
- * @validity: 
- * @outer: 
- * 
+ * @parent:
+ * @valid:
+ *
  * Calculate a conglomerate validity based on wrapping one secure part inside
  * another one.
  **/
@@ -533,13 +532,13 @@ camel_cipher_validity_free (CamelCipherValidity *validity)
 	if (validity == NULL)
 		return;
 
-	while ((child = (CamelCipherValidity *)e_dlist_remhead(&validity->children)))
+	while ((child = (CamelCipherValidity *)camel_dlist_remhead(&validity->children)))
 		camel_cipher_validity_free(child);
 
-	while ((info = (CamelCipherCertInfo *)e_dlist_remhead(&validity->sign.signers)))
+	while ((info = (CamelCipherCertInfo *)camel_dlist_remhead(&validity->sign.signers)))
 		ccv_certinfo_free(info);
 
-	while ((info = (CamelCipherCertInfo *)e_dlist_remhead(&validity->encrypt.encrypters)))
+	while ((info = (CamelCipherCertInfo *)camel_dlist_remhead(&validity->encrypt.encrypters)))
 		ccv_certinfo_free(info);
 
 	camel_cipher_validity_clear(validity);
@@ -559,11 +558,11 @@ static void
 camel_cipher_context_finalise (CamelObject *o)
 {
 	CamelCipherContext *context = (CamelCipherContext *)o;
-	
+
 	camel_object_unref (CAMEL_OBJECT (context->session));
-	
+
 	g_mutex_free (context->priv->lock);
-	
+
 	g_free (context->priv);
 }
 
@@ -571,7 +570,7 @@ static void
 camel_cipher_context_class_init (CamelCipherContextClass *camel_cipher_context_class)
 {
 	parent_class = camel_type_get_global_classfuncs (camel_object_get_type ());
-	
+
 	camel_cipher_context_class->hash_to_id = cipher_hash_to_id;
 	camel_cipher_context_class->id_to_hash = cipher_id_to_hash;
 	camel_cipher_context_class->sign = cipher_sign;
@@ -586,7 +585,7 @@ CamelType
 camel_cipher_context_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_object_get_type (),
 					    "CamelCipherContext",
@@ -597,7 +596,7 @@ camel_cipher_context_get_type (void)
 					    (CamelObjectInitFunc) camel_cipher_context_init,
 					    (CamelObjectFinalizeFunc) camel_cipher_context_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -610,12 +609,12 @@ cc_prepare_sign(CamelMimePart *part)
 {
 	CamelDataWrapper *dw;
 	CamelTransferEncoding encoding;
-	int parts, i;
-	
+	gint parts, i;
+
 	dw = camel_medium_get_content_object((CamelMedium *)part);
 	if (!dw)
 		return;
-	
+
 	if (CAMEL_IS_MULTIPART (dw)) {
 		parts = camel_multipart_get_number((CamelMultipart *)dw);
 		for (i = 0; i < parts; i++)
@@ -637,19 +636,19 @@ cc_prepare_sign(CamelMimePart *part)
  * @part: Part to write.
  * @flags: flags for the canonicalisation filter (CamelMimeFilterCanon)
  * @ostream: stream to write canonicalised output to.
- * 
+ *
  * Writes a part to a stream in a canonicalised format, suitable for signing/encrypting.
  *
  * The transfer encoding paramaters for the part may be changed by this function.
- * 
+ *
  * Return value: -1 on error;
  **/
-int
+gint
 camel_cipher_canonical_to_stream(CamelMimePart *part, guint32 flags, CamelStream *ostream)
 {
 	CamelStreamFilter *filter;
 	CamelMimeFilter *canon;
-	int res = -1;
+	gint res = -1;
 
 	if (flags & (CAMEL_MIME_FILTER_CANON_FROM|CAMEL_MIME_FILTER_CANON_STRIP))
 		cc_prepare_sign(part);
