@@ -36,7 +36,7 @@
 #include "camel-exception.h"
 #include "camel-session.h"
 
-#define d(x) 
+#define d(x)
 
 #define CDS_CLASS(o) (CAMEL_DISCO_STORE_CLASS (CAMEL_OBJECT_GET_CLASS (o)))
 
@@ -48,18 +48,18 @@ static void disco_construct (CamelService *service, CamelSession *session,
 static gboolean disco_connect (CamelService *service, CamelException *ex);
 static void disco_cancel_connect (CamelService *service);
 static gboolean disco_disconnect (CamelService *service, gboolean clean, CamelException *ex);
-static CamelFolder *disco_get_folder (CamelStore *store, const char *name,
+static CamelFolder *disco_get_folder (CamelStore *store, const gchar *name,
 				      guint32 flags, CamelException *ex);
 static CamelFolderInfo *disco_get_folder_info (CamelStore *store,
-					       const char *top, guint32 flags,
+					       const gchar *top, guint32 flags,
 					       CamelException *ex);
 static void set_status (CamelDiscoStore *disco_store,
 			CamelDiscoStoreStatus status,
 			CamelException *ex);
 static gboolean can_work_offline (CamelDiscoStore *disco_store);
 
-static int disco_setv (CamelObject *object, CamelException *ex, CamelArgV *args);
-static int disco_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
+static gint disco_setv (CamelObject *object, CamelException *ex, CamelArgV *args);
+static gint disco_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
 
 static void
 camel_disco_store_class_init (CamelDiscoStoreClass *camel_disco_store_class)
@@ -70,22 +70,22 @@ camel_disco_store_class_init (CamelDiscoStoreClass *camel_disco_store_class)
 		CAMEL_SERVICE_CLASS (camel_disco_store_class);
 	CamelStoreClass *camel_store_class =
 		CAMEL_STORE_CLASS (camel_disco_store_class);
-	
+
 	parent_class = CAMEL_STORE_CLASS (camel_type_get_global_classfuncs (camel_store_get_type ()));
-	
+
 	/* virtual method definition */
 	camel_disco_store_class->set_status = set_status;
 	camel_disco_store_class->can_work_offline = can_work_offline;
-	
+
 	/* virtual method overload */
 	camel_object_class->setv = disco_setv;
 	camel_object_class->getv = disco_getv;
-	
+
 	camel_service_class->construct = disco_construct;
 	camel_service_class->connect = disco_connect;
 	camel_service_class->disconnect = disco_disconnect;
 	camel_service_class->cancel_connect = disco_cancel_connect;
-	
+
 	camel_store_class->get_folder = disco_get_folder;
 	camel_store_class->get_folder_info = disco_get_folder_info;
 }
@@ -94,7 +94,7 @@ CamelType
 camel_disco_store_get_type (void)
 {
 	static CamelType camel_disco_store_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_disco_store_type == CAMEL_INVALID_TYPE) {
 		camel_disco_store_type = camel_type_register (
 			CAMEL_STORE_TYPE,
@@ -106,18 +106,18 @@ camel_disco_store_get_type (void)
 			NULL,
 			NULL);
 	}
-	
+
 	return camel_disco_store_type;
 }
 
-static int
+static gint
 disco_setv (CamelObject *object, CamelException *ex, CamelArgV *args)
 {
 	/* CamelDiscoStore doesn't currently have anything to set */
 	return CAMEL_OBJECT_CLASS (parent_class)->setv (object, ex, args);
 }
 
-static int
+static gint
 disco_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args)
 {
 	/* CamelDiscoStore doesn't currently have anything to get */
@@ -225,28 +225,28 @@ disco_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 }
 
 static CamelFolder *
-disco_get_folder (CamelStore *store, const char *name,
+disco_get_folder (CamelStore *store, const gchar *name,
 		  guint32 flags, CamelException *ex)
 {
 	CamelDiscoStore *disco_store = CAMEL_DISCO_STORE (store);
-	
+
 	switch (camel_disco_store_status (disco_store)) {
 	case CAMEL_DISCO_STORE_ONLINE:
 		return CDS_CLASS (store)->get_folder_online (store, name, flags, ex);
-		
+
 	case CAMEL_DISCO_STORE_OFFLINE:
 		return CDS_CLASS (store)->get_folder_offline (store, name, flags, ex);
-		
+
 	case CAMEL_DISCO_STORE_RESYNCING:
-		return CDS_CLASS (store)->get_folder_resyncing (store, name, flags, ex);	
+		return CDS_CLASS (store)->get_folder_resyncing (store, name, flags, ex);
 	}
-	
+
 	g_assert_not_reached ();
 	return NULL;
 }
 
 static CamelFolderInfo *
-disco_get_folder_info (CamelStore *store, const char *top,
+disco_get_folder_info (CamelStore *store, const gchar *top,
 		       guint32 flags, CamelException *ex)
 {
 	CamelDiscoStore *disco_store = CAMEL_DISCO_STORE (store);
@@ -254,7 +254,7 @@ disco_get_folder_info (CamelStore *store, const char *top,
 	switch (camel_disco_store_status (disco_store)) {
 	case CAMEL_DISCO_STORE_ONLINE:
 		return CDS_CLASS (store)->get_folder_info_online (store, top, flags, ex);
-		
+
 	case CAMEL_DISCO_STORE_OFFLINE:
 		/* Can't edit subscriptions while offline */
 		if ((store->flags & CAMEL_STORE_SUBSCRIPTIONS) &&
@@ -262,13 +262,13 @@ disco_get_folder_info (CamelStore *store, const char *top,
 			camel_disco_store_check_online (disco_store, ex);
 			return NULL;
 		}
-		
+
 		return CDS_CLASS (store)->get_folder_info_offline (store, top, flags, ex);
-		
+
 	case CAMEL_DISCO_STORE_RESYNCING:
 		return CDS_CLASS (store)->get_folder_info_resyncing (store, top, flags, ex);
 	}
-	
+
 	g_assert_not_reached ();
 	return NULL;
 }
@@ -314,10 +314,10 @@ set_status(CamelDiscoStore *disco_store, CamelDiscoStoreStatus status, CamelExce
 			if (((CamelStore *)disco_store)->folders) {
 				GPtrArray *folders;
 				CamelFolder *folder;
-				int i, sync;
-				
+				gint i, sync;
+
 				sync =  camel_url_get_param(((CamelService *)disco_store)->url, "offline_sync") != NULL;
-				
+
 				folders = camel_object_bag_list(((CamelStore *)disco_store)->folders);
 				for (i=0;i<folders->len;i++) {
 					folder = folders->pdata[i];
@@ -331,11 +331,11 @@ set_status(CamelDiscoStore *disco_store, CamelDiscoStoreStatus status, CamelExce
 				g_ptr_array_free(folders, TRUE);
 			}
 		}
-		
+
 		camel_store_sync(CAMEL_STORE (disco_store), FALSE, &x);
 		camel_exception_clear(&x);
 	}
-	
+
 	if (!camel_service_disconnect (CAMEL_SERVICE (disco_store), network_state, ex))
 		return;
 
@@ -423,10 +423,10 @@ camel_disco_store_prepare_for_offline(CamelDiscoStore *disco_store, CamelExcepti
 			if (((CamelStore *)disco_store)->folders) {
 				GPtrArray *folders;
 				CamelFolder *folder;
-				int i, sync;
-				
+				gint i, sync;
+
 				sync =  camel_url_get_param(((CamelService *)disco_store)->url, "offline_sync") != NULL;
-				
+
 				folders = camel_object_bag_list(((CamelStore *)disco_store)->folders);
 				for (i=0;i<folders->len;i++) {
 					folder = folders->pdata[i];
@@ -440,7 +440,7 @@ camel_disco_store_prepare_for_offline(CamelDiscoStore *disco_store, CamelExcepti
 				g_ptr_array_free(folders, TRUE);
 			}
 		}
-		
+
 		camel_store_sync(CAMEL_STORE (disco_store), FALSE, &x);
 		camel_exception_clear(&x);
 	}
