@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -49,7 +49,7 @@ struct _CamelMimeFilterGZip {
 	struct _CamelMimeFilterGZipPrivate *priv;
 
 	CamelMimeFilterGZipMode mode;
-	int level;
+	gint level;
 };
 
 struct _CamelMimeFilterGZipClass {
@@ -60,7 +60,7 @@ struct _CamelMimeFilterGZipClass {
 
 CamelType camel_mime_filter_gzip_get_type (void);
 
-CamelMimeFilter *camel_mime_filter_gzip_new (CamelMimeFilterGZipMode mode, int level);
+CamelMimeFilter *camel_mime_filter_gzip_new (CamelMimeFilterGZipMode mode, gint level);
 
 G_END_DECLS
 
