@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2001 Ximian Inc.
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -52,8 +52,8 @@ struct _CamelMimeFilterHTMLPrivate {
 #define ARRAY_LEN(x) (sizeof(x)/sizeof((x)[0]))
 
 static struct {
-	char *element;
-	char *remap;
+	gchar *element;
+	gchar *remap;
 } map_start[] = {
 	{ "p", "\n\n" },
 	{ "br", "\n" },
@@ -62,8 +62,8 @@ static struct {
 
 
 static struct {
-	char *element;
-	char *remap;
+	gchar *element;
+	gchar *remap;
 } map_end[] = {
 	{ "h1", "\n" }, { "h2", "\n" }, { "h3", "\n" }, { "h4", "\n" }, { "h5", "\n" }, { "h6", "\n" },
 };
@@ -77,7 +77,7 @@ CamelType
 camel_mime_filter_html_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type (), "CamelMimeFilterHTML",
 					    sizeof (CamelMimeFilterHTML),
@@ -87,7 +87,7 @@ camel_mime_filter_html_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_filter_html_init,
 					    (CamelObjectFinalizeFunc) camel_mime_filter_html_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -110,25 +110,25 @@ camel_mime_filter_html_init       (CamelObject *o)
 }
 
 static void
-run(CamelMimeFilter *mf, char *in, size_t inlen, size_t prespace, char **out, size_t *outlenptr, size_t *outprespace, int last)
+run(CamelMimeFilter *mf, const gchar *in, gsize inlen, gsize prespace, gchar **out, gsize *outlenptr, gsize *outprespace, gint last)
 {
 	CamelMimeFilterHTML *f = (CamelMimeFilterHTML *) mf;
 	camel_html_parser_t state;
-	char *outp;
-	
-	d(printf("converting html:\n%.*s\n", (int)inlen, in));
-	
+	gchar *outp;
+
+	d(printf("converting html:\n%.*s\n", (gint)inlen, in));
+
 	/* We should generally shrink the data, but this'll do */
 	camel_mime_filter_set_size (mf, inlen * 2 + 256, FALSE);
 	outp = mf->outbuf;
-	
+
 	camel_html_parser_set_data (f->priv->ctxt, in, inlen, last);
 	do {
-		const char *data;
-		int len;
-		
+		const gchar *data;
+		gint len;
+
 		state = camel_html_parser_step(f->priv->ctxt, &data, &len);
-		
+
 		switch(state) {
 		case CAMEL_HTML_PARSER_DATA:
 		case CAMEL_HTML_PARSER_ENT:
@@ -148,17 +148,17 @@ run(CamelMimeFilter *mf, char *in, size_t inlen, size_t prespace, char **out, si
 	*outlenptr = outp - mf->outbuf;
 	*outprespace = mf->outbuf - mf->outreal;
 
-	d(printf("converted html end:\n%.*s\n", (int)*outlenptr, *out));
+	d(printf("converted html end:\n%.*s\n", (gint)*outlenptr, *out));
 }
 
 static void
-complete(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out, size_t *outlenptr, size_t *outprespace)
+complete(CamelMimeFilter *mf, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlenptr, gsize *outprespace)
 {
 	run(mf, in, len, prespace, out, outlenptr, outprespace, TRUE);
 }
 
 static void
-filter(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out, size_t *outlenptr, size_t *outprespace)
+filter(CamelMimeFilter *mf, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlenptr, gsize *outprespace)
 {
 	run(mf, in, len, prespace, out, outlenptr, outprespace, FALSE);
 }
@@ -176,7 +176,7 @@ static void
 camel_mime_filter_html_class_init (CamelMimeFilterHTMLClass *klass)
 {
 	CamelMimeFilterClass *filter_class = (CamelMimeFilterClass *) klass;
-	
+
 	camel_mime_filter_html_parent = CAMEL_MIME_FILTER_CLASS (camel_type_get_global_classfuncs (camel_mime_filter_get_type ()));
 
 	filter_class->reset = reset;
@@ -189,8 +189,8 @@ camel_mime_filter_html_class_init (CamelMimeFilterHTMLClass *klass)
  * camel_mime_filter_html_new:
  *
  * Create a new #CamelMimeFilterHTML object.
- * 
- * Returns a new #CamelMimeFilterHTML object
+ *
+ * Returns: a new #CamelMimeFilterHTML object
  **/
 CamelMimeFilterHTML *
 camel_mime_filter_html_new (void)
