@@ -30,7 +30,7 @@ CamelType
 camel_mime_filter_index_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type (), "CamelMimeFilterIndex",
 					    sizeof (CamelMimeFilterIndex),
@@ -40,7 +40,7 @@ camel_mime_filter_index_get_type (void)
 					    NULL,
 					    (CamelObjectFinalizeFunc) camel_mime_filter_index_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -55,7 +55,7 @@ camel_mime_filter_index_finalize(CamelObject *o)
 }
 
 static void
-complete(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out, size_t *outlenptr, size_t *outprespace)
+complete(CamelMimeFilter *mf, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlenptr, gsize *outprespace)
 {
 	CamelMimeFilterIndex *f = (CamelMimeFilterIndex *)mf;
 
@@ -67,13 +67,13 @@ complete(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out,
 	camel_index_name_add_buffer(f->name, NULL, 0);
 
 donothing:
-	*out = in;
+	*out = (gchar *) in;
 	*outlenptr = len;
 	*outprespace = prespace;
 }
 
 static void
-filter(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out, size_t *outlenptr, size_t *outprespace)
+filter(CamelMimeFilter *mf, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlenptr, gsize *outprespace)
 {
 	CamelMimeFilterIndex *f = (CamelMimeFilterIndex *)mf;
 
@@ -84,7 +84,7 @@ filter(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out, s
 	camel_index_name_add_buffer(f->name, in, len);
 
 donothing:
-	*out = in;
+	*out = (gchar *) in;
 	*outlenptr = len;
 	*outprespace = prespace;
 }
@@ -93,7 +93,7 @@ static void
 camel_mime_filter_index_class_init (CamelMimeFilterIndexClass *klass)
 {
 	CamelMimeFilterClass *filter_class = (CamelMimeFilterClass *) klass;
-	
+
 	camel_mime_filter_index_parent = CAMEL_MIME_FILTER_CLASS (camel_type_get_global_classfuncs (camel_mime_filter_get_type ()));
 
 	/*filter_class->reset = reset;*/
@@ -105,7 +105,7 @@ camel_mime_filter_index_class_init (CamelMimeFilterIndexClass *klass)
  * camel_mime_filter_index_new:
  *
  * Create a new #CamelMimeFilterIndex object
- * 
+ *
  * Returns: a new #CamelMimeFilterIndex object
  **/
 CamelMimeFilterIndex *
@@ -169,8 +169,8 @@ void
 camel_mime_filter_index_set_index (CamelMimeFilterIndex *filter, CamelIndex *index)
 {
 	if (filter->index) {
-		char *out;
-		size_t outlen, outspace;
+		gchar *out;
+		gsize outlen, outspace;
 
 		camel_mime_filter_complete((CamelMimeFilter *)filter, "", 0, 0, &out, &outlen, &outspace);
 		camel_object_unref (index);
