@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000 Ximian, Inc.
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
@@ -29,11 +29,11 @@
 #include "camel-mime-filter-linewrap.h"
 
 
-static void filter (CamelMimeFilter *f, char *in, size_t len, size_t prespace,
-		    char **out, size_t *outlen, size_t *outprespace);
-static void complete (CamelMimeFilter *f, char *in, size_t len,
-		      size_t prespace, char **out, size_t *outlen,
-		      size_t *outprespace);
+static void filter (CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace,
+		    gchar **out, gsize *outlen, gsize *outprespace);
+static void complete (CamelMimeFilter *f, const gchar *in, gsize len,
+		      gsize prespace, gchar **out, gsize *outlen,
+		      gsize *outprespace);
 static void reset (CamelMimeFilter *f);
 
 
@@ -67,12 +67,13 @@ camel_mime_filter_linewrap_get_type (void)
 }
 
 static void
-filter (CamelMimeFilter *f, char *in, size_t len, size_t prespace,
-	char **out, size_t *outlen, size_t *outprespace)
+filter (CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace,
+	gchar **out, gsize *outlen, gsize *outprespace)
 {
 	CamelMimeFilterLinewrap *linewrap = (CamelMimeFilterLinewrap *)f;
-	char *inend, *p, *q;
-	int nchars = linewrap->nchars;
+	gchar *q;
+	const gchar *inend, *p;
+	gint nchars = linewrap->nchars;
 
 	/* we'll be adding chars here so we need a bigger buffer */
 	camel_mime_filter_set_size (f, 3 * len, FALSE);
@@ -114,8 +115,8 @@ filter (CamelMimeFilter *f, char *in, size_t len, size_t prespace,
 }
 
 static void
-complete (CamelMimeFilter *f, char *in, size_t len, size_t prespace,
-	  char **out, size_t *outlen, size_t *outprespace)
+complete (CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace,
+	  gchar **out, gsize *outlen, gsize *outprespace)
 {
 	if (len)
 		filter (f, in, len, prespace, out, outlen, outprespace);
@@ -130,7 +131,7 @@ reset (CamelMimeFilter *f)
 }
 
 CamelMimeFilter *
-camel_mime_filter_linewrap_new (guint preferred_len, guint max_len, char indent_char)
+camel_mime_filter_linewrap_new (guint preferred_len, guint max_len, gchar indent_char)
 {
 	CamelMimeFilterLinewrap *linewrap =
 		CAMEL_MIME_FILTER_LINEWRAP (camel_object_new (CAMEL_MIME_FILTER_LINEWRAP_TYPE));
