@@ -48,7 +48,7 @@
 #define CONVERT_ADDRSPEC  CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES
 
 static struct {
-	unsigned int mask;
+	guint mask;
 	urlpattern_t pattern;
 } patterns[] = {
 	{ CONVERT_WEB_URLS, { "file://",   "",        camel_url_file_start,     camel_url_file_end     } },
@@ -82,7 +82,7 @@ CamelType
 camel_mime_filter_tohtml_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type (),
 					    "CamelMimeFilterToHTML",
@@ -93,7 +93,7 @@ camel_mime_filter_tohtml_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_filter_tohtml_init,
 					    (CamelObjectFinalizeFunc) camel_mime_filter_tohtml_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -101,7 +101,7 @@ static void
 camel_mime_filter_tohtml_finalize (CamelObject *obj)
 {
 	CamelMimeFilterToHTML *filter = (CamelMimeFilterToHTML *) obj;
-	
+
 	camel_url_scanner_free (filter->scanner);
 }
 
@@ -109,7 +109,7 @@ static void
 camel_mime_filter_tohtml_init (CamelMimeFilterToHTML *filter)
 {
 	filter->scanner = camel_url_scanner_new ();
-	
+
 	filter->flags = 0;
 	filter->colour = 0;
 	filter->column = 0;
@@ -117,27 +117,27 @@ camel_mime_filter_tohtml_init (CamelMimeFilterToHTML *filter)
 }
 
 
-static char *
-check_size (CamelMimeFilter *filter, char *outptr, char **outend, size_t len)
+static gchar *
+check_size (CamelMimeFilter *filter, gchar *outptr, gchar **outend, gsize len)
 {
-	size_t offset;
-	
+	gsize offset;
+
 	if (*outend - outptr >= len)
 		return outptr;
-	
+
 	offset = outptr - filter->outbuf;
-	
+
 	camel_mime_filter_set_size (filter, filter->outsize + len, TRUE);
-	
+
 	*outend = filter->outbuf + filter->outsize;
-	
+
 	return filter->outbuf + offset;
 }
 
-static char *
-append_string_verbatim (CamelMimeFilter *filter, const char *str, char *outptr, char **outend)
+static gchar *
+append_string_verbatim (CamelMimeFilter *filter, const gchar *str, gchar *outptr, gchar **outend)
 {
-	size_t len = strlen (str);
+	gsize len = strlen (str);
 
 	outptr = check_size (filter, outptr, outend, len);
 	memcpy(outptr, str, len);
@@ -146,43 +146,43 @@ append_string_verbatim (CamelMimeFilter *filter, const char *str, char *outptr,
 	return outptr;
 }
 
-static int
-citation_depth (const char *in)
+static gint
+citation_depth (const gchar *in)
 {
-	register const char *inptr = in;
-	int depth = 1;
-	
+	register const gchar *inptr = in;
+	gint depth = 1;
+
 	if (*inptr++ != '>')
 		return 0;
-	
+
 #if FOOLISHLY_UNMUNGE_FROM
 	/* check that it isn't an escaped From line */
 	if (!strncmp (inptr, "From", 4))
 		return 0;
 #endif
-	
+
 	while (*inptr != '\n') {
 		if (*inptr == ' ')
 			inptr++;
-		
+
 		if (*inptr++ != '>')
 			break;
-		
+
 		depth++;
 	}
-	
+
 	return depth;
 }
 
-static char *
-writeln (CamelMimeFilter *filter, const unsigned char *in, const unsigned char *inend, char *outptr, char **outend)
+static gchar *
+writeln (CamelMimeFilter *filter, const guchar *in, const guchar *inend, gchar *outptr, gchar **outend)
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
-	const unsigned char *inptr = in;
-	
+	const guchar *inptr = in;
+
 	while (inptr < inend) {
 		guint32 u;
-		
+
 		outptr = check_size (filter, outptr, outend, 16);
 
 		u = camel_utf8_getc_limit (&inptr, inend);
@@ -237,19 +237,20 @@ writeln (CamelMimeFilter *filter, const unsigned char *in, const unsigned char *
 			break;
 		}
 	}
-	
+
 	return outptr;
 }
 
 static void
-html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
-	      char **out, size_t *outlen, size_t *outprespace, gboolean flush)
+html_convert (CamelMimeFilter *filter, const gchar *in, gsize inlen, gsize prespace,
+	      gchar **out, gsize *outlen, gsize *outprespace, gboolean flush)
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
-	register char *inptr, *outptr;
-	char *start, *outend;
-	const char *inend;
-	int depth;
+	const gchar *inptr;
+	gchar *outptr, *outend;
+	const gchar *start;
+	const gchar *inend;
+	gint depth;
 
 	if (inlen == 0) {
 		if (html->pre_open) {
@@ -263,21 +264,21 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 			*outlen = outptr - filter->outbuf;
 			*outprespace = filter->outpre;
 		} else {
-			*out = in;
+			*out = (gchar *) in;
 			*outlen = 0;
 			*outprespace = 0;
 		}
 
 		return;
 	}
-	
+
 	camel_mime_filter_set_size (filter, inlen * 2 + 6, FALSE);
-	
+
 	inptr = in;
 	inend = in + inlen;
 	outptr = filter->outbuf;
 	outend = filter->outbuf + filter->outsize;
-	
+
 	if (html->flags & CAMEL_MIME_FILTER_TOHTML_PRE && !html->pre_open) {
 		outptr = g_stpcpy (outptr, "<pre>");
 		html->pre_open = TRUE;
@@ -287,17 +288,17 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 	do {
 		while (inptr < inend && *inptr != '\n')
 			inptr++;
-		
+
 		if (inptr >= inend && !flush)
 			break;
-		
+
 		html->column = 0;
 		depth = 0;
-		
+
 		if (html->flags & CAMEL_MIME_FILTER_TOHTML_MARK_CITATION) {
 			if ((depth = citation_depth (start)) > 0) {
 				/* FIXME: we could easily support multiple colour depths here */
-				
+
 				outptr = check_size (filter, outptr, &outend, 25);
 				outptr += sprintf(outptr, "<font color=\"#%06x\">", (html->colour & 0xffffff));
 			}
@@ -312,81 +313,81 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 			outptr = g_stpcpy (outptr, "&gt; ");
 			html->column += 2;
 		}
-		
+
 #define CONVERT_URLS (CAMEL_MIME_FILTER_TOHTML_CONVERT_URLS | CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES)
 		if (html->flags & CONVERT_URLS) {
-			size_t matchlen, len;
+			gsize matchlen, len;
 			urlmatch_t match;
-			
+
 			len = inptr - start;
-			
+
 			do {
 				if (camel_url_scanner_scan (html->scanner, start, len, &match)) {
 					/* write out anything before the first regex match */
-					outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)start + match.um_so,
+					outptr = writeln (filter, (const guchar *)start, (const guchar *)start + match.um_so,
 							  outptr, &outend);
-					
+
 					start += match.um_so;
 					len -= match.um_so;
-					
+
 					matchlen = match.um_eo - match.um_so;
-					
+
 					/* write out the href tag */
 					outptr = append_string_verbatim (filter, "<a href=\"", outptr, &outend);
 					/* prefix shouldn't need escaping, but let's be safe */
 					outptr = writeln (filter,
-							(const unsigned char *)match.prefix,
-							(const unsigned char *)match.prefix + strlen (match.prefix),
+							(const guchar *)match.prefix,
+							(const guchar *)match.prefix + strlen (match.prefix),
 							outptr, &outend);
 					outptr = writeln (filter,
-							(const unsigned char *)start,
-							(const unsigned char *)start + matchlen,
+							(const guchar *)start,
+							(const guchar *)start + matchlen,
 							outptr, &outend);
 					outptr = append_string_verbatim (filter, "\">", outptr, &outend);
-					
+
 					/* now write the matched string */
 					outptr = writeln (filter,
-							(const unsigned char *)start,
-							(const unsigned char *)start + matchlen,
+							(const guchar *)start,
+							(const guchar *)start + matchlen,
 							outptr, &outend);
 					html->column += matchlen;
 					start += matchlen;
 					len -= matchlen;
-					
+
 					/* close the href tag */
 					outptr = append_string_verbatim (filter, "</a>", outptr, &outend);
 				} else {
 					/* nothing matched so write out the remainder of this line buffer */
-					outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)start + len, outptr, &outend);
+					outptr = writeln (filter, (const guchar *)start, (const guchar *)start + len, outptr, &outend);
 					break;
 				}
 			} while (len > 0);
 		} else {
-			outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)inptr, outptr, &outend);
+			outptr = writeln (filter, (const guchar *)start, (const guchar *)inptr, outptr, &outend);
 		}
-		
+
 		if ((html->flags & CAMEL_MIME_FILTER_TOHTML_MARK_CITATION) && depth > 0) {
 			outptr = check_size (filter, outptr, &outend, 8);
 			outptr = g_stpcpy (outptr, "</font>");
 		}
-		
+
 		if (inptr < inend) {
 			if (html->flags & CAMEL_MIME_FILTER_TOHTML_CONVERT_NL) {
 				outptr = check_size (filter, outptr, &outend, 5);
 				outptr = g_stpcpy (outptr, "<br>");
 			}
-			
+
 			*outptr++ = '\n';
 		}
-		
+
 		start = ++inptr;
 	} while (inptr < inend);
-	
+
 	if (flush) {
 		/* flush the rest of our input buffer */
 		if (start < inend)
-			outptr = writeln (filter, (const unsigned char *)start, (const unsigned char *)inend, outptr, &outend);
-		
+			outptr = writeln (filter, (const guchar *)start, (const guchar *)inend, outptr, &outend);
+
 		if (html->pre_open) {
 			/* close the pre-tag */
 			outptr = check_size (filter, outptr, &outend, 10);
@@ -396,22 +397,22 @@ html_convert (CamelMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 		/* backup */
 		camel_mime_filter_backup (filter, start, (unsigned) (inend - start));
 	}
-	
+
 	*out = filter->outbuf;
 	*outlen = outptr - filter->outbuf;
 	*outprespace = filter->outpre;
 }
 
 static void
-filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-	       char **out, size_t *outlen, size_t *outprespace)
+filter_filter (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+	       gchar **out, gsize *outlen, gsize *outprespace)
 {
 	html_convert (filter, in, len, prespace, out, outlen, outprespace, FALSE);
 }
 
-static void 
-filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-		 char **out, size_t *outlen, size_t *outprespace)
+static void
+filter_complete (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+		 gchar **out, gsize *outlen, gsize *outprespace)
 {
 	html_convert (filter, in, len, prespace, out, outlen, outprespace, TRUE);
 }
@@ -420,7 +421,7 @@ static void
 filter_reset (CamelMimeFilter *filter)
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
-	
+
 	html->column = 0;
 	html->pre_open = FALSE;
 }
@@ -429,9 +430,9 @@ static void
 camel_mime_filter_tohtml_class_init (CamelMimeFilterToHTMLClass *klass)
 {
 	CamelMimeFilterClass *filter_class = (CamelMimeFilterClass *) klass;
-	
+
 	camel_mime_filter_tohtml_parent = CAMEL_MIME_FILTER_CLASS (camel_type_get_global_classfuncs (camel_mime_filter_get_type ()));
-	
+
 	filter_class->reset = filter_reset;
 	filter_class->filter = filter_filter;
 	filter_class->complete = filter_complete;
@@ -452,18 +453,18 @@ CamelMimeFilter *
 camel_mime_filter_tohtml_new (guint32 flags, guint32 colour)
 {
 	CamelMimeFilterToHTML *new;
-	int i;
-	
+	gint i;
+
 	new = CAMEL_MIME_FILTER_TOHTML (camel_object_new (camel_mime_filter_tohtml_get_type ()));
-	
+
 	new->flags = flags;
 	new->colour = colour;
-	
+
 	for (i = 0; i < NUM_URL_PATTERNS; i++) {
 		if (patterns[i].mask & flags)
 			camel_url_scanner_add (new->scanner, &patterns[i].pattern);
 	}
-	
+
 	return CAMEL_MIME_FILTER (new);
 }
 
@@ -479,23 +480,23 @@ camel_mime_filter_tohtml_new (guint32 flags, guint32 colour)
  * Returns: a newly allocated string containing the HTMLified version
  * of @in
  **/
-char *
-camel_text_to_html (const char *in, guint32 flags, guint32 colour)
+gchar *
+camel_text_to_html (const gchar *in, guint32 flags, guint32 colour)
 {
 	CamelMimeFilter *filter;
-	size_t outlen, outpre;
-	char *outbuf;
-	
+	gsize outlen, outpre;
+	gchar *outbuf;
+
 	g_return_val_if_fail (in != NULL, NULL);
-	
+
 	filter = camel_mime_filter_tohtml_new (flags, colour);
-	
-	camel_mime_filter_complete (filter, (char *) in, strlen (in), 0,
+
+	camel_mime_filter_complete (filter, (gchar *) in, strlen (in), 0,
 				    &outbuf, &outlen, &outpre);
-	
+
 	outbuf = g_strndup (outbuf, outlen);
-	
+
 	camel_object_unref (filter);
-	
+
 	return outbuf;
 }
