@@ -48,12 +48,12 @@ typedef struct _CamelMimeFilterToHTML CamelMimeFilterToHTML;
 
 struct _CamelMimeFilterToHTML {
 	CamelMimeFilter parent;
-	
+
 	struct _CamelUrlScanner *scanner;
-	
+
 	guint32 flags;
 	guint32 colour;
-	
+
 	guint32 column   : 31;
 	guint32 pre_open : 1;
 };
@@ -68,9 +68,9 @@ CamelType        camel_mime_filter_tohtml_get_type (void);
 CamelMimeFilter *camel_mime_filter_tohtml_new (guint32 flags, guint32 colour);
 
 
-/* utility functions to replace e_text_to_html shit */
+/* utility functions to replace e_text_to_html */
 
-char *camel_text_to_html (const char *in, guint32 flags, guint32 colour);
+gchar *camel_text_to_html (const gchar *in, guint32 flags, guint32 colour);
 
 G_END_DECLS
 
