@@ -45,7 +45,7 @@ CamelType
 camel_mime_filter_windows_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type (),
 					    "CamelMimeFilterWindows",
@@ -56,7 +56,7 @@ camel_mime_filter_windows_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_filter_windows_init,
 					    (CamelObjectFinalizeFunc) camel_mime_filter_windows_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -64,7 +64,7 @@ static void
 camel_mime_filter_windows_finalize (CamelObject *o)
 {
 	CamelMimeFilterWindows *windows = (CamelMimeFilterWindows *) o;
-	
+
 	g_free (windows->claimed_charset);
 }
 
@@ -72,26 +72,26 @@ static void
 camel_mime_filter_windows_init (CamelObject *o)
 {
 	CamelMimeFilterWindows *windows = (CamelMimeFilterWindows *) o;
-	
+
 	windows->is_windows = FALSE;
 	windows->claimed_charset = NULL;
 }
 
 static void
-filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-	       char **out, size_t *outlen, size_t *outprespace)
+filter_filter (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+	       gchar **out, gsize *outlen, gsize *outprespace)
 {
 	CamelMimeFilterWindows *windows = (CamelMimeFilterWindows *) filter;
-	register unsigned char *inptr;
-	unsigned char *inend;
-	
+	register guchar *inptr;
+	guchar *inend;
+
 	if (!windows->is_windows) {
-		inptr = (unsigned char *) in;
+		inptr = (guchar *) in;
 		inend = inptr + len;
-		
+
 		while (inptr < inend) {
-			register unsigned char c = *inptr++;
-			
+			register guchar c = *inptr++;
+
 			if (c >= 128 && c <= 159) {
 				w(g_warning ("Encountered Windows charset masquerading as %s",
 					     windows->claimed_charset));
@@ -100,15 +100,15 @@ filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 			}
 		}
 	}
-	
-	*out = in;
+
+	*out = (gchar *) in;
 	*outlen = len;
 	*outprespace = prespace;
 }
 
-static void 
-filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-		 char **out, size_t *outlen, size_t *outprespace)
+static void
+filter_complete (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+		 gchar **out, gsize *outlen, gsize *outprespace)
 {
 	filter_filter (filter, in, len, prespace, out, outlen, outprespace);
 }
@@ -117,7 +117,7 @@ static void
 filter_reset (CamelMimeFilter *filter)
 {
 	CamelMimeFilterWindows *windows = (CamelMimeFilterWindows *) filter;
-	
+
 	windows->is_windows = FALSE;
 }
 
@@ -125,9 +125,9 @@ static void
 camel_mime_filter_windows_class_init (CamelMimeFilterWindowsClass *klass)
 {
 	CamelMimeFilterClass *filter_class = (CamelMimeFilterClass *) klass;
-	
+
 	parent_class = CAMEL_MIME_FILTER_CLASS (camel_type_get_global_classfuncs (camel_mime_filter_get_type ()));
-	
+
 	filter_class->reset = filter_reset;
 	filter_class->filter = filter_filter;
 	filter_class->complete = filter_complete;
@@ -144,16 +144,16 @@ camel_mime_filter_windows_class_init (CamelMimeFilterWindowsClass *klass)
  * Returns: a new #CamelMimeFilter object
  **/
 CamelMimeFilter *
-camel_mime_filter_windows_new (const char *claimed_charset)
+camel_mime_filter_windows_new (const gchar *claimed_charset)
 {
 	CamelMimeFilterWindows *new;
-	
+
 	g_return_val_if_fail (claimed_charset != NULL, NULL);
-	
+
 	new = CAMEL_MIME_FILTER_WINDOWS (camel_object_new (camel_mime_filter_windows_get_type ()));
-	
+
 	new->claimed_charset = g_strdup (claimed_charset);
-	
+
 	return CAMEL_MIME_FILTER (new);
 }
 
@@ -173,7 +173,7 @@ gboolean
 camel_mime_filter_windows_is_windows_charset (CamelMimeFilterWindows *filter)
 {
 	g_return_val_if_fail (CAMEL_IS_MIME_FILTER_WINDOWS (filter), FALSE);
-	
+
 	return filter->is_windows;
 }
 
@@ -189,11 +189,11 @@ camel_mime_filter_windows_is_windows_charset (CamelMimeFilterWindows *filter)
  *
  * Returns: the name of the actual charset
  **/
-const char *
+const gchar *
 camel_mime_filter_windows_real_charset (CamelMimeFilterWindows *filter)
 {
 	g_return_val_if_fail (CAMEL_IS_MIME_FILTER_WINDOWS (filter), NULL);
-	
+
 	if (filter->is_windows)
 		return camel_charset_iso_to_windows (filter->claimed_charset);
 	else
