@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,10 +32,10 @@
 static void camel_mime_filter_yenc_class_init (CamelMimeFilterYencClass *klass);
 static void camel_mime_filter_yenc_init (CamelMimeFilterYenc *filter, CamelMimeFilterYencClass *klass);
 
-static void filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-			   char **out, size_t *outlen, size_t *outprespace);
-static void filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-			     char **out, size_t *outlen, size_t *outprespace);
+static void filter_filter (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+			   gchar **out, gsize *outlen, gsize *outprespace);
+static void filter_complete (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+			     gchar **out, gsize *outlen, gsize *outprespace);
 static void filter_reset (CamelMimeFilter *filter);
 
 
@@ -46,7 +46,7 @@ CamelType
 camel_mime_filter_yenc_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type (),
 					    "CamelMimeFilterYenc",
@@ -57,7 +57,7 @@ camel_mime_filter_yenc_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_filter_yenc_init,
 					    NULL);
 	}
-	
+
 	return type;
 }
 
@@ -66,9 +66,9 @@ static void
 camel_mime_filter_yenc_class_init (CamelMimeFilterYencClass *klass)
 {
 	CamelMimeFilterClass *filter_class = (CamelMimeFilterClass *) klass;
-	
+
 	parent_class = CAMEL_MIME_FILTER_CLASS (camel_type_get_global_classfuncs (camel_mime_filter_get_type ()));
-	
+
 	filter_class->reset = filter_reset;
 	filter_class->filter = filter_filter;
 	filter_class->complete = filter_complete;
@@ -85,28 +85,28 @@ camel_mime_filter_yenc_init (CamelMimeFilterYenc *filter, CamelMimeFilterYencCla
 
 /* here we do all of the basic yEnc filtering */
 static void
-filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-	       char **out, size_t *outlen, size_t *outprespace)
+filter_filter (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+	       gchar **out, gsize *outlen, gsize *outprespace)
 {
 	CamelMimeFilterYenc *yenc = (CamelMimeFilterYenc *) filter;
-	size_t newlen = 0;
-	
+	gsize newlen = 0;
+
 	switch (yenc->direction) {
 	case CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE:
 		/* won't go to more than 2 * (x + 2) + 62 */
 		camel_mime_filter_set_size (filter, (len + 2) * 2 + 62, FALSE);
-		newlen = camel_yencode_step ((const unsigned char *) in, len, (unsigned char *) filter->outbuf, &yenc->state,
+		newlen = camel_yencode_step ((const guchar *) in, len, (guchar *) filter->outbuf, &yenc->state,
 					     &yenc->pcrc, &yenc->crc);
 		g_assert (newlen <= (len + 2) * 2 + 62);
 		break;
 	case CAMEL_MIME_FILTER_YENC_DIRECTION_DECODE:
 		if (!(yenc->state & CAMEL_MIME_YDECODE_STATE_DECODE)) {
-			register char *inptr, *inend;
-			size_t left;
-			
+			const gchar *inptr, *inend;
+			gsize left;
+
 			inptr = in;
 			inend = inptr + len;
-			
+
 			/* we cannot start decoding until we have found an =ybegin line */
 			if (!(yenc->state & CAMEL_MIME_YDECODE_STATE_BEGIN)) {
 				while (inptr < inend) {
@@ -130,16 +130,16 @@ filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 						}
 						break;
 					}
-					
+
 					/* go to the next line */
 					while (inptr < inend && *inptr != '\n')
 						inptr++;
-					
+
 					if (inptr < inend)
 						inptr++;
 				}
 			}
-			
+
 			left = inend - inptr;
 			if ((yenc->state & CAMEL_MIME_YDECODE_STATE_BEGIN) && left > 0) {
 				/* we have found an '=ybegin' line but we may yet have an "=ypart" line to
@@ -162,35 +162,35 @@ filter_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 				}
 			}
 		}
-		
+
 		if ((yenc->state & CAMEL_MIME_YDECODE_STATE_DECODE) && !(yenc->state & CAMEL_MIME_YDECODE_STATE_END)) {
 			/* all yEnc headers have been found so we can now start decoding */
 			camel_mime_filter_set_size (filter, len + 3, FALSE);
-			newlen = camel_ydecode_step ((const unsigned char *) in, len, (unsigned char *) filter->outbuf, &yenc->state, &yenc->pcrc, &yenc->crc);
+			newlen = camel_ydecode_step ((const guchar *) in, len, (guchar *) filter->outbuf, &yenc->state, &yenc->pcrc, &yenc->crc);
 			g_assert (newlen <= len + 3);
 		} else {
 			newlen = 0;
 		}
 		break;
 	}
-	
+
 	*out = filter->outbuf;
 	*outlen = newlen;
 	*outprespace = filter->outpre;
 }
 
 static void
-filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
-		 char **out, size_t *outlen, size_t *outprespace)
+filter_complete (CamelMimeFilter *filter, const gchar *in, gsize len, gsize prespace,
+		 gchar **out, gsize *outlen, gsize *outprespace)
 {
 	CamelMimeFilterYenc *yenc = (CamelMimeFilterYenc *) filter;
-	size_t newlen = 0;
-	
+	gsize newlen = 0;
+
 	switch (yenc->direction) {
 	case CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE:
 		/* won't go to more than 2 * (x + 2) + 62 */
 		camel_mime_filter_set_size (filter, (len + 2) * 2 + 62, FALSE);
-		newlen = camel_yencode_close ((const unsigned char *) in, len, (unsigned char *) filter->outbuf, &yenc->state,
+		newlen = camel_yencode_close ((const guchar *) in, len, (guchar *) filter->outbuf, &yenc->state,
 					       &yenc->pcrc, &yenc->crc);
 		g_assert (newlen <= (len + 2) * 2 + 62);
 		break;
@@ -198,7 +198,7 @@ filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 		if ((yenc->state & CAMEL_MIME_YDECODE_STATE_DECODE) && !(yenc->state & CAMEL_MIME_YDECODE_STATE_END)) {
 			/* all yEnc headers have been found so we can now start decoding */
 			camel_mime_filter_set_size (filter, len + 3, FALSE);
-			newlen = camel_ydecode_step ((const unsigned char *) in, len, (unsigned char *) filter->outbuf, &yenc->state,
+			newlen = camel_ydecode_step ((const guchar *) in, len, (guchar *) filter->outbuf, &yenc->state,
 						      &yenc->pcrc, &yenc->crc);
 			g_assert (newlen <= len + 3);
 		} else {
@@ -206,7 +206,7 @@ filter_complete (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 		}
 		break;
 	}
-	
+
 	*out = filter->outbuf;
 	*outlen = newlen;
 	*outprespace = filter->outpre;
@@ -217,7 +217,7 @@ static void
 filter_reset (CamelMimeFilter *filter)
 {
 	CamelMimeFilterYenc *yenc = (CamelMimeFilterYenc *) filter;
-	
+
 	switch (yenc->direction) {
 	case CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE:
 		yenc->state = CAMEL_MIME_YENCODE_STATE_INIT;
@@ -237,16 +237,16 @@ filter_reset (CamelMimeFilter *filter)
  *
  * Create a new #CamelMimeFilterYenc filter object.
  *
- * Returns a new #CamelMimeFilterYenc object
+ * Returns: a new #CamelMimeFilterYenc object
  **/
 CamelMimeFilter *
 camel_mime_filter_yenc_new (CamelMimeFilterYencDirection direction)
 {
 	CamelMimeFilterYenc *new;
-	
+
 	new = (CamelMimeFilterYenc *) camel_object_new (CAMEL_TYPE_MIME_FILTER_YENC);
 	new->direction = direction;
-	
+
 	switch (direction) {
 	case CAMEL_MIME_FILTER_YENC_DIRECTION_ENCODE:
 		new->state = CAMEL_MIME_YENCODE_STATE_INIT;
@@ -257,7 +257,7 @@ camel_mime_filter_yenc_new (CamelMimeFilterYencDirection direction)
 	default:
 		g_assert_not_reached ();
 	}
-	
+
 	return (CamelMimeFilter *) new;
 }
 
@@ -270,10 +270,10 @@ camel_mime_filter_yenc_new (CamelMimeFilterYencDirection direction)
  * Sets the current state of the yencoder/ydecoder
  **/
 void
-camel_mime_filter_yenc_set_state (CamelMimeFilterYenc *yenc, int state)
+camel_mime_filter_yenc_set_state (CamelMimeFilterYenc *yenc, gint state)
 {
 	g_return_if_fail (CAMEL_IS_MIME_FILTER_YENC (yenc));
-	
+
 	yenc->state = state;
 }
 
@@ -289,7 +289,7 @@ void
 camel_mime_filter_yenc_set_crc (CamelMimeFilterYenc *yenc, guint32 crc)
 {
 	g_return_if_fail (CAMEL_IS_MIME_FILTER_YENC (yenc));
-	
+
 	yenc->crc = crc;
 }
 
@@ -302,17 +302,17 @@ camel_mime_filter_yenc_set_crc (CamelMimeFilterYenc *yenc, guint32 crc)
  *
  * Gets the part id of the current decoded yEnc stream or %-1 on fail.
  *
- * Returns the part id of the current decoded yEnc stream or %-1 on
+ * Returns: the part id of the current decoded yEnc stream or %-1 on
  * fail.
  **/
-int
+gint
 camel_mime_filter_yenc_get_part (CamelMimeFilterYenc *yenc)
 {
 	g_return_val_if_fail (CAMEL_IS_MIME_FILTER_YENC (yenc), -1);
-	
+
 	if (yenc->state & CAMEL_MIME_YDECODE_STATE_PART)
 		return yenc->part;
-	
+
 	return -1;
 }
 #endif
@@ -323,13 +323,13 @@ camel_mime_filter_yenc_get_part (CamelMimeFilterYenc *yenc)
  *
  * Get the computed part crc or (#guint32) %-1 on fail.
  *
- * Returns the computed part crc or (#guint32) %-1 on fail.
+ * Returns: the computed part crc or (#guint32) %-1 on fail.
  **/
 guint32
 camel_mime_filter_yenc_get_pcrc (CamelMimeFilterYenc *yenc)
 {
 	g_return_val_if_fail (CAMEL_IS_MIME_FILTER_YENC (yenc), -1);
-	
+
 	return CAMEL_MIME_YENCODE_CRC_FINAL (yenc->pcrc);
 }
 
@@ -340,18 +340,18 @@ camel_mime_filter_yenc_get_pcrc (CamelMimeFilterYenc *yenc)
  *
  * Get the computed crc or (#guint32) -1 on fail.
  *
- * Returns the computed crc or (#guint32) -1 on fail.
+ * Returns: the computed crc or (#guint32) -1 on fail.
  **/
 guint32
 camel_mime_filter_yenc_get_crc (CamelMimeFilterYenc *yenc)
 {
 	g_return_val_if_fail (CAMEL_IS_MIME_FILTER_YENC (yenc), -1);
-	
+
 	return CAMEL_MIME_YENCODE_CRC_FINAL (yenc->crc);
 }
 
 
-static const int yenc_crc_table[256] = {
+static const gint yenc_crc_table[256] = {
 	0x00000000, 0x77073096, 0xee0e612c, 0x990951ba, 0x076dc419, 0x706af48f, 0xe963a535, 0x9e6495a3,
 	0x0edb8832, 0x79dcb8a4, 0xe0d5e91e, 0x97d2d988, 0x09b64c2b, 0x7eb17cbd, 0xe7b82d07, 0x90bf1d91,
 	0x1db71064, 0x6ab020f2, 0xf3b97148, 0x84be41de, 0x1adad47d, 0x6ddde4eb, 0xf4d4b551, 0x83d385c7,
@@ -386,7 +386,7 @@ static const int yenc_crc_table[256] = {
 	0xb3667a2e, 0xc4614ab8, 0x5d681b02, 0x2a6f2b94, 0xb40bbe37, 0xc30c8ea1, 0x5a05df1b, 0x2d02ef8d
 };
 
-#define yenc_crc_add(crc, c) (yenc_crc_table[(((int) (crc)) ^ ((unsigned char) (c))) & 0xff] ^ ((((int) (crc)) >> 8) & 0x00ffffff))
+#define yenc_crc_add(crc, c) (yenc_crc_table[(((gint) (crc)) ^ ((guchar) (c))) & 0xff] ^ ((((gint) (crc)) >> 8) & 0x00ffffff))
 
 #define YENC_NEWLINE_ESCAPE (CAMEL_MIME_YDECODE_STATE_EOLN | CAMEL_MIME_YDECODE_STATE_ESCAPE)
 
@@ -410,45 +410,45 @@ static const int yenc_crc_table[256] = {
  * combined crc32 value of all the parts using #CAMEL_MIME_YENCODE_CRC_FINAL
  * (@crc).
  *
- * Returns the number of bytes decoded
+ * Returns: the number of bytes decoded
  **/
-size_t
-camel_ydecode_step (const unsigned char *in, size_t inlen, unsigned char *out,
-		    int *state, guint32 *pcrc, guint32 *crc)
+gsize
+camel_ydecode_step (const guchar *in, gsize inlen, guchar *out,
+		    gint *state, guint32 *pcrc, guint32 *crc)
 {
-	register const unsigned char *inptr;
-	register unsigned char *outptr;
-	const unsigned char *inend;
-	unsigned char ch;
-	int ystate;
-	
+	register const guchar *inptr;
+	register guchar *outptr;
+	const guchar *inend;
+	guchar ch;
+	gint ystate;
+
 	if (*state & CAMEL_MIME_YDECODE_STATE_END)
 		return 0;
-	
+
 	ystate = *state;
-	
+
 	inend = in + inlen;
 	outptr = out;
-	
+
 	inptr = in;
 	while (inptr < inend) {
 		ch = *inptr++;
-		
+
 		if ((ystate & YENC_NEWLINE_ESCAPE) == YENC_NEWLINE_ESCAPE) {
 			ystate &= ~CAMEL_MIME_YDECODE_STATE_EOLN;
-			
+
 			if (ch == 'y') {
 				/* we probably have a =yend here */
 				ystate |= CAMEL_MIME_YDECODE_STATE_END;
 				break;
 			}
 		}
-		
+
 		if (ch == '\n') {
 			ystate |= CAMEL_MIME_YDECODE_STATE_EOLN;
 			continue;
 		}
-		
+
 		if (ystate & CAMEL_MIME_YDECODE_STATE_ESCAPE) {
 			ystate &= ~CAMEL_MIME_YDECODE_STATE_ESCAPE;
 			ch -= 64;
@@ -456,17 +456,17 @@ camel_ydecode_step (const unsigned char *in, size_t inlen, unsigned char *out,
 			ystate |= CAMEL_MIME_YDECODE_STATE_ESCAPE;
 			continue;
 		}
-		
+
 		ystate &= ~CAMEL_MIME_YDECODE_STATE_EOLN;
-		
+
 		*outptr++ = ch -= 42;
-		
+
 		*pcrc = yenc_crc_add (*pcrc, ch);
 		*crc = yenc_crc_add (*crc, ch);
 	}
-	
+
 	*state = ystate;
-	
+
 	return outptr - out;
 }
 
@@ -490,32 +490,32 @@ camel_ydecode_step (const unsigned char *in, size_t inlen, unsigned char *out,
  * Along the same lines, @pcrc and @crc should be initialized to
  * #CAMEL_MIME_YENCODE_CRC_INIT before using.
  *
- * Returns the number of bytes encoded
+ * Returns: the number of bytes encoded
  **/
-size_t
-camel_yencode_step (const unsigned char *in, size_t inlen, unsigned char *out,
-		    int *state, guint32 *pcrc, guint32 *crc)
+gsize
+camel_yencode_step (const guchar *in, gsize inlen, guchar *out,
+		    gint *state, guint32 *pcrc, guint32 *crc)
 {
-	register const unsigned char *inptr;
-	register unsigned char *outptr;
-	const unsigned char *inend;
-	register int already;
-	unsigned char ch;
-	
+	register const guchar *inptr;
+	register guchar *outptr;
+	const guchar *inend;
+	register gint already;
+	guchar ch;
+
 	inend = in + inlen;
 	outptr = out;
-	
+
 	already = *state;
-	
+
 	inptr = in;
 	while (inptr < inend) {
 		ch = (*inptr++);
-		
+
 		*pcrc = yenc_crc_add (*pcrc, ch);
 		*crc = yenc_crc_add (*crc, ch);
-		
+
 		ch += 42;
-		
+
 		if (ch == '\0' || ch == '\t' || ch == '\r' || ch == '\n' || ch == '=') {
 			*outptr++ = '=';
 			*outptr++ = ch + 64;
@@ -524,15 +524,15 @@ camel_yencode_step (const unsigned char *in, size_t inlen, unsigned char *out,
 			*outptr++ = ch;
 			already++;
 		}
-		
+
 		if (already >= 128) {
 			*outptr++ = '\n';
 			already = 0;
 		}
 	}
-	
+
 	*state = already;
-	
+
 	return outptr - out;
 }
 
@@ -555,23 +555,23 @@ camel_yencode_step (const unsigned char *in, size_t inlen, unsigned char *out,
  * #CAMEL_MIME_YENCODE_CRC_FINAL (@crc) to get the combined crc32 value of
  * all the parts.
  *
- * Returns the number of bytes encoded.
+ * Returns: the number of bytes encoded.
  **/
-size_t
-camel_yencode_close (const unsigned char *in, size_t inlen, unsigned char *out,
-		     int *state, guint32 *pcrc, guint32 *crc)
+gsize
+camel_yencode_close (const guchar *in, gsize inlen, guchar *out,
+		     gint *state, guint32 *pcrc, guint32 *crc)
 {
-	register unsigned char *outptr;
-	
+	register guchar *outptr;
+
 	outptr = out;
-	
+
 	if (inlen)
 		outptr += camel_yencode_step (in, inlen, out, state, pcrc, crc);
-	
+
 	if (*state)
 		*outptr++ = '\n';
-	
+
 	*state = CAMEL_MIME_YENCODE_STATE_INIT;
-	
+
 	return outptr - out;
 }
