@@ -1,5 +1,5 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- 
- * camel-multipart.c : Abstract class for a multipart 
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * camel-multipart.c : Abstract class for a multipart
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -59,10 +59,10 @@ static CamelMimePart *signed_remove_part_at (CamelMultipart *multipart, guint in
 static CamelMimePart *signed_get_part (CamelMultipart *multipart, guint index);
 static guint signed_get_number (CamelMultipart *multipart);
 
-static ssize_t write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
+static gssize write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
 static void set_mime_type_field (CamelDataWrapper *data_wrapper, CamelContentType *mime_type);
-static int construct_from_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
-static int signed_construct_from_parser (CamelMultipart *multipart, struct _CamelMimeParser *mp);
+static gint construct_from_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
+static gint signed_construct_from_parser (CamelMultipart *multipart, struct _CamelMimeParser *mp);
 
 static CamelMultipartClass *parent_class = NULL;
 
@@ -180,12 +180,12 @@ camel_multipart_signed_new (void)
 	return multipart;
 }
 
-static int
+static gint
 skip_content(CamelMimeParser *cmp)
 {
-	char *buf;
-	size_t len;
-	int state;
+	gchar *buf;
+	gsize len;
+	gint state;
 
 	switch (camel_mime_parser_state(cmp)) {
 	case CAMEL_MIME_PARSER_STATE_HEADER:
@@ -224,16 +224,16 @@ skip_content(CamelMimeParser *cmp)
 	return 0;
 }
 
-static int
+static gint
 parse_content(CamelMultipartSigned *mps)
 {
 	CamelMimeParser *cmp;
 	CamelMultipart *mp = (CamelMultipart *)mps;
 	CamelStreamMem *mem;
-	const char *boundary;
-	char *buf;
-	size_t len;
-	int state;
+	const gchar *boundary;
+	gchar *buf;
+	gsize len;
+	gint state;
 
 	boundary = camel_multipart_get_boundary(mp);
 	if (boundary == NULL) {
@@ -282,7 +282,7 @@ parse_content(CamelMultipartSigned *mps)
 
 	if (state == CAMEL_MIME_PARSER_STATE_MULTIPART_END) {
 		mps->end2 = camel_mime_parser_tell_start_boundary(cmp);
-		
+
 		camel_multipart_set_preface(mp, camel_mime_parser_preface(cmp));
 		camel_multipart_set_postface(mp, camel_mime_parser_postface(cmp));
 	}
@@ -304,7 +304,7 @@ set_mime_type_field(CamelDataWrapper *data_wrapper, CamelContentType *mime_type)
 
 	((CamelDataWrapperClass *)parent_class)->set_mime_type_field(data_wrapper, mime_type);
 	if (mime_type) {
-		const char *micalg, *protocol;
+		const gchar *micalg, *protocol;
 
 		protocol = camel_content_type_param(mime_type, "protocol");
 		g_free(mps->protocol);
@@ -441,7 +441,7 @@ set_stream(CamelMultipartSigned *mps, CamelStream *mem)
 	}
 }
 
-static int
+static gint
 construct_from_stream(CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
 	CamelMultipartSigned *mps = (CamelMultipartSigned *)data_wrapper;
@@ -455,14 +455,14 @@ construct_from_stream(CamelDataWrapper *data_wrapper, CamelStream *stream)
 	return 0;
 }
 
-static int
+static gint
 signed_construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser *mp)
 {
-	int err;
+	gint err;
 	CamelContentType *content_type;
 	CamelMultipartSigned *mps = (CamelMultipartSigned *)multipart;
-	char *buf;
-	size_t len;
+	gchar *buf;
+	gsize len;
 	CamelStream *mem;
 
 	/* we *must not* be in multipart state, otherwise the mime parser will
@@ -487,15 +487,15 @@ signed_construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser
 		return 0;
 }
 
-static ssize_t
+static gssize
 write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
 	CamelMultipartSigned *mps = (CamelMultipartSigned *)data_wrapper;
 	CamelMultipart *mp = (CamelMultipart *)mps;
-	const char *boundary;
-	ssize_t total = 0;
-	ssize_t count;
-	
+	const gchar *boundary;
+	gssize total = 0;
+	gssize count;
+
 	/* we have 3 basic cases:
 	   1. constructed, we write out the data wrapper stream we got
 	   2. signed content, we create and write out a new stream
@@ -534,7 +534,7 @@ write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 	if (count == -1)
 		return -1;
 	total += count;
-	
+
 	/* boundary */
 	count = camel_stream_printf(stream, "\n--%s\n", boundary);
 	if (count == -1)
@@ -561,7 +561,7 @@ write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 		total += count;
 	}
 
-	return total;	
+	return total;
 }
 
 
@@ -598,7 +598,7 @@ camel_multipart_signed_get_content_stream(CamelMultipartSigned *mps, CamelExcept
 		sub = camel_seekable_substream_new((CamelSeekableStream *)((CamelDataWrapper *)mps)->stream, mps->start1, mps->end1);
 		constream = (CamelStream *)camel_stream_filter_new_with_stream(sub);
 		camel_object_unref((CamelObject *)sub);
-		
+
 		/* Note: see rfc2015 or rfc3156, section 5 */
 		canon_filter = camel_mime_filter_canon_new (CAMEL_MIME_FILTER_CANON_CRLF);
 		camel_stream_filter_add((CamelStreamFilter *)constream, (CamelMimeFilter *)canon_filter);
