@@ -52,12 +52,12 @@ static CamelMimePart *       get_part          (CamelMultipart *multipart,
 						guint index);
 static guint                 get_number        (CamelMultipart *multipart);
 static void                  set_boundary      (CamelMultipart *multipart,
-						const char *boundary);
+						const gchar *boundary);
 static const gchar *         get_boundary      (CamelMultipart *multipart);
-static ssize_t               write_to_stream   (CamelDataWrapper *data_wrapper,
+static gssize               write_to_stream   (CamelDataWrapper *data_wrapper,
 						CamelStream *stream);
 
-static int construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser *mp);
+static gint construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser *mp);
 
 static CamelDataWrapperClass *parent_class = NULL;
 
@@ -345,13 +345,13 @@ camel_multipart_get_number (CamelMultipart *multipart)
 
 
 static void
-set_boundary (CamelMultipart *multipart, const char *boundary)
+set_boundary (CamelMultipart *multipart, const gchar *boundary)
 {
 	CamelDataWrapper *cdw = CAMEL_DATA_WRAPPER (multipart);
-	char *bgen, bbuf[27], *p;
+	gchar *bgen, bbuf[27], *p;
 	guint8 *digest;
 	gsize length;
-	int state, save;
+	gint state, save;
 
 	g_return_if_fail (cdw->mime_type != NULL);
 
@@ -362,9 +362,9 @@ set_boundary (CamelMultipart *multipart, const char *boundary)
 		GChecksum *checksum;
 
 		/* Generate a fairly random boundary string. */
-		bgen = g_strdup_printf ("%p:%lu:%lu", (void *) multipart,
-					(unsigned long) getpid(),
-					(unsigned long) time(NULL));
+		bgen = g_strdup_printf ("%p:%lu:%lu", (gpointer) multipart,
+					(gulong) getpid(),
+					(gulong) time(NULL));
 
 		checksum = g_checksum_new (G_CHECKSUM_MD5);
 		g_checksum_update (checksum, (guchar *) bgen, -1);
@@ -396,7 +396,7 @@ set_boundary (CamelMultipart *multipart, const char *boundary)
  * be used.
  **/
 void
-camel_multipart_set_boundary (CamelMultipart *multipart, const char *boundary)
+camel_multipart_set_boundary (CamelMultipart *multipart, const gchar *boundary)
 {
 	g_return_if_fail (CAMEL_IS_MULTIPART (multipart));
 
@@ -419,7 +419,7 @@ get_boundary (CamelMultipart *multipart)
  *
  * Returns: the boundary
  **/
-const char *
+const gchar *
 camel_multipart_get_boundary (CamelMultipart *multipart)
 {
 	return CMP_CLASS (multipart)->get_boundary (multipart);
@@ -444,21 +444,21 @@ is_offline (CamelDataWrapper *data_wrapper)
 }
 
 /* this is MIME specific, doesn't belong here really */
-static ssize_t
+static gssize
 write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
 	CamelMultipart *multipart = CAMEL_MULTIPART (data_wrapper);
 	const gchar *boundary;
-	ssize_t total = 0;
-	ssize_t count;
+	gssize total = 0;
+	gssize count;
 	GList *node;
 
 	/* get the bundary text */
 	boundary = camel_multipart_get_boundary (multipart);
-	
+
 	/* we cannot write a multipart without a boundary string */
 	g_return_val_if_fail (boundary, -1);
-	
+
 	/*
 	 * write the preface text (usually something like
 	 *   "This is a mime message, if you see this, then
@@ -510,13 +510,13 @@ write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
  * camel_multipart_set_preface:
  * @multipart: a #CamelMultipart object
  * @preface: the multipart preface
- * 
+ *
  * Set the preface text for this multipart.  Will be written out infront
  * of the multipart.  This text should only include US-ASCII strings, and
  * be relatively short, and will be ignored by any MIME mail client.
  **/
 void
-camel_multipart_set_preface(CamelMultipart *multipart, const char *preface)
+camel_multipart_set_preface(CamelMultipart *multipart, const gchar *preface)
 {
 	if (multipart->preface != preface) {
 		g_free(multipart->preface);
@@ -531,7 +531,7 @@ camel_multipart_set_preface(CamelMultipart *multipart, const char *preface)
  * camel_multipart_set_postface:
  * @multipart: a #CamelMultipart object
  * @postface: multipat postface
- * 
+ *
  * Set the postfix text for this multipart.  Will be written out after
  * the last boundary of the multipart, and ignored by any MIME mail
  * client.
@@ -539,7 +539,7 @@ camel_multipart_set_preface(CamelMultipart *multipart, const char *preface)
  * Generally postface texts should not be sent with multipart messages.
  **/
 void
-camel_multipart_set_postface(CamelMultipart *multipart, const char *postface)
+camel_multipart_set_postface(CamelMultipart *multipart, const gchar *postface)
 {
 	if (multipart->postface != postface) {
 		g_free(multipart->postface);
@@ -550,24 +550,24 @@ camel_multipart_set_postface(CamelMultipart *multipart, const char *postface)
 	}
 }
 
-static int
+static gint
 construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser *mp)
 {
-	int err;
+	gint err;
 	CamelContentType *content_type;
 	CamelMimePart *bodypart;
-	char *buf;
-	size_t len;
-	
+	gchar *buf;
+	gsize len;
+
 	g_assert(camel_mime_parser_state(mp) == CAMEL_MIME_PARSER_STATE_MULTIPART);
-	
+
 	/* FIXME: we should use a came-mime-mutlipart, not jsut a camel-multipart, but who cares */
 	d(printf("Creating multi-part\n"));
-		
+
 	content_type = camel_mime_parser_content_type(mp);
 	camel_multipart_set_boundary(multipart,
 				     camel_content_type_param(content_type, "boundary"));
-	
+
 	while (camel_mime_parser_step(mp, &buf, &len) != CAMEL_MIME_PARSER_STATE_MULTIPART_END) {
 		camel_mime_parser_unstep(mp);
 		bodypart = camel_mime_part_new();
@@ -575,11 +575,11 @@ construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser *mp)
 		camel_multipart_add_part(multipart, bodypart);
 		camel_object_unref((CamelObject *)bodypart);
 	}
-	
+
 	/* these are only return valid data in the MULTIPART_END state */
 	camel_multipart_set_preface(multipart, camel_mime_parser_preface (mp));
 	camel_multipart_set_postface(multipart, camel_mime_parser_postface (mp));
-	
+
 	err = camel_mime_parser_errno(mp);
 	if (err != 0) {
 		errno = err;
@@ -598,7 +598,7 @@ construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser *mp)
  *
  * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_multipart_construct_from_parser(CamelMultipart *multipart, struct _CamelMimeParser *mp)
 {
 	g_return_val_if_fail(CAMEL_IS_MULTIPART(multipart), -1);
