@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
- * 	    Jeffrey Stedfast <fejj@ximian.com>
+ *	    Jeffrey Stedfast <fejj@ximian.com>
  *	    Chris Toshok <toshok@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -32,13 +32,12 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#ifndef G_OS_WIN32
-#include <sys/poll.h>
-#endif
-
 #include "camel-exception.h"
 #include "camel-msgport.h"
 #include "camel-net-utils.h"
+#ifdef G_OS_WIN32
+#include "camel-net-utils-win32.h"
+#endif
 #include "camel-operation.h"
 
 #define d(x)
@@ -64,8 +63,8 @@ typedef short in_port_t;
  * i.e. g_win32_error_message().
  */
 
-static const char *
-gai_strerror (int error_code)
+static const gchar *
+gai_strerror (gint error_code)
 {
 	gchar *msg = g_win32_error_message (error_code);
 	GQuark quark = g_quark_from_string (msg);
@@ -88,14 +87,14 @@ This should probably go away */
 G_LOCK_DEFINE_STATIC (gethost_mutex);
 #endif
 
-#define ALIGN(x) (((x) + (sizeof (char *) - 1)) & ~(sizeof (char *) - 1))
+#define ALIGN(x) (((x) + (sizeof (gchar *) - 1)) & ~(sizeof (gchar *) - 1))
 
 #define GETHOST_PROCESS(h, host, buf, buflen, herr) G_STMT_START {     \
-	int num_aliases = 0, num_addrs = 0;                            \
-	int req_length;                                                \
-	char *p;                                                       \
-	int i;                                                         \
-	                                                               \
+	gint num_aliases = 0, num_addrs = 0;                            \
+	gint req_length;                                                \
+	gchar *p;                                                       \
+	gint i;                                                         \
+								       \
 	/* check to make sure we have enough room in our buffer */     \
 	req_length = 0;                                                \
 	if (h->h_aliases) {                                            \
@@ -103,45 +102,45 @@ G_LOCK_DEFINE_STATIC (gethost_mutex);
 			req_length += strlen (h->h_aliases[i]) + 1;    \
 		num_aliases = i;                                       \
 	}                                                              \
-	                                                               \
+								       \
 	if (h->h_addr_list) {                                          \
 		for (i = 0; h->h_addr_list[i]; i++)                    \
 			req_length += h->h_length;                     \
 		num_addrs = i;                                         \
 	}                                                              \
-	                                                               \
-	req_length += sizeof (char *) * (num_aliases + 1);             \
-	req_length += sizeof (char *) * (num_addrs + 1);               \
+								       \
+	req_length += sizeof (gchar *) * (num_aliases + 1);             \
+	req_length += sizeof (gchar *) * (num_addrs + 1);               \
 	req_length += strlen (h->h_name) + 1;                          \
-	                                                               \
+								       \
 	if (buflen < req_length) {                                     \
 		*herr = ERANGE;                                        \
 		G_UNLOCK (gethost_mutex);                              \
 		return ERANGE;                                         \
 	}                                                              \
-	                                                               \
+								       \
 	/* we store the alias/addr pointers in the buffer */           \
         /* their addresses here. */                                    \
 	p = buf;                                                       \
 	if (num_aliases) {                                             \
-		host->h_aliases = (char **) p;                         \
-		p += sizeof (char *) * (num_aliases + 1);              \
+		host->h_aliases = (gchar **) p;                         \
+		p += sizeof (gchar *) * (num_aliases + 1);              \
 	} else                                                         \
 		host->h_aliases = NULL;                                \
                                                                        \
 	if (num_addrs) {                                               \
-		host->h_addr_list = (char **) p;                       \
-		p += sizeof (char *) * (num_addrs + 1);                \
+		host->h_addr_list = (gchar **) p;                       \
+		p += sizeof (gchar *) * (num_addrs + 1);                \
 	} else                                                         \
 		host->h_addr_list = NULL;                              \
-	                                                               \
+								       \
 	/* copy the host name into the buffer */                       \
 	host->h_name = p;                                              \
 	strcpy (p, h->h_name);                                         \
 	p += strlen (h->h_name) + 1;                                   \
 	host->h_addrtype = h->h_addrtype;                              \
 	host->h_length = h->h_length;                                  \
-	                                                               \
+								       \
 	/* copy the aliases/addresses into the buffer */               \
         /* and assign pointers into the hostent */                     \
 	*p = 0;                                                        \
@@ -153,7 +152,7 @@ G_LOCK_DEFINE_STATIC (gethost_mutex);
 		}                                                      \
 		host->h_aliases[num_aliases] = NULL;                   \
 	}                                                              \
-	                                                               \
+								       \
 	if (num_addrs) {                                               \
 		for (i = 0; i < num_addrs; i++) {                      \
 			memcpy (p, h->h_addr_list[i], h->h_length);    \
@@ -167,10 +166,10 @@ G_LOCK_DEFINE_STATIC (gethost_mutex);
 
 #ifdef ENABLE_IPv6
 /* some helpful utils for IPv6 lookups */
-#define IPv6_BUFLEN_MIN  (sizeof (char *) * 3)
+#define IPv6_BUFLEN_MIN  (sizeof (gchar *) * 3)
 
-static int
-ai_to_herr (int error)
+static gint
+ai_to_herr (gint error)
 {
 	switch (error) {
 	case EAI_NONAME:
@@ -203,15 +202,15 @@ ai_to_herr (int error)
 
 #endif /* ENABLE_IPv6 */
 
-static int
-camel_gethostbyname_r (const char *name, struct hostent *host,
-		       char *buf, size_t buflen, int *herr)
+static gint
+camel_gethostbyname_r (const gchar *name, struct hostent *host,
+		       gchar *buf, gsize buflen, gint *herr)
 {
 #ifdef ENABLE_IPv6
 	struct addrinfo hints, *res;
-	int retval, len;
-	char *addr;
-	
+	gint retval, len;
+	gchar *addr;
+
 	memset (&hints, 0, sizeof (struct addrinfo));
 #ifdef HAVE_AI_ADDRCONFIG
 	hints.ai_flags = AI_CANONNAME | AI_ADDRCONFIG;
@@ -221,49 +220,49 @@ camel_gethostbyname_r (const char *name, struct hostent *host,
 	hints.ai_family = PF_UNSPEC;
 	hints.ai_socktype = SOCK_STREAM;
 	hints.ai_protocol = IPPROTO_TCP;
-	
+
 	if ((retval = getaddrinfo (name, NULL, &hints, &res)) != 0) {
 		*herr = ai_to_herr (retval);
 		return -1;
 	}
-	
+
 	len = ALIGN (strlen (res->ai_canonname) + 1);
-	if (buflen < IPv6_BUFLEN_MIN + len + res->ai_addrlen + sizeof (char *))
+	if (buflen < IPv6_BUFLEN_MIN + len + res->ai_addrlen + sizeof (gchar *))
 		return ERANGE;
-	
+
 	/* h_name */
 	strcpy (buf, res->ai_canonname);
 	host->h_name = buf;
 	buf += len;
-	
+
 	/* h_aliases */
-	((char **) buf)[0] = NULL;
-	host->h_aliases = (char **) buf;
-	buf += sizeof (char *);
-	
+	((gchar **) buf)[0] = NULL;
+	host->h_aliases = (gchar **) buf;
+	buf += sizeof (gchar *);
+
 	/* h_addrtype and h_length */
 	host->h_length = res->ai_addrlen;
 	if (res->ai_family == PF_INET6) {
 		host->h_addrtype = AF_INET6;
-		
-		addr = (char *) &((struct sockaddr_in6 *) res->ai_addr)->sin6_addr;
+
+		addr = (gchar *) &((struct sockaddr_in6 *) res->ai_addr)->sin6_addr;
 	} else {
 		host->h_addrtype = AF_INET;
-		
-		addr = (char *) &((struct sockaddr_in *) res->ai_addr)->sin_addr;
+
+		addr = (gchar *) &((struct sockaddr_in *) res->ai_addr)->sin_addr;
 	}
-	
+
 	memcpy (buf, addr, host->h_length);
 	addr = buf;
 	buf += ALIGN (host->h_length);
-	
+
 	/* h_addr_list */
-	((char **) buf)[0] = addr;
-	((char **) buf)[1] = NULL;
-	host->h_addr_list = (char **) buf;
-	
+	((gchar **) buf)[0] = addr;
+	((gchar **) buf)[1] = NULL;
+	host->h_addr_list = (gchar **) buf;
+
 	freeaddrinfo (res);
-	
+
 	return 0;
 #else /* No support for IPv6 addresses */
 #ifdef HAVE_GETHOSTBYNAME_R
@@ -274,8 +273,8 @@ camel_gethostbyname_r (const char *name, struct hostent *host,
 		return errno;
 #else
 	struct hostent *hp;
-	int retval;
-	
+	gint retval;
+
 	retval = gethostbyname_r (name, host, buf, buflen, &hp, herr);
 	if (hp != NULL) {
 		*herr = 0;
@@ -289,69 +288,69 @@ camel_gethostbyname_r (const char *name, struct hostent *host,
 		 */
 		retval = -1;
 	}
-	
+
 	return retval;
 #endif
 #else /* No support for gethostbyname_r */
 	struct hostent *h;
-	
+
 	G_LOCK (gethost_mutex);
-	
+
 	h = gethostbyname (name);
-	
+
 	if (!h) {
 		*herr = h_errno;
 		G_UNLOCK (gethost_mutex);
 		return -1;
 	}
-	
+
 	GETHOST_PROCESS (h, host, buf, buflen, herr);
-	
+
 	G_UNLOCK (gethost_mutex);
-	
+
 	return 0;
 #endif /* HAVE_GETHOSTBYNAME_R */
 #endif /* ENABLE_IPv6 */
 }
 
-static int
-camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *host,
-		       char *buf, size_t buflen, int *herr)
+static gint
+camel_gethostbyaddr_r (const gchar *addr, gint addrlen, gint type, struct hostent *host,
+		       gchar *buf, gsize buflen, gint *herr)
 {
 #ifdef ENABLE_IPv6
-	int retval, len;
-	
+	gint retval, len;
+
 	if ((retval = getnameinfo (addr, addrlen, buf, buflen, NULL, 0, NI_NAMEREQD)) != 0) {
 		*herr = ai_to_herr (retval);
 		return -1;
 	}
-	
+
 	len = ALIGN (strlen (buf) + 1);
-	if (buflen < IPv6_BUFLEN_MIN + len + addrlen + sizeof (char *))
+	if (buflen < IPv6_BUFLEN_MIN + len + addrlen + sizeof (gchar *))
 		return ERANGE;
-	
+
 	/* h_name */
 	host->h_name = buf;
 	buf += len;
-	
+
 	/* h_aliases */
-	((char **) buf)[0] = NULL;
-	host->h_aliases = (char **) buf;
-	buf += sizeof (char *);
-	
+	((gchar **) buf)[0] = NULL;
+	host->h_aliases = (gchar **) buf;
+	buf += sizeof (gchar *);
+
 	/* h_addrtype and h_length */
 	host->h_length = addrlen;
 	host->h_addrtype = type;
-	
+
 	memcpy (buf, addr, host->h_length);
 	addr = buf;
 	buf += ALIGN (host->h_length);
-	
+
 	/* h_addr_list */
-	((char **) buf)[0] = addr;
-	((char **) buf)[1] = NULL;
-	host->h_addr_list = (char **) buf;
-	
+	((gchar **) buf)[0] = addr;
+	((gchar **) buf)[1] = NULL;
+	host->h_addr_list = (gchar **) buf;
+
 	return 0;
 #else /* No support for IPv6 addresses */
 #ifdef HAVE_GETHOSTBYADDR_R
@@ -362,8 +361,8 @@ camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *
 		return errno;
 #else
 	struct hostent *hp;
-	int retval;
-	
+	gint retval;
+
 	retval = gethostbyaddr_r (addr, addrlen, type, host, buf, buflen, &hp, herr);
 	if (hp != NULL) {
 		*herr = 0;
@@ -378,26 +377,26 @@ camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *
 		 */
 		retval = -1;
 	}
-	
+
 	return retval;
 #endif
 #else /* No support for gethostbyaddr_r */
 	struct hostent *h;
-	
+
 	G_LOCK (gethost_mutex);
-	
+
 	h = gethostbyaddr (addr, addrlen, type);
-	
+
 	if (!h) {
 		*herr = h_errno;
 		G_UNLOCK (gethost_mutex);
 		return -1;
 	}
-	
+
 	GETHOST_PROCESS (h, host, buf, buflen, herr);
-	
+
 	G_UNLOCK (gethost_mutex);
-	
+
 	return 0;
 #endif /* HAVE_GETHOSTBYADDR_R */
 #endif /* ENABLE_IPv6 */
@@ -407,30 +406,30 @@ camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *
 /* ********************************************************************** */
 struct _addrinfo_msg {
 	CamelMsg msg;
-	unsigned int cancelled:1;
+	guint cancelled:1;
 
 	/* for host lookup */
-	const char *name;
-	const char *service;
-	int result;
+	const gchar *name;
+	const gchar *service;
+	gint result;
 	const struct addrinfo *hints;
 	struct addrinfo **res;
 
 	/* for host lookup emulation */
 #ifdef NEED_ADDRINFO
 	struct hostent hostbuf;
-	int hostbuflen;
-	char *hostbufmem;
+	gint hostbuflen;
+	gchar *hostbufmem;
 #endif
 
 	/* for name lookup */
 	const struct sockaddr *addr;
 	socklen_t addrlen;
-	char *host;
-	int hostlen;
-	char *serv;
-	int servlen;
-	int flags;
+	gchar *host;
+	gint hostlen;
+	gchar *serv;
+	gint servlen;
+	gint flags;
 };
 
 static void
@@ -445,36 +444,36 @@ cs_freeinfo(struct _addrinfo_msg *msg)
 }
 
 /* returns -1 if we didn't wait for reply from thread */
-static int
-cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error, CamelException *ex)
+static gint
+cs_waitinfo(gpointer (worker)(gpointer), struct _addrinfo_msg *msg, const gchar *error, CamelException *ex)
 {
 	CamelMsgPort *reply_port;
 	pthread_t id;
-	int err, cancel_fd, cancel = 0, fd;
+	gint err, cancel_fd, cancel = 0, fd;
 
 	cancel_fd = camel_operation_cancel_fd(NULL);
 	if (cancel_fd == -1) {
 		worker(msg);
 		return 0;
 	}
-	
+
 	reply_port = msg->msg.reply_port = camel_msgport_new();
 	fd = camel_msgport_fd(msg->msg.reply_port);
 	if ((err = pthread_create(&id, NULL, worker, msg)) == 0) {
-		int status;
+		gint status;
 #ifndef G_OS_WIN32
-		struct pollfd polls[2];
+		GPollFD polls[2];
 
 		polls[0].fd = fd;
-		polls[0].events = POLLIN;
+		polls[0].events = G_IO_IN;
 		polls[1].fd = cancel_fd;
-		polls[1].events = POLLIN;
+		polls[1].events = G_IO_IN;
 
 		d(printf("waiting for name return/cancellation in main process\n"));
 		do {
 			polls[0].revents = 0;
 			polls[1].revents = 0;
-			status = poll(polls, 2, -1);
+			status = g_poll(polls, 2, -1);
 		} while (status == -1 && errno == EINTR);
 #else
 		fd_set read_set;
@@ -488,7 +487,7 @@ cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error
 
 		if (status == -1 ||
 #ifndef G_OS_WIN32
-		    (polls[1].revents & POLLIN)
+		    (polls[1].revents & G_IO_IN)
 #else
 		    FD_ISSET (cancel_fd, &read_set)
 #endif
@@ -503,7 +502,7 @@ cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error
 						     );
 			else
 				camel_exception_setv(ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
-			
+
 			/* We cancel so if the thread impl is decent it causes immediate exit.
 			   We detach so we dont need to wait for it to exit if it isn't.
 			   We check the reply port incase we had a reply in the mean time, which we free later */
@@ -529,16 +528,16 @@ cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error
 }
 
 #ifdef NEED_ADDRINFO
-static void *
-cs_getaddrinfo(void *data)
+static gpointer
+cs_getaddrinfo(gpointer data)
 {
 	struct _addrinfo_msg *msg = data;
-	int herr;
+	gint herr;
 	struct hostent h;
 	struct addrinfo *res, *last = NULL;
 	struct sockaddr_in *sin;
 	in_port_t port = 0;
-	int i;
+	gint i;
 
 	/* This is a pretty simplistic emulation of getaddrinfo */
 
@@ -547,7 +546,7 @@ cs_getaddrinfo(void *data)
                 msg->hostbuflen *= 2;
                 msg->hostbufmem = g_realloc(msg->hostbufmem, msg->hostbuflen);
 	}
-	
+
 	/* If we got cancelled, dont reply, just free it */
 	if (msg->cancelled)
 		goto cancel;
@@ -570,7 +569,7 @@ cs_getaddrinfo(void *data)
 
 	/* check service mapping */
 	if (msg->service) {
-		const char *p = msg->service;
+		const gchar *p = msg->service;
 
 		while (*p) {
 			if (*p < '0' || *p > '9')
@@ -579,7 +578,7 @@ cs_getaddrinfo(void *data)
 		}
 
 		if (*p) {
-			const char *socktype = NULL;
+			const gchar *socktype = NULL;
 			struct servent *serv;
 
 			if (msg->hints && msg->hints->ai_socktype) {
@@ -636,25 +635,34 @@ cancel:
 	return NULL;
 }
 #else
-static void *
-cs_getaddrinfo(void *data)
+static gpointer
+cs_getaddrinfo(gpointer data)
 {
 	struct _addrinfo_msg *info = data;
 
 	info->result = getaddrinfo(info->name, info->service, info->hints, info->res);
-	
+
+	/* On Solaris, the service name 'http' or 'https' is not defined.
+	   Use the port as the service name directly. */
+	if (info->result && info->service) {
+		if (strcmp (info->service, "http") == 0)
+			info->result = getaddrinfo(info->name, "80", info->hints, info->res);
+		else if (strcmp (info->service, "https") == 0)
+			info->result = getaddrinfo(info->name, "443", info->hints, info->res);
+	}
+
 	if (info->cancelled) {
 		cs_freeinfo(info);
 	} else {
 		camel_msgport_reply((CamelMsg *)info);
 	}
-	
+
 	return NULL;
 }
 #endif /* NEED_ADDRINFO */
 
 struct addrinfo *
-camel_getaddrinfo(const char *name, const char *service, const struct addrinfo *hints, CamelException *ex)
+camel_getaddrinfo(const gchar *name, const gchar *service, const struct addrinfo *hints, CamelException *ex)
 {
 	struct _addrinfo_msg *msg;
 	struct addrinfo *res = NULL;
@@ -662,7 +670,7 @@ camel_getaddrinfo(const char *name, const char *service, const struct addrinfo *
 	struct addrinfo myhints;
 #endif
 	g_return_val_if_fail(name != NULL, NULL);
-	
+
 	if (camel_operation_cancel_check(NULL)) {
 		camel_exception_set(ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
 		return NULL;
@@ -676,7 +684,7 @@ camel_getaddrinfo(const char *name, const char *service, const struct addrinfo *
 		memset(&myhints, 0, sizeof(myhints));
 	else
 		memcpy (&myhints, hints, sizeof (myhints));
-	
+
 	myhints.ai_family = AF_INET;
 	hints = &myhints;
 #endif
@@ -723,11 +731,11 @@ camel_freeaddrinfo(struct addrinfo *host)
 }
 
 #ifdef NEED_ADDRINFO
-static void *
-cs_getnameinfo(void *data)
+static gpointer
+cs_getnameinfo(gpointer data)
 {
 	struct _addrinfo_msg *msg = data;
-	int herr;
+	gint herr;
 	struct hostent h;
 	struct sockaddr_in *sin = (struct sockaddr_in *)msg->addr;
 
@@ -739,13 +747,13 @@ cs_getnameinfo(void *data)
 
 	/* FIXME: honour getnameinfo flags: do we care, not really */
 
-	while ((msg->result = camel_gethostbyaddr_r((const char *)&sin->sin_addr, sizeof(sin->sin_addr), AF_INET, &h,
+	while ((msg->result = camel_gethostbyaddr_r((const gchar *)&sin->sin_addr, sizeof(sin->sin_addr), AF_INET, &h,
 						    msg->hostbufmem, msg->hostbuflen, &herr)) == ERANGE) {
 		pthread_testcancel ();
                 msg->hostbuflen *= 2;
                 msg->hostbufmem = g_realloc(msg->hostbufmem, msg->hostbuflen);
 	}
-	
+
 	if (msg->cancelled)
 		goto cancel;
 
@@ -754,8 +762,8 @@ cs_getnameinfo(void *data)
 		if (msg->result == 0 && h.h_name && h.h_name[0]) {
 			msg->host = g_strdup(h.h_name);
 		} else {
-			unsigned char *in = (unsigned char *)&sin->sin_addr;
-			
+			guchar *in = (guchar *)&sin->sin_addr;
+
 			/* sin_addr is always network order which is big-endian */
 			msg->host = g_strdup_printf("%u.%u.%u.%u", in[0], in[1], in[2], in[3]);
 		}
@@ -772,14 +780,14 @@ cancel:
 	return NULL;
 }
 #else
-static void *
-cs_getnameinfo(void *data)
+static gpointer
+cs_getnameinfo(gpointer data)
 {
 	struct _addrinfo_msg *msg = data;
 
 	/* there doens't appear to be a return code which says host or serv buffers are too short, lengthen them */
 	msg->result = getnameinfo(msg->addr, msg->addrlen, msg->host, msg->hostlen, msg->serv, msg->servlen, msg->flags);
-	
+
 	if (msg->cancelled)
 		cs_freeinfo(msg);
 	else
@@ -789,11 +797,11 @@ cs_getnameinfo(void *data)
 }
 #endif
 
-int
-camel_getnameinfo(const struct sockaddr *sa, socklen_t salen, char **host, char **serv, int flags, CamelException *ex)
+gint
+camel_getnameinfo(const struct sockaddr *sa, socklen_t salen, gchar **host, gchar **serv, gint flags, CamelException *ex)
 {
 	struct _addrinfo_msg *msg;
-	int result;
+	gint result;
 
 	if (camel_operation_cancel_check(NULL)) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
