@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001-2003 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -96,10 +96,10 @@ camel_sasl_anonymous_get_type (void)
  *
  * Create a new #CamelSaslAnonymous object.
  *
- * Returns a new #CamelSasl object
+ * Returns: a new #CamelSasl object
  **/
 CamelSasl *
-camel_sasl_anonymous_new (CamelSaslAnonTraceType type, const char *trace_info)
+camel_sasl_anonymous_new (CamelSaslAnonTraceType type, const gchar *trace_info)
 {
 	CamelSaslAnonymous *sasl_anon;
 
