@@ -60,7 +60,7 @@ typedef struct {
 	off_t (*seek)       (CamelSeekableStream *stream, off_t offset,
 			     CamelStreamSeekPolicy policy);
 	off_t (*tell)	    (CamelSeekableStream *stream);
-	int  (*set_bounds)  (CamelSeekableStream *stream,
+	gint  (*set_bounds)  (CamelSeekableStream *stream,
 			     off_t start, off_t end);
 } CamelSeekableStreamClass;
 
@@ -70,8 +70,8 @@ CamelType camel_seekable_stream_get_type (void);
 /* public methods */
 off_t    camel_seekable_stream_seek            (CamelSeekableStream *stream, off_t offset,
 						CamelStreamSeekPolicy policy);
-off_t	 camel_seekable_stream_tell    	       (CamelSeekableStream *stream);
-int	 camel_seekable_stream_set_bounds      (CamelSeekableStream *stream, off_t start, off_t end);
+off_t	 camel_seekable_stream_tell	       (CamelSeekableStream *stream);
+gint	 camel_seekable_stream_set_bounds      (CamelSeekableStream *stream, off_t start, off_t end);
 
 G_END_DECLS
 
