@@ -48,24 +48,27 @@
 #include "camel-string-utils.h"
 #include "camel-transport.h"
 #include "camel-url.h"
+#include "camel-folder.h"
+#include "camel-mime-message.h"
 
 #define d(x)
 
 #define CS_CLASS(so) ((CamelSessionClass *)((CamelObject *)so)->klass)
 
 static CamelService *get_service (CamelSession *session,
-				  const char *url_string,
+				  const gchar *url_string,
 				  CamelProviderType type,
 				  CamelException *ex);
-static char *get_storage_path (CamelSession *session,
+static gchar *get_storage_path (CamelSession *session,
 			       CamelService *service,
 			       CamelException *ex);
 
-static void *session_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, unsigned int size);
+static gpointer session_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, guint size);
 static void session_thread_msg_free(CamelSession *session, CamelSessionThreadMsg *msg);
-static int session_thread_queue(CamelSession *session, CamelSessionThreadMsg *msg, int flags);
-static void session_thread_wait(CamelSession *session, int id);
-static void session_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const char *text, int pc);
+static gint session_thread_queue(CamelSession *session, CamelSessionThreadMsg *msg, gint flags);
+static void session_thread_wait(CamelSession *session, gint id);
+static void session_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const gchar *text, gint pc);
+static void session_forward_to (CamelSession *session, CamelFolder *folder, CamelMimeMessage *message, const gchar *address, CamelException *ex);
 
 static void
 camel_session_init (CamelSession *session)
@@ -73,7 +76,7 @@ camel_session_init (CamelSession *session)
 	session->online = TRUE;
 	session->network_state = TRUE;
 	session->priv = g_malloc0(sizeof(*session->priv));
-	
+
 	session->priv->lock = g_mutex_new();
 	session->priv->thread_lock = g_mutex_new();
 	session->priv->thread_id = 1;
@@ -87,7 +90,7 @@ camel_session_finalise (CamelObject *o)
 {
 	CamelSession *session = (CamelSession *)o;
 	GThreadPool *thread_pool = session->priv->thread_pool;
-	
+
 	g_hash_table_destroy(session->priv->thread_active);
 
 	if (thread_pool != NULL) {
@@ -113,13 +116,15 @@ camel_session_class_init (CamelSessionClass *camel_session_class)
 	/* virtual method definition */
 	camel_session_class->get_service = get_service;
 	camel_session_class->get_storage_path = get_storage_path;
-	
+
 	camel_session_class->thread_msg_new = session_thread_msg_new;
 	camel_session_class->thread_msg_free = session_thread_msg_free;
 	camel_session_class->thread_queue = session_thread_queue;
 	camel_session_class->thread_wait = session_thread_wait;
 	camel_session_class->thread_status = session_thread_status;
 
+	camel_session_class->forward_to = session_forward_to;
+
 	camel_object_class_add_event((CamelObjectClass *)camel_session_class, "online", NULL);
 }
 
@@ -151,20 +156,20 @@ camel_session_get_type (void)
  * Constructs @session.
  **/
 void
-camel_session_construct (CamelSession *session, const char *storage_path)
+camel_session_construct (CamelSession *session, const gchar *storage_path)
 {
 	session->storage_path = g_strdup (storage_path);
 }
 
 static CamelService *
-get_service (CamelSession *session, const char *url_string,
+get_service (CamelSession *session, const gchar *url_string,
 	     CamelProviderType type, CamelException *ex)
 {
 	CamelURL *url;
 	CamelProvider *provider;
 	CamelService *service;
 	CamelException internal_ex;
-	
+
 	url = camel_url_new (url_string, ex);
 	if (!url)
 		return NULL;
@@ -178,7 +183,7 @@ get_service (CamelSession *session, const char *url_string,
 				      url->protocol);
 		provider = NULL;
 	}
-	
+
 	if (!provider) {
 		camel_url_free (url);
 		return NULL;
@@ -189,7 +194,7 @@ get_service (CamelSession *session, const char *url_string,
 	 */
 	if (url->path && !CAMEL_PROVIDER_ALLOWS (provider, CAMEL_URL_PART_PATH))
 		camel_url_set_path (url, NULL);
-	
+
 	/* Now look up the service in the provider's cache */
 	service = camel_object_bag_reserve(provider->service_cache[type], url);
 	if (service == NULL) {
@@ -231,7 +236,7 @@ get_service (CamelSession *session, const char *url_string,
  * Returns: the requested #CamelService, or %NULL
  **/
 CamelService *
-camel_session_get_service (CamelSession *session, const char *url_string,
+camel_session_get_service (CamelSession *session, const gchar *url_string,
 			   CamelProviderType type, CamelException *ex)
 {
 	CamelService *service;
@@ -261,7 +266,7 @@ camel_session_get_service (CamelSession *session, const char *url_string,
  **/
 CamelService *
 camel_session_get_service_connected (CamelSession *session,
-				     const char *url_string,
+				     const gchar *url_string,
 				     CamelProviderType type,
 				     CamelException *ex)
 {
@@ -282,16 +287,16 @@ camel_session_get_service_connected (CamelSession *session,
 }
 
 
-static char *
+static gchar *
 get_storage_path (CamelSession *session, CamelService *service, CamelException *ex)
 {
-	char *path, *p;
+	gchar *path, *p;
 
 	p = camel_service_get_path (service);
 	path = g_strdup_printf ("%s/%s", session->storage_path, p);
 	g_free (p);
 
-#ifdef G_OS_WIN32 
+#ifdef G_OS_WIN32
 	if (g_access (path, F_OK) == 0)
 #else
 	if (access (path, F_OK) == 0)
@@ -324,7 +329,7 @@ get_storage_path (CamelSession *session, CamelService *service, CamelException *
  * Returns: the path (which the caller must free), or %NULL if an error
  * occurs.
  **/
-char *
+gchar *
 camel_session_get_storage_path (CamelSession *session, CamelService *service,
 				CamelException *ex)
 {
@@ -360,23 +365,23 @@ camel_session_get_storage_path (CamelSession *session, CamelService *service,
  * If #CAMEL_SESSION_PASSWORD_STATIC is set, it means the password returned
  * will be stored statically by the caller automatically, for the current
  * session.
- * 
+ *
  * The authenticator should set @ex to #CAMEL_EXCEPTION_USER_CANCEL if
  * the user did not provide the information. The caller must #g_free
  * the information returned when it is done with it.
  *
  * Returns: the authentication information or %NULL
  **/
-char *
+gchar *
 camel_session_get_password (CamelSession *session, CamelService *service,
-			    const char *domain, const char *prompt, const char *item,
+			    const gchar *domain, const gchar *prompt, const gchar *item,
 			    guint32 flags,
 			    CamelException *ex)
 {
 	g_return_val_if_fail (CAMEL_IS_SESSION (session), NULL);
 	g_return_val_if_fail (prompt != NULL, NULL);
 	g_return_val_if_fail (item != NULL, NULL);
-	
+
 	return CS_CLASS (session)->get_password (session, service, domain, prompt, item, flags, ex);
 }
 
@@ -399,7 +404,7 @@ camel_session_get_password (CamelSession *session, CamelService *service,
  **/
 void
 camel_session_forget_password (CamelSession *session, CamelService *service,
-			       const char *domain, const char *item, CamelException *ex)
+			       const gchar *domain, const gchar *item, CamelException *ex)
 {
 	g_return_if_fail (CAMEL_IS_SESSION (session));
 	g_return_if_fail (item != NULL);
@@ -424,7 +429,7 @@ camel_session_forget_password (CamelSession *session, CamelService *service,
  */
 gboolean
 camel_session_alert_user (CamelSession *session, CamelSessionAlertType type,
-			  const char *prompt, gboolean cancel)
+			  const gchar *prompt, gboolean cancel)
 {
 	g_return_val_if_fail (CAMEL_IS_SESSION (session), FALSE);
 	g_return_val_if_fail (prompt != NULL, FALSE);
@@ -433,7 +438,7 @@ camel_session_alert_user (CamelSession *session, CamelSessionAlertType type,
 }
 
 gboolean
-camel_session_lookup_addressbook (CamelSession *session, const char *name)
+camel_session_lookup_addressbook (CamelSession *session, const gchar *name)
 {
 	g_return_val_if_fail (CAMEL_IS_SESSION (session), FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
@@ -452,14 +457,14 @@ camel_session_lookup_addressbook (CamelSession *session, const char *name)
  *
  * Returns: a newly-allocated password prompt string
  **/
-char *
-camel_session_build_password_prompt (const char *type,
-                                     const char *user,
-                                     const char *host)
+gchar *
+camel_session_build_password_prompt (const gchar *type,
+                                     const gchar *user,
+                                     const gchar *host)
 {
-	char *user_markup;
-	char *host_markup;
-	char *prompt;
+	gchar *user_markup;
+	gchar *host_markup;
+	gchar *prompt;
 
 	g_return_val_if_fail (type != NULL, NULL);
 	g_return_val_if_fail (user != NULL, NULL);
@@ -522,24 +527,24 @@ camel_session_set_online (CamelSession *session, gboolean online)
  **/
 CamelFilterDriver *
 camel_session_get_filter_driver (CamelSession *session,
-				 const char *type,
+				 const gchar *type,
 				 CamelException *ex)
 {
 	return CS_CLASS (session)->get_filter_driver (session, type, ex);
 }
 
 static void
-cs_thread_status(CamelOperation *op, const char *what, int pc, void *data)
+cs_thread_status(CamelOperation *op, const gchar *what, gint pc, gpointer data)
 {
 	CamelSessionThreadMsg *m = data;
 
 	CS_CLASS(m->session)->thread_status(m->session, m, what, pc);
 }
 
-static void *
+static gpointer
 session_thread_msg_new (CamelSession *session,
                         CamelSessionThreadOps *ops,
-                        unsigned int size)
+                        guint size)
 {
 	CamelSessionThreadMsg *m;
 
@@ -571,7 +576,7 @@ session_thread_msg_free (CamelSession *session,
 	CAMEL_SESSION_UNLOCK(session, thread_lock);
 
 	d(printf("free msg, ops->free = %p\n", msg->ops->free));
-	
+
 	if (msg->ops->free)
 		msg->ops->free(session, msg);
 	if (msg->op)
@@ -596,13 +601,13 @@ session_thread_proxy (CamelSessionThreadMsg *msg,
 	camel_session_thread_msg_free(session, msg);
 }
 
-static int
+static gint
 session_thread_queue (CamelSession *session,
                       CamelSessionThreadMsg *msg,
-                      int flags)
+                      gint flags)
 {
 	GThreadPool *thread_pool;
-	int id;
+	gint id;
 
 	CAMEL_SESSION_LOCK(session, thread_lock);
 	thread_pool = session->priv->thread_pool;
@@ -622,9 +627,9 @@ session_thread_queue (CamelSession *session,
 
 static void
 session_thread_wait (CamelSession *session,
-                     int id)
+                     gint id)
 {
-	int wait;
+	gint wait;
 
 	/* we just busy wait, only other alternative is to setup a reply port? */
 	do {
@@ -640,8 +645,8 @@ session_thread_wait (CamelSession *session,
 static void
 session_thread_status (CamelSession *session,
                        CamelSessionThreadMsg *msg,
-                       const char *text,
-                       int pc)
+                       const gchar *text,
+                       gint pc)
 {
 }
 
@@ -650,7 +655,7 @@ session_thread_status (CamelSession *session,
  * @session: a #CamelSession object
  * @ops: thread operations
  * @size: number of bytes
- * 
+ *
  * Create a new thread message, using ops as the receive/reply/free
  * ops, of @size bytes.
  *
@@ -659,10 +664,10 @@ session_thread_status (CamelSession *session,
  *
  * Returns: a new #CamelSessionThreadMsg
  **/
-void *
+gpointer
 camel_session_thread_msg_new (CamelSession *session,
                               CamelSessionThreadOps *ops,
-                              unsigned int size)
+                              guint size)
 {
 	g_return_val_if_fail (CAMEL_IS_SESSION (session), NULL);
 	g_return_val_if_fail (ops != NULL, NULL);
@@ -675,7 +680,7 @@ camel_session_thread_msg_new (CamelSession *session,
  * camel_session_thread_msg_free:
  * @session: a #CamelSession object
  * @msg: a #CamelSessionThreadMsg
- * 
+ *
  * Free a @msg.  Note that the message must have been allocated using
  * msg_new, and must nto have been submitted to any queue function.
  **/
@@ -694,17 +699,17 @@ camel_session_thread_msg_free (CamelSession *session,
  * @session: a #CamelSession object
  * @msg: a #CamelSessionThreadMsg
  * @flags: queue type flags, currently 0.
- * 
+ *
  * Queue a thread message in another thread for processing.
  * The operation should be (but needn't) run in a queued manner
  * with other operations queued in this manner.
- * 
+ *
  * Returns: the id of the operation queued
  **/
-int
+gint
 camel_session_thread_queue (CamelSession *session,
                             CamelSessionThreadMsg *msg,
-                            int flags)
+                            gint flags)
 {
 	g_return_val_if_fail (CAMEL_IS_SESSION (session), -1);
 	g_return_val_if_fail (msg != NULL, -1);
@@ -721,7 +726,7 @@ camel_session_thread_queue (CamelSession *session,
  **/
 void
 camel_session_thread_wait (CamelSession *session,
-                           int id)
+                           gint id)
 {
 	g_return_if_fail (CAMEL_IS_SESSION (session));
 
@@ -734,7 +739,7 @@ camel_session_thread_wait (CamelSession *session,
 /**
  * camel_session_check_junk:
  * @session: a #CamelSession object
- * 
+ *
  * Do we have to check incoming messages to be junk?
  *
  * Returns: whether or not we are checking incoming messages for junk
@@ -751,7 +756,7 @@ camel_session_check_junk (CamelSession *session)
  * camel_session_set_check_junk:
  * @session: a #CamelSession object
  * @check_junk: state
- * 
+ *
  * Set check_junk flag, if set, incoming mail will be checked for being junk.
  **/
 void
@@ -782,11 +787,11 @@ camel_session_set_network_state (CamelSession *session,
 
 void
 camel_session_set_junk_headers (CamelSession *session,
-                                const char **headers,
-                                const char **values,
-                                int len)
+                                const gchar **headers,
+                                const gchar **values,
+                                gint len)
 {
-	int i;
+	gint i;
 
 	g_return_if_fail (CAMEL_IS_SESSION (session));
 
@@ -809,3 +814,27 @@ camel_session_get_junk_headers (CamelSession *session)
 
 	return session->priv->junk_headers;
 }
+
+static void
+session_forward_to (CamelSession *session, CamelFolder *folder, CamelMimeMessage *message, const gchar *address, CamelException *ex)
+{
+	if (ex)
+		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("Camel session doesn't support forwarding of a message."));
+}
+
+/**
+ * camel_session_forward_to:
+ * Forwards message to some address(es) in a given type. The meaning of the forward_type defines session itself.
+ * @session #CameSession.
+ * @folder #CamelFolder where is @message located.
+ * @message Message to forward.
+ * @address Where forward to.
+ * @ex Exception.
+ **/
+void
+camel_session_forward_to (CamelSession *session, CamelFolder *folder, CamelMimeMessage *message, const gchar *address, CamelException *ex)
+{
+	g_return_if_fail (CAMEL_IS_SESSION (session));
+
+	CS_CLASS (session)->forward_to (session, folder, message, address, ex);
+}
