@@ -6,7 +6,7 @@
  * Author :
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -27,12 +27,11 @@
 #ifndef CAMEL_SESSION_H
 #define CAMEL_SESSION_H 1
 
+#include <camel/camel-msgport.h>
 #include <camel/camel-object.h>
 #include <camel/camel-provider.h>
 #include <camel/camel-junk-plugin.h>
 
-#include <libedataserver/e-msgport.h>
-
 #define CAMEL_SESSION_TYPE     (camel_session_get_type ())
 #define CAMEL_SESSION(obj)     (CAMEL_CHECK_CAST((obj), CAMEL_SESSION_TYPE, CamelSession))
 #define CAMEL_SESSION_CLASS(k) (CAMEL_CHECK_CLASS_CAST ((k), CAMEL_SESSION_TYPE, CamelSessionClass))
@@ -59,7 +58,7 @@ struct _CamelSession
 	CamelObject parent_object;
 	struct _CamelSessionPrivate *priv;
 
-	char *storage_path;
+	gchar *storage_path;
 	CamelJunkPlugin *junk_plugin;
 
 	guint online:1;
@@ -74,41 +73,56 @@ typedef struct {
 	CamelObjectClass parent_class;
 
 	CamelService *  (*get_service)       (CamelSession *session,
-					      const char *url_string,
+					      const gchar *url_string,
 					      CamelProviderType type,
 					      CamelException *ex);
-	char *          (*get_storage_path)  (CamelSession *session,
+	gchar *          (*get_storage_path)  (CamelSession *session,
 					      CamelService *service,
 					      CamelException *ex);
 
-	char *          (*get_password)      (CamelSession *session,
+	gchar *          (*get_password)      (CamelSession *session,
 					      CamelService *service,
-					      const char *domain,
-					      const char *prompt,
-					      const char *item,
+					      const gchar *domain,
+					      const gchar *prompt,
+					      const gchar *item,
 					      guint32 flags,
 					      CamelException *ex);
 	void            (*forget_password)   (CamelSession *session,
 					      CamelService *service,
-					      const char *domain,
-					      const char *item,
+					      const gchar *domain,
+					      const gchar *item,
 					      CamelException *ex);
 	gboolean        (*alert_user)        (CamelSession *session,
 					      CamelSessionAlertType type,
-					      const char *prompt,
+					      const gchar *prompt,
 					      gboolean cancel);
 
 	CamelFilterDriver * (*get_filter_driver) (CamelSession *session,
-						  const char *type,
+						  const gchar *type,
 						  CamelException *ex);
 
 	/* mechanism for creating and maintaining multiple threads of control */
-	void *(*thread_msg_new)(CamelSession *session, CamelSessionThreadOps *ops, unsigned int size);
-	void (*thread_msg_free)(CamelSession *session, CamelSessionThreadMsg *msg);
-	int (*thread_queue)(CamelSession *session, CamelSessionThreadMsg *msg, int flags);
-	void (*thread_wait)(CamelSession *session, int id);
-	void (*thread_status)(CamelSession *session, CamelSessionThreadMsg *msg, const char *text, int pc);
-	gboolean (*lookup_addressbook) (CamelSession *session, const char *name);
+	gpointer           (*thread_msg_new)    (CamelSession *session,
+					      CamelSessionThreadOps *ops,
+					      guint size);
+	void            (*thread_msg_free)   (CamelSession *session,
+					      CamelSessionThreadMsg *msg);
+	gint             (*thread_queue)      (CamelSession *session,
+					      CamelSessionThreadMsg *msg,
+					      gint flags);
+	void            (*thread_wait)       (CamelSession *session,
+					      gint id);
+	void            (*thread_status)     (CamelSession *session,
+					      CamelSessionThreadMsg *msg,
+					      const gchar *text,
+					      gint pc);
+	gboolean        (*lookup_addressbook)(CamelSession *session,
+					      const gchar *name);
+	void		(*forward_to)        (CamelSession *session,
+					      struct _CamelFolder *folder,
+					      struct _CamelMimeMessage *message,
+					      const gchar *address,
+					      CamelException *ex);
 } CamelSessionClass;
 
 
@@ -119,59 +133,61 @@ CamelType camel_session_get_type (void);
 
 
 void            camel_session_construct             (CamelSession *session,
-						     const char *storage_path);
+						     const gchar *storage_path);
 
 CamelService *  camel_session_get_service           (CamelSession *session,
-						     const char *url_string,
+						     const gchar *url_string,
 						     CamelProviderType type,
 						     CamelException *ex);
 CamelService *  camel_session_get_service_connected (CamelSession *session,
-						     const char *url_string,
+						     const gchar *url_string,
 						     CamelProviderType type,
 						     CamelException *ex);
 
 #define camel_session_get_store(session, url_string, ex) \
-	((CamelStore *) camel_session_get_service_connected (session, url_string, CAMEL_PROVIDER_STORE, ex))
+	((CamelStore *) camel_session_get_service_connected \
+	(session, url_string, CAMEL_PROVIDER_STORE, ex))
 #define camel_session_get_transport(session, url_string, ex) \
-	((CamelTransport *) camel_session_get_service_connected (session, url_string, CAMEL_PROVIDER_TRANSPORT, ex))
+	((CamelTransport *) camel_session_get_service_connected \
+	(session, url_string, CAMEL_PROVIDER_TRANSPORT, ex))
 
-char *             camel_session_get_storage_path   (CamelSession *session,
+gchar *             camel_session_get_storage_path   (CamelSession *session,
 						     CamelService *service,
 						     CamelException *ex);
 
-char *             camel_session_get_password       (CamelSession *session,
+gchar *             camel_session_get_password       (CamelSession *session,
 						     CamelService *service,
-						     const char *domain,
-						     const char *prompt,
-						     const char *item,
+						     const gchar *domain,
+						     const gchar *prompt,
+						     const gchar *item,
 						     guint32 flags,
 						     CamelException *ex);
 void               camel_session_forget_password    (CamelSession *session,
 						     CamelService *service,
-						     const char *domain,
-						     const char *item,
+						     const gchar *domain,
+						     const gchar *item,
 						     CamelException *ex);
 gboolean           camel_session_alert_user         (CamelSession *session,
 						     CamelSessionAlertType type,
-						     const char *prompt,
+						     const gchar *prompt,
 						     gboolean cancel);
 
-char *		   camel_session_build_password_prompt
-						    (const char *type,
-						     const char *user,
-						     const char *host);
+gchar *             camel_session_build_password_prompt
+						    (const gchar *type,
+						     const gchar *user,
+						     const gchar *host);
 
 gboolean           camel_session_is_online          (CamelSession *session);
 void               camel_session_set_online         (CamelSession *session,
 						     gboolean online);
 
 CamelFilterDriver *camel_session_get_filter_driver  (CamelSession *session,
-						     const char *type,
+						     const gchar *type,
 						     CamelException *ex);
 
-gboolean  camel_session_check_junk               (CamelSession *session);
-void      camel_session_set_check_junk           (CamelSession *session,
-						  gboolean      check_junk);
+gboolean           camel_session_check_junk         (CamelSession *session);
+void               camel_session_set_check_junk     (CamelSession *session,
+						     gboolean check_junk);
 
 struct _CamelSessionThreadOps {
 	void (*receive)(CamelSession *session, struct _CamelSessionThreadMsg *m);
@@ -179,28 +195,45 @@ struct _CamelSessionThreadOps {
 };
 
 struct _CamelSessionThreadMsg {
-	EMsg msg;
+	CamelMsg msg;
 
-	int id;
+	gint id;
 
 	CamelException ex;
 	CamelSessionThreadOps *ops;
 	struct _CamelOperation *op;
 	CamelSession *session;
 
-	void *data; /* free for implementation to define, not used by camel, do not use in client code */
+	gpointer data; /* free for implementation to define, not used by camel, do not use in client code */
 	/* user fields follow */
 };
 
-void *camel_session_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, unsigned int size);
-void camel_session_thread_msg_free(CamelSession *session, CamelSessionThreadMsg *msg);
-int camel_session_thread_queue(CamelSession *session, CamelSessionThreadMsg *msg, int flags);
-void camel_session_thread_wait(CamelSession *session, int id);
-gboolean camel_session_get_network_state (CamelSession *session);
-void camel_session_set_network_state (CamelSession *session, gboolean network_state);
-const GHashTable * camel_session_get_junk_headers (CamelSession *session);
-void camel_session_set_junk_headers (CamelSession *session, const char **headers, const char **values, int len);
-gboolean camel_session_lookup_addressbook (CamelSession *session, const char *name);
+gpointer              camel_session_thread_msg_new     (CamelSession *session,
+						     CamelSessionThreadOps *ops,
+						     guint size);
+void               camel_session_thread_msg_free    (CamelSession *session,
+						     CamelSessionThreadMsg *msg);
+gint                camel_session_thread_queue       (CamelSession *session,
+						     CamelSessionThreadMsg *msg,
+						     gint flags);
+void               camel_session_thread_wait        (CamelSession *session,
+						     gint id);
+gboolean           camel_session_get_network_state  (CamelSession *session);
+void               camel_session_set_network_state  (CamelSession *session,
+						     gboolean network_state);
+const GHashTable * camel_session_get_junk_headers   (CamelSession *session);
+void               camel_session_set_junk_headers   (CamelSession *session,
+						     const gchar **headers,
+						     const gchar **values,
+						     gint len);
+gboolean           camel_session_lookup_addressbook (CamelSession *session,
+						     const gchar *name);
+
+void		   camel_session_forward_to         (CamelSession *session,
+						     struct _CamelFolder *folder,
+						     struct _CamelMimeMessage *message,
+						     const gchar *address,
+						     CamelException *ex);
 
 G_END_DECLS
 
