@@ -54,16 +54,16 @@
 
 #define _PRIVATE(o) (((CamelStoreSummary *)(o))->priv)
 
-static int summary_header_load(CamelStoreSummary *, FILE *);
-static int summary_header_save(CamelStoreSummary *, FILE *);
+static gint summary_header_load(CamelStoreSummary *, FILE *);
+static gint summary_header_save(CamelStoreSummary *, FILE *);
 
-static CamelStoreInfo * store_info_new(CamelStoreSummary *, const char *);
+static CamelStoreInfo * store_info_new(CamelStoreSummary *, const gchar *);
 static CamelStoreInfo * store_info_load(CamelStoreSummary *, FILE *);
-static int		 store_info_save(CamelStoreSummary *, FILE *, CamelStoreInfo *);
+static gint		 store_info_save(CamelStoreSummary *, FILE *, CamelStoreInfo *);
 static void		 store_info_free(CamelStoreSummary *, CamelStoreInfo *);
 
-static const char *store_info_string(CamelStoreSummary *, const CamelStoreInfo *, int);
-static void store_info_set_string(CamelStoreSummary *, CamelStoreInfo *, int, const char *);
+static const gchar *store_info_string(CamelStoreSummary *, const CamelStoreInfo *, gint);
+static void store_info_set_string(CamelStoreSummary *, CamelStoreInfo *, int, const gchar *);
 
 static void camel_store_summary_class_init (CamelStoreSummaryClass *klass);
 static void camel_store_summary_init       (CamelStoreSummary *obj);
@@ -106,7 +106,7 @@ camel_store_summary_init (CamelStoreSummary *s)
 
 	s->folders = g_ptr_array_new();
 	s->folders_path = g_hash_table_new(g_str_hash, g_str_equal);
-	
+
 	p->summary_lock = g_mutex_new();
 	p->io_lock = g_mutex_new();
 	p->alloc_lock = g_mutex_new();
@@ -129,12 +129,12 @@ camel_store_summary_finalise (CamelObject *obj)
 
 	if (s->store_info_chunks)
 		e_memchunk_destroy(s->store_info_chunks);
-	
+
 	g_mutex_free(p->summary_lock);
 	g_mutex_free(p->io_lock);
 	g_mutex_free(p->alloc_lock);
 	g_mutex_free(p->ref_lock);
-	
+
 	g_free(p);
 }
 
@@ -142,7 +142,7 @@ CamelType
 camel_store_summary_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_object_get_type (), "CamelStoreSummary",
 					    sizeof (CamelStoreSummary),
@@ -152,7 +152,7 @@ camel_store_summary_get_type (void)
 					    (CamelObjectInitFunc) camel_store_summary_init,
 					    (CamelObjectFinalizeFunc) camel_store_summary_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -161,7 +161,7 @@ camel_store_summary_get_type (void)
  * camel_store_summary_new:
  *
  * Create a new #CamelStoreSummary object.
- * 
+ *
  * Returns: a new #CamelStoreSummary object
  **/
 CamelStoreSummary *
@@ -175,11 +175,11 @@ camel_store_summary_new (void)
  * camel_store_summary_set_filename:
  * @summary: a #CamelStoreSummary
  * @filename: a filename
- * 
+ *
  * Set the filename where the summary will be loaded to/saved from.
  **/
 void
-camel_store_summary_set_filename(CamelStoreSummary *s, const char *name)
+camel_store_summary_set_filename(CamelStoreSummary *s, const gchar *name)
 {
 	CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
 
@@ -213,12 +213,12 @@ camel_store_summary_set_uri_base(CamelStoreSummary *s, CamelURL *base)
 /**
  * camel_store_summary_count:
  * @summary: a #CamelStoreSummary object
- * 
+ *
  * Get the number of summary items stored in this summary.
- * 
- * Returns: the number of items int he summary.
+ *
+ * Returns: the number of items gint he summary.
  **/
-int
+gint
 camel_store_summary_count(CamelStoreSummary *s)
 {
 	return s->folders->len;
@@ -229,18 +229,18 @@ camel_store_summary_count(CamelStoreSummary *s)
  * camel_store_summary_index:
  * @summary: a #CamelStoreSummary object
  * @index: record index
- * 
+ *
  * Retrieve a summary item by index number.
  *
  * A referenced to the summary item is returned, which may be ref'd or
  * free'd as appropriate.
  *
  * It must be freed using #camel_store_summary_info_free.
- * 
+ *
  * Returns: the summary item, or %NULL if @index is out of range
  **/
 CamelStoreInfo *
-camel_store_summary_index(CamelStoreSummary *s, int i)
+camel_store_summary_index(CamelStoreSummary *s, gint i)
 {
 	CamelStoreInfo *info = NULL;
 
@@ -264,7 +264,7 @@ camel_store_summary_index(CamelStoreSummary *s, int i)
 /**
  * camel_store_summary_array:
  * @summary: a #CamelStoreSummary object
- * 
+ *
  * Obtain a copy of the summary array.  This is done atomically,
  * so cannot contain empty entries.
  *
@@ -277,8 +277,8 @@ camel_store_summary_array(CamelStoreSummary *s)
 {
 	CamelStoreInfo *info;
 	GPtrArray *res = g_ptr_array_new();
-	int i;
-	
+	gint i;
+
 	CAMEL_STORE_SUMMARY_LOCK(s, ref_lock);
 	CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
 
@@ -299,13 +299,13 @@ camel_store_summary_array(CamelStoreSummary *s)
  * camel_store_summary_array_free:
  * @summary: a #CamelStoreSummary object
  * @array: the summary array as gotten from #camel_store_summary_array
- * 
+ *
  * Free the folder summary array.
  **/
 void
 camel_store_summary_array_free(CamelStoreSummary *s, GPtrArray *array)
 {
-	int i;
+	gint i;
 
 	for (i=0;i<array->len;i++)
 		camel_store_summary_info_free(s, array->pdata[i]);
@@ -318,7 +318,7 @@ camel_store_summary_array_free(CamelStoreSummary *s, GPtrArray *array)
  * camel_store_summary_path:
  * @summary: a #CamelStoreSummary object
  * @path: path to the item
- * 
+ *
  * Retrieve a summary item by path name.
  *
  * A referenced to the summary item is returned, which may be ref'd or
@@ -330,7 +330,7 @@ camel_store_summary_array_free(CamelStoreSummary *s, GPtrArray *array)
  * available
  **/
 CamelStoreInfo *
-camel_store_summary_path(CamelStoreSummary *s, const char *path)
+camel_store_summary_path(CamelStoreSummary *s, const gchar *path)
 {
 	CamelStoreInfo *info;
 
@@ -357,11 +357,11 @@ camel_store_summary_path(CamelStoreSummary *s, const char *path)
  *
  * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_store_summary_load(CamelStoreSummary *s)
 {
 	FILE *in;
-	int i;
+	gint i;
 	CamelStoreInfo *info;
 
 	g_assert(s->summary_path);
@@ -385,7 +385,7 @@ camel_store_summary_load(CamelStoreSummary *s)
 	}
 
 	CAMEL_STORE_SUMMARY_UNLOCK(s, io_lock);
-	
+
 	if (fclose (in) != 0)
 		return -1;
 
@@ -400,7 +400,7 @@ error:
 	fclose (in);
 	s->flags |= ~CAMEL_STORE_SUMMARY_DIRTY;
 	errno = i;
-	
+
 	return -1;
 }
 
@@ -408,18 +408,18 @@ error:
 /**
  * camel_store_summary_save:
  * @summary: a #CamelStoreSummary object
- * 
+ *
  * Writes the summary to disk.  The summary is only written if changes
  * have occured.
- * 
+ *
  * Returns: %0 on succes or %-1 on fail
  **/
-int
+gint
 camel_store_summary_save(CamelStoreSummary *s)
 {
 	FILE *out;
-	int fd;
-	int i;
+	gint fd;
+	gint i;
 	guint32 count;
 	CamelStoreInfo *info;
 
@@ -470,14 +470,14 @@ camel_store_summary_save(CamelStoreSummary *s)
 	}
 
 	CAMEL_STORE_SUMMARY_UNLOCK(s, io_lock);
-	
+
 	if (fflush (out) != 0 || fsync (fileno (out)) == -1) {
 		i = errno;
 		fclose (out);
 		errno = i;
 		return -1;
 	}
-	
+
 	if (fclose (out) != 0)
 		return -1;
 
@@ -489,18 +489,18 @@ camel_store_summary_save(CamelStoreSummary *s)
 /**
  * camel_store_summary_header_load:
  * @summary: a #CamelStoreSummary object
- * 
+ *
  * Only load the header information from the summary,
  * keep the rest on disk.  This should only be done on
  * a fresh summary object.
- * 
+ *
  * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_store_summary_header_load(CamelStoreSummary *s)
 {
 	FILE *in;
-	int ret;
+	gint ret;
 
 	g_assert(s->summary_path);
 
@@ -511,7 +511,7 @@ camel_store_summary_header_load(CamelStoreSummary *s)
 	CAMEL_STORE_SUMMARY_LOCK(s, io_lock);
 	ret = ((CamelStoreSummaryClass *)(CAMEL_OBJECT_GET_CLASS(s)))->summary_header_load(s, in);
 	CAMEL_STORE_SUMMARY_UNLOCK(s, io_lock);
-	
+
 	fclose(in);
 	s->flags &= ~CAMEL_STORE_SUMMARY_DIRTY;
 	return ret;
@@ -522,7 +522,7 @@ camel_store_summary_header_load(CamelStoreSummary *s)
  * camel_store_summary_add:
  * @summary: a #CamelStoreSummary object
  * @info: a #CamelStoreInfo
- * 
+ *
  * Adds a new @info record to the summary.  If @info->uid is %NULL,
  * then a new uid is automatically re-assigned by calling
  * #camel_store_summary_next_uid_string.
@@ -545,7 +545,7 @@ camel_store_summary_add(CamelStoreSummary *s, CamelStoreInfo *info)
 	CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
 
 	g_ptr_array_add(s->folders, info);
-	g_hash_table_insert(s->folders_path, (char *)camel_store_info_path(s, info), info);
+	g_hash_table_insert(s->folders_path, (gchar *)camel_store_info_path(s, info), info);
 	s->flags |= CAMEL_STORE_SUMMARY_DIRTY;
 
 	CAMEL_STORE_SUMMARY_UNLOCK(s, summary_lock);
@@ -556,13 +556,13 @@ camel_store_summary_add(CamelStoreSummary *s, CamelStoreInfo *info)
  * camel_store_summary_add_from_path:
  * @summary: a #CamelStoreSummary object
  * @path: item path
- * 
+ *
  * Build a new info record based on the name, and add it to the summary.
  *
  * Returns: the newly added record
  **/
 CamelStoreInfo *
-camel_store_summary_add_from_path(CamelStoreSummary *s, const char *path)
+camel_store_summary_add_from_path(CamelStoreSummary *s, const gchar *path)
 {
 	CamelStoreInfo *info;
 
@@ -575,7 +575,7 @@ camel_store_summary_add_from_path(CamelStoreSummary *s, const char *path)
 	} else {
 		info = camel_store_summary_info_new_from_path(s, path);
 		g_ptr_array_add(s->folders, info);
-		g_hash_table_insert(s->folders_path, (char *)camel_store_info_path(s, info), info);
+		g_hash_table_insert(s->folders_path, (gchar *)camel_store_info_path(s, info), info);
 		s->flags |= CAMEL_STORE_SUMMARY_DIRTY;
 	}
 
@@ -589,7 +589,7 @@ camel_store_summary_add_from_path(CamelStoreSummary *s, const char *path)
  * camel_store_summary_info_new_from_path:
  * @summary: a #CamelStoreSummary object
  * @path: item path
- * 
+ *
  * Create a new info record from a name.
  *
  * This info record MUST be freed using
@@ -599,7 +599,7 @@ camel_store_summary_add_from_path(CamelStoreSummary *s, const char *path)
  * Returns: the #CamelStoreInfo associated with @path
  **/
 CamelStoreInfo *
-camel_store_summary_info_new_from_path(CamelStoreSummary *s, const char *path)
+camel_store_summary_info_new_from_path(CamelStoreSummary *s, const gchar *path)
 {
 	return ((CamelStoreSummaryClass *)(CAMEL_OBJECT_GET_CLASS(s)))->store_info_new(s, path);
 }
@@ -609,7 +609,7 @@ camel_store_summary_info_new_from_path(CamelStoreSummary *s, const char *path)
  * camel_store_summary_info_free:
  * @summary: a #CamelStoreSummary object
  * @info: a #CamelStoreInfo
- * 
+ *
  * Unref and potentially free @info, and all associated memory.
  **/
 void
@@ -630,7 +630,7 @@ camel_store_summary_info_free(CamelStoreSummary *s, CamelStoreInfo *info)
 
 	CAMEL_STORE_SUMMARY_UNLOCK(s, ref_lock);
 
-	((CamelStoreSummaryClass *)(CAMEL_OBJECT_GET_CLASS(s)))->store_info_free(s, info);		
+	((CamelStoreSummaryClass *)(CAMEL_OBJECT_GET_CLASS(s)))->store_info_free(s, info);
 }
 
 
@@ -638,7 +638,7 @@ camel_store_summary_info_free(CamelStoreSummary *s, CamelStoreInfo *info)
  * camel_store_summary_info_ref:
  * @summary: a #CamelStoreSummary object
  * @info: a #CamelStoreInfo
- * 
+ *
  * Add an extra reference to @info.
  **/
 void
@@ -657,7 +657,7 @@ camel_store_summary_info_ref(CamelStoreSummary *s, CamelStoreInfo *info)
 /**
  * camel_store_summary_touch:
  * @summary: a #CamelStoreSummary object
- * 
+ *
  * Mark the summary as changed, so that a save will force it to be
  * written back to disk.
  **/
@@ -673,13 +673,13 @@ camel_store_summary_touch(CamelStoreSummary *s)
 /**
  * camel_store_summary_clear:
  * @summary: a #CamelStoreSummary object
- * 
+ *
  * Empty the summary contents.
  **/
 void
 camel_store_summary_clear(CamelStoreSummary *s)
 {
-	int i;
+	gint i;
 
 	CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
 	if (camel_store_summary_count(s) == 0) {
@@ -702,7 +702,7 @@ camel_store_summary_clear(CamelStoreSummary *s)
  * camel_store_summary_remove:
  * @summary: a #CamelStoreSummary object
  * @info: a #CamelStoreInfo
- * 
+ *
  * Remove a specific @info record from the summary.
  **/
 void
@@ -722,18 +722,18 @@ camel_store_summary_remove(CamelStoreSummary *s, CamelStoreInfo *info)
  * camel_store_summary_remove_path:
  * @summary: a #CamelStoreSummary object
  * @path: item path
- * 
+ *
  * Remove a specific info record from the summary, by @path.
  **/
 void
-camel_store_summary_remove_path(CamelStoreSummary *s, const char *path)
+camel_store_summary_remove_path(CamelStoreSummary *s, const gchar *path)
 {
         CamelStoreInfo *oldinfo;
-        char *oldpath;
+        gchar *oldpath;
 
 	CAMEL_STORE_SUMMARY_LOCK(s, ref_lock);
 	CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
-        if (g_hash_table_lookup_extended(s->folders_path, path, (void *)&oldpath, (void *)&oldinfo)) {
+        if (g_hash_table_lookup_extended(s->folders_path, path, (gpointer)&oldpath, (gpointer)&oldinfo)) {
 		/* make sure it doesn't vanish while we're removing it */
 		oldinfo->refcount++;
 		CAMEL_STORE_SUMMARY_UNLOCK(s, summary_lock);
@@ -751,11 +751,11 @@ camel_store_summary_remove_path(CamelStoreSummary *s, const char *path)
  * camel_store_summary_remove_index:
  * @summary: a #CamelStoreSummary object
  * @index: item index
- * 
+ *
  * Remove a specific info record from the summary, by index.
  **/
 void
-camel_store_summary_remove_index(CamelStoreSummary *s, int index)
+camel_store_summary_remove_index(CamelStoreSummary *s, gint index)
 {
 	CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
 	if (index < s->folders->len) {
@@ -772,7 +772,7 @@ camel_store_summary_remove_index(CamelStoreSummary *s, int index)
 	}
 }
 
-static int
+static gint
 summary_header_load(CamelStoreSummary *s, FILE *in)
 {
 	gint32 version, flags, count;
@@ -802,7 +802,7 @@ summary_header_load(CamelStoreSummary *s, FILE *in)
 	return 0;
 }
 
-static int
+static gint
 summary_header_save(CamelStoreSummary *s, FILE *out)
 {
 	fseek(out, 0, SEEK_SET);
@@ -820,10 +820,10 @@ summary_header_save(CamelStoreSummary *s, FILE *out)
 /**
  * camel_store_summary_info_new:
  * @summary: a #CamelStoreSummary object
- * 
+ *
  * Allocate a new #CamelStoreInfo, suitable for adding to this
  * summary.
- * 
+ *
  * Returns: the newly allocated #CamelStoreInfo
  **/
 CamelStoreInfo *
@@ -847,8 +847,8 @@ camel_store_summary_info_new(CamelStoreSummary *s)
  *
  * Returns: the string value
  **/
-const char *
-camel_store_info_string(CamelStoreSummary *s, const CamelStoreInfo *info, int type)
+const gchar *
+camel_store_info_string(CamelStoreSummary *s, const CamelStoreInfo *info, gint type)
 {
 	return ((CamelStoreSummaryClass *)(CAMEL_OBJECT_GET_CLASS(s)))->store_info_string(s, info, type);
 }
@@ -864,13 +864,13 @@ camel_store_info_string(CamelStoreSummary *s, const CamelStoreInfo *info, int ty
  * Set a specific string on the @info.
  **/
 void
-camel_store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *info, int type, const char *value)
+camel_store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *info, gint type, const gchar *value)
 {
 	((CamelStoreSummaryClass *)(CAMEL_OBJECT_GET_CLASS(s)))->store_info_set_string(s, info, type, value);
 }
 
 static CamelStoreInfo *
-store_info_new(CamelStoreSummary *s, const char *f)
+store_info_new(CamelStoreSummary *s, const gchar *f)
 {
 	CamelStoreInfo *info;
 
@@ -922,7 +922,7 @@ store_info_load(CamelStoreSummary *s, FILE *in)
 	return NULL;
 }
 
-static int
+static gint
 store_info_save(CamelStoreSummary *s, FILE *out, CamelStoreInfo *info)
 {
 	io(printf("Saving folder info\n"));
@@ -943,10 +943,10 @@ store_info_free(CamelStoreSummary *s, CamelStoreInfo *info)
 	g_slice_free1(s->store_info_size, info);
 }
 
-static const char *
-store_info_string(CamelStoreSummary *s, const CamelStoreInfo *info, int type)
+static const gchar *
+store_info_string(CamelStoreSummary *s, const CamelStoreInfo *info, gint type)
 {
-	const char *p;
+	const gchar *p;
 
 	/* FIXME: Locks? */
 
@@ -976,28 +976,28 @@ store_info_string(CamelStoreSummary *s, const CamelStoreInfo *info, int type)
 }
 
 static void
-store_info_set_string (CamelStoreSummary *s, CamelStoreInfo *info, int type, const char *str)
+store_info_set_string (CamelStoreSummary *s, CamelStoreInfo *info, gint type, const gchar *str)
 {
-	const char *p;
-	char *v;
-	int len;
+	const gchar *p;
+	gchar *v;
+	gint len;
 
 	g_assert (info != NULL);
 
 	switch(type) {
 	case CAMEL_STORE_INFO_PATH:
 		CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
-		g_hash_table_remove(s->folders_path, (char *)camel_store_info_path(s, info));
+		g_hash_table_remove(s->folders_path, (gchar *)camel_store_info_path(s, info));
 		g_free(info->path);
 		g_free(info->uri);
 		info->path = g_strdup(str);
-		g_hash_table_insert(s->folders_path, (char *)camel_store_info_path(s, info), info);
+		g_hash_table_insert(s->folders_path, (gchar *)camel_store_info_path(s, info), info);
 		s->flags |= CAMEL_STORE_SUMMARY_DIRTY;
 		CAMEL_STORE_SUMMARY_UNLOCK(s, summary_lock);
 		break;
 	case CAMEL_STORE_INFO_NAME:
 		CAMEL_STORE_SUMMARY_LOCK(s, summary_lock);
-		g_hash_table_remove(s->folders_path, (char *)camel_store_info_path(s, info));
+		g_hash_table_remove(s->folders_path, (gchar *)camel_store_info_path(s, info));
 		p = strrchr(info->path, '/');
 		if (p) {
 			len = p-info->path+1;
@@ -1009,7 +1009,7 @@ store_info_set_string (CamelStoreSummary *s, CamelStoreInfo *info, int type, con
 		}
 		g_free(info->path);
 		info->path = v;
-		g_hash_table_insert(s->folders_path, (char *)camel_store_info_path(s, info), info);
+		g_hash_table_insert(s->folders_path, (gchar *)camel_store_info_path(s, info), info);
 		CAMEL_STORE_SUMMARY_UNLOCK(s, summary_lock);
 		break;
 	case CAMEL_STORE_INFO_URI:
