@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; fill-column: 160 -*- */
 /*
- *  Copyright (C) 2000 Ximian Inc.
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -29,27 +29,27 @@
 
 #include "camel-stream-filter.h"
 
-#define d(x) 
+#define d(x)
 
 /* use my malloc debugger? */
-/*extern void g_check(void *mp);*/
+/*extern void g_check(gpointer mp);*/
 #define g_check(x)
 
 struct _filter {
 	struct _filter *next;
-	int id;
+	gint id;
 	CamelMimeFilter *filter;
 };
 
 struct _CamelStreamFilterPrivate {
 	struct _filter *filters;
-	int filterid;		/* next filter id */
-	
-	char *realbuffer;	/* buffer - READ_PAD */
-	char *buffer;		/* READ_SIZE bytes */
+	gint filterid;		/* next filter id */
 
-	char *filtered;		/* the filtered data */
-	size_t filteredlen;
+	gchar *realbuffer;	/* buffer - READ_PAD */
+	gchar *buffer;		/* READ_SIZE bytes */
+
+	gchar *filtered;		/* the filtered data */
+	gsize filteredlen;
 
 	guint last_was_read:1;	/* was the last op read or write? */
 	guint flushed:1;        /* were the filters flushed? */
@@ -63,12 +63,12 @@ struct _CamelStreamFilterPrivate {
 static void camel_stream_filter_class_init (CamelStreamFilterClass *klass);
 static void camel_stream_filter_init       (CamelStreamFilter *obj);
 
-static	ssize_t   do_read       (CamelStream *stream, char *buffer, size_t n);
-static	ssize_t   do_write      (CamelStream *stream, const char *buffer, size_t n);
-static	int       do_flush      (CamelStream *stream);
-static	int       do_close      (CamelStream *stream);
+static	gssize   do_read       (CamelStream *stream, gchar *buffer, gsize n);
+static	gssize   do_write      (CamelStream *stream, const gchar *buffer, gsize n);
+static	gint       do_flush      (CamelStream *stream);
+static	gint       do_close      (CamelStream *stream);
 static	gboolean  do_eos        (CamelStream *stream);
-static	int       do_reset      (CamelStream *stream);
+static	gint       do_reset      (CamelStream *stream);
 
 static CamelStreamClass *camel_stream_filter_parent;
 
@@ -83,7 +83,7 @@ camel_stream_filter_class_init (CamelStreamFilterClass *klass)
 	camel_stream_class->write = do_write;
 	camel_stream_class->flush = do_flush;
 	camel_stream_class->close = do_close;
-	camel_stream_class->eos = do_eos; 
+	camel_stream_class->eos = do_eos;
 	camel_stream_class->reset = do_reset;
 
 }
@@ -92,7 +92,7 @@ static void
 camel_stream_filter_init (CamelStreamFilter *obj)
 {
 	struct _CamelStreamFilterPrivate *p;
-	
+
 	_PRIVATE(obj) = p = g_malloc0(sizeof(*p));
 	p->realbuffer = g_malloc(READ_SIZE + READ_PAD);
 	p->buffer = p->realbuffer + READ_PAD;
@@ -123,7 +123,7 @@ CamelType
 camel_stream_filter_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (CAMEL_STREAM_TYPE, "CamelStreamFilter",
 					    sizeof (CamelStreamFilter),
@@ -133,7 +133,7 @@ camel_stream_filter_get_type (void)
 					    (CamelObjectInitFunc) camel_stream_filter_init,
 					    (CamelObjectFinalizeFunc) camel_stream_filter_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -141,8 +141,8 @@ camel_stream_filter_get_type (void)
  * camel_stream_filter_new:
  *
  * Create a new #CamelStreamFilter object.
- * 
- * Returns a new #CamelStreamFilter object.
+ *
+ * Returns: a new #CamelStreamFilter object.
  **/
 CamelStreamFilter *
 camel_stream_filter_new_with_stream(CamelStream *stream)
@@ -159,16 +159,16 @@ camel_stream_filter_new_with_stream(CamelStream *stream)
  * camel_stream_filter_add:
  * @stream: a #CamelStreamFilter object
  * @filter: a #CamelMimeFilter object
- * 
+ *
  * Add a new #CamelMimeFilter to execute during the processing of this
  * stream.  Each filter added is processed after the previous one.
  *
  * Note that a filter should only be added to a single stream
  * at a time, otherwise unpredictable results may occur.
- * 
- * Returns a filter id for the added @filter.
+ *
+ * Returns: a filter id for the added @filter.
  **/
-int
+gint
 camel_stream_filter_add (CamelStreamFilter *stream, CamelMimeFilter *filter)
 {
 	struct _CamelStreamFilterPrivate *p = _PRIVATE(stream);
@@ -192,11 +192,11 @@ camel_stream_filter_add (CamelStreamFilter *stream, CamelMimeFilter *filter)
  * camel_stream_filter_remove:
  * @stream: a #CamelStreamFilter object
  * @id: Filter id, as returned from #camel_stream_filter_add
- * 
+ *
  * Remove a processing filter from the stream by id.
  **/
 void
-camel_stream_filter_remove(CamelStreamFilter *stream, int id)
+camel_stream_filter_remove(CamelStreamFilter *stream, gint id)
 {
 	struct _CamelStreamFilterPrivate *p = _PRIVATE(stream);
 	struct _filter *fn, *f;
@@ -213,12 +213,12 @@ camel_stream_filter_remove(CamelStreamFilter *stream, int id)
 	}
 }
 
-static ssize_t
-do_read (CamelStream *stream, char *buffer, size_t n)
+static gssize
+do_read (CamelStream *stream, gchar *buffer, gsize n)
 {
 	CamelStreamFilter *filter = (CamelStreamFilter *)stream;
 	struct _CamelStreamFilterPrivate *p = _PRIVATE(filter);
-	ssize_t size;
+	gssize size;
 	struct _filter *f;
 
 	p->last_was_read = TRUE;
@@ -226,7 +226,7 @@ do_read (CamelStream *stream, char *buffer, size_t n)
 	g_check(p->realbuffer);
 
 	if (p->filteredlen<=0) {
-		size_t presize = READ_PAD;
+		gsize presize = READ_PAD;
 
 		size = camel_stream_read(filter->source, p->buffer, READ_SIZE);
 		if (size <= 0) {
@@ -252,7 +252,7 @@ do_read (CamelStream *stream, char *buffer, size_t n)
 			p->filteredlen = size;
 
 			d(printf ("\n\nOriginal content (%s): '", ((CamelObject *)filter->source)->klass->name));
-			d(fwrite(p->filtered, sizeof(char), p->filteredlen, stdout));
+			d(fwrite(p->filtered, sizeof(gchar), p->filteredlen, stdout));
 			d(printf("'\n"));
 
 			while (f) {
@@ -261,7 +261,7 @@ do_read (CamelStream *stream, char *buffer, size_t n)
 				g_check(p->realbuffer);
 
 				d(printf ("Filtered content (%s): '", ((CamelObject *)f->filter)->klass->name));
-				d(fwrite(p->filtered, sizeof(char), p->filteredlen, stdout));
+				d(fwrite(p->filtered, sizeof(gchar), p->filteredlen, stdout));
 				d(printf("'\n"));
 
 				f = f->next;
@@ -282,19 +282,19 @@ do_read (CamelStream *stream, char *buffer, size_t n)
 /* Note: Since the caller expects to write out as much as they asked us to
    write (for 'success'), we return what they asked us to write (for 'success')
    rather than the true number of written bytes */
-static ssize_t
-do_write (CamelStream *stream, const char *buf, size_t n)
+static gssize
+do_write (CamelStream *stream, const gchar *buf, gsize n)
 {
 	CamelStreamFilter *filter = (CamelStreamFilter *)stream;
 	struct _CamelStreamFilterPrivate *p = _PRIVATE(filter);
 	struct _filter *f;
-	size_t presize, len, left = n;
-	char *buffer, realbuffer[READ_SIZE+READ_PAD];
+	gsize presize, len, left = n;
+	gchar *buffer, realbuffer[READ_SIZE+READ_PAD];
 
 	p->last_was_read = FALSE;
 
 	d(printf ("\n\nWriting: Original content (%s): '", ((CamelObject *)filter->source)->klass->name));
-	d(fwrite(buf, sizeof(char), n, stdout));
+	d(fwrite(buf, sizeof(gchar), n, stdout));
 	d(printf("'\n"));
 
 	g_check(p->realbuffer);
@@ -315,7 +315,7 @@ do_write (CamelStream *stream, const char *buf, size_t n)
 			g_check(p->realbuffer);
 
 			d(printf ("Filtered content (%s): '", ((CamelObject *)f->filter)->klass->name));
-			d(fwrite(buffer, sizeof(char), len, stdout));
+			d(fwrite(buffer, sizeof(gchar), len, stdout));
 			d(printf("'\n"));
 
 			f = f->next;
@@ -330,33 +330,33 @@ do_write (CamelStream *stream, const char *buf, size_t n)
 	return n;
 }
 
-static int
+static gint
 do_flush (CamelStream *stream)
 {
 	CamelStreamFilter *filter = (CamelStreamFilter *)stream;
 	struct _CamelStreamFilterPrivate *p = _PRIVATE(filter);
 	struct _filter *f;
-	char *buffer;
-	size_t presize;
-	size_t len;
-	
+	gchar *buffer;
+	gsize presize;
+	gsize len;
+
 	if (p->last_was_read)
 		return 0;
-	
-	buffer = "";
+
+	buffer = (gchar *) "";
 	len = 0;
 	presize = 0;
 	f = p->filters;
-	
+
 	d(printf ("\n\nFlushing: Original content (%s): '", ((CamelObject *)filter->source)->klass->name));
-	d(fwrite(buffer, sizeof(char), len, stdout));
+	d(fwrite(buffer, sizeof(gchar), len, stdout));
 	d(printf("'\n"));
 
 	while (f) {
 		camel_mime_filter_complete(f->filter, buffer, len, presize, &buffer, &len, &presize);
 
 		d(printf ("Filtered content (%s): '", ((CamelObject *)f->filter)->klass->name));
-		d(fwrite(buffer, sizeof(char), len, stdout));
+		d(fwrite(buffer, sizeof(gchar), len, stdout));
 		d(printf("'\n"));
 
 		f = f->next;
@@ -366,7 +366,7 @@ do_flush (CamelStream *stream)
 	return camel_stream_flush(filter->source);
 }
 
-static int
+static gint
 do_close (CamelStream *stream)
 {
 	CamelStreamFilter *filter = (CamelStreamFilter *)stream;
@@ -383,17 +383,17 @@ do_eos (CamelStream *stream)
 {
 	CamelStreamFilter *filter = (CamelStreamFilter *)stream;
 	struct _CamelStreamFilterPrivate *p = _PRIVATE(filter);
-	
+
 	if (p->filteredlen > 0)
 		return FALSE;
-	
+
 	if (!p->flushed)
 		return FALSE;
-	
+
 	return camel_stream_eos(filter->source);
 }
 
-static int
+static gint
 do_reset (CamelStream *stream)
 {
 	CamelStreamFilter *filter = (CamelStreamFilter *)stream;
@@ -402,7 +402,7 @@ do_reset (CamelStream *stream)
 
 	p->filteredlen = 0;
 	p->flushed = FALSE;
-	
+
 	/* and reset filters */
 	f = p->filters;
 	while (f) {
