@@ -39,8 +39,8 @@ static CamelSeekableStreamClass *parent_class = NULL;
 /* Returns the class for a CamelStreamMem */
 #define CSM_CLASS(so) CAMEL_STREAM_MEM_CLASS(CAMEL_OBJECT_GET_CLASS(so))
 
-static ssize_t stream_read (CamelStream *stream, char *buffer, size_t n);
-static ssize_t stream_write (CamelStream *stream, const char *buffer, size_t n);
+static gssize stream_read (CamelStream *stream, gchar *buffer, gsize n);
+static gssize stream_write (CamelStream *stream, const gchar *buffer, gsize n);
 static gboolean stream_eos (CamelStream *stream);
 static off_t stream_seek (CamelSeekableStream *stream, off_t offset,
 			  CamelStreamSeekPolicy policy);
@@ -75,9 +75,9 @@ camel_stream_mem_init (CamelObject *object)
 }
 
 /* could probably be a util method */
-static void clear_mem(void *p, size_t len)
+static void clear_mem(gpointer p, gsize len)
 {
-	char *s = p;
+	gchar *s = p;
 
 	/* This also helps debug bad access memory errors */
 	while (len > 4) {
@@ -139,7 +139,7 @@ camel_stream_mem_new (void)
  * Returns: a new #CamelStreamMem
  **/
 CamelStream *
-camel_stream_mem_new_with_buffer (const char *buffer, size_t len)
+camel_stream_mem_new_with_buffer (const gchar *buffer, gsize len)
 {
 	GByteArray *ba;
 
@@ -176,7 +176,7 @@ camel_stream_mem_new_with_byte_array (GByteArray *buffer)
 /**
  * camel_stream_mem_set_secure:
  * @mem: a #CamelStreamMem object
- * 
+ *
  * Mark the memory stream as secure.  At the very least this means the
  * data in the buffer will be cleared when the buffer is finalised.
  * This only applies to buffers owned by the stream.
@@ -226,7 +226,7 @@ camel_stream_mem_set_byte_array (CamelStreamMem *mem, GByteArray *buffer)
  * and so may have resource implications to consider.
  **/
 void
-camel_stream_mem_set_buffer (CamelStreamMem *mem, const char *buffer, size_t len)
+camel_stream_mem_set_buffer (CamelStreamMem *mem, const gchar *buffer, gsize len)
 {
 	GByteArray *ba;
 
@@ -251,12 +251,12 @@ camel_stream_mem_finalize (CamelObject *object)
 	}
 }
 
-static ssize_t
-stream_read (CamelStream *stream, char *buffer, size_t n)
+static gssize
+stream_read (CamelStream *stream, gchar *buffer, gsize n)
 {
 	CamelStreamMem *camel_stream_mem = CAMEL_STREAM_MEM (stream);
 	CamelSeekableStream *seekable = CAMEL_SEEKABLE_STREAM (stream);
-	ssize_t nread;
+	gssize nread;
 
 	if (seekable->bound_end != CAMEL_STREAM_UNBOUND)
 		n = MIN(seekable->bound_end - seekable->position, n);
@@ -271,13 +271,13 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 	return nread;
 }
 
-static ssize_t
-stream_write (CamelStream *stream, const char *buffer, size_t n)
+static gssize
+stream_write (CamelStream *stream, const gchar *buffer, gsize n)
 {
 	CamelStreamMem *stream_mem = CAMEL_STREAM_MEM (stream);
 	CamelSeekableStream *seekable = CAMEL_SEEKABLE_STREAM (stream);
-	ssize_t nwrite = n;
-	
+	gssize nwrite = n;
+
 	if (seekable->bound_end != CAMEL_STREAM_UNBOUND)
 		nwrite = MIN(seekable->bound_end - seekable->position, n);
 
@@ -332,7 +332,7 @@ stream_seek (CamelSeekableStream *stream, off_t offset,
 		position = MAX (position, stream->bound_start);
 
 	if (position > stream_mem->buffer->len) {
-		int oldlen = stream_mem->buffer->len;
+		gint oldlen = stream_mem->buffer->len;
 		g_byte_array_set_size (stream_mem->buffer, position);
 		memset (stream_mem->buffer->data + oldlen, 0,
 			position - oldlen);
