@@ -36,18 +36,18 @@ G_BEGIN_DECLS
 struct _CamelTcpStreamRaw
 {
 	CamelTcpStream parent_object;
-	
-	int sockfd;
+
+	gint sockfd;
 #ifdef G_OS_WIN32
-	int is_nonblocking;
+	gint is_nonblocking;
 #endif
 };
 
 typedef struct {
 	CamelTcpStreamClass parent_class;
-	
+
 	/* virtual functions */
-	
+
 } CamelTcpStreamRawClass;
 
 /* Standard Camel function */
