@@ -2,7 +2,7 @@
 /*
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
- *  Copyright 2003 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,16 +34,16 @@
 
 /**
  * camel_utf8_putc:
- * @ptr: 
- * @c: 
- * 
+ * @ptr:
+ * @c:
+ *
  * Output a 32 bit unicode character as utf8 octets.  At most 4 octets will
  * be written to @ptr.  @ptr will be advanced to the next character position.
  **/
 void
-camel_utf8_putc(unsigned char **ptr, guint32 c)
+camel_utf8_putc(guchar **ptr, guint32 c)
 {
-	register unsigned char *p = *ptr;
+	register guchar *p = *ptr;
 
 	if (c <= 0x7f)
 		*p++ = c;
@@ -67,20 +67,20 @@ camel_utf8_putc(unsigned char **ptr, guint32 c)
 
 /**
  * camel_utf8_getc:
- * @ptr: 
- * 
+ * @ptr:
+ *
  * Get a Unicode character from a utf8 stream.  @ptr will be advanced
  * to the next character position.  Invalid utf8 characters will be
  * silently skipped.  @ptr should point to a NUL terminated array.
- * 
+ *
  * Return value: The next Unicode character.  @ptr will be advanced to
  * the next character always.
  **/
 guint32
-camel_utf8_getc(const unsigned char **ptr)
+camel_utf8_getc(const guchar **ptr)
 {
-	register unsigned char *p = (unsigned char *)*ptr;
-	register unsigned char c, r;
+	register guchar *p = (guchar *)*ptr;
+	register guchar c, r;
 	register guint32 v, m;
 
 again:
@@ -102,7 +102,7 @@ loop:
 			r<<=1;
 			m<<=5;
 		} while (r & 0x40);
-		
+
 		*ptr = p;
 
 		v &= ~m;
@@ -115,22 +115,22 @@ loop:
 
 /**
  * camel_utf8_getc_limit:
- * @ptr: 
+ * @ptr:
  * @end: must not be NULL.
- * 
- * Get the next utf8 char at @ptr, and return it, advancing @ptr to
+ *
+ * Get the next utf8 gchar at @ptr, and return it, advancing @ptr to
  * the next character.  If @end is reached before a full utf8
- * character can be read, then the invalid Unicode char 0xffff is
+ * character can be read, then the invalid Unicode gchar 0xffff is
  * returned as a sentinel (Unicode 3.1, section 2.7), and @ptr is not
  * advanced.
- * 
+ *
  * Return value: The next utf8 char, or 0xffff.
  **/
 guint32
-camel_utf8_getc_limit(const unsigned char **ptr, const unsigned char *end)
+camel_utf8_getc_limit(const guchar **ptr, const guchar *end)
 {
-	register unsigned char *p = (unsigned char *)*ptr;
-	register unsigned char c, r;
+	register guchar *p = (guchar *)*ptr;
+	register guchar c, r;
 	register guint32 v = 0xffff, m;
 
 again:
@@ -146,7 +146,7 @@ loop:
 			do {
 				if (p >= end)
 					return 0xffff;
-				
+
 				c = *p++;
 				if ((c & 0xc0) != 0x80) {
 					r = c;
@@ -156,9 +156,9 @@ loop:
 				r<<=1;
 				m<<=5;
 			} while (r & 0x40);
-			
+
 			*ptr = p;
-			
+
 			v &= ~m;
 			return v;
 		} else {
@@ -172,18 +172,18 @@ loop:
 void
 g_string_append_u(GString *out, guint32 c)
 {
-	unsigned char buffer[8];
-	unsigned char *p = buffer;
+	guchar buffer[8];
+	guchar *p = buffer;
 
 	camel_utf8_putc(&p, c);
 	*p = 0;
-	g_string_append(out, (const char *) buffer);
+	g_string_append(out, (const gchar *) buffer);
 }
 
-static const char utf7_alphabet[] =
+static const gchar utf7_alphabet[] =
 	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+,";
 
-static const unsigned char utf7_rank[256] = {
+static const guchar utf7_rank[256] = {
 	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
 	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x3e,0x3f,0xff,0xff,0xff,
@@ -204,25 +204,25 @@ static const unsigned char utf7_rank[256] = {
 
 /**
  * camel_utf7_utf8:
- * @ptr: 
- * 
+ * @ptr:
+ *
  * Convert a modified utf7 string to utf8.  If the utf7 string
  * contains 8 bit characters, they are treated as iso-8859-1.
- * 
+ *
  * The IMAP rules [rfc2060] are used in the utf7 encoding.
  *
  * Return value: The converted string.
  **/
-char *
-camel_utf7_utf8(const char *ptr)
+gchar *
+camel_utf7_utf8(const gchar *ptr)
 {
-	const unsigned char *p = (unsigned char *)ptr;
-	unsigned int c;
+	const guchar *p = (guchar *)ptr;
+	guint c;
 	guint32 v=0, x;
 	GString *out;
-	int i=0;
-	int state = 0;
-	char *ret;
+	gint i=0;
+	gint state = 0;
+	gchar *ret;
 
 	out = g_string_new("");
 	do {
@@ -286,24 +286,24 @@ static void utf7_closeb64(GString *out, guint32 v, guint32 i)
 
 /**
  * camel_utf8_utf7:
- * @ptr: 
- * 
+ * @ptr:
+ *
  * Convert a utf8 string to a modified utf7 format.
  *
  * The IMAP rules [rfc2060] are used in the utf7 encoding.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
-char *
-camel_utf8_utf7(const char *ptr)
+gchar *
+camel_utf8_utf7(const gchar *ptr)
 {
-	const unsigned char *p = (unsigned char *)ptr;
-	unsigned int c;
+	const guchar *p = (guchar *)ptr;
+	guint c;
 	guint32 x, v = 0;
-	int state = 0;
+	gint state = 0;
 	GString *out;
-	int i = 0;
-	char *ret;
+	gint i = 0;
+	gchar *ret;
 
 	out = g_string_new("");
 
@@ -344,30 +344,30 @@ camel_utf8_utf7(const char *ptr)
 
 /**
  * camel_utf8_ucs2:
- * @ptr: 
- * 
+ * @ptr:
+ *
  * Convert a utf8 string into a ucs2 one.  The ucs string will be in
  * network byte order, and terminated with a 16 bit NULL.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
-char *
-camel_utf8_ucs2(const char *pptr)
+gchar *
+camel_utf8_ucs2(const gchar *pptr)
 {
 	GByteArray *work = g_byte_array_new();
 	guint32 c;
-	char *out;
-	const unsigned char *ptr = (const unsigned char *) pptr;
+	gchar *out;
+	const guchar *ptr = (const guchar *) pptr;
 
 	/* what if c is > 0xffff ? */
 
 	while ( (c = camel_utf8_getc(&ptr)) ) {
 		guint16 s = g_htons(c);
 
-		g_byte_array_append(work, (unsigned char *) &s, 2);
+		g_byte_array_append(work, (guchar *) &s, 2);
 	}
 
-	g_byte_array_append(work, (unsigned char *) "\000\000", 2);
+	g_byte_array_append(work, (guchar *) "\000\000", 2);
 	out = g_malloc(work->len);
 	memcpy(out, work->data, work->len);
 	g_byte_array_free(work, TRUE);
@@ -377,19 +377,19 @@ camel_utf8_ucs2(const char *pptr)
 
 /**
  * camel_ucs2_utf8:
- * @ptr: 
- * 
+ * @ptr:
+ *
  * Convert a ucs2 string into a utf8 one.  The ucs2 string is treated
  * as network byte ordered, and terminated with a 16 bit NUL.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
-char *camel_ucs2_utf8(const char *ptr)
+gchar *camel_ucs2_utf8(const gchar *ptr)
 {
 	guint16 *ucs = (guint16 *)ptr;
 	guint32 c;
 	GString *work = g_string_new("");
-	char *out;
+	gchar *out;
 
 	while ( (c = *ucs++) )
 		g_string_append_u(work, g_ntohs(c));
@@ -399,3 +399,27 @@ char *camel_ucs2_utf8(const char *ptr)
 
 	return out;
 }
+
+/**
+ * camel_utf8_make_valid:
+ * @text:
+ *
+ * Ensures the returned text will be valid UTF-8 string, with incorrect letters
+ * changed to question marks. Returned pointer should be freed with g_free.
+ **/
+gchar *
+camel_utf8_make_valid (const gchar *text)
+{
+	gchar *res = g_strdup (text), *p;
+
+	if (!res)
+		return res;
+
+	p = res;
+	while (!g_utf8_validate (p, -1, (const gchar **) &p)) {
+		/* make all invalid characters appear as question marks */
+		*p = '?';
+	}
+
+	return res;
+}
