@@ -42,7 +42,7 @@
 #define d(x)
 
 static CamelFolderSummaryClass *camel_vee_summary_parent;
-const char *unread_str = " (and\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n;  (or\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n; (match-threads \"all\"  (and\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n)\n;  (match-threads \"all\"  (or\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n)\n;";
+const gchar *unread_str = " (and\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n;  (or\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n; (match-threads \"all\"  (and\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n)\n;  (match-threads \"all\"  (or\n  \n     (match-all (not (system-flag  \"Seen\")))\n    \n  )\n)\n;";
 
 static void
 vee_message_info_free(CamelFolderSummary *s, CamelMessageInfo *info)
@@ -71,13 +71,13 @@ vee_message_info_clone(CamelFolderSummary *s, const CamelMessageInfo *mi)
 
 #define HANDLE_NULL_INFO(value) if (!rmi) { d(g_warning (G_STRLOC ": real info is NULL for %s, safeguarding\n", mi->uid)); return value; }
 
-static const void *
-vee_info_ptr (const CamelMessageInfo *mi, int id)
+static gconstpointer
+vee_info_ptr (const CamelMessageInfo *mi, gint id)
 {
 	CamelVeeMessageInfo *vmi = (CamelVeeMessageInfo *) mi;
 	CamelMessageInfo *rmi;
 	gpointer p;
-	
+
 	rmi = camel_folder_summary_uid (vmi->summary, mi->uid+8);
 	HANDLE_NULL_INFO(NULL);
 	p = (gpointer) camel_message_info_ptr(rmi, id);
@@ -87,11 +87,11 @@ vee_info_ptr (const CamelMessageInfo *mi, int id)
 }
 
 static guint32
-vee_info_uint32(const CamelMessageInfo *mi, int id)
+vee_info_uint32(const CamelMessageInfo *mi, gint id)
 {
 	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
 	guint32 ret;
-	
+
 	HANDLE_NULL_INFO(0);
 	ret = camel_message_info_uint32 (rmi, id);
 	if (id == CAMEL_MESSAGE_INFO_FLAGS)
@@ -103,11 +103,11 @@ vee_info_uint32(const CamelMessageInfo *mi, int id)
 }
 
 static time_t
-vee_info_time(const CamelMessageInfo *mi, int id)
+vee_info_time(const CamelMessageInfo *mi, gint id)
 {
 	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
 	time_t ret;
-	
+
 	HANDLE_NULL_INFO(0);
 	ret = camel_message_info_time (rmi, id);
 	camel_message_info_free (rmi);
@@ -116,24 +116,24 @@ vee_info_time(const CamelMessageInfo *mi, int id)
 }
 
 static gboolean
-vee_info_user_flag(const CamelMessageInfo *mi, const char *id)
+vee_info_user_flag(const CamelMessageInfo *mi, const gchar *id)
 {
 	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
 	gboolean ret;
-	
+
 	HANDLE_NULL_INFO(FALSE);
-	ret = 	camel_message_info_user_flag (rmi, id);
+	ret =	camel_message_info_user_flag (rmi, id);
 	camel_message_info_free (rmi);
 
 	return ret;
 }
 
-static const char *
-vee_info_user_tag(const CamelMessageInfo *mi, const char *id)
+static const gchar *
+vee_info_user_tag(const CamelMessageInfo *mi, const gchar *id)
 {
 	CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
-	const char *ret;
-	
+	const gchar *ret;
+
 	HANDLE_NULL_INFO("");
 	ret = camel_message_info_user_tag (rmi, id);
 	camel_message_info_free (rmi);
@@ -142,41 +142,41 @@ vee_info_user_tag(const CamelMessageInfo *mi, const char *id)
 }
 
 static gboolean
-vee_info_set_user_flag(CamelMessageInfo *mi, const char *name, gboolean value)
+vee_info_set_user_flag(CamelMessageInfo *mi, const gchar *name, gboolean value)
 {
-	int res = FALSE;
+	gint res = FALSE;
 
 	if (mi->uid) {
 		CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
 		HANDLE_NULL_INFO(FALSE);
 		res = camel_message_info_set_user_flag(rmi, name, value);
-		camel_message_info_free (rmi);		
+		camel_message_info_free (rmi);
 	}
- 
+
 	return res;
 }
 
 static gboolean
-vee_info_set_user_tag(CamelMessageInfo *mi, const char *name, const char *value)
+vee_info_set_user_tag(CamelMessageInfo *mi, const gchar *name, const gchar *value)
 {
-	int res = FALSE;
+	gint res = FALSE;
 
 	if (mi->uid) {
 		CamelMessageInfo *rmi = camel_folder_summary_uid (((CamelVeeMessageInfo *)mi)->summary, mi->uid+8);
-		HANDLE_NULL_INFO(FALSE);		
+		HANDLE_NULL_INFO(FALSE);
 		res = camel_message_info_set_user_tag(rmi, name, value);
-		camel_message_info_free (rmi);			
+		camel_message_info_free (rmi);
 	}
- 
+
 	return res;
 }
 
 void
 camel_vee_summary_load_check_unread_vfolder (CamelVeeSummary *vs)
 {
-	static int only_once = FALSE;
-	static char *exp = NULL;
-	char *meta;
+	static gint only_once = FALSE;
+	static gchar *exp = NULL;
+	gchar *meta;
 	gboolean hacked_unread_folder = FALSE;
 	CamelVeeFolder *vf;
 
@@ -212,7 +212,7 @@ camel_vee_summary_load_check_unread_vfolder (CamelVeeSummary *vs)
 static gboolean
 vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 {
-	int res = FALSE;
+	gint res = FALSE;
 	CamelVeeFolder *vf = (CamelVeeFolder *)mi->summary->folder;
 	gboolean hacked_unread_folder = FALSE;
 
@@ -225,7 +225,7 @@ vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 	if (vf->priv->unread_vfolder == 1)
 		hacked_unread_folder = TRUE;
 	else {
-		char *meta = camel_object_meta_get (mi->summary->folder, "vfolder:unread");
+		gchar *meta = camel_object_meta_get (mi->summary->folder, "vfolder:unread");
 		if (meta && strcmp (meta, "true") == 0)
 			hacked_unread_folder = TRUE;
 		g_free(meta);
@@ -265,12 +265,14 @@ vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 		if (hacked_unread_folder && !vsummary->fake_visible_count)
 			vsummary->fake_visible_count = mi->summary->visible_count;
 
+#if 0
 		/* Keep the summary in sync */
-		//mi->summary->unread_count += unread - old_unread;
-		//mi->summary->deleted_count += deleted - old_deleted;
-		//mi->summary->junk_count += junked - old_junked;
-		//mi->summary->junk_not_deleted_count += junked_not_deleted - old_junked_not_deleted;
-		//mi->summary->visible_count += visible - old_visible;
+		mi->summary->unread_count += unread - old_unread;
+		mi->summary->deleted_count += deleted - old_deleted;
+		mi->summary->junk_count += junked - old_junked;
+		mi->summary->junk_not_deleted_count += junked_not_deleted - old_junked_not_deleted;
+		mi->summary->visible_count += visible - old_visible;
+#endif
 
 		if (vsummary->fake_visible_count || hacked_unread_folder)
 			vsummary->fake_visible_count += visible - old_visible;
@@ -284,7 +286,7 @@ vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 
 			camel_folder_change_info_change_uid(changes, mi->uid);
 
-			array = g_ptr_array_new (); 
+			array = g_ptr_array_new ();
 			g_ptr_array_add (array, (gpointer)rmi->uid);
 
 			match = camel_folder_search_by_uids (rmi->summary->folder, vf->expression, array, NULL);
@@ -300,15 +302,15 @@ vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 
 			camel_object_trigger_event(mi->summary->folder, "folder_changed", changes);
 			camel_folder_change_info_free(changes);
-		}		
+		}
 		camel_message_info_free (rmi);
 	}
- 
+
 	return res;
 }
 
 static CamelMessageInfo *
-message_info_from_uid (CamelFolderSummary *s, const char *uid)
+message_info_from_uid (CamelFolderSummary *s, const gchar *uid)
 {
 	CamelMessageInfo *info;
 
@@ -324,10 +326,10 @@ message_info_from_uid (CamelFolderSummary *s, const char *uid)
 
 	CAMEL_SUMMARY_UNLOCK(s, ref_lock);
 	CAMEL_SUMMARY_UNLOCK(s, summary_lock);
-	
+
 	if (!info) {
 		CamelVeeMessageInfo *vinfo;
-		char tmphash[9];
+		gchar tmphash[9];
 
 		/* This function isn't really nice. But no great way
 		 * But in vfolder case, this may not be so bad, as vuid has the hash in first 8 bytes.
@@ -338,7 +340,7 @@ message_info_from_uid (CamelFolderSummary *s, const char *uid)
 			d(g_message ("Unable to find %s in the summary of %s", uid, s->folder->full_name));
 			return NULL;
 		}
-		
+
 		/* Create the info and load it, its so easy. */
 		info = camel_message_info_new (s);
 		camel_message_info_ref(info);
@@ -351,7 +353,7 @@ message_info_from_uid (CamelFolderSummary *s, const char *uid)
 		camel_object_ref (vinfo->summary);
 		camel_folder_summary_insert (s, info, FALSE);
 	}
-	return info;	
+	return info;
 }
 
 static void
@@ -440,32 +442,32 @@ camel_vee_summary_new(CamelFolder *parent)
 }
 
 GPtrArray *
-camel_vee_summary_get_ids (CamelVeeSummary *summary, char hash[8])
+camel_vee_summary_get_ids (CamelVeeSummary *summary, gchar hash[8])
 {
-	char *shash = g_strdup_printf("%c%c%c%c%c%c%c%c", hash[0], hash[1], hash[2], hash[3], hash[4], hash[5], hash[6], hash[7]);
+	gchar *shash = g_strdup_printf("%c%c%c%c%c%c%c%c", hash[0], hash[1], hash[2], hash[3], hash[4], hash[5], hash[6], hash[7]);
 	CamelFolderSummary *cfs = (CamelFolderSummary *)summary;
 	GPtrArray *array;
 
 	/* FIXME[disk-summary] fix exception passing */
 	array = camel_db_get_vuids_from_vfolder(cfs->folder->parent_store->cdb_r, cfs->folder->full_name, shash, NULL);
-	
+
 	g_free(shash);
 
 	return array;
 }
 
 CamelVeeMessageInfo *
-camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const char *uid, const char hash[8])
+camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const gchar *uid, const gchar hash[8])
 {
 	CamelVeeMessageInfo *mi;
-	char *vuid;
+	gchar *vuid;
 	GHashTable * fcache;
 	vuid = g_malloc(strlen(uid)+9);
 	memcpy(vuid, hash, 8);
 	strcpy(vuid+8, uid);
 
 	CAMEL_SUMMARY_LOCK(s, summary_lock);
-	mi = (CamelVeeMessageInfo *) g_hash_table_lookup(((CamelFolderSummary *) s)->loaded_infos, vuid); 
+	mi = (CamelVeeMessageInfo *) g_hash_table_lookup(((CamelFolderSummary *) s)->loaded_infos, vuid);
 	CAMEL_SUMMARY_UNLOCK(s, summary_lock);
 
 	if (mi) {
@@ -486,7 +488,7 @@ camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const cha
 	mi->old_flags = GPOINTER_TO_UINT(g_hash_table_lookup (fcache, uid));
 	/* We would do lazy loading of flags, when the folders are loaded to memory through folder_reloaded signal */
 	camel_object_ref (summary);
-	mi->info.uid = (char *) camel_pstring_strdup (vuid);
+	mi->info.uid = (gchar *) camel_pstring_strdup (vuid);
 	g_free (vuid);
 	camel_message_info_ref (mi);
 	/* Get the flags and store it. We can use it a lot * /
@@ -496,6 +498,6 @@ camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const cha
 		camel_message_info_free (rmi);
 	}*/
 	camel_folder_summary_insert(&s->summary, (CamelMessageInfo *)mi, FALSE);
-	
+
 	return mi;
 }
