@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -39,7 +39,7 @@ typedef struct _CamelVTrashFolderClass CamelVTrashFolderClass;
 #define CAMEL_VTRASH_NAME ".#evolution/Trash"
 #define CAMEL_VJUNK_NAME ".#evolution/Junk"
 
-typedef enum _camel_vtrash_folder_t {
+typedef enum {
 	CAMEL_VTRASH_FOLDER_TRASH,
 	CAMEL_VTRASH_FOLDER_JUNK,
 	CAMEL_VTRASH_FOLDER_LAST
@@ -48,13 +48,13 @@ typedef enum _camel_vtrash_folder_t {
 struct _CamelVTrashFolder {
 	CamelVeeFolder parent;
 
-	enum _camel_vtrash_folder_t type;
+	camel_vtrash_folder_t type;
 	guint32 bit;
 };
 
 struct _CamelVTrashFolderClass {
 	CamelVeeFolderClass parent_class;
-	
+
 };
 
 CamelType       camel_vtrash_folder_get_type    (void);
