@@ -2,7 +2,7 @@
 /*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Parthasarathi Susarla <sparthasarathi@novell.com>  
+ * Authors: Parthasarathi Susarla <sparthasarathi@novell.com>
  *
  * Description: Based on the imap implementaion of camelstoresummary
  *
@@ -44,16 +44,16 @@
 
 static void namespace_clear(CamelStoreSummary *s);
 
-static int summary_header_load(CamelStoreSummary *, FILE *);
-static int summary_header_save(CamelStoreSummary *, FILE *);
+static gint summary_header_load(CamelStoreSummary *, FILE *);
+static gint summary_header_save(CamelStoreSummary *, FILE *);
 
-static CamelStoreInfo *store_info_load(CamelStoreSummary *s, FILE *in) ;
-static int store_info_save(CamelStoreSummary *s, FILE *out, CamelStoreInfo *mi) ;
-static void store_info_free(CamelStoreSummary *s, CamelStoreInfo *mi) ;
-static void store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *mi, int type, const char *str) ;
+static CamelStoreInfo *store_info_load(CamelStoreSummary *s, FILE *in);
+static gint store_info_save(CamelStoreSummary *s, FILE *out, CamelStoreInfo *mi);
+static void store_info_free(CamelStoreSummary *s, CamelStoreInfo *mi);
+static void store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *mi, gint type, const gchar *str);
 
-static const char *store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, int type) ;
-CamelGroupwiseStoreNamespace *camel_groupwise_store_summary_namespace_find_full(CamelGroupwiseStoreSummary *s, const char *full) ;
+static const gchar *store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, gint type);
+CamelGroupwiseStoreNamespace *camel_groupwise_store_summary_namespace_find_full(CamelGroupwiseStoreSummary *s, const gchar *full);
 
 static void camel_groupwise_store_summary_class_init (CamelGroupwiseStoreSummaryClass *klass);
 static void camel_groupwise_store_summary_init       (CamelGroupwiseStoreSummary *obj);
@@ -69,7 +69,7 @@ camel_groupwise_store_summary_class_init (CamelGroupwiseStoreSummaryClass *klass
 
 	ssklass->summary_header_load = summary_header_load;
 	ssklass->summary_header_save = summary_header_save;
-	
+
 	ssklass->store_info_load = store_info_load;
 	ssklass->store_info_save = store_info_save;
 	ssklass->store_info_free = store_info_free;
@@ -125,9 +125,9 @@ camel_groupwise_store_summary_new (void)
 
 
 CamelGroupwiseStoreInfo *
-camel_groupwise_store_summary_full_name(CamelGroupwiseStoreSummary *s, const char *full_name)
+camel_groupwise_store_summary_full_name(CamelGroupwiseStoreSummary *s, const gchar *full_name)
 {
-	int count, i;
+	gint count, i;
 	CamelGroupwiseStoreInfo *info;
 
 	count = camel_store_summary_count((CamelStoreSummary *)s);
@@ -143,12 +143,12 @@ camel_groupwise_store_summary_full_name(CamelGroupwiseStoreSummary *s, const cha
 	return NULL;
 }
 
-char *
-camel_groupwise_store_summary_full_to_path(CamelGroupwiseStoreSummary *s, const char *full_name, char dir_sep)
+gchar *
+camel_groupwise_store_summary_full_to_path(CamelGroupwiseStoreSummary *s, const gchar *full_name, gchar dir_sep)
 {
-	char *path, *p;
-	int c;
-	const char *f;
+	gchar *path, *p;
+	gint c;
+	const gchar *f;
 
 	if (dir_sep != '/') {
 		p = path = alloca(strlen(full_name)*3+1);
@@ -163,7 +163,7 @@ camel_groupwise_store_summary_full_to_path(CamelGroupwiseStoreSummary *s, const
 		}
 		*p = 0;
 	} else
-		path = (char *)full_name;
+		path = (gchar *)full_name;
 
 	return g_strdup (path);
 }
@@ -177,7 +177,7 @@ static guint32 hexnib(guint32 c)
 		return 0;
 }
 
-static int
+static gint
 namespace_save(CamelStoreSummary *s, FILE *in, CamelGroupwiseStoreNamespace *ns)
 {
 	if (camel_file_util_encode_string(in, ns->path) == -1
@@ -225,14 +225,14 @@ namespace_load(CamelStoreSummary *s, FILE *in)
 	return ns;
 }
 
-char *
-camel_groupwise_store_summary_path_to_full(CamelGroupwiseStoreSummary *s, const char *path, char dir_sep)
+gchar *
+camel_groupwise_store_summary_path_to_full(CamelGroupwiseStoreSummary *s, const gchar *path, gchar dir_sep)
 {
-	unsigned char *full, *f;
+	gchar *full, *f;
 	guint32 c, v = 0;
-	const char *p;
-	int state=0;
-	char *subpath, *last = NULL;
+	const gchar *p;
+	gint state=0;
+	gchar *subpath, *last = NULL;
 	CamelStoreInfo *si;
 	CamelGroupwiseStoreNamespace *ns;
 
@@ -265,7 +265,7 @@ camel_groupwise_store_summary_path_to_full(CamelGroupwiseStoreSummary *s, const
 	else
 		p = path;
 
-	while ( (c = camel_utf8_getc((const unsigned char **)&p)) ) {
+	while ( (c = camel_utf8_getc((const guchar **)&p)) ) {
 		switch(state) {
 			case 0:
 				if (c == '%')
@@ -273,7 +273,7 @@ camel_groupwise_store_summary_path_to_full(CamelGroupwiseStoreSummary *s, const
 				else {
 					if (c == '/')
 						c = dir_sep;
-					camel_utf8_putc(&f, c);
+					camel_utf8_putc((guchar **) &f, c);
 				}
 				break;
 			case 1:
@@ -283,11 +283,11 @@ camel_groupwise_store_summary_path_to_full(CamelGroupwiseStoreSummary *s, const
 			case 2:
 				state = 0;
 				v |= hexnib(c);
-				camel_utf8_putc(&f, v);
+				camel_utf8_putc((guchar **) &f, v);
 				break;
 		}
 	}
-	camel_utf8_putc(&f, c);
+	camel_utf8_putc((guchar **) &f, c);
 
 	/* merge old path part if required */
 	f = g_strdup (full);
@@ -301,13 +301,13 @@ camel_groupwise_store_summary_path_to_full(CamelGroupwiseStoreSummary *s, const
 		g_free(f);
 		f = full;
 	}
-	return f ;
+	return f;
 }
 
 CamelGroupwiseStoreNamespace *
-camel_groupwise_store_summary_namespace_find_full(CamelGroupwiseStoreSummary *s, const char *full)
+camel_groupwise_store_summary_namespace_find_full(CamelGroupwiseStoreSummary *s, const gchar *full)
 {
-	int len;
+	gint len;
 	CamelGroupwiseStoreNamespace *ns;
 
 	/* NB: this currently only compares against 1 namespace, in future compare against others */
@@ -327,12 +327,12 @@ camel_groupwise_store_summary_namespace_find_full(CamelGroupwiseStoreSummary *s,
 }
 
 CamelGroupwiseStoreInfo *
-camel_groupwise_store_summary_add_from_full(CamelGroupwiseStoreSummary *s, const char *full, char dir_sep)
+camel_groupwise_store_summary_add_from_full(CamelGroupwiseStoreSummary *s, const gchar *full, gchar dir_sep)
 {
 	CamelGroupwiseStoreInfo *info;
-	char *pathu8, *prefix;
-	int len;
-	char *full_name;
+	gchar *pathu8, *prefix;
+	gint len;
+	gchar *full_name;
 	CamelGroupwiseStoreNamespace *ns;
 
 	d(printf("adding full name '%s' '%c'\n", full, dir_sep));
@@ -378,17 +378,18 @@ camel_groupwise_store_summary_add_from_full(CamelGroupwiseStoreSummary *s, const
 	if (info) {
 		d(printf("  '%s' -> '%s'\n", pathu8, full_name));
 		camel_store_info_set_string((CamelStoreSummary *)s, (CamelStoreInfo *)info, CAMEL_STORE_INFO_LAST, full_name);
-	} else
+	} else {
 		d(printf("  failed\n"));
+	}
 
 	return info;
 }
 
-char *
-camel_groupwise_store_summary_full_from_path(CamelGroupwiseStoreSummary *s, const char *path)
+gchar *
+camel_groupwise_store_summary_full_from_path(CamelGroupwiseStoreSummary *s, const gchar *path)
 {
 	CamelGroupwiseStoreNamespace *ns;
-	char *name = NULL;
+	gchar *name = NULL;
 
 	ns = camel_groupwise_store_summary_namespace_find_path(s, path);
 	if (ns)
@@ -400,11 +401,11 @@ camel_groupwise_store_summary_full_from_path(CamelGroupwiseStoreSummary *s, cons
 }
 
 CamelGroupwiseStoreNamespace *
-camel_groupwise_store_summary_namespace_new(CamelGroupwiseStoreSummary *s, const char *full_name, char dir_sep)
+camel_groupwise_store_summary_namespace_new(CamelGroupwiseStoreSummary *s, const gchar *full_name, gchar dir_sep)
 {
 	CamelGroupwiseStoreNamespace *ns;
-	char *p, *o, c;
-	int len;
+	gchar *p, *o, c;
+	gint len;
 
 	ns = g_malloc0(sizeof(*ns));
 	ns->full_name = g_strdup(full_name);
@@ -426,7 +427,7 @@ camel_groupwise_store_summary_namespace_new(CamelGroupwiseStoreSummary *s, const
 	return ns;
 }
 
-void 
+void
 camel_groupwise_store_summary_namespace_set(CamelGroupwiseStoreSummary *s, CamelGroupwiseStoreNamespace *ns)
 {
 	d(printf("Setting namesapce to '%s' '%c' -> '%s'\n", ns->full_name, ns->sep, ns->path));
@@ -436,9 +437,9 @@ camel_groupwise_store_summary_namespace_set(CamelGroupwiseStoreSummary *s, Camel
 }
 
 CamelGroupwiseStoreNamespace *
-camel_groupwise_store_summary_namespace_find_path(CamelGroupwiseStoreSummary *s, const char *path)
+camel_groupwise_store_summary_namespace_find_path(CamelGroupwiseStoreSummary *s, const gchar *path)
 {
-	int len;
+	gint len;
 	CamelGroupwiseStoreNamespace *ns;
 
 	/* NB: this currently only compares against 1 namespace, in future compare against others */
@@ -458,41 +459,41 @@ camel_groupwise_store_summary_namespace_find_path(CamelGroupwiseStoreSummary *s,
 
 
 
-static int
+static gint
 summary_header_load(CamelStoreSummary *s, FILE *in)
 {
-	CamelGroupwiseStoreSummary *summary = (CamelGroupwiseStoreSummary *)s ;
-	 gint32 version, capabilities, count ;
+	CamelGroupwiseStoreSummary *summary = (CamelGroupwiseStoreSummary *)s;
+	 gint32 version, capabilities, count;
+
+	namespace_clear (s);
 
-	namespace_clear (s) ;
-	
 	if (camel_groupwise_store_summary_parent->summary_header_load ((CamelStoreSummary *)s, in) == -1
 			|| camel_file_util_decode_fixed_int32(in, &version) == -1)
-		return -1 ;
+		return -1;
 
-	summary->version = version ;
+	summary->version = version;
 
 	if (camel_file_util_decode_fixed_int32(in, &capabilities) == -1
 			|| camel_file_util_decode_fixed_int32(in, &count) == -1
 			|| count > 1)
 		return -1;
 
-	summary->capabilities = capabilities ;
+	summary->capabilities = capabilities;
 	if (count == 1) {
-		if ((summary->namespace = namespace_load (s, in)) == NULL)	
-			return -1 ;
+		if ((summary->namespace = namespace_load (s, in)) == NULL)
+			return -1;
 	}
-	return 0 ;
+	return 0;
 }
 
 
-static int
+static gint
 summary_header_save(CamelStoreSummary *s, FILE *out)
 {
-	CamelGroupwiseStoreSummary *summary = (CamelGroupwiseStoreSummary *) s ;
-	guint32 count ;
+	CamelGroupwiseStoreSummary *summary = (CamelGroupwiseStoreSummary *) s;
+	guint32 count;
 
-	count = summary->namespace?1:0 ;
+	count = summary->namespace?1:0;
 	if (camel_groupwise_store_summary_parent->summary_header_save((CamelStoreSummary *)s, out) == -1
 			|| camel_file_util_encode_fixed_int32(out, 0) == -1
 			|| camel_file_util_encode_fixed_int32(out, summary->capabilities) == -1
@@ -503,7 +504,7 @@ summary_header_save(CamelStoreSummary *s, FILE *out)
 		return -1;
 
 
-	return 0 ;
+	return 0;
 }
 
 static CamelStoreInfo *
@@ -522,7 +523,7 @@ store_info_load(CamelStoreSummary *s, FILE *in)
 	return (CamelStoreInfo *)si;
 }
 
-static int
+static gint
 store_info_save(CamelStoreSummary *s, FILE *out, CamelStoreInfo *mi)
 {
 	CamelGroupwiseStoreInfo *summary = (CamelGroupwiseStoreInfo *)mi;
@@ -548,8 +549,8 @@ store_info_free(CamelStoreSummary *s, CamelStoreInfo *mi)
 
 
 
-static const char *
-store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, int type)
+static const gchar *
+store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, gint type)
 {
 	CamelGroupwiseStoreInfo *isi = (CamelGroupwiseStoreInfo *)mi;
 
@@ -566,7 +567,7 @@ store_info_string(CamelStoreSummary *s, const CamelStoreInfo *mi, int type)
 }
 
 static void
-store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *mi, int type, const char *str)
+store_info_set_string(CamelStoreSummary *s, CamelStoreInfo *mi, gint type, const gchar *str)
 {
 	CamelGroupwiseStoreInfo *isi = (CamelGroupwiseStoreInfo *)mi;
 
