@@ -39,7 +39,7 @@
 #include <glib/gstdio.h>
 
 #include "camel-debug.h"
-#include "camel-folder.h" 
+#include "camel-folder.h"
 #include "camel-net-utils.h"
 #include "camel-private.h"
 #include "camel-session.h"
@@ -51,21 +51,21 @@
 #include "camel-groupwise-summary.h"
 #include "camel-groupwise-utils.h"
 
-#define d(x) 
+#define d(x)
 #define CURSOR_ITEM_LIMIT 100
 #define JUNK_ENABLE 1
 #define JUNK_PERSISTENCE 14
 
-const char * CREATE_CURSOR_VIEW = "peek id default recipient threading hasAttachment subject status priority startDate created delivered size recurrenceKey";
+const gchar * CREATE_CURSOR_VIEW = "peek id default recipient threading hasAttachment subject status priority startDate created delivered size recurrenceKey";
 
 struct _CamelGroupwiseStorePrivate {
-	char *server_name;
-	char *port;
-	char *user;
-	char *use_ssl;
+	gchar *server_name;
+	gchar *port;
+	gchar *user;
+	gchar *use_ssl;
 
-	char *base_url;
-	char *storage_path;
+	gchar *base_url;
+	gchar *storage_path;
 
 	GHashTable *id_hash; /*get names from ids*/
 	GHashTable *name_hash;/*get ids from names*/
@@ -76,9 +76,9 @@ struct _CamelGroupwiseStorePrivate {
 static CamelOfflineStoreClass *parent_class = NULL;
 
 extern CamelServiceAuthType camel_groupwise_password_authtype; /*for the query_auth_types function*/
-static CamelFolderInfo *convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, const char *url, CamelException *ex);
+static CamelFolderInfo *convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, const gchar *url, CamelException *ex);
 static void groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex);
-static int match_path(const char *path, const char *name);
+static gint match_path(const gchar *path, const gchar *name);
 
 
 
@@ -89,9 +89,9 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (service);
 	CamelStore *store = CAMEL_STORE (service);
-	const char *property_value;
+	const gchar *property_value;
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
-	char *path = NULL;
+	gchar *path = NULL;
 
 	d(printf ("\nin groupwise store constrcut\n"));
 
@@ -110,12 +110,12 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 	 * This is a dirty hack. But it *WORKS*
 	 */
 	groupwise_store->list_loaded = 3;
-	
+
 	/*storage path*/
 	priv->storage_path = camel_session_get_storage_path (session, service, ex);
 	if (!priv->storage_path)
 		return;
-	
+
 	/*store summary*/
 	path = g_alloca (strlen (priv->storage_path) + 32);
 	sprintf (path, "%s/.summary", priv->storage_path);
@@ -123,7 +123,7 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 	camel_store_summary_set_filename ((CamelStoreSummary *)groupwise_store->summary, path);
 	camel_store_summary_touch ((CamelStoreSummary *)groupwise_store->summary);
 	camel_store_summary_load ((CamelStoreSummary *) groupwise_store->summary);
-	
+
 	/*host and user*/
 	priv->server_name = g_strdup (url->host);
 	priv->user = g_strdup (url->user);
@@ -143,10 +143,10 @@ groupwise_store_construct (CamelService *service, CamelSession *session,
 		priv->port = g_strdup (property_value);
 
 	/*filter*/
-	if (camel_url_get_param (url, "filter")) 
+	if (camel_url_get_param (url, "filter"))
 		store->flags |= CAMEL_STORE_FILTER_INBOX;
-	
-	/*Hash Table*/	
+
+	/*Hash Table*/
 	priv->id_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	priv->name_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	priv->parent_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
@@ -180,20 +180,20 @@ groupwise_auth_loop (CamelService *service, CamelException *ex)
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
 	gboolean authenticated = FALSE;
-	char *uri;
+	gchar *uri;
 	EGwConnectionErrors errors = {E_GW_CONNECTION_STATUS_INVALID_OBJECT, NULL};
 
-	if (priv->use_ssl && !g_str_equal (priv->use_ssl, "never")) 
+	if (priv->use_ssl && !g_str_equal (priv->use_ssl, "never"))
 		uri = g_strconcat ("https://", priv->server_name, ":", priv->port, "/soap", NULL);
-	else 
+	else
 		uri = g_strconcat ("http://", priv->server_name, ":", priv->port, "/soap", NULL);
 	service->url->passwd = NULL;
-	
+
 
 	while (!authenticated) {
-	
+
 		if (!service->url->passwd && !(store->flags & CAMEL_STORE_PROXY)) {
-			char *prompt;
+			gchar *prompt;
 
 			prompt = camel_session_build_password_prompt (
 				"GroupWise", service->url->user, service->url->host);
@@ -211,7 +211,7 @@ groupwise_auth_loop (CamelService *service, CamelException *ex)
 
 		priv->cnc = e_gw_connection_new_with_error_handler (uri, priv->user, service->url->passwd, &errors);
 		if (!E_IS_GW_CONNECTION(priv->cnc) && priv->use_ssl && g_str_equal (priv->use_ssl, "when-possible")) {
-			char *http_uri = g_strconcat ("http://", uri + 8, NULL);
+			gchar *http_uri = g_strconcat ("http://", uri + 8, NULL);
 			priv->cnc = e_gw_connection_new (http_uri, priv->user, service->url->passwd);
 			g_free (http_uri);
 		}
@@ -262,9 +262,9 @@ check_for_connection (CamelService *service, CamelException *ex)
 void
 groupwise_store_set_current_folder (CamelGroupwiseStore *groupwise_store, CamelFolder *folder)
 {
-		
+
 	CAMEL_SERVICE_REC_LOCK (groupwise_store, connect_lock);
-	
+
 	if (groupwise_store->current_folder) {
 		camel_object_unref (groupwise_store->current_folder);
 		groupwise_store->current_folder = NULL;
@@ -274,7 +274,7 @@ groupwise_store_set_current_folder (CamelGroupwiseStore *groupwise_store, CamelF
 		camel_object_ref (folder);
 		groupwise_store->current_folder = folder;
 	}
-	
+
 	CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 }
 
@@ -287,8 +287,8 @@ groupwise_connect (CamelService *service, CamelException *ex)
 	CamelSession *session = service->session;
 
 	d("in groupwise store connect\n");
-	
-/*	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL || 
+
+/*	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL ||
 	     (service->status == CAMEL_SERVICE_DISCONNECTED))
 		return FALSE; */
 	if (service->status == CAMEL_SERVICE_DISCONNECTED)
@@ -301,7 +301,7 @@ groupwise_connect (CamelService *service, CamelException *ex)
 	}
 
 	CAMEL_SERVICE_REC_LOCK (service, connect_lock);
-	
+
 	if (priv->cnc) {
 		CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
 		return TRUE;
@@ -312,14 +312,14 @@ groupwise_connect (CamelService *service, CamelException *ex)
 		camel_service_disconnect (service, TRUE, NULL);
 		return FALSE;
 	}
-	
-	
+
+
 	service->status = CAMEL_SERVICE_CONNECTED;
 	((CamelOfflineStore *) store)->state = CAMEL_OFFLINE_STORE_NETWORK_AVAIL;
 
 	if (!e_gw_connection_get_version (priv->cnc)) {
-		camel_session_alert_user(session, 
-				CAMEL_SESSION_ALERT_WARNING, 
+		camel_session_alert_user(session,
+				CAMEL_SESSION_ALERT_WARNING,
 				_("Some features may not work correctly with your current server version"),
 				FALSE);
 
@@ -349,13 +349,13 @@ groupwise_disconnect_cleanup (CamelService *service, gboolean clean, CamelExcept
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (service);
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
-	
+
 	g_print ("camel_groupwise_store_finalize\n");
 	if (groupwise_store->summary) {
 		camel_store_summary_save ((CamelStoreSummary *)groupwise_store->summary);
 		camel_object_unref (groupwise_store->summary);
 	}
-	
+
 	if (priv) {
 		if (priv->user) {
 			g_free (priv->user);
@@ -377,13 +377,13 @@ groupwise_disconnect_cleanup (CamelService *service, gboolean clean, CamelExcept
 			g_free (priv->base_url);
 			priv->base_url = NULL;
 		}
-		
+
 		if (priv->storage_path)
 			g_free(priv->storage_path);
 
 		if(groupwise_store->root_container)
 			g_free (groupwise_store->root_container);
-		
+
 		if (priv->id_hash)
 			g_hash_table_destroy (priv->id_hash);
 
@@ -403,7 +403,7 @@ static gboolean
 groupwise_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (service);
-	
+
 	if (clean) {
 		CAMEL_SERVICE_REC_LOCK (groupwise_store, connect_lock);
 		if (groupwise_store->priv && groupwise_store->priv->cnc) {
@@ -415,8 +415,8 @@ groupwise_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 
 		CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 	}
-	
-	//groupwise_disconnect_cleanup (service, clean, ex);
+
+	/* groupwise_disconnect_cleanup (service, clean, ex); */
 	return TRUE;
 }
 
@@ -424,14 +424,14 @@ static  GList*
 groupwise_store_query_auth_types (CamelService *service, CamelException *ex)
 {
 	GList *auth_types = NULL;
-	
+
 	d("in query auth types\n");
 	auth_types = g_list_prepend (auth_types,  &camel_groupwise_password_authtype);
 	return auth_types;
 }
 
 static gboolean
-groupwise_is_system_folder (const char *folder_name)
+groupwise_is_system_folder (const gchar *folder_name)
 {
 	if (!strcmp (folder_name, "Mailbox") ||
 	    !strcmp (folder_name, "Trash") ||
@@ -446,10 +446,10 @@ groupwise_is_system_folder (const char *folder_name)
 
 /*Build/populate CamelFolderInfo structure based on the imap_build_folder_info function*/
 static CamelFolderInfo *
-groupwise_build_folder_info(CamelGroupwiseStore *gw_store, const char *parent_name, const char *folder_name)
+groupwise_build_folder_info(CamelGroupwiseStore *gw_store, const gchar *parent_name, const gchar *folder_name)
 {
 	CamelURL *url;
-	const char *name;
+	const gchar *name;
 	CamelFolderInfo *fi;
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 
@@ -488,21 +488,21 @@ groupwise_build_folder_info(CamelGroupwiseStore *gw_store, const char *parent_na
 
 	if (groupwise_is_system_folder (folder_name))
 		fi->flags |= CAMEL_FOLDER_SYSTEM;
-	
+
 
 	fi->name = g_strdup(name);
 	return fi;
 }
 
 static void
-groupwise_forget_folder (CamelGroupwiseStore *gw_store, const char *folder_name, CamelException *ex)
+groupwise_forget_folder (CamelGroupwiseStore *gw_store, const gchar *folder_name, CamelException *ex)
 {
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
-	char *state_file;
-	char *folder_dir, *storage_path;
+	gchar *state_file;
+	gchar *folder_dir, *storage_path;
 	CamelFolderInfo *fi;
-	const char *name;
-	
+	const gchar *name;
+
 	name = folder_name;
 
 	storage_path = g_strdup_printf ("%s/folders", priv->storage_path);
@@ -529,12 +529,12 @@ groupwise_forget_folder (CamelGroupwiseStore *gw_store, const char *folder_name,
 }
 
 static CamelFolder *
-groupwise_get_folder_from_disk (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
+groupwise_get_folder_from_disk (CamelStore *store, const gchar *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelGroupwiseStore *gw_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 	CamelFolder *folder;
-	char *folder_dir, *storage_path;
+	gchar *folder_dir, *storage_path;
 
 	storage_path = g_strdup_printf("%s/folders", priv->storage_path);
 	folder_dir = e_path_to_physical (storage_path, folder_name);
@@ -552,22 +552,22 @@ groupwise_get_folder_from_disk (CamelStore *store, const char *folder_name, guin
 	return folder;
 }
 
-static CamelFolder * 
-groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
+static CamelFolder *
+groupwise_get_folder (CamelStore *store, const gchar *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelGroupwiseStore *gw_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 	CamelFolder *folder;
 	CamelGroupwiseSummary *summary;
-	char *container_id, *folder_dir, *storage_path;
+	gchar *container_id, *folder_dir, *storage_path;
 	EGwConnectionStatus status;
 	GList *list = NULL;
 	gboolean done = FALSE, all_ok = TRUE;
-	const char *position = E_GW_CURSOR_POSITION_END; 
-	int count = 0, cursor, summary_count = 0;
+	const gchar *position = E_GW_CURSOR_POSITION_END;
+	gint count = 0, cursor, summary_count = 0;
 	CamelStoreInfo *si = NULL;
 	guint total = 0;
-	
+
 	folder = groupwise_get_folder_from_disk (store, folder_name, flags, ex);
 	if (folder) {
 		groupwise_store_set_current_folder (gw_store, folder);
@@ -584,7 +584,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 		return NULL;
 	}
-	
+
 	if (!E_IS_GW_CONNECTION( priv->cnc)) {
 		if (!groupwise_connect (CAMEL_SERVICE(store), ex)) {
 			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
@@ -592,7 +592,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 		}
 	}
 
-	container_id = 	g_strdup (g_hash_table_lookup (priv->name_hash, folder_name));
+	container_id =	g_strdup (g_hash_table_lookup (priv->name_hash, folder_name));
 
 
 	storage_path = g_strdup_printf("%s/folders", priv->storage_path);
@@ -607,7 +607,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 		return NULL;
 	}
 	g_free (folder_dir);
-	
+
 	si = camel_store_summary_path ((CamelStoreSummary *)gw_store->summary, folder_name);
 	if (si) {
 		total = si->total;
@@ -620,10 +620,16 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	if(!summary_count || !summary->time_string) {
 		d(g_print ("\n\n** %s **: No summary as yet : using get cursor request\n\n", folder->name);)
 
-		status = e_gw_connection_create_cursor (priv->cnc, container_id, 
+		status = e_gw_connection_create_cursor (priv->cnc, container_id,
 				CREATE_CURSOR_VIEW,
 				NULL,
 				&cursor);
+		if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+			status = e_gw_connection_create_cursor (priv->cnc, container_id,
+				CREATE_CURSOR_VIEW,
+				NULL,
+				&cursor);
+
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 			g_free (container_id);
@@ -634,8 +640,8 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 		camel_folder_summary_clear (folder->summary);
 
 		while (!done) {
-				status = e_gw_connection_read_cursor (priv->cnc, container_id, 
-								cursor, FALSE, 
+				status = e_gw_connection_read_cursor (priv->cnc, container_id,
+								cursor, FALSE,
 								CURSOR_ITEM_LIMIT, position, &list);
 				if (status != E_GW_CONNECTION_STATUS_OK) {
 						all_ok = FALSE;
@@ -667,8 +673,8 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 
 				gw_update_summary (folder, list,  ex);
 
-				/* For shared-folders created by the user, we don't get the total number of messages, 
-				in the getFolderList call. So, we need to wait until an empty list is returned in the 
+				/* For shared-folders created by the user, we don't get the total number of messages,
+				in the getFolderList call. So, we need to wait until an empty list is returned in the
 				read cursor call. Hence, we need the !list checking in the code below */
 				if (count == total || !list)
 						done = TRUE;
@@ -682,7 +688,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 		e_gw_connection_destroy_cursor (priv->cnc, container_id, cursor);
 
 		camel_operation_end (NULL);
-	} 
+	}
 	if (done && all_ok) {
 		if (summary->time_string)
 			g_free (summary->time_string);
@@ -699,20 +705,20 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	return folder;
 }
 
-void 
+void
 gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guint32 flags, CamelException *ex)
 {
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 	CamelGroupwiseSummary *summary;
-	char *container_id;
+	gchar *container_id;
 	EGwConnectionStatus status;
 	GList *list = NULL;
 	gboolean done = FALSE;
-	const char *position = E_GW_CURSOR_POSITION_END; 
-	int count = 0, cursor, summary_count = 0;
+	const gchar *position = E_GW_CURSOR_POSITION_END;
+	gint count = 0, cursor, summary_count = 0;
 	CamelStoreInfo *si = NULL;
 	guint total = 0;
-	
+
 	camel_exception_clear (ex);
 
 	CAMEL_SERVICE_REC_LOCK (gw_store, connect_lock);
@@ -721,15 +727,15 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 		return;
 	}
-	
+
 	if (!E_IS_GW_CONNECTION( priv->cnc)) {
 		if (!groupwise_connect (CAMEL_SERVICE((CamelStore*)gw_store), ex)) {
 			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 			return;
 		}
 	}
-	
-	container_id = 	g_strdup (g_hash_table_lookup (priv->name_hash, folder->full_name));
+
+	container_id =	g_strdup (g_hash_table_lookup (priv->name_hash, folder->full_name));
 
 	si = camel_store_summary_path ((CamelStoreSummary *)gw_store->summary, folder->name);
 	if (si) {
@@ -745,7 +751,12 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 	if(!summary_count || !summary->time_string) {
 			d(g_print ("\n\n** %s **: Summary missing???? Reloading summary....\n\n", folder->name);)
 
-					status = e_gw_connection_create_cursor (priv->cnc, container_id, 
+					status = e_gw_connection_create_cursor (priv->cnc, container_id,
+									CREATE_CURSOR_VIEW,
+									NULL,
+									&cursor);
+			if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+					status = e_gw_connection_create_cursor (priv->cnc, container_id,
 									CREATE_CURSOR_VIEW,
 									NULL,
 									&cursor);
@@ -758,8 +769,8 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 			camel_operation_start (NULL, _("Fetching summary information for new messages in %s"), folder->name);
 
 			while (!done) {
-					status = e_gw_connection_read_cursor (priv->cnc, container_id, 
-									cursor, FALSE, 
+					status = e_gw_connection_read_cursor (priv->cnc, container_id,
+									cursor, FALSE,
 									CURSOR_ITEM_LIMIT, position, &list);
 					if (status != E_GW_CONNECTION_STATUS_OK) {
 							CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
@@ -785,8 +796,8 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 
 					gw_update_summary (folder, list,  ex);
 
-					/* For shared-folders created by the user, we don't get the total number of messages, 
-					   in the getFolderList call. So, we need to wait until an empty list is returned in the 
+					/* For shared-folders created by the user, we don't get the total number of messages,
+					   in the getFolderList call. So, we need to wait until an empty list is returned in the
 					   read cursor call. Hence, we need the !list checking in the code below */
 					if (count == total || !list)
 							done = TRUE;
@@ -800,7 +811,7 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 			e_gw_connection_destroy_cursor (priv->cnc, container_id, cursor);
 
 			camel_operation_end (NULL);
-	} 
+	}
 
 	if (done) {
 		if (summary->time_string)
@@ -811,17 +822,17 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 	camel_folder_summary_save_to_db (folder->summary, ex);
 
 	groupwise_store_set_current_folder (gw_store, NULL);
-	
+
 	g_free (container_id);
 	CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 	return;
 }
 
 static CamelFolderInfo *
-convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, const char *url, CamelException *ex)
+convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, const gchar *url, CamelException *ex)
 {
-	const char *name = NULL, *id = NULL, *parent = NULL;
-	char *par_name = NULL;
+	const gchar *name = NULL, *id = NULL, *parent = NULL;
+	gchar *par_name = NULL;
 	CamelFolderInfo *fi;
 	CamelGroupwiseStoreInfo *si = NULL;
 	CamelGroupwiseStorePrivate *priv = store->priv;
@@ -848,7 +859,7 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 		(type == E_GW_CONTAINER_TYPE_DRAFT) ||
 		(type == E_GW_CONTAINER_TYPE_CABINET) ||
 		(type == E_GW_CONTAINER_TYPE_JUNK) ||
-		(type == E_GW_CONTAINER_TYPE_TRASH) ) 
+		(type == E_GW_CONTAINER_TYPE_TRASH) )
 		fi->flags |= CAMEL_FOLDER_SYSTEM;
 	/*
 	   parent_hash contains the "parent id <-> container id" combination. So we form
@@ -870,12 +881,12 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 			temp = g_hash_table_lookup (priv->id_hash, temp_parent );
 			if (temp == NULL) {
 				break;
-			}	
+			}
 			str = g_strconcat ( temp, "/", str, NULL);
 
 			temp_parent = g_hash_table_lookup (priv->parent_hash, temp_parent);
 
-		} 
+		}
 		fi->full_name = g_strdup (str);
 		fi->uri = g_strconcat (url, str, NULL);
 		g_free (str);
@@ -911,7 +922,7 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 	si->info.unread = fi->unread;
 	si->info.flags = fi->flags;
 	/*refresh info*/
-	if (store->current_folder 
+	if (store->current_folder
 	    && !strcmp (store->current_folder->full_name, fi->full_name)
 	    && type != E_GW_CONTAINER_TYPE_INBOX) {
 		CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS (store->current_folder))->refresh_info(store->current_folder, ex);
@@ -920,7 +931,7 @@ convert_to_folder_info (CamelGroupwiseStore *store, EGwContainer *container, con
 }
 
 static void
-get_folders_free (void *k, void *v, void *d)
+get_folders_free (gpointer k, gpointer v, gpointer d)
 {
 	CamelFolderInfo *fi = v;
 	camel_folder_info_free (fi);
@@ -930,13 +941,13 @@ static void
 groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 {
 	CamelGroupwiseStorePrivate  *priv = store->priv;
-	int status;
+	gint status;
 	GList *folder_list = NULL, *temp_list = NULL, *list = NULL;
-	char *url, *temp_url;
+	gchar *url, *temp_url;
 	CamelFolderInfo *info = NULL, *hfi = NULL;
 	GHashTable *present;
 	CamelStoreInfo *si = NULL;
-	int count, i;
+	gint count, i;
 
 	if (!priv->cnc && ((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_AVAIL) {
 		if (((CamelService *)store)->status == CAMEL_SERVICE_DISCONNECTED){
@@ -946,6 +957,8 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 	}
 
 	status = e_gw_connection_get_container_list (priv->cnc, "folders", &folder_list);
+	if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+		status = e_gw_connection_get_container_list (priv->cnc, "folders", &folder_list);
 	if (status != E_GW_CONNECTION_STATUS_OK) {
 		g_warning ("Could not get folder list..\n");
 		return;
@@ -961,13 +974,13 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 
 	if ( url[strlen(url) - 1] != '/') {
 		temp_url = g_strconcat (url, "/", NULL);
-		g_free ((char *)url);
+		g_free ((gchar *)url);
 		url = temp_url;
 	}
-	
+
 	/*populate the hash table for finding the mapping from container id <-> folder name*/
-	for (;temp_list != NULL ; temp_list = g_list_next (temp_list) ) {
-		const char *name, *id, *parent;
+	for (;temp_list != NULL; temp_list = g_list_next (temp_list) ) {
+		const gchar *name, *id, *parent;
 		name = e_gw_container_get_name (E_GW_CONTAINER (temp_list->data));
 		id = e_gw_container_get_id(E_GW_CONTAINER(temp_list->data));
 		parent = e_gw_container_get_parent_id (E_GW_CONTAINER(temp_list->data));
@@ -980,7 +993,7 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 		}
 
 		/*id_hash returns the name for a given container id*/
-		g_hash_table_insert (priv->id_hash, g_strdup(id), g_strdup(name)); 
+		g_hash_table_insert (priv->id_hash, g_strdup(id), g_strdup(name));
 		/*parent_hash returns the parent container id, given an id*/
 		g_hash_table_insert (priv->parent_hash, g_strdup(id), g_strdup(parent));
 	}
@@ -990,7 +1003,7 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 	for (;folder_list != NULL; folder_list = g_list_next (folder_list)) {
 		EGwContainerType type;
 		EGwContainer *container = E_GW_CONTAINER (folder_list->data);
-		
+
 		type = e_gw_container_get_container_type (container);
 
 		if (e_gw_container_is_root(container))
@@ -998,7 +1011,7 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 		if ( (type == E_GW_CONTAINER_TYPE_CALENDAR) || (type == E_GW_CONTAINER_TYPE_CONTACTS) )
 			continue;
 
-		info = convert_to_folder_info (store, E_GW_CONTAINER (folder_list->data), (const char *)url, ex);
+		info = convert_to_folder_info (store, E_GW_CONTAINER (folder_list->data), (const gchar *)url, ex);
 		if (info) {
 			hfi = g_hash_table_lookup (present, info->full_name);
 			if (hfi == NULL)
@@ -1009,8 +1022,8 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 			}
 		}
 	}
-	
-	g_free ((char *)url);
+
+	g_free ((gchar *)url);
 	e_gw_connection_free_container_list (list);
 	count = camel_store_summary_count ((CamelStoreSummary *)store->summary);
 
@@ -1036,14 +1049,14 @@ groupwise_folders_sync (CamelGroupwiseStore *store, CamelException *ex)
 }
 
 static CamelFolderInfo *
-groupwise_get_folder_info_offline (CamelStore *store, const char *top,
+groupwise_get_folder_info_offline (CamelStore *store, const gchar *top,
 			 guint32 flags, CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelFolderInfo *fi;
 	GPtrArray *folders;
-	char *path, *name;
-	int i;
+	gchar *path, *name;
+	gint i;
 
 	folders = g_ptr_array_new ();
 
@@ -1064,9 +1077,9 @@ groupwise_get_folder_info_offline (CamelStore *store, const char *top,
 	for (i=0;i<camel_store_summary_count((CamelStoreSummary *)groupwise_store->summary);i++) {
 		CamelStoreInfo *si = camel_store_summary_index((CamelStoreSummary *)groupwise_store->summary, i);
 
-		if (si == NULL) 
+		if (si == NULL)
 			continue;
-		
+
 		if ( !strcmp(name, camel_groupwise_store_info_full_name (groupwise_store->summary, si))
 		     || match_path (path, camel_groupwise_store_info_full_name (groupwise_store->summary, si))) {
 			fi = groupwise_build_folder_info(groupwise_store, NULL, camel_store_info_path((CamelStoreSummary *)groupwise_store->summary, si));
@@ -1130,13 +1143,13 @@ static CamelSessionThreadOps store_refresh_ops = {
 /*** Thread stuff ends ***/
 
 static CamelFolderInfo *
-groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, CamelException *ex)
+groupwise_get_folder_info (CamelStore *store, const gchar *top, guint32 flags, CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
 	CamelFolderInfo *info = NULL;
-	char *top_folder = NULL;
-	
+	gchar *top_folder = NULL;
+
 	if (top) {
 		top_folder = g_hash_table_lookup (priv->name_hash, top);
 		/* 'top' is a valid path, but doesnt have a container id
@@ -1148,7 +1161,7 @@ groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, Ca
 		}*/
 	}
 
-	if (top && groupwise_is_system_folder (top)) 
+	if (top && groupwise_is_system_folder (top))
 		return groupwise_build_folder_info (groupwise_store, NULL, top );
 
 	/*
@@ -1182,7 +1195,7 @@ groupwise_get_folder_info (CamelStore *store, const char *top, guint32 flags, Ca
 		if (!priv->cnc) {
 			if (groupwise_connect ((CamelService *)store, ex)) {
 				g_warning ("Could connect!!!\n");
-			} else 
+			} else
 				g_warning ("Could not connect..failure connecting\n");
 		}
 		if (camel_groupwise_store_connected (groupwise_store, ex)) {
@@ -1212,25 +1225,27 @@ create_junk_folder (CamelStore *store)
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate  *priv = groupwise_store->priv;
 	CamelFolderInfo *root = NULL;
-	char *parent_name, *folder_name, *child_container_id, *parent_id;
-	int status;
+	const gchar *parent_name, *folder_name, *child_container_id, *parent_id;
+	gint status;
 
 	parent_name = "";
 	folder_name = "Junk Mail";
 	parent_id = "";
 	/* TODO: check for offlining*/
-		
+
 	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 	status = e_gw_connection_modify_junk_settings (priv->cnc, JUNK_ENABLE, 0, 0,  JUNK_PERSISTENCE);
+	if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+		status = e_gw_connection_modify_junk_settings (priv->cnc, JUNK_ENABLE, 0, 0,  JUNK_PERSISTENCE);
 	if (status == E_GW_CONNECTION_STATUS_OK) {
 		root = groupwise_build_folder_info(groupwise_store, parent_name, folder_name);
 		camel_store_summary_save((CamelStoreSummary *)groupwise_store->summary);
-		
+
 		child_container_id = e_gw_connection_get_container_id (priv->cnc, "Junk Mail");
 		if (!child_container_id)
 			g_warning("failed to retrieve id for junk folder");
-		
-		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name)); 
+
+		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name));
 		g_hash_table_insert (priv->name_hash, g_strdup(folder_name), g_strdup(child_container_id));
 		g_hash_table_insert (priv->parent_hash, g_strdup(child_container_id), g_strdup(parent_id));
 		camel_object_trigger_event (CAMEL_OBJECT (store), "folder_created", root);
@@ -1242,21 +1257,22 @@ create_junk_folder (CamelStore *store)
 
 static CamelFolderInfo*
 groupwise_create_folder(CamelStore *store,
-		const char *parent_name,
-		const char *folder_name,
+		const gchar *parent_name,
+		const gchar *folder_name,
 		CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate  *priv = groupwise_store->priv;
 	CamelFolderInfo *root = NULL;
-	char *parent_id , *child_container_id;
-	int status;
+	const gchar *parent_id;
+	gchar *child_container_id;
+	gint status;
 
 	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot create GroupWise folders in offline mode."));
 		return NULL;
 	}
-	
+
 	if(parent_name == NULL) {
 		parent_name = "";
 		if (groupwise_is_system_folder (folder_name)) {
@@ -1281,11 +1297,13 @@ groupwise_create_folder(CamelStore *store,
 	}
 	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 	status = e_gw_connection_create_folder(priv->cnc,parent_id,folder_name, &child_container_id);
+	if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+		status = e_gw_connection_create_folder(priv->cnc,parent_id,folder_name, &child_container_id);
 	if (status == E_GW_CONNECTION_STATUS_OK) {
 		root = groupwise_build_folder_info(groupwise_store, parent_name,folder_name);
 		camel_store_summary_save((CamelStoreSummary *)groupwise_store->summary);
 
-		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name)); 
+		g_hash_table_insert (priv->id_hash, g_strdup(child_container_id), g_strdup(folder_name));
 		g_hash_table_insert (priv->name_hash, g_strdup(root->full_name), g_strdup(child_container_id));
 		g_hash_table_insert (priv->parent_hash, g_strdup(child_container_id), g_strdup(parent_id));
 
@@ -1295,15 +1313,15 @@ groupwise_create_folder(CamelStore *store,
 	return root;
 }
 
-static void 
+static void
 groupwise_delete_folder(CamelStore *store,
-				   const char *folder_name,
+				   const gchar *folder_name,
 				   CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate  *priv = groupwise_store->priv;
 	EGwConnectionStatus status;
-	const char * container;
+	const gchar * container;
 
 	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 
@@ -1315,6 +1333,8 @@ groupwise_delete_folder(CamelStore *store,
 	container = g_hash_table_lookup (priv->name_hash, folder_name);
 
 	status = e_gw_connection_remove_item (priv->cnc, container, container);
+	if (status == E_GW_CONNECTION_STATUS_INVALID_CONNECTION)
+		status = e_gw_connection_remove_item (priv->cnc, container, container);
 
 	if (status == E_GW_CONNECTION_STATUS_OK) {
 		groupwise_store_set_current_folder (groupwise_store, NULL);
@@ -1323,24 +1343,24 @@ groupwise_delete_folder(CamelStore *store,
 
 		g_hash_table_remove (priv->id_hash, container);
 		g_hash_table_remove (priv->name_hash, folder_name);
-		
+
 		g_hash_table_remove (priv->parent_hash, container);
 	}
 	CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 }
 
-static void 
+static void
 groupwise_rename_folder(CamelStore *store,
-		        const char *old_name,
-			const char *new_name,
+			const gchar *old_name,
+			const gchar *new_name,
 			CamelException *ex)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (store);
 	CamelGroupwiseStorePrivate  *priv = groupwise_store->priv;
-	char *oldpath, *newpath, *storepath;
-	const char *container_id;
-	char *temp_new = NULL;
-	
+	gchar *oldpath, *newpath, *storepath;
+	const gchar *container_id;
+	gchar *temp_new = NULL;
+
 	if (groupwise_is_system_folder (old_name)) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot rename GroupWise folder '%s' to '%s'"),
 				      old_name, new_name);
@@ -1361,7 +1381,7 @@ groupwise_rename_folder(CamelStore *store,
 	if (temp_new)
 		temp_new++;
 	else
-		temp_new = (char *)new_name;
+		temp_new = (gchar *)new_name;
 
 	if (!container_id || e_gw_connection_rename_folder (priv->cnc, container_id , temp_new) != E_GW_CONNECTION_STATUS_OK)
 	{
@@ -1393,26 +1413,26 @@ groupwise_rename_folder(CamelStore *store,
 	CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 }
 
-char * 
-groupwise_get_name(CamelService *service, gboolean brief) 
+gchar *
+groupwise_get_name(CamelService *service, gboolean brief)
 {
-	if(brief) 
+	if(brief)
 		return g_strdup_printf(_("GroupWise server %s"), service->url->host);
 	else
-		return g_strdup_printf(_("GroupWise service for %s on %s"), 
+		return g_strdup_printf(_("GroupWise service for %s on %s"),
 				       service->url->user, service->url->host);
 }
 
-const char *
-camel_groupwise_store_container_id_lookup (CamelGroupwiseStore *gw_store, const char *folder_name)
+const gchar *
+camel_groupwise_store_container_id_lookup (CamelGroupwiseStore *gw_store, const gchar *folder_name)
 {
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 
 	return g_hash_table_lookup (priv->name_hash, folder_name);
 }
 
-const char *
-camel_groupwise_store_folder_lookup (CamelGroupwiseStore *gw_store, const char *container_id)
+const gchar *
+camel_groupwise_store_folder_lookup (CamelGroupwiseStore *gw_store, const gchar *container_id)
 {
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 
@@ -1426,13 +1446,13 @@ cnc_lookup (CamelGroupwiseStorePrivate *priv)
 	return priv->cnc;
 }
 
-char *
+gchar *
 storage_path_lookup (CamelGroupwiseStorePrivate *priv)
 {
 	return priv->storage_path;
 }
 
-const char *
+const gchar *
 groupwise_base_url_lookup (CamelGroupwiseStorePrivate *priv)
 {
 	return priv->base_url;
@@ -1443,14 +1463,14 @@ groupwise_get_trash (CamelStore *store, CamelException *ex)
 {
 	CamelFolder *folder = camel_store_get_folder(store, "Trash", 0, ex);
 	if (folder) {
-		 char *state = g_build_filename((CAMEL_GROUPWISE_STORE(store))->priv->storage_path, "folders", "Trash", "cmeta", NULL);
+		 gchar *state = g_build_filename((CAMEL_GROUPWISE_STORE(store))->priv->storage_path, "folders", "Trash", "cmeta", NULL);
 
 		camel_object_set(folder, NULL, CAMEL_OBJECT_STATE_FILE, state, NULL);
 		g_free(state);
 		camel_object_state_read(folder);
 
 		return folder;
-	} else 
+	} else
 		return NULL;
 }
 
@@ -1468,7 +1488,7 @@ groupwise_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelExc
 /*
  * Function to check if we are both connected and are _actually_
  * online. Based on an equivalient function in IMAP
- */ 
+ */
 gboolean
 camel_groupwise_store_connected (CamelGroupwiseStore *store, CamelException *ex)
 {
@@ -1480,10 +1500,10 @@ camel_groupwise_store_connected (CamelGroupwiseStore *store, CamelException *ex)
 	return FALSE;
 }
 
-static int 
-match_path(const char *path, const char *name)
+static gint
+match_path(const gchar *path, const gchar *name)
 {
-	char p, n;
+	gchar p, n;
 
 	p = *path++;
 	n = *name++;
@@ -1514,18 +1534,18 @@ camel_groupwise_store_class_init (CamelGroupwiseStoreClass *camel_groupwise_stor
 		CAMEL_SERVICE_CLASS (camel_groupwise_store_class);
 	CamelStoreClass *camel_store_class =
 		CAMEL_STORE_CLASS (camel_groupwise_store_class);
-	
+
 	parent_class = CAMEL_OFFLINE_STORE_CLASS (camel_type_get_global_classfuncs (camel_offline_store_get_type ()));
-	
+
 	camel_service_class->construct = groupwise_store_construct;
 	camel_service_class->query_auth_types = groupwise_store_query_auth_types;
 	camel_service_class->get_name = groupwise_get_name;
 	camel_service_class->connect = groupwise_connect;
 	camel_service_class->disconnect = groupwise_disconnect;
-	
+
 	camel_store_class->hash_folder_name = groupwise_hash_folder_name;
 	camel_store_class->compare_folder_name = groupwise_compare_folder_name;
-	
+
 	camel_store_class->get_folder = groupwise_get_folder;
 	camel_store_class->create_folder = groupwise_create_folder;
 	camel_store_class->delete_folder = groupwise_delete_folder;
@@ -1543,13 +1563,13 @@ camel_groupwise_store_finalize (CamelObject *object)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (object);
 	CamelGroupwiseStorePrivate *priv = groupwise_store->priv;
-	
+
 	g_print ("camel_groupwise_store_finalize\n");
 	if (groupwise_store->summary) {
 		camel_store_summary_save ((CamelStoreSummary *)groupwise_store->summary);
 		camel_object_unref (groupwise_store->summary);
 	}
-	
+
 	if (priv) {
 		if (priv->user) {
 			g_free (priv->user);
@@ -1571,7 +1591,7 @@ camel_groupwise_store_finalize (CamelObject *object)
 			g_free (priv->base_url);
 			priv->base_url = NULL;
 		}
-		
+
 		if (E_IS_GW_CONNECTION (priv->cnc)) {
 			g_object_unref (priv->cnc);
 			priv->cnc = NULL;
@@ -1582,7 +1602,7 @@ camel_groupwise_store_finalize (CamelObject *object)
 
 		if(groupwise_store->root_container)
 			g_free (groupwise_store->root_container);
-		
+
 		if (priv->id_hash)
 			g_hash_table_destroy (priv->id_hash);
 
@@ -1603,7 +1623,7 @@ camel_groupwise_store_init (gpointer object, gpointer klass)
 {
 	CamelGroupwiseStore *groupwise_store = CAMEL_GROUPWISE_STORE (object);
 	CamelGroupwiseStorePrivate *priv = g_new0 (CamelGroupwiseStorePrivate, 1);
-	
+
 	d("in groupwise store init\n");
 	priv->server_name = NULL;
 	priv->port = NULL;
@@ -1612,14 +1632,14 @@ camel_groupwise_store_init (gpointer object, gpointer klass)
 	priv->cnc = NULL;
 	groupwise_store->priv = priv;
 	groupwise_store->current_folder = NULL;
-	
+
 }
 
 CamelType
 camel_groupwise_store_get_type (void)
 {
 	static CamelType camel_groupwise_store_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_groupwise_store_type == CAMEL_INVALID_TYPE)	{
 		camel_groupwise_store_type =
 			camel_type_register (camel_offline_store_get_type (),
@@ -1631,7 +1651,7 @@ camel_groupwise_store_get_type (void)
 					     (CamelObjectInitFunc) camel_groupwise_store_init,
 					     (CamelObjectFinalizeFunc) camel_groupwise_store_finalize);
 	}
-	
+
 	return camel_groupwise_store_type;
 }
 
