@@ -1,14 +1,14 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-imap-message-cache.c: Class for an IMAP message cache */
 
-/* 
- * Author: 
+/*
+ * Author:
  *   Dan Winship <danw@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -59,9 +59,9 @@ struct _part_find {
 	/* UID name on disk - e.g. "0." or "0.HEADERS". On windows "0." is
 	 * stored as "0.~"
 	 */
-	char *disk_part_name;
+	gchar *disk_part_name;
 	/* Was the part found? */
-	int found;
+	gint found;
 };
 
 
@@ -69,7 +69,7 @@ CamelType
 camel_imap_message_cache_get_type (void)
 {
 	static CamelType camel_imap_message_cache_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_imap_message_cache_type == CAMEL_INVALID_TYPE) {
 		camel_imap_message_cache_type = camel_type_register (
 			CAMEL_OBJECT_TYPE, "CamelImapMessageCache",
@@ -112,10 +112,10 @@ finalize (CamelImapMessageCache *cache)
 }
 
 static void
-cache_put (CamelImapMessageCache *cache, const char *uid, const char *key,
+cache_put (CamelImapMessageCache *cache, const gchar *uid, const gchar *key,
 	   CamelStream *stream)
 {
-	char *hash_key;
+	gchar *hash_key;
 	GPtrArray *subparts;
 	gpointer okey, ostream;
 	guint32 uidval;
@@ -165,13 +165,13 @@ cache_put (CamelImapMessageCache *cache, const char *uid, const char *key,
  * expensive, but the parts hash is immediately usable.
  **/
 CamelImapMessageCache *
-camel_imap_message_cache_new (const char *path, CamelFolderSummary *summary,
+camel_imap_message_cache_new (const gchar *path, CamelFolderSummary *summary,
 			      CamelException *ex)
 {
 	CamelImapMessageCache *cache;
 	GDir *dir;
-	const char *dname;
-	char *uid, *p;
+	const gchar *dname;
+	gchar *uid, *p;
 	GPtrArray *deletes;
 	GError *error = NULL;
 	GHashTable *shash;
@@ -205,7 +205,7 @@ camel_imap_message_cache_new (const char *path, CamelFolderSummary *summary,
 		if (g_hash_table_lookup(shash, uid))
 			cache_put (cache, uid, dname, NULL);
 		else
-			g_ptr_array_add (deletes, g_strdup_printf ("%s/%s", cache->path, dname)); 
+			g_ptr_array_add (deletes, g_strdup_printf ("%s/%s", cache->path, dname));
 
 		g_free (uid);
 	}
@@ -233,13 +233,13 @@ camel_imap_message_cache_new (const char *path, CamelFolderSummary *summary,
  **/
 
 gboolean
-camel_imap_message_cache_delete (const char *path, CamelException *ex)
+camel_imap_message_cache_delete (const gchar *path, CamelException *ex)
 {
 	GDir *dir;
-	const char *dname;
+	const gchar *dname;
 	GError *error = NULL;
 	GPtrArray *deletes;
-	
+
 	dir = g_dir_open (path, 0, &error);
 	if (!dir) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
@@ -251,8 +251,8 @@ camel_imap_message_cache_delete (const char *path, CamelException *ex)
 
 	deletes = g_ptr_array_new ();
 	while ((dname = g_dir_read_name (dir)))
-		g_ptr_array_add (deletes, g_strdup_printf ("%s/%s", path, dname)); 
-	
+		g_ptr_array_add (deletes, g_strdup_printf ("%s/%s", path, dname));
+
 	g_dir_close (dir);
 
 	while (deletes->len) {
@@ -279,13 +279,13 @@ camel_imap_message_cache_max_uid (CamelImapMessageCache *cache)
 
 /**
  * camel_imap_message_cache_set_path:
- * @cache: 
- * @path: 
- * 
+ * @cache:
+ * @path:
+ *
  * Set the path used for the message cache.
  **/
 void
-camel_imap_message_cache_set_path (CamelImapMessageCache *cache, const char *path)
+camel_imap_message_cache_set_path (CamelImapMessageCache *cache, const gchar *path)
 {
 	g_free(cache->path);
 	cache->path = g_strdup(path);
@@ -295,7 +295,7 @@ static void
 stream_finalize (CamelObject *stream, gpointer event_data, gpointer user_data)
 {
 	CamelImapMessageCache *cache = user_data;
-	char *key;
+	gchar *key;
 
 	key = g_hash_table_lookup (cache->cached, stream);
 	if (!key)
@@ -306,12 +306,12 @@ stream_finalize (CamelObject *stream, gpointer event_data, gpointer user_data)
 
 
 static CamelStream *
-insert_setup (CamelImapMessageCache *cache, const char *uid, const char *part_spec,
-	      char **path, char **key, CamelException *ex)
+insert_setup (CamelImapMessageCache *cache, const gchar *uid, const gchar *part_spec,
+	      gchar **path, gchar **key, CamelException *ex)
 {
 	CamelStream *stream;
-	int fd;
-	
+	gint fd;
+
 #ifdef G_OS_WIN32
 	/* Trailing periods in file names are silently dropped on
 	 * Win32, argh. The code in this file requires the period to
@@ -326,7 +326,7 @@ insert_setup (CamelImapMessageCache *cache, const char *uid, const char *part_sp
 	stream = g_hash_table_lookup (cache->parts, *key);
 	if (stream)
 		camel_object_unref (CAMEL_OBJECT (stream));
-	
+
 	fd = g_open (*path, O_RDWR | O_CREAT | O_TRUNC | O_BINARY, 0600);
 	if (fd == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
@@ -335,12 +335,12 @@ insert_setup (CamelImapMessageCache *cache, const char *uid, const char *part_sp
 		g_free (*path);
 		return NULL;
 	}
-	
+
 	return camel_stream_fs_new_with_fd (fd);
 }
 
 static CamelStream *
-insert_abort (char *path, CamelStream *stream)
+insert_abort (gchar *path, CamelStream *stream)
 {
 	g_unlink (path);
 	g_free (path);
@@ -349,8 +349,8 @@ insert_abort (char *path, CamelStream *stream)
 }
 
 static CamelStream *
-insert_finish (CamelImapMessageCache *cache, const char *uid, char *path,
-	       char *key, CamelStream *stream)
+insert_finish (CamelImapMessageCache *cache, const gchar *uid, gchar *path,
+	       gchar *key, CamelStream *stream)
 {
 	camel_stream_flush (stream);
 	camel_stream_reset (stream);
@@ -374,24 +374,24 @@ insert_finish (CamelImapMessageCache *cache, const char *uid, char *path,
  * caller must unref.
  **/
 CamelStream *
-camel_imap_message_cache_insert (CamelImapMessageCache *cache, const char *uid,
-				 const char *part_spec, const char *data,
-				 int len, CamelException *ex)
+camel_imap_message_cache_insert (CamelImapMessageCache *cache, const gchar *uid,
+				 const gchar *part_spec, const gchar *data,
+				 gint len, CamelException *ex)
 {
-	char *path, *key;
+	gchar *path, *key;
 	CamelStream *stream;
-	
+
 	stream = insert_setup (cache, uid, part_spec, &path, &key, ex);
 	if (!stream)
 		return NULL;
-	
+
 	if (camel_stream_write (stream, data, len) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Failed to cache message %s: %s"),
 				      uid, g_strerror (errno));
 		return insert_abort (path, stream);
 	}
-	
+
 	return insert_finish (cache, uid, path, key, stream);
 }
 
@@ -406,16 +406,16 @@ camel_imap_message_cache_insert (CamelImapMessageCache *cache, const char *uid,
  **/
 void
 camel_imap_message_cache_insert_stream (CamelImapMessageCache *cache,
-					const char *uid, const char *part_spec,
+					const gchar *uid, const gchar *part_spec,
 					CamelStream *data_stream, CamelException *ex)
 {
-	char *path, *key;
+	gchar *path, *key;
 	CamelStream *stream;
-	
+
 	stream = insert_setup (cache, uid, part_spec, &path, &key, ex);
 	if (!stream)
 		return;
-	
+
 	if (camel_stream_write_to_stream (data_stream, stream) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Failed to cache message %s: %s"),
@@ -438,16 +438,16 @@ camel_imap_message_cache_insert_stream (CamelImapMessageCache *cache,
  **/
 void
 camel_imap_message_cache_insert_wrapper (CamelImapMessageCache *cache,
-					 const char *uid, const char *part_spec,
+					 const gchar *uid, const gchar *part_spec,
 					 CamelDataWrapper *wrapper, CamelException *ex)
 {
-	char *path, *key;
+	gchar *path, *key;
 	CamelStream *stream;
 
 	stream = insert_setup (cache, uid, part_spec, &path, &key, ex);
 	if (!stream)
 		return;
-	
+
 	if (camel_data_wrapper_write_to_stream (wrapper, stream) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Failed to cache message %s: %s"),
@@ -468,17 +468,17 @@ camel_imap_message_cache_insert_wrapper (CamelImapMessageCache *cache,
  *
  * Return value: the filename of a cache item
  **/
-char*
+gchar *
 camel_imap_message_cache_get_filename (CamelImapMessageCache *cache,
-				       const char *uid,
-				       const char *part_spec,
+				       const gchar *uid,
+				       const gchar *part_spec,
 				       CamelException *ex)
 {
-	char *path;
-	
+	gchar *path;
+
 	if (uid[0] == 0)
 		return NULL;
-	
+
 #ifdef G_OS_WIN32
 	/* See comment in insert_setup() */
 	if (!*part_spec)
@@ -500,15 +500,15 @@ camel_imap_message_cache_get_filename (CamelImapMessageCache *cache,
  * caller must unref), or %NULL if that data is not cached.
  **/
 CamelStream *
-camel_imap_message_cache_get (CamelImapMessageCache *cache, const char *uid,
-			      const char *part_spec, CamelException *ex)
+camel_imap_message_cache_get (CamelImapMessageCache *cache, const gchar *uid,
+			      const gchar *part_spec, CamelException *ex)
 {
 	CamelStream *stream;
-	char *path, *key;
-	
+	gchar *path, *key;
+
 	if (uid[0] == 0)
 		return NULL;
-	
+
 #ifdef G_OS_WIN32
 	/* See comment in insert_setup() */
 	if (!*part_spec)
@@ -524,7 +524,7 @@ camel_imap_message_cache_get (CamelImapMessageCache *cache, const char *uid,
 		g_free (path);
 		return stream;
 	}
-	
+
 	stream = camel_stream_fs_new_with_name (path, O_RDONLY, 0);
 	if (stream) {
 		cache_put (cache, uid, key, stream);
@@ -533,9 +533,9 @@ camel_imap_message_cache_get (CamelImapMessageCache *cache, const char *uid,
 				      _("Failed to cache %s: %s"),
 				      part_spec, g_strerror (errno));
 	}
-	
+
 	g_free (path);
-	
+
 	return stream;
 }
 
@@ -547,12 +547,12 @@ camel_imap_message_cache_get (CamelImapMessageCache *cache, const char *uid,
  * Removes all data associated with @uid from @cache.
  **/
 void
-camel_imap_message_cache_remove (CamelImapMessageCache *cache, const char *uid)
+camel_imap_message_cache_remove (CamelImapMessageCache *cache, const gchar *uid)
 {
 	GPtrArray *subparts;
-	char *key, *path;
+	gchar *key, *path;
 	CamelObject *stream;
-	int i;
+	gint i;
 
 	subparts = g_hash_table_lookup (cache->parts, uid);
 	if (!subparts)
@@ -593,7 +593,7 @@ void
 camel_imap_message_cache_clear (CamelImapMessageCache *cache)
 {
 	GPtrArray *uids;
-	int i;
+	gint i;
 
 	uids = g_ptr_array_new ();
 	g_hash_table_foreach (cache->parts, add_uids, uids);
@@ -616,20 +616,20 @@ camel_imap_message_cache_clear (CamelImapMessageCache *cache)
  **/
 void
 camel_imap_message_cache_copy (CamelImapMessageCache *source,
-			       const char *source_uid,
+			       const gchar *source_uid,
 			       CamelImapMessageCache *dest,
-			       const char *dest_uid,
+			       const gchar *dest_uid,
 			       CamelException *ex)
 {
 	GPtrArray *subparts;
 	CamelStream *stream;
-	char *part;
-	int i;
-	
+	gchar *part;
+	gint i;
+
 	subparts = g_hash_table_lookup (source->parts, source_uid);
 	if (!subparts || !subparts->len)
 		return;
-	
+
 	for (i = 0; i < subparts->len; i++) {
 		part = strchr (subparts->pdata[i], '.');
 		if (!part++)
@@ -656,7 +656,7 @@ _match_part(gpointer part_name, gpointer user_data)
  * The intent is that only uids fully cached are returned, but that may not be
  * what is achieved. An additional constraint is that this check should be
  * cheap, so that going offline is not an expensive operation. Filtering all
- * uids is inefficient in the first place; significant processing per uid 
+ * uids is inefficient in the first place; significant processing per uid
  * makes synchronisation very expensive. At the suggestion of Srinivasa Ragavan
  * (see http://bugzilla.gnome.org/show_bug.cgi?id=564339) the cache->parts hash
  * table is consulted. If there is a parts-list in the hash table containing
@@ -676,7 +676,7 @@ GPtrArray *
 camel_imap_message_cache_filter_cached(CamelImapMessageCache *cache, GPtrArray *uids, CamelException *ex)
 {
 	GPtrArray *result, *parts_list;
-	int i;
+	gint i;
 	struct _part_find part_find;
 	/* Look for a part "" for each uid. */
 	result = g_ptr_array_sized_new(uids->len);
@@ -689,7 +689,7 @@ camel_imap_message_cache_filter_cached(CamelImapMessageCache *cache, GPtrArray *
 			 */
 			part_find.found = 0;
 			part_find.disk_part_name = g_strdup_printf("%s" BASE_PART_SUFFIX,
-								   (char *)uids->pdata[i]);
+								   (gchar *)uids->pdata[i]);
 			g_ptr_array_foreach(parts_list, _match_part, &part_find);
 			g_free(part_find.disk_part_name);
 			if (part_find.found)
@@ -701,7 +701,7 @@ camel_imap_message_cache_filter_cached(CamelImapMessageCache *cache, GPtrArray *
 		/* No message parts, or message part "" not found: include the
 		 * uid in the result.
 		 */
-		g_ptr_array_add(result, (char *)camel_pstring_strdup(uids->pdata[i]));
+		g_ptr_array_add(result, (gchar *)camel_pstring_strdup(uids->pdata[i]));
 	}
 	return result;
 }
