@@ -1,14 +1,14 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-imap-message-cache.h: Class for an IMAP message cache */
 
-/* 
- * Author: 
+/*
+ * Author:
  *   Dan Winship <danw@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -40,7 +40,7 @@ G_BEGIN_DECLS
 struct _CamelImapMessageCache {
 	CamelObject parent_object;
 
-	char *path;
+	gchar *path;
         /* parts contains two sorts of objects.
          * If the key contains '.' then it is a stream (also reverse-indexed in
          * cached).
@@ -56,59 +56,59 @@ struct _CamelImapMessageCache {
 typedef struct {
 	CamelFolderClass parent_class;
 
-	/* Virtual methods */	
-	
+	/* Virtual methods */
+
 } CamelImapMessageCacheClass;
 
 
 /* public methods */
-CamelImapMessageCache *camel_imap_message_cache_new (const char *path,
+CamelImapMessageCache *camel_imap_message_cache_new (const gchar *path,
 						     CamelFolderSummary *summary,
 						     CamelException *ex);
 
 void camel_imap_message_cache_set_path (CamelImapMessageCache *cache,
-					const char *path);
+					const gchar *path);
 
 guint32     camel_imap_message_cache_max_uid (CamelImapMessageCache *cache);
 
 CamelStream *camel_imap_message_cache_insert (CamelImapMessageCache *cache,
-					      const char *uid,
-					      const char *part_spec,
-					      const char *data,
-					      int len,
+					      const gchar *uid,
+					      const gchar *part_spec,
+					      const gchar *data,
+					      gint len,
 					      CamelException *ex);
 void camel_imap_message_cache_insert_stream  (CamelImapMessageCache *cache,
-					      const char *uid,
-					      const char *part_spec,
+					      const gchar *uid,
+					      const gchar *part_spec,
 					      CamelStream *data_stream,
 					      CamelException *ex);
 void camel_imap_message_cache_insert_wrapper (CamelImapMessageCache *cache,
-					      const char *uid,
-					      const char *part_spec,
+					      const gchar *uid,
+					      const gchar *part_spec,
 					      CamelDataWrapper *wrapper,
 					      CamelException *ex);
 
 CamelStream *camel_imap_message_cache_get    (CamelImapMessageCache *cache,
-					      const char *uid,
-					      const char *part_spec,
+					      const gchar *uid,
+					      const gchar *part_spec,
 					      CamelException *ex);
 
-char*       camel_imap_message_cache_get_filename (CamelImapMessageCache *cache,
-					      const char *uid,
-					      const char *part_spec,
+gchar *       camel_imap_message_cache_get_filename (CamelImapMessageCache *cache,
+					      const gchar *uid,
+					      const gchar *part_spec,
 					      CamelException *ex);
 
 void         camel_imap_message_cache_remove (CamelImapMessageCache *cache,
-					      const char *uid);
+					      const gchar *uid);
 
 void         camel_imap_message_cache_clear  (CamelImapMessageCache *cache);
 
 void         camel_imap_message_cache_copy   (CamelImapMessageCache *source,
-					      const char *source_uid,
+					      const gchar *source_uid,
 					      CamelImapMessageCache *dest,
-					      const char *dest_uid,
+					      const gchar *dest_uid,
 					      CamelException *ex);
-gboolean     camel_imap_message_cache_delete (const char *path, 
+gboolean     camel_imap_message_cache_delete (const gchar *path,
 					      CamelException *ex);
 GPtrArray *  camel_imap_message_cache_filter_cached(CamelImapMessageCache *,
                                               GPtrArray *uids,
