@@ -51,7 +51,7 @@ static CamelDataWrapperClass *parent_class = NULL;
 /* Returns the class for a CamelDataWrapper */
 #define CDW_CLASS(so) CAMEL_DATA_WRAPPER_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
-static ssize_t write_to_stream (CamelDataWrapper *imap_wrapper, CamelStream *stream);
+static gssize write_to_stream (CamelDataWrapper *imap_wrapper, CamelStream *stream);
 
 static void
 camel_imap_wrapper_class_init (CamelImapWrapperClass *camel_imap_wrapper_class)
@@ -76,9 +76,9 @@ camel_imap_wrapper_finalize (CamelObject *object)
 		g_free (imap_wrapper->uid);
 	if (imap_wrapper->part)
 		g_free (imap_wrapper->part_spec);
-	
+
 	g_mutex_free (imap_wrapper->priv->lock);
-	
+
 	g_free (imap_wrapper->priv);
 }
 
@@ -116,11 +116,11 @@ static void
 imap_wrapper_hydrate (CamelImapWrapper *imap_wrapper, CamelStream *stream)
 {
 	CamelDataWrapper *data_wrapper = (CamelDataWrapper *) imap_wrapper;
-	
+
 	camel_object_ref (stream);
 	data_wrapper->stream = stream;
 	data_wrapper->offline = FALSE;
-	
+
 	camel_object_unref (imap_wrapper->folder);
 	imap_wrapper->folder = NULL;
 	g_free (imap_wrapper->uid);
@@ -130,15 +130,15 @@ imap_wrapper_hydrate (CamelImapWrapper *imap_wrapper, CamelStream *stream)
 }
 
 
-static ssize_t
+static gssize
 write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
 	CamelImapWrapper *imap_wrapper = CAMEL_IMAP_WRAPPER (data_wrapper);
-	
+
 	CAMEL_IMAP_WRAPPER_LOCK (imap_wrapper, lock);
 	if (data_wrapper->offline) {
 		CamelStream *datastream;
-		
+
 		datastream = camel_imap_folder_fetch_data (
 			imap_wrapper->folder, imap_wrapper->uid,
 			imap_wrapper->part_spec, FALSE, NULL);
@@ -147,17 +147,17 @@ write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 #ifdef ENETUNREACH
 			errno = ENETUNREACH;
 #else
-#warning FIXME: what errno to use if no ENETUNREACH
+/* FIXME[disk-summary] what errno to use if no ENETUNREACH */
 			errno = EINVAL;
 #endif
 			return -1;
 		}
-		
+
 		imap_wrapper_hydrate (imap_wrapper, datastream);
 		camel_object_unref (datastream);
 	}
 	CAMEL_IMAP_WRAPPER_UNLOCK (imap_wrapper, lock);
-	
+
 	return parent_class->write_to_stream (data_wrapper, stream);
 }
 
@@ -165,7 +165,7 @@ write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 CamelDataWrapper *
 camel_imap_wrapper_new (CamelImapFolder *imap_folder,
 			CamelContentType *type, CamelTransferEncoding encoding,
-			const char *uid, const char *part_spec,
+			const gchar *uid, const gchar *part_spec,
 			CamelMimePart *part)
 {
 	CamelImapWrapper *imap_wrapper;
