@@ -77,10 +77,10 @@ enum {
 	CAMEL_IMAP4_CAPABILITY_ACL              = (1 << 10),
 	CAMEL_IMAP4_CAPABILITY_MULTIAPPEND      = (1 << 11),
 	CAMEL_IMAP4_CAPABILITY_UNSELECT         = (1 << 12),
-	
+
 	CAMEL_IMAP4_CAPABILITY_XGWEXTENSIONS    = (1 << 16),
 	CAMEL_IMAP4_CAPABILITY_XGWMOVE          = (1 << 17),
-	
+
 	CAMEL_IMAP4_CAPABILITY_useful_lsub      = (1 << 30),
 	CAMEL_IMAP4_CAPABILITY_utf8_search      = (1 << 31),
 };
@@ -107,19 +107,19 @@ typedef struct _CamelIMAP4RespCode {
 	camel_imap4_resp_code_t code;
 	union {
 		guint32 flags;
-		char *parse;
+		gchar *parse;
 		guint32 uidnext;
 		guint32 uidvalidity;
 		guint32 unseen;
-		char *newname[2];
+		gchar *newname[2];
 		struct {
 			guint32 uidvalidity;
 			guint32 uid;
 		} appenduid;
 		struct {
 			guint32 uidvalidity;
-			char *srcset;
-			char *destset;
+			gchar *srcset;
+			gchar *destset;
 		} copyuid;
 	} v;
 } CamelIMAP4RespCode;
@@ -135,8 +135,8 @@ enum {
 
 typedef struct _CamelIMAP4Namespace {
 	struct _CamelIMAP4Namespace *next;
-	char *path;
-	char sep;
+	gchar *path;
+	gchar sep;
 } CamelIMAP4Namespace;
 
 typedef struct _CamelIMAP4NamespaceList {
@@ -154,41 +154,41 @@ typedef gboolean (* CamelIMAP4ReconnectFunc) (CamelIMAP4Engine *engine, CamelExc
 
 struct _CamelIMAP4Engine {
 	CamelObject parent_object;
-	
+
 	CamelIMAP4ReconnectFunc reconnect;
 	gboolean reconnecting;
-	
+
 	CamelSession *session;
 	CamelService *service;
 	CamelURL *url;
-	
+
 	camel_imap4_engine_t state;
 	camel_imap4_level_t level;
 	guint32 capa;
-	
+
 	guint32 maxlen:31;
 	guint32 maxlentype:1;
-	
+
 	CamelIMAP4NamespaceList namespaces;
 	GHashTable *authtypes;                    /* supported authtypes */
-	
+
 	struct _CamelIMAP4Stream *istream;
 	CamelStream *ostream;
-	
-	unsigned char tagprefix;             /* 'A'..'Z' */
-	unsigned int tag;                    /* next command tag */
-	int nextid;
-	
+
+	guchar tagprefix;             /* 'A'..'Z' */
+	guint tag;                    /* next command tag */
+	gint nextid;
+
 	struct _CamelIMAP4Folder *folder;    /* currently selected folder */
-	
+
 	CamelDList queue;                    /* queue of waiting commands */
 	struct _CamelIMAP4Command *current;
 };
 
 struct _CamelIMAP4EngineClass {
 	CamelObjectClass parent_class;
-	
-	unsigned char tagprefix;
+
+	guchar tagprefix;
 };
 
 
@@ -197,39 +197,39 @@ CamelType camel_imap4_engine_get_type (void);
 CamelIMAP4Engine *camel_imap4_engine_new (CamelService *service, CamelIMAP4ReconnectFunc reconnect);
 
 /* returns 0 on success or -1 on error */
-int camel_imap4_engine_take_stream (CamelIMAP4Engine *engine, CamelStream *stream, CamelException *ex);
+gint camel_imap4_engine_take_stream (CamelIMAP4Engine *engine, CamelStream *stream, CamelException *ex);
 
 void camel_imap4_engine_disconnect (CamelIMAP4Engine *engine);
 
-int camel_imap4_engine_capability (CamelIMAP4Engine *engine, CamelException *ex);
-int camel_imap4_engine_namespace (CamelIMAP4Engine *engine, CamelException *ex);
+gint camel_imap4_engine_capability (CamelIMAP4Engine *engine, CamelException *ex);
+gint camel_imap4_engine_namespace (CamelIMAP4Engine *engine, CamelException *ex);
 
-int camel_imap4_engine_select_folder (CamelIMAP4Engine *engine, CamelFolder *folder, CamelException *ex);
+gint camel_imap4_engine_select_folder (CamelIMAP4Engine *engine, CamelFolder *folder, CamelException *ex);
 
 struct _CamelIMAP4Command *camel_imap4_engine_queue (CamelIMAP4Engine *engine, CamelFolder *folder,
-						     const char *format, ...);
+						     const gchar *format, ...);
 struct _CamelIMAP4Command *camel_imap4_engine_prequeue (CamelIMAP4Engine *engine, CamelFolder *folder,
-							const char *format, ...);
+							const gchar *format, ...);
 
 void camel_imap4_engine_dequeue (CamelIMAP4Engine *engine, struct _CamelIMAP4Command *ic);
 
-int camel_imap4_engine_iterate (CamelIMAP4Engine *engine);
+gint camel_imap4_engine_iterate (CamelIMAP4Engine *engine);
 
 
 /* untagged response utility functions */
-int camel_imap4_engine_handle_untagged_1 (CamelIMAP4Engine *engine, struct _camel_imap4_token_t *token, CamelException *ex);
+gint camel_imap4_engine_handle_untagged_1 (CamelIMAP4Engine *engine, struct _camel_imap4_token_t *token, CamelException *ex);
 void camel_imap4_engine_handle_untagged (CamelIMAP4Engine *engine, CamelException *ex);
 
 /* stream wrapper utility functions */
-int camel_imap4_engine_next_token (CamelIMAP4Engine *engine, struct _camel_imap4_token_t *token, CamelException *ex);
-int camel_imap4_engine_line (CamelIMAP4Engine *engine, unsigned char **line, size_t *len, CamelException *ex);
-int camel_imap4_engine_literal (CamelIMAP4Engine *engine, unsigned char **literal, size_t *len, CamelException *ex);
-int camel_imap4_engine_nstring (CamelIMAP4Engine *engine, unsigned char **nstring, CamelException *ex);
-int camel_imap4_engine_eat_line (CamelIMAP4Engine *engine, CamelException *ex);
+gint camel_imap4_engine_next_token (CamelIMAP4Engine *engine, struct _camel_imap4_token_t *token, CamelException *ex);
+gint camel_imap4_engine_line (CamelIMAP4Engine *engine, guchar **line, gsize *len, CamelException *ex);
+gint camel_imap4_engine_literal (CamelIMAP4Engine *engine, guchar **literal, gsize *len, CamelException *ex);
+gint camel_imap4_engine_nstring (CamelIMAP4Engine *engine, guchar **nstring, CamelException *ex);
+gint camel_imap4_engine_eat_line (CamelIMAP4Engine *engine, CamelException *ex);
 
 
 /* response code stuff */
-int camel_imap4_engine_parse_resp_code (CamelIMAP4Engine *engine, CamelException *ex);
+gint camel_imap4_engine_parse_resp_code (CamelIMAP4Engine *engine, CamelException *ex);
 void camel_imap4_resp_code_free (CamelIMAP4RespCode *rcode);
 
 G_END_DECLS
