@@ -65,34 +65,34 @@ static CamelProviderConfEntry imap4_conf_entries[] = {
 static CamelProvider imap4_provider = {
 	"imap4",
 	N_("IMAP4rev1"),
-	
+
 	N_("For reading and storing mail on IMAPv4rev1 servers."),
-	
+
 	"mail",
-	
+
 	CAMEL_PROVIDER_IS_REMOTE | CAMEL_PROVIDER_IS_SOURCE |
 	CAMEL_PROVIDER_IS_STORAGE | CAMEL_PROVIDER_SUPPORTS_SSL,
-	
+
 	CAMEL_URL_NEED_USER | CAMEL_URL_NEED_HOST | CAMEL_URL_ALLOW_AUTH | CAMEL_URL_FRAGMENT_IS_PATH,
-	
+
 	imap4_conf_entries,
-	
+
 	/* ... */
 };
 
 CamelServiceAuthType camel_imap4_password_authtype = {
 	N_("Password"),
-	
+
 	N_("This option will connect to the IMAPv4rev1 server using a "
 	   "plaintext password."),
-	
+
 	"",
 	TRUE
 };
 
 
 static void
-add_hash (guint *hash, char *s)
+add_hash (guint *hash, gchar *s)
 {
 	if (s)
 		*hash ^= g_str_hash(s);
@@ -103,17 +103,16 @@ imap4_url_hash (gconstpointer key)
 {
 	const CamelURL *u = (CamelURL *)key;
 	guint hash = 0;
-	
+
 	add_hash (&hash, u->user);
-	add_hash (&hash, u->authmech);
 	add_hash (&hash, u->host);
 	hash ^= u->port;
-	
+
 	return hash;
 }
 
-static int
-check_equal (char *s1, char *s2)
+static gint
+check_equal (gchar *s1, gchar *s2)
 {
 	if (s1 == NULL) {
 		if (s2 == NULL)
@@ -121,21 +120,20 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-	
+
 	if (s2 == NULL)
 		return FALSE;
-	
+
 	return strcmp (s1, s2) == 0;
 }
 
-static int
+static gint
 imap4_url_equal (gconstpointer a, gconstpointer b)
 {
 	const CamelURL *u1 = a, *u2 = b;
-	
+
 	return check_equal (u1->protocol, u2->protocol)
 		&& check_equal (u1->user, u2->user)
-		&& check_equal (u1->authmech, u2->authmech)
 		&& check_equal (u1->host, u2->host)
 		&& u1->port == u2->port;
 }
@@ -150,6 +148,6 @@ camel_provider_module_init (void)
 	imap4_provider.authtypes = camel_sasl_authtype_list (FALSE);
 	imap4_provider.authtypes = g_list_prepend (imap4_provider.authtypes, &camel_imap4_password_authtype);
 	imap4_provider.translation_domain = GETTEXT_PACKAGE;
-	
+
 	camel_provider_register (&imap4_provider);
 }
