@@ -42,29 +42,29 @@ struct _CamelIMAP4Engine;
 
 struct _CamelIMAP4Search {
 	CamelFolderSearch parent_object;
-	
+
 	struct _CamelIMAP4Engine *engine;
-	
+
 	guint32 lastuid;	/* current 'last uid' for the folder */
 	guint32 validity;	/* validity of the current folder */
-	
+
 	CamelDataCache *cache;	/* disk-cache for searches */
-	
+
 	/* cache of body search matches */
 	CamelDList matches;
 	GHashTable *matches_hash;
-	unsigned int matches_count;
+	guint matches_count;
 };
 
 struct _CamelIMAP4SearchClass {
 	CamelFolderSearchClass parent_class;
-	
+
 };
 
 
 CamelType camel_imap4_search_get_type (void);
 
-CamelFolderSearch *camel_imap4_search_new (struct _CamelIMAP4Engine *engine, const char *cachedir);
+CamelFolderSearch *camel_imap4_search_new (struct _CamelIMAP4Engine *engine, const gchar *cachedir);
 
 G_END_DECLS
 
