@@ -1,6 +1,8 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Camel
- *  Copyright (C) 1999-2006 Jeffrey Stedfast
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ *  Authors: Jeffrey Stedfast <fejj@novell.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -31,7 +33,7 @@
 #define CHARS_QUOTED_SPECIALS "\\\""
 #define CHARS_LIST_WILDCARDS  "*%"
 
-unsigned char camel_imap4_specials[256] = {
+guchar camel_imap4_specials[256] = {
 	  2,  2,  2,  2,  2,  2,  2,  2,  2,  6,  6,  2,  2,  6,  2,  2,
           2,  2,  2,  2,  2,  2,  2,  2,  2,  2,  2,  2,  2,  2,  2,  2,
          20,  0,  8,  0,  0, 32,  0,  0,  1,  1, 32,  0,  0,  0,  0,  0,
@@ -52,10 +54,10 @@ unsigned char camel_imap4_specials[256] = {
 
 
 static void
-imap4_init_bits (unsigned short bit, unsigned short bitcopy, int remove, unsigned char *vals)
+imap4_init_bits (unsigned short bit, unsigned short bitcopy, gint remove, guchar *vals)
 {
-	int i, len = strlen (vals);
-	
+	gint i, len = strlen (vals);
+
 	if (!remove) {
 		for (i = 0; i < len; i++)
 			camel_imap4_specials[vals[i]] |= bit;
@@ -83,16 +85,16 @@ imap4_init_bits (unsigned short bit, unsigned short bitcopy, int remove, unsigne
 void
 camel_imap4_specials_init (void)
 {
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < 256; i++) {
 		camel_imap4_specials[i] = 0;
 		if (i <= 0x1f || i >= 0x7f)
 			camel_imap4_specials[i] |= IS_CTRL;
 	}
-	
+
 	camel_imap4_specials[' '] |= IS_SPACE;
-	
+
 	imap4_init_bits (IS_LWSP, 0, 0, CHARS_LWSP);
 	imap4_init_bits (IS_ASPECIAL, 0, 0, CHARS_ATOM_SPECIALS);
 	imap4_init_bits (IS_QSPECIAL, 0, 0, CHARS_QUOTED_SPECIALS);
