@@ -20,13 +20,13 @@
 #define e(x)
 #define c(x)			/* command build debug */
 
-static void imap_engine_command_addv(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const char *fmt, va_list ap);
+static void imap_engine_command_addv(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const gchar *fmt, va_list ap);
 static void imap_engine_command_complete(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic);
 
 struct _handler {
 	CamelIMAPPEngineFunc func;
-	void *data;
-	char name[1];
+	gpointer data;
+	gchar name[1];
 };
 
 static void
@@ -41,10 +41,10 @@ static void
 object_init(CamelIMAPPEngine *ie, CamelIMAPPEngineClass *ieclass)
 {
 	ie->handlers = g_hash_table_new(g_str_hash, g_str_equal);
-	e_dlist_init(&ie->active);
-	e_dlist_init(&ie->done);
+	camel_dlist_init(&ie->active);
+	camel_dlist_init(&ie->done);
 
-	ie->port = e_msgport_new();
+	ie->port = camel_msgport_new();
 
 	ie->tagprefix = ieclass->tagprefix;
 	ieclass->tagprefix++;
@@ -56,7 +56,7 @@ object_init(CamelIMAPPEngine *ie, CamelIMAPPEngineClass *ieclass)
 }
 
 static void
-handler_free(void *key, void *mem, void *data)
+handler_free(gpointer key, gpointer mem, gpointer data)
 {
 	g_free(mem);
 }
@@ -94,7 +94,7 @@ camel_imapp_engine_get_type (void)
 
 /* FIXME: check this, just taken from old code, not rfc */
 struct {
-	char *name;
+	gchar *name;
 	guint32 flag;
 } capa_table[] = {
 	{ "IMAP4", IMAP_CAPABILITY_IMAP4 },
@@ -114,10 +114,10 @@ capability_data ::= "CAPABILITY" SPACE [1#capability SPACE] "IMAP4rev1"
                     ;; compatibility MUST list "IMAP4" as the first
                     ;; capability.
 */
-static int resp_capability(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint resp_capability(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
-	int tok, len, i;
-	unsigned char *token, *p, c;
+	gint tok, len, i;
+	guchar *token, *p, c;
 
 	/* FIXME: handle auth types */
 
@@ -131,7 +131,7 @@ static int resp_capability(CamelIMAPPEngine *ie, guint32 id, void *data)
 				*p++ = toupper(c);
 		case IMAP_TOK_INT:
 			printf(" cap: '%s'\n", token);
-			for (i=0;i<(int)(sizeof(capa_table)/sizeof(capa_table[0]));i++)
+			for (i=0;i<(gint)(sizeof(capa_table)/sizeof(capa_table[0]));i++)
 				if (strcmp(token, capa_table[i].name))
 					ie->capa |= capa_table[i].flag;
 			break;
@@ -152,14 +152,14 @@ static int resp_capability(CamelIMAPPEngine *ie, guint32 id, void *data)
 /* expunge command, id is expunged seq number */
 /* message_data    ::= nz_number SPACE ("EXPUNGE" /
    ("FETCH" SPACE msg_att)) */
-static int resp_expunge(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint resp_expunge(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
 	printf("message expunged: %d\n", id);
 
 	return camel_imapp_engine_skip(ie);
 }
 
-static int resp_flags(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint resp_flags(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
 	guint32 flags;
 
@@ -171,7 +171,7 @@ static int resp_flags(CamelIMAPPEngine *ie, guint32 id, void *data)
 }
 
 /* exists count */
-static int resp_exists(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint resp_exists(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
 	printf("messages exist: %d\n", id);
 
@@ -181,7 +181,7 @@ static int resp_exists(CamelIMAPPEngine *ie, guint32 id, void *data)
 	return camel_imapp_engine_skip(ie);
 }
 
-static int resp_recent(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint resp_recent(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
 	printf("messages recent: %d\n", id);
 
@@ -191,7 +191,7 @@ static int resp_recent(CamelIMAPPEngine *ie, guint32 id, void *data)
 	return camel_imapp_engine_skip(ie);
 }
 
-static int resp_fetch(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint resp_fetch(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
 	struct _fetch_info *finfo;
 
@@ -203,7 +203,7 @@ static int resp_fetch(CamelIMAPPEngine *ie, guint32 id, void *data)
 }
 
 #if 0
-static int resp_list(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint resp_list(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
 	struct _list_info *linfo;
 
@@ -241,9 +241,9 @@ camel_imapp_engine_new(CamelIMAPPStream *stream)
 
 	/* TODO: move this to a driver:connect call? */
 	CAMEL_TRY {
-		unsigned char *token;
-		unsigned int len;
-		int tok;
+		guchar *token;
+		guint len;
+		gint tok;
 
 		tok = camel_imapp_stream_token(stream, &token, &len);
 		if (tok == '*') {
@@ -280,11 +280,11 @@ camel_imapp_engine_new(CamelIMAPPStream *stream)
 }
 
 void
-camel_imapp_engine_add_handler(CamelIMAPPEngine *imap, const char *response, CamelIMAPPEngineFunc func, void *data)
+camel_imapp_engine_add_handler(CamelIMAPPEngine *imap, const gchar *response, CamelIMAPPEngineFunc func, gpointer data)
 {
 	struct _handler *h;
-	const unsigned char *p;
-	unsigned char *o, c;
+	const guchar *p;
+	guchar *o, c;
 
 	h = g_malloc0(sizeof(*h) + strlen(response));
 	h->func = func;
@@ -299,7 +299,7 @@ camel_imapp_engine_add_handler(CamelIMAPPEngine *imap, const char *response, Cam
 	g_hash_table_insert(imap->handlers, h->name, h);
 }
 
-int
+gint
 camel_imapp_engine_capabilities(CamelIMAPPEngine *ie)
 {
 	CamelIMAPPCommand *ic;
@@ -317,19 +317,19 @@ camel_imapp_engine_capabilities(CamelIMAPPEngine *ie)
 }
 
 /* skip the rest of the line of tokens */
-int
+gint
 camel_imapp_engine_skip(CamelIMAPPEngine *imap)
 {
-	int tok;
-	unsigned char *token;
-	unsigned int len;
+	gint tok;
+	guchar *token;
+	guint len;
 
 	do {
 		tok = camel_imapp_stream_token(imap->stream, &token, &len);
 		if (tok == IMAP_TOK_LITERAL) {
 			camel_imapp_stream_set_literal(imap->stream, len);
 			while ((tok = camel_imapp_stream_getl(imap->stream, &token, &len)) > 0) {
-				printf("Skip literal data '%.*s'\n", (int)len, token);
+				printf("Skip literal data '%.*s'\n", (gint)len, token);
 			}
 		}
 	} while (tok != '\n' && tok >= 0);
@@ -341,12 +341,12 @@ camel_imapp_engine_skip(CamelIMAPPEngine *imap)
 }
 
 /* handle any untagged responses */
-static int
+static gint
 iterate_untagged(CamelIMAPPEngine *imap)
 {
-	unsigned int id, len;
-	unsigned char *token, *p, c;
-	int tok;
+	guint id, len;
+	guchar *token, *p, c;
+	gint tok;
 	struct _handler *h;
 	struct _status_info *sinfo;
 
@@ -439,7 +439,7 @@ iterate_untagged(CamelIMAPPEngine *imap)
 
 /* handle any continuation requests
    either data continuations, or auth continuation */
-static int
+static gint
 iterate_continuation(CamelIMAPPEngine *imap)
 {
 	CamelIMAPPCommand *ic;
@@ -468,9 +468,9 @@ iterate_continuation(CamelIMAPPEngine *imap)
 		break;
 	case CAMEL_IMAPP_COMMAND_AUTH: {
 		CamelException *ex = camel_exception_new();
-		char *resp;
-		unsigned char *token;
-		int tok, len;
+		gchar *resp;
+		guchar *token;
+		gint tok, len;
 
 		tok = camel_imapp_stream_token(imap->stream, &token, &len);
 		resp = camel_sasl_challenge_base64((CamelSasl *)cp->ob, token, ex);
@@ -510,7 +510,7 @@ iterate_continuation(CamelIMAPPEngine *imap)
 	}
 
 	if (imap->literal == NULL) {
-		ic = (CamelIMAPPCommand *)e_dlist_remhead(&imap->queue);
+		ic = (CamelIMAPPCommand *)camel_dlist_remhead(&imap->queue);
 		if (ic) {
 			printf("found outstanding op, queueing\n");
 			camel_imapp_engine_command_queue(imap, ic);
@@ -521,11 +521,11 @@ iterate_continuation(CamelIMAPPEngine *imap)
 }
 
 /* handle a completion line */
-static int
-iterate_completion(CamelIMAPPEngine *imap, unsigned char *token)
+static gint
+iterate_completion(CamelIMAPPEngine *imap, guchar *token)
 {
 	CamelIMAPPCommand *ic;
-	unsigned int tag;
+	guint tag;
 
 	if (token[0] != imap->tagprefix)
 		camel_exception_throw(1, "Server sent unexpected response: %s", token);
@@ -536,8 +536,8 @@ iterate_completion(CamelIMAPPEngine *imap, unsigned char *token)
 		printf("Got completion response for command %05u '%s'\n", ic->tag, ic->name);
 		printf("%p: removing command from qwueue, we were at '%s'\n", ic, ic->current->data);
 		printf("%p: removing command\n", ic);
-		e_dlist_remove((EDListNode *)ic);
-		e_dlist_addtail(&imap->done, (EDListNode *)ic);
+		camel_dlist_remove((CamelDListNode *)ic);
+		camel_dlist_addtail(&imap->done, (CamelDListNode *)ic);
 		if (imap->literal == ic)
 			imap->literal = NULL;
 		ic->status = imap_parse_status(imap->stream);
@@ -561,12 +561,12 @@ iterate_completion(CamelIMAPPEngine *imap, unsigned char *token)
 		printf("Warning: continuation command '%s' finished with outstanding continuation\n", imap->literal->name);
 		ic = imap->literal;
 				/* set the command complete with a failure code? */
-		e_dlist_remove((EDListNode *)ic);
-		e_dlist_addtail(&imap->done, (EDListNode *)ic);
+		camel_dlist_remove((CamelDListNode *)ic);
+		camel_dlist_addtail(&imap->done, (CamelDListNode *)ic);
 		imap->literal = NULL;
 	}
 
-	ic = (CamelIMAPPCommand *)e_dlist_remhead(&imap->queue);
+	ic = (CamelIMAPPCommand *)camel_dlist_remhead(&imap->queue);
 	if (ic) {
 		printf("found outstanding op, queueing\n");
 		camel_imapp_engine_command_queue(imap, ic);
@@ -577,15 +577,15 @@ iterate_completion(CamelIMAPPEngine *imap, unsigned char *token)
 
 
 /* Do work if there's any to do */
-int
+gint
 camel_imapp_engine_iterate(CamelIMAPPEngine *imap, CamelIMAPPCommand *icwait)
 /* throws IO,PARSE exception */
 {
-	unsigned int len;
-	unsigned char *token;
-	int tok;
+	guint len;
+	guchar *token;
+	gint tok;
 
-	if ((icwait && icwait->status != NULL) || e_dlist_empty(&imap->active))
+	if ((icwait && icwait->status != NULL) || camel_dlist_empty(&imap->active))
 		return 0;
 
 	/* handle exceptions here? */
@@ -602,14 +602,14 @@ camel_imapp_engine_iterate(CamelIMAPPEngine *imap, CamelIMAPPCommand *icwait)
 	else
 		camel_exception_throw(1, "unexpected server response: %s", token);
 
-	if (e_dlist_empty(&imap->active))
+	if (camel_dlist_empty(&imap->active))
 		return 0;
 
 	return 1;
 }
 
 CamelIMAPPCommand *
-camel_imapp_engine_command_new(CamelIMAPPEngine *imap, const char *name, const char *select, const char *fmt, ...)
+camel_imapp_engine_command_new(CamelIMAPPEngine *imap, const gchar *name, const gchar *select, const gchar *fmt, ...)
 {
 	CamelIMAPPCommand *ic;
 	va_list ap;
@@ -619,7 +619,7 @@ camel_imapp_engine_command_new(CamelIMAPPEngine *imap, const char *name, const c
 	ic->name = name;
 	ic->mem = (CamelStreamMem *)camel_stream_mem_new();
 	ic->select = g_strdup(select);
-	e_dlist_init(&ic->parts);
+	camel_dlist_init(&ic->parts);
 
 	if (fmt && fmt[0]) {
 		va_start(ap, fmt);
@@ -631,7 +631,7 @@ camel_imapp_engine_command_new(CamelIMAPPEngine *imap, const char *name, const c
 }
 
 void
-camel_imapp_engine_command_add(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const char *fmt, ...)
+camel_imapp_engine_command_add(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const gchar *fmt, ...)
 {
 	va_list ap;
 
@@ -645,7 +645,7 @@ camel_imapp_engine_command_add(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, co
 }
 
 void
-camel_imapp_engine_command_complete(CamelIMAPPEngine *imap, struct _CamelIMAPPCommand *ic, CamelIMAPPCommandFunc func, void *data)
+camel_imapp_engine_command_complete(CamelIMAPPEngine *imap, struct _CamelIMAPPCommand *ic, CamelIMAPPCommandFunc func, gpointer data)
 {
 	ic->complete = func;
 	ic->complete_data = data;
@@ -667,7 +667,7 @@ camel_imapp_engine_command_free (CamelIMAPPEngine *imap, CamelIMAPPCommand *ic)
 	imap_free_status(ic->status);
 	g_free(ic->select);
 
-	while ( (cp = ((CamelIMAPPCommandPart *)e_dlist_remhead(&ic->parts))) ) {
+	while ( (cp = ((CamelIMAPPCommandPart *)camel_dlist_remhead(&ic->parts))) ) {
 		g_free(cp->data);
 		if (cp->ob)
 			camel_object_unref(cp->ob);
@@ -688,11 +688,11 @@ camel_imapp_engine_command_queue(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic)
 	if (ic->mem)
 		imap_engine_command_complete(imap, ic);
 
-	e_msgport_put(imap->port, (EMsg *)ic);
+	camel_msgport_push(imap->port, (CamelMsg *)ic);
 }
 
 CamelIMAPPCommand *
-camel_imapp_engine_command_find (CamelIMAPPEngine *imap, const char *name)
+camel_imapp_engine_command_find (CamelIMAPPEngine *imap, const gchar *name)
 {
 	CamelIMAPPCommand *ic, *in;
 
@@ -714,7 +714,7 @@ camel_imapp_engine_command_find (CamelIMAPPEngine *imap, const char *name)
 }
 
 CamelIMAPPCommand *
-camel_imapp_engine_command_find_tag(CamelIMAPPEngine *imap, unsigned int tag)
+camel_imapp_engine_command_find_tag(CamelIMAPPEngine *imap, guint tag)
 {
 	CamelIMAPPCommand *ic, *in;
 
@@ -737,7 +737,7 @@ camel_imapp_engine_command_find_tag(CamelIMAPPEngine *imap, unsigned int tag)
 /* ********************************************************************** */
 
 CamelIMAPPSelectResponse *
-camel_imapp_engine_select(CamelIMAPPEngine *imap, const char *name)
+camel_imapp_engine_select(CamelIMAPPEngine *imap, const gchar *name)
 {
 	CamelIMAPPSelectResponse * volatile resp;
 	CamelIMAPPCommand * volatile ic = NULL;
@@ -784,7 +784,7 @@ imap_engine_command_add_part(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, came
 {
 	CamelIMAPPCommandPart *cp;
 	CamelStreamNull *null;
-	unsigned int ob_size = 0;
+	guint ob_size = 0;
 
 	switch(type & CAMEL_IMAPP_COMMAND_MASK) {
 	case CAMEL_IMAPP_COMMAND_DATAWRAPPER:
@@ -827,14 +827,14 @@ imap_engine_command_add_part(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, came
 	/* FIXME: hackish? */
 	g_byte_array_set_size(ic->mem->buffer, 0);
 
-	e_dlist_addtail(&ic->parts, (EDListNode *)cp);
+	camel_dlist_addtail(&ic->parts, (CamelDListNode *)cp);
 }
 
 #if c(!)0
-static int len(EDList *list)
+static gint len(CamelDList *list)
 {
-	int count = 0;
-	EDListNode *n = list->head;
+	gint count = 0;
+	CamelDListNode *n = list->head;
 
 	while (n->next) {
 		n = n->next;
@@ -847,7 +847,7 @@ static int len(EDList *list)
 static void
 imap_engine_command_complete(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic)
 {
-	c(printf("completing command buffer is [%d] '%.*s'\n", ic->mem->buffer->len, (int)ic->mem->buffer->len, ic->mem->buffer->data));
+	c(printf("completing command buffer is [%d] '%.*s'\n", ic->mem->buffer->len, (gint)ic->mem->buffer->len, ic->mem->buffer->data));
 	c(printf("command has %d parts\n", len(&ic->parts)));
 	if (ic->mem->buffer->len > 0)
 		imap_engine_command_add_part(imap, ic, CAMEL_IMAPP_COMMAND_SIMPLE, NULL);
@@ -859,24 +859,24 @@ imap_engine_command_complete(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic)
 }
 
 static void
-imap_engine_command_addv(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const char *fmt, va_list ap)
+imap_engine_command_addv(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const gchar *fmt, va_list ap)
 {
-	const unsigned char *p, *ps, *start;
-	unsigned char c;
-	unsigned int width;
-	char ch;
-	int llong;
-	int left;
-	int fill;
-	int zero;
-	char *s;
-	int d;
-	long int l;
+	const guchar *p, *ps, *start;
+	guchar c;
+	guint width;
+	gchar ch;
+	gint llong;
+	gint left;
+	gint fill;
+	gint zero;
+	gchar *s;
+	gint d;
+	glong gint l;
 	guint32 f;
 	CamelStream *S;
 	CamelDataWrapper *D;
 	CamelSasl *A;
-	char buffer[16];
+	gchar buffer[16];
 
 	c(printf("adding command, fmt = '%s'\n", fmt));
 
@@ -936,17 +936,17 @@ imap_engine_command_addv(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const ch
 					imap_engine_command_add_part(imap, ic, CAMEL_IMAPP_COMMAND_DATAWRAPPER, (CamelObject *)D);
 					break;
 				case 't': /* token */
-					s = va_arg(ap, char *);
+					s = va_arg(ap, gchar *);
 					camel_stream_write((CamelStream *)ic->mem, s, strlen(s));
 					break;
 				case 's': /* simple string */
-					s = va_arg(ap, char *);
+					s = va_arg(ap, gchar *);
 					c(printf("got string '%s'\n", s));
 					/* FIXME: escpae chars, convert to literal or literal+, etc */
 					camel_stream_printf((CamelStream *)ic->mem, "\"%s\"", s);
 					break;
 				case 'f': /* imap folder name */
-					s = va_arg(ap, char *);
+					s = va_arg(ap, gchar *);
 					c(printf("got folder '%s'\n", s));
 					/* FIXME: encode folder name */
 					/* FIXME: namespace? */
@@ -957,21 +957,21 @@ imap_engine_command_addv(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const ch
 					imap_write_flags((CamelStream *)ic->mem, f);
 					break;
 				case 'c':
-					d = va_arg(ap, int);
+					d = va_arg(ap, gint);
 					ch = d;
 					camel_stream_write((CamelStream *)ic->mem, &ch, 1);
 					break;
 				case 'd': /* int/unsigned */
 				case 'u':
 					if (llong) {
-						l = va_arg(ap, long int);
-						c(printf("got long int '%d'\n", (int)l));
+						l = va_arg(ap, glong gint);
+						c(printf("got glong gint '%d'\n", (gint)l));
 						memcpy(buffer, start, p-start);
 						buffer[p-start] = 0;
 						camel_stream_printf((CamelStream *)ic->mem, buffer, l);
 					} else {
-						d = va_arg(ap, int);
-						c(printf("got int '%d'\n", d));
+						d = va_arg(ap, gint);
+						c(printf("got gint '%d'\n", d));
 						memcpy(buffer, start, p-start);
 						buffer[p-start] = 0;
 						camel_stream_printf((CamelStream *)ic->mem, buffer, d);
@@ -997,8 +997,8 @@ imap_engine_command_addv(CamelIMAPPEngine *imap, CamelIMAPPCommand *ic, const ch
 }
 
 
-static void *
-cie_worker(void *data)
+static gpointer
+cie_worker(gpointer data)
 {
 	CamelIMAPPCommand *ic = data;
 	CamelIMAPPEngine *imap;
@@ -1023,7 +1023,7 @@ cie_worker(void *data)
 	/* first, check if command can be sent yet ... queue if not */
 	if (imap->literal != NULL) {
 		printf("%p: queueing while literal active\n", ic);
-		e_dlist_addtail(&imap->queue, (EDListNode *)ic);
+		camel_dlist_addtail(&imap->queue, (CamelDListNode *)ic);
 		return;
 	}
 
@@ -1040,11 +1040,11 @@ cie_worker(void *data)
 		printf("%p: active literal\n", ic);
 		g_assert(cp->next);
 		imap->literal = ic;
-		e_dlist_addtail(&imap->active, (EDListNode *)ic);
+		camel_dlist_addtail(&imap->active, (CamelDListNode *)ic);
 	} else {
 		printf("%p: active non-literal\n", ic);
 		g_assert(cp->next && cp->next->next == NULL);
-		e_dlist_addtail(&imap->active, (EDListNode *)ic);
+		camel_dlist_addtail(&imap->active, (CamelDListNode *)ic);
 	}
 }
 
@@ -1116,7 +1116,7 @@ camel_exception_throw_ex(CamelException *ex)
 }
 
 void
-camel_exception_throw(int id, char *fmt, ...)
+camel_exception_throw(gint id, gchar *fmt, ...)
 {
 	CamelException *ex;
 	va_list ap;
