@@ -4,8 +4,8 @@
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -52,19 +52,21 @@ static CamelLocalFolderClass *parent_class = NULL;
 #define CF_CLASS(so) CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 #define CMAILDIRS_CLASS(so) CAMEL_STORE_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
-static CamelLocalSummary *maildir_create_summary(CamelLocalFolder *lf, const char *path, const char *folder, CamelIndex *index);
+static CamelLocalSummary *maildir_create_summary(CamelLocalFolder *lf, const gchar *path, const gchar *folder, CamelIndex *index);
 
-static void maildir_append_message(CamelFolder * folder, CamelMimeMessage * message, const CamelMessageInfo *info, char **appended_uid, CamelException * ex);
+static void maildir_append_message(CamelFolder * folder, CamelMimeMessage * message, const CamelMessageInfo *info, gchar **appended_uid, CamelException * ex);
 static CamelMimeMessage *maildir_get_message(CamelFolder * folder, const gchar * uid, CamelException * ex);
-static char* maildir_get_filename (CamelFolder *folder, const char *uid, CamelException *ex);
+static gchar * maildir_get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex);
+static gint maildir_cmp_uids (CamelFolder *folder, const gchar *uid1, const gchar *uid2);
+static void maildir_sort_uids (CamelFolder *folder, GPtrArray *uids);
 
 static void maildir_finalize(CamelObject * object);
 
-static int
+static gint
 maildir_folder_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 {
 	CamelFolder *folder = (CamelFolder *)object;
-	int i;
+	gint i;
 	guint32 tag;
 
 	for (i=0;i<args->argc;i++) {
@@ -104,6 +106,8 @@ static void camel_maildir_folder_class_init(CamelObjectClass * camel_maildir_fol
 	camel_folder_class->append_message = maildir_append_message;
 	camel_folder_class->get_message = maildir_get_message;
 	camel_folder_class->get_filename = maildir_get_filename;
+	camel_folder_class->cmp_uids = maildir_cmp_uids;
+	camel_folder_class->sort_uids = maildir_sort_uids;
 
 	lclass->create_summary = maildir_create_summary;
 }
@@ -132,12 +136,12 @@ CamelType camel_maildir_folder_get_type(void)
 							   (CamelObjectInitFunc) maildir_init,
 							   (CamelObjectFinalizeFunc) maildir_finalize);
 	}
- 
+
 	return camel_maildir_folder_type;
 }
 
 CamelFolder *
-camel_maildir_folder_new(CamelStore *parent_store, const char *full_name, guint32 flags, CamelException *ex)
+camel_maildir_folder_new(CamelStore *parent_store, const gchar *full_name, guint32 flags, CamelException *ex)
 {
 	CamelFolder *folder;
 
@@ -155,28 +159,31 @@ camel_maildir_folder_new(CamelStore *parent_store, const char *full_name, guint3
 	return folder;
 }
 
-static CamelLocalSummary *maildir_create_summary(CamelLocalFolder *lf, const char *path, const char *folder, CamelIndex *index)
+static CamelLocalSummary *maildir_create_summary(CamelLocalFolder *lf, const gchar *path, const gchar *folder, CamelIndex *index)
 {
 	return (CamelLocalSummary *)camel_maildir_summary_new((CamelFolder *)lf, path, folder, index);
 }
 
 static void
-maildir_append_message (CamelFolder *folder, CamelMimeMessage *message, const CamelMessageInfo *info, char **appended_uid, CamelException *ex)
+maildir_append_message (CamelFolder *folder, CamelMimeMessage *message, const CamelMessageInfo *info, gchar **appended_uid, CamelException *ex)
 {
 	CamelMaildirFolder *maildir_folder = (CamelMaildirFolder *)folder;
 	CamelLocalFolder *lf = (CamelLocalFolder *)folder;
 	CamelStream *output_stream;
 	CamelMessageInfo *mi;
 	CamelMaildirMessageInfo *mdi;
-	char *name, *dest = NULL;
-	
+	gchar *name, *dest = NULL;
+
 	d(printf("Appending message\n"));
 
 	/* add it to the summary/assign the uid, etc */
 	mi = camel_local_summary_add((CamelLocalSummary *)folder->summary, message, info, lf->changes, ex);
 	if (camel_exception_is_set (ex))
 		return;
-	
+
+	if ((camel_message_info_flags (mi) & CAMEL_MESSAGE_ATTACHMENTS) && !camel_mime_message_has_attachment (message))
+		camel_message_info_set_flags (mi, CAMEL_MESSAGE_ATTACHMENTS, 0);
+
 	mdi = (CamelMaildirMessageInfo *)mi;
 
 	d(printf("Appending message: uid is %s filename is %s\n", camel_message_info_uid(mi), mdi->filename));
@@ -186,11 +193,11 @@ maildir_append_message (CamelFolder *folder, CamelMimeMessage *message, const Ca
 	output_stream = camel_stream_fs_new_with_name (name, O_WRONLY|O_CREAT, 0600);
 	if (output_stream == NULL)
 		goto fail_write;
-	
+
 	if (camel_data_wrapper_write_to_stream ((CamelDataWrapper *)message, output_stream) == -1
 	    || camel_stream_close (output_stream) == -1)
 		goto fail_write;
-	
+
 	/* now move from tmp to cur (bypass new, does it matter?) */
 	dest = g_strdup_printf("%s/cur/%s", lf->folder_path, camel_maildir_info_filename (mdi));
 	if (rename (name, dest) == -1)
@@ -224,18 +231,18 @@ maildir_append_message (CamelFolder *folder, CamelMimeMessage *message, const Ca
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Cannot append message to maildir folder: %s: %s"),
 				      name, g_strerror (errno));
-	
+
 	if (output_stream) {
 		camel_object_unref (CAMEL_OBJECT (output_stream));
 		unlink (name);
 	}
-	
+
 	g_free (name);
 	g_free (dest);
 }
 
-static char* 
-maildir_get_filename (CamelFolder *folder, const char *uid, CamelException *ex)
+static gchar *
+maildir_get_filename (CamelFolder *folder, const gchar *uid, CamelException *ex)
 {
 	CamelLocalFolder *lf = (CamelLocalFolder *)folder;
 	CamelMaildirMessageInfo *mdi;
@@ -263,7 +270,7 @@ maildir_get_message(CamelFolder * folder, const gchar * uid, CamelException * ex
 	CamelStream *message_stream = NULL;
 	CamelMimeMessage *message = NULL;
 	CamelMessageInfo *info;
-	char *name;
+	gchar *name;
 	CamelMaildirMessageInfo *mdi;
 
 	d(printf("getting message: %s\n", uid));
@@ -307,3 +314,46 @@ maildir_get_message(CamelFolder * folder, const gchar * uid, CamelException * ex
 
 	return message;
 }
+
+static gint
+maildir_cmp_uids (CamelFolder *folder, const gchar *uid1, const gchar *uid2)
+{
+	CamelMessageInfo *a, *b;
+	time_t tma, tmb;
+
+	g_return_val_if_fail (folder != NULL, 0);
+	g_return_val_if_fail (folder->summary != NULL, 0);
+
+	a = camel_folder_summary_uid (folder->summary, uid1);
+	b = camel_folder_summary_uid (folder->summary, uid2);
+
+	g_return_val_if_fail (a != NULL, 0);
+	g_return_val_if_fail (b != NULL, 0);
+
+	tma = camel_message_info_date_received (a);
+	tmb = camel_message_info_date_received (b);
+
+	return tma < tmb ? -1 : tma == tmb ? 0 : 1;
+}
+
+static void
+maildir_sort_uids (CamelFolder *folder, GPtrArray *uids)
+{
+	g_return_if_fail (parent_class != NULL);
+	g_return_if_fail (folder != NULL);
+
+	if (uids && uids->len > 1) {
+		CamelException ex;
+
+		camel_exception_init (&ex);
+
+		camel_folder_summary_ensure_infos_loaded (folder->summary, uids->len, &ex);
+
+		if (camel_exception_is_set (&ex))
+			g_warning ("%s: %s", G_STRFUNC, camel_exception_get_description (&ex));
+
+		camel_exception_clear (&ex);
+	}
+
+	CAMEL_FOLDER_CLASS (parent_class)->sort_uids (folder, uids);
+}
