@@ -55,33 +55,33 @@
 
 #define EXTRACT_DIGIT(val) part++; val=strtoul (part, &part, 10);
 #define EXTRACT_FIRST_DIGIT(val) val=strtoul (part, &part, 10);
- 
+
 static CamelFIRecord * summary_header_to_db (CamelFolderSummary *, CamelException *ex);
-static int summary_header_from_db (CamelFolderSummary *, CamelFIRecord *);
+static gint summary_header_from_db (CamelFolderSummary *, CamelFIRecord *);
 static CamelMessageInfo * message_info_from_db(CamelFolderSummary *s, CamelMIRecord *record);
 static CamelMIRecord * message_info_to_db(CamelFolderSummary *s, CamelMessageInfo *info);
 
 
-static int summary_header_load (CamelFolderSummary *, FILE *);
-static int summary_header_save (CamelFolderSummary *, FILE *);
+static gint summary_header_load (CamelFolderSummary *, FILE *);
+static gint summary_header_save (CamelFolderSummary *, FILE *);
 
 static CamelMessageInfo * message_info_new_from_header(CamelFolderSummary *, struct _camel_header_raw *);
 static CamelMessageInfo * message_info_new_from_parser(CamelFolderSummary *, CamelMimeParser *);
 static CamelMessageInfo * message_info_load (CamelFolderSummary *, FILE *);
-static int		  message_info_save (CamelFolderSummary *, FILE *, CamelMessageInfo *);
-static int 		  meta_message_info_save(CamelFolderSummary *s, FILE *out_meta, FILE *out, CamelMessageInfo *mi);
+static gint		  message_info_save (CamelFolderSummary *, FILE *, CamelMessageInfo *);
+static gint		  meta_message_info_save(CamelFolderSummary *s, FILE *out_meta, FILE *out, CamelMessageInfo *mi);
 /*static void		  message_info_free (CamelFolderSummary *, CamelMessageInfo *);*/
 
-static char *mbox_summary_encode_x_evolution (CamelLocalSummary *cls, const CamelLocalMessageInfo *mi);
+static gchar *mbox_summary_encode_x_evolution (CamelLocalSummary *cls, const CamelLocalMessageInfo *mi);
 
-static int mbox_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex);
-static int mbox_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint mbox_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint mbox_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
 #ifdef STATUS_PINE
 static CamelMessageInfo *mbox_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMessageInfo *info, CamelFolderChangeInfo *ci, CamelException *ex);
 #endif
 
-static int mbox_summary_sync_quick(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
-static int mbox_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint mbox_summary_sync_quick(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint mbox_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
 
 static void camel_mbox_summary_class_init (CamelMboxSummaryClass *klass);
 static void camel_mbox_summary_init       (CamelMboxSummary *obj);
@@ -92,8 +92,8 @@ static void camel_mbox_summary_finalise   (CamelObject *obj);
 #define STATUS_XSTATUS (CAMEL_MESSAGE_FLAGGED|CAMEL_MESSAGE_ANSWERED|CAMEL_MESSAGE_DELETED)
 #define STATUS_STATUS (CAMEL_MESSAGE_SEEN)
 
-static void encode_status(guint32 flags, char status[8]);
-static guint32 decode_status(const char *status);
+static void encode_status(guint32 flags, gchar status[8]);
+static guint32 decode_status(const gchar *status);
 #endif
 
 static CamelLocalSummaryClass *camel_mbox_summary_parent;
@@ -102,7 +102,7 @@ CamelType
 camel_mbox_summary_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_local_summary_get_type(), "CamelMboxSummary",
 					   sizeof (CamelMboxSummary),
@@ -112,13 +112,13 @@ camel_mbox_summary_get_type(void)
 					   (CamelObjectInitFunc) camel_mbox_summary_init,
 					   (CamelObjectFinalizeFunc) camel_mbox_summary_finalise);
 	}
-	
+
 	return type;
 }
 static gboolean
-mbox_info_set_user_flag(CamelMessageInfo *mi, const char *name, gboolean value)
+mbox_info_set_user_flag(CamelMessageInfo *mi, const gchar *name, gboolean value)
 {
-	int res;
+	gint res;
 
 	res = ((CamelFolderSummaryClass *)camel_mbox_summary_parent)->info_set_user_flag(mi, name, value);
 	if (res)
@@ -128,9 +128,9 @@ mbox_info_set_user_flag(CamelMessageInfo *mi, const char *name, gboolean value)
 }
 
 static gboolean
-mbox_info_set_user_tag(CamelMessageInfo *mi, const char *name, const char *value)
+mbox_info_set_user_tag(CamelMessageInfo *mi, const gchar *name, const gchar *value)
 {
-	int res;
+	gint res;
 
 	res = ((CamelFolderSummaryClass *)camel_mbox_summary_parent)->info_set_user_tag(mi, name, value);
 	if (res)
@@ -159,7 +159,7 @@ camel_mbox_summary_class_init(CamelMboxSummaryClass *klass)
 {
 	CamelFolderSummaryClass *sklass = (CamelFolderSummaryClass *)klass;
 	CamelLocalSummaryClass *lklass = (CamelLocalSummaryClass *)klass;
-	
+
 	camel_mbox_summary_parent = (CamelLocalSummaryClass *)camel_type_get_global_classfuncs(camel_local_summary_get_type());
 
 	sklass->summary_header_load = summary_header_load;
@@ -169,7 +169,7 @@ camel_mbox_summary_class_init(CamelMboxSummaryClass *klass)
 	sklass->summary_header_to_db = summary_header_to_db;
 	sklass->message_info_from_db = message_info_from_db;
 	sklass->message_info_to_db = message_info_to_db;
-	
+
 	sklass->message_info_new_from_header  = message_info_new_from_header;
 	sklass->message_info_new_from_parser = message_info_new_from_parser;
 	sklass->message_info_load = message_info_load;
@@ -182,7 +182,7 @@ camel_mbox_summary_class_init(CamelMboxSummaryClass *klass)
 #ifdef STATUS_PINE
 	sklass->info_set_flags = mbox_info_set_flags;
 #endif
-	
+
 	lklass->encode_x_evolution = mbox_summary_encode_x_evolution;
 	lklass->check = mbox_summary_check;
 	lklass->sync = mbox_summary_sync;
@@ -198,7 +198,7 @@ static void
 camel_mbox_summary_init(CamelMboxSummary *obj)
 {
 	struct _CamelFolderSummary *s = (CamelFolderSummary *)obj;
-	
+
 	/* subclasses need to set the right instance data sizes */
 	s->message_info_size = sizeof(CamelMboxMessageInfo);
 	s->content_info_size = sizeof(CamelMboxMessageContentInfo);
@@ -217,11 +217,11 @@ camel_mbox_summary_finalise(CamelObject *obj)
  * camel_mbox_summary_new:
  *
  * Create a new CamelMboxSummary object.
- * 
+ *
  * Return value: A new CamelMboxSummary widget.
  **/
 CamelMboxSummary *
-camel_mbox_summary_new(struct _CamelFolder *folder, const char *filename, const char *mbox_name, CamelIndex *index)
+camel_mbox_summary_new(struct _CamelFolder *folder, const gchar *filename, const gchar *mbox_name, CamelIndex *index)
 {
 	CamelMboxSummary *new = (CamelMboxSummary *)camel_object_new(camel_mbox_summary_get_type());
 
@@ -239,22 +239,22 @@ camel_mbox_summary_new(struct _CamelFolder *folder, const char *filename, const
 	return new;
 }
 
-void camel_mbox_summary_xstatus(CamelMboxSummary *mbs, int state)
+void camel_mbox_summary_xstatus(CamelMboxSummary *mbs, gint state)
 {
 	mbs->xstatus = state;
 }
 
-static char *
+static gchar *
 mbox_summary_encode_x_evolution (CamelLocalSummary *cls, const CamelLocalMessageInfo *mi)
 {
-	const char *p, *uidstr;
+	const gchar *p, *uidstr;
 	guint32 uid;
 
 	/* This is busted, it is supposed to encode ALL DATA */
 	p = uidstr = camel_message_info_uid(mi);
 	while (*p && isdigit(*p))
 		p++;
-	
+
 	if (*p == 0 && sscanf(uidstr, "%u", &uid) == 1) {
 		return g_strdup_printf("%08x-%04x", uid, mi->info.flags & 0xffff);
 	} else {
@@ -262,11 +262,11 @@ mbox_summary_encode_x_evolution (CamelLocalSummary *cls, const CamelLocalMessage
 	}
 }
 
-static int 
+static gint
 summary_header_from_db (CamelFolderSummary *s, struct _CamelFIRecord *fir)
 {
 	CamelMboxSummary *mbs = CAMEL_MBOX_SUMMARY(s);
-	char *part;
+	gchar *part;
 
 	((CamelFolderSummaryClass *)camel_mbox_summary_parent)->summary_header_from_db(s, fir);
 
@@ -275,12 +275,12 @@ summary_header_from_db (CamelFolderSummary *s, struct _CamelFIRecord *fir)
 		EXTRACT_DIGIT(mbs->version)
 		EXTRACT_DIGIT(mbs->folder_size)
 	}
-	
+
 	return 0;
 }
 
 
-static int
+static gint
 summary_header_load(CamelFolderSummary *s, FILE *in)
 {
 	CamelMboxSummary *mbs = CAMEL_MBOX_SUMMARY(s);
@@ -293,31 +293,31 @@ summary_header_load(CamelFolderSummary *s, FILE *in)
 		return camel_file_util_decode_uint32(in, (guint32 *) &mbs->folder_size);
 
 	/* version 1 */
-	if (camel_file_util_decode_fixed_int32(in, &mbs->version) == -1
-	    || camel_file_util_decode_size_t(in, &mbs->folder_size) == -1)
+	if (camel_file_util_decode_fixed_int32(in, (gint32 *) &mbs->version) == -1
+	    || camel_file_util_decode_gsize(in, &mbs->folder_size) == -1)
 		return -1;
 
 	return 0;
 }
 
-static CamelFIRecord * 
+static CamelFIRecord *
 summary_header_to_db (CamelFolderSummary *s, CamelException *ex)
 {
 	CamelMboxSummary *mbs = CAMEL_MBOX_SUMMARY(s);
 	struct _CamelFIRecord *fir;
-	char *tmp;
+	gchar *tmp;
 
 	fir = ((CamelFolderSummaryClass *)camel_mbox_summary_parent)->summary_header_to_db (s, ex);
 	if (fir) {
 		tmp = fir->bdata;
-		fir->bdata = g_strdup_printf ("%s %d %d", tmp ? tmp : "", CAMEL_MBOX_SUMMARY_VERSION, (int) mbs->folder_size);
+		fir->bdata = g_strdup_printf ("%s %d %d", tmp ? tmp : "", CAMEL_MBOX_SUMMARY_VERSION, (gint) mbs->folder_size);
 		g_free (tmp);
 	}
-	
+
 	return fir;
 }
 
-static int
+static gint
 summary_header_save(CamelFolderSummary *s, FILE *out)
 {
 	CamelMboxSummary *mbs = CAMEL_MBOX_SUMMARY(s);
@@ -327,7 +327,7 @@ summary_header_save(CamelFolderSummary *s, FILE *out)
 
 	camel_file_util_encode_fixed_int32(out, CAMEL_MBOX_SUMMARY_VERSION);
 
-	return camel_file_util_encode_size_t(out, mbs->folder_size);
+	return camel_file_util_encode_gsize(out, mbs->folder_size);
 }
 
 static CamelMessageInfo *
@@ -338,11 +338,11 @@ message_info_new_from_header(CamelFolderSummary *s, struct _camel_header_raw *h)
 
 	mi = (CamelMboxMessageInfo *)((CamelFolderSummaryClass *)camel_mbox_summary_parent)->message_info_new_from_header(s, h);
 	if (mi) {
-		const char *xev, *uid;
+		const gchar *xev, *uid;
 		CamelMboxMessageInfo *info = NULL;
-		int add = 0;	/* bitmask of things to add, 1 assign uid, 2, just add as new, 4 = recent */
+		gint add = 0;	/* bitmask of things to add, 1 assign uid, 2, just add as new, 4 = recent */
 #ifdef STATUS_PINE
-		const char *status = NULL, *xstatus = NULL;
+		const gchar *status = NULL, *xstatus = NULL;
 		guint32 flags = 0;
 
 		if (mbs->xstatus) {
@@ -407,7 +407,7 @@ message_info_new_from_header(CamelFolderSummary *s, struct _camel_header_raw *h)
 
 		mi->frompos = -1;
 	}
-	
+
 	return (CamelMessageInfo *)mi;
 }
 
@@ -422,15 +422,15 @@ message_info_new_from_parser(CamelFolderSummary *s, CamelMimeParser *mp)
 
 		mbi->frompos = camel_mime_parser_tell_start_from(mp);
 	}
-	
+
 	return mi;
 }
 
-static CamelMessageInfo * 
+static CamelMessageInfo *
 message_info_from_db(CamelFolderSummary *s, struct _CamelMIRecord *mir)
 {
 	CamelMessageInfo *mi;
-	char *part;
+	gchar *part;
 
 	mi = ((CamelFolderSummaryClass *)camel_mbox_summary_parent)->message_info_from_db(s, mir);
 
@@ -455,18 +455,18 @@ message_info_load(CamelFolderSummary *s, FILE *in)
 	mi = ((CamelFolderSummaryClass *)camel_mbox_summary_parent)->message_info_load(s, in);
 	if (mi) {
 		CamelMboxMessageInfo *mbi = (CamelMboxMessageInfo *)mi;
-		
+
 		if (camel_file_util_decode_off_t(in, &mbi->frompos) == -1)
 			goto error;
 	}
-	
+
 	return mi;
 error:
 	camel_message_info_free(mi);
 	return NULL;
 }
 
-static int
+static gint
 meta_message_info_save(CamelFolderSummary *s, FILE *out_meta, FILE *out, CamelMessageInfo *mi)
 {
 	CamelMboxMessageInfo *mbi = (CamelMboxMessageInfo *)mi;
@@ -480,7 +480,7 @@ meta_message_info_save(CamelFolderSummary *s, FILE *out_meta, FILE *out, CamelMe
 	return 0;
 }
 
-static struct _CamelMIRecord * 
+static struct _CamelMIRecord *
 message_info_to_db(CamelFolderSummary *s, CamelMessageInfo *info)
 {
 	CamelMboxMessageInfo *mbi = (CamelMboxMessageInfo *)info;
@@ -493,7 +493,7 @@ message_info_to_db(CamelFolderSummary *s, CamelMessageInfo *info)
 }
 
 
-static int
+static gint
 message_info_save(CamelFolderSummary *s, FILE *out, CamelMessageInfo *mi)
 {
 	CamelMboxMessageInfo *mbi = (CamelMboxMessageInfo *)mi;
@@ -508,21 +508,21 @@ message_info_save(CamelFolderSummary *s, FILE *out, CamelMessageInfo *mi)
 }
 
 /* like summary_rebuild, but also do changeinfo stuff (if supplied) */
-static int
+static gint
 summary_update(CamelLocalSummary *cls, off_t offset, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
-	int i, count;
+	gint i, count;
 	CamelFolderSummary *s = (CamelFolderSummary *)cls;
 	CamelMboxSummary *mbs = (CamelMboxSummary *)cls;
 	CamelMimeParser *mp;
 	CamelMboxMessageInfo *mi;
-	int fd;
-	int ok = 0;
+	gint fd;
+	gint ok = 0;
 	struct stat st;
 	off_t size = 0;
 	GSList *del = NULL;
 
-	d(printf("Calling summary update, from pos %d\n", (int)offset));
+	d(printf("Calling summary update, from pos %d\n", (gint)offset));
 
 	cls->index_force = FALSE;
 
@@ -537,7 +537,7 @@ summary_update(CamelLocalSummary *cls, off_t offset, CamelFolderChangeInfo *chan
 		camel_operation_end(NULL);
 		return -1;
 	}
-	
+
 	if (fstat(fd, &st) == 0)
 		size = st.st_size;
 
@@ -563,7 +563,7 @@ summary_update(CamelLocalSummary *cls, off_t offset, CamelFolderChangeInfo *chan
 	   from the old end, so everything must be treated as new */
 	count = camel_folder_summary_count(s);
 	if (count != camel_folder_summary_cache_size(s)) /* It makes sense to load summary, if it isn't there. */
-		camel_folder_summary_reload_from_db (s, ex);	
+		camel_folder_summary_reload_from_db (s, ex);
 	for (i=0;i<count;i++) {
 		mi = (CamelMboxMessageInfo *)camel_folder_summary_index(s, i);
 		if (offset == 0)
@@ -577,8 +577,8 @@ summary_update(CamelLocalSummary *cls, off_t offset, CamelFolderChangeInfo *chan
 	while (camel_mime_parser_step(mp, NULL, NULL) == CAMEL_MIME_PARSER_STATE_FROM) {
 		CamelMessageInfo *info;
 		off_t pc = camel_mime_parser_tell_start_from (mp) + 1;
-		
-		camel_operation_progress (NULL, (int) (((float) pc / size) * 100));
+
+		camel_operation_progress (NULL, (gint) (((gfloat) pc / size) * 100));
 
 		info = camel_folder_summary_add_from_parser(s, mp);
 		if (info == NULL) {
@@ -608,14 +608,14 @@ summary_update(CamelLocalSummary *cls, off_t offset, CamelFolderChangeInfo *chan
 		}
 		camel_message_info_free(mi);
 	}
-	
+
 	/* Delete all in one transaction */
 	camel_db_delete_uids (s->folder->parent_store->cdb_w, s->folder->full_name, del, ex);
 	g_slist_foreach (del, (GFunc) camel_pstring_free, NULL);
-	g_slist_free (del);	
+	g_slist_free (del);
 
 	mbs->changes = NULL;
-	
+
 	/* update the file size/mtime in the summary */
 	if (ok != -1) {
 		if (g_stat(cls->folder_path, &st) == 0) {
@@ -630,14 +630,14 @@ summary_update(CamelLocalSummary *cls, off_t offset, CamelFolderChangeInfo *chan
 	return ok;
 }
 
-static int
+static gint
 mbox_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changes, CamelException *ex)
 {
 	CamelMboxSummary *mbs = (CamelMboxSummary *)cls;
 	CamelFolderSummary *s = (CamelFolderSummary *)cls;
 	struct stat st;
-	int ret = 0;
-	int i, count;
+	gint ret = 0;
+	gint i, count;
 
 	d(printf("Checking summary\n"));
 
@@ -698,12 +698,12 @@ mbox_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changes, Camel
 }
 
 /* perform a full sync */
-static int
+static gint
 mbox_summary_sync_full(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
 	CamelLocalSummary *cls = (CamelLocalSummary *)mbs;
-	int fd = -1, fdout = -1;
-	char *tmpname = NULL;
+	gint fd = -1, fdout = -1;
+	gchar *tmpname = NULL;
 	guint32 flags = (expunge?1:0);
 
 	d(printf("performing full summary/sync\n"));
@@ -769,15 +769,15 @@ mbox_summary_sync_full(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChang
 	tmpname = NULL;
 
 	camel_operation_end(NULL);
-		
+
 	return 0;
  error:
 	if (fd != -1)
 		close(fd);
-	
+
 	if (fdout != -1)
 		close(fdout);
-	
+
 	if (tmpname)
 		g_unlink(tmpname);
 
@@ -791,17 +791,17 @@ cms_sort_frompos (gpointer a, gpointer b, gpointer data)
 {
 	CamelFolderSummary *summary = (CamelFolderSummary *)data;
 	CamelMboxMessageInfo *info1, *info2;
-	int ret = 0;
+	gint ret = 0;
 
 	/* Things are in memory already. Sorting speeds up syncing, if things are sorted by from pos. */
-	info1 = (CamelMboxMessageInfo *)camel_folder_summary_uid (summary, *(char **)a);
-	info2 = (CamelMboxMessageInfo *)camel_folder_summary_uid (summary, *(char **)b);
+	info1 = (CamelMboxMessageInfo *)camel_folder_summary_uid (summary, *(gchar **)a);
+	info2 = (CamelMboxMessageInfo *)camel_folder_summary_uid (summary, *(gchar **)b);
 
 	if (info1->frompos > info2->frompos)
 		ret = 1;
 	else if  (info1->frompos < info2->frompos)
 		ret = -1;
-	else 
+	else
 		ret = 0;
 	camel_message_info_free (info1);
 	camel_message_info_free (info2);
@@ -811,18 +811,18 @@ cms_sort_frompos (gpointer a, gpointer b, gpointer data)
 }
 
 /* perform a quick sync - only system flags have changed */
-static int
+static gint
 mbox_summary_sync_quick(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
 	CamelLocalSummary *cls = (CamelLocalSummary *)mbs;
 	CamelFolderSummary *s = (CamelFolderSummary *)mbs;
 	CamelMimeParser *mp = NULL;
-	int i;
+	gint i;
 	CamelMboxMessageInfo *info = NULL;
-	int fd = -1, pfd;
-	char *xevnew, *xevtmp;
-	const char *xev;
-	int len;
+	gint fd = -1, pfd;
+	gchar *xevnew, *xevtmp;
+	const gchar *xev;
+	gint len;
 	off_t lastpos;
 	GPtrArray *summary = NULL;
 
@@ -859,10 +859,10 @@ mbox_summary_sync_quick(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChan
 	summary = camel_folder_summary_get_changed ((CamelFolderSummary *)mbs);
 	if (summary->len)
 		g_ptr_array_sort_with_data (summary, (GCompareDataFunc)cms_sort_frompos, (gpointer) mbs);
-	
+
 	for (i = 0; i < summary->len; i++) {
-		int xevoffset;
-		int pc = (i+1)*100/summary->len;
+		gint xevoffset;
+		gint pc = (i+1)*100/summary->len;
 
 		camel_operation_progress(NULL, pc);
 
@@ -876,7 +876,7 @@ mbox_summary_sync_quick(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChan
 			continue;
 		}
 
-		d(printf("Updating message %s: %d\n", camel_message_info_uid(info), (int)info->frompos));
+		d(printf("Updating message %s: %d\n", camel_message_info_uid(info), (gint)info->frompos));
 
 		camel_mime_parser_seek(mp, info->frompos, SEEK_SET);
 
@@ -884,16 +884,16 @@ mbox_summary_sync_quick(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChan
 			g_warning("Expected a From line here, didn't get it");
 			camel_exception_setv(ex, CAMEL_EXCEPTION_SYSTEM,
 					     _("Summary and folder mismatch, even after a sync"));
-			goto error;			
+			goto error;
 		}
 
 		if (camel_mime_parser_tell_start_from(mp) != info->frompos) {
 			g_warning("Didn't get the next message where I expected (%d) got %d instead",
-				  (int)info->frompos, (int)camel_mime_parser_tell_start_from(mp));
+				  (gint)info->frompos, (gint)camel_mime_parser_tell_start_from(mp));
 			camel_exception_setv(ex, CAMEL_EXCEPTION_SYSTEM,
 					     _("Summary and folder mismatch, even after a sync"));
 			goto error;
-		} 
+		}
 
 		if (camel_mime_parser_step(mp, NULL, NULL) == CAMEL_MIME_PARSER_STATE_FROM_END) {
 			g_warning("camel_mime_parser_step failed (2)");
@@ -953,11 +953,11 @@ mbox_summary_sync_quick(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChan
 	camel_object_unref((CamelObject *)mp);
 
 	camel_operation_end(NULL);
-	
+
 	return 0;
  error:
 	g_ptr_array_foreach (summary, (GFunc) camel_pstring_free, NULL);
-	g_ptr_array_free (summary, TRUE);	
+	g_ptr_array_free (summary, TRUE);
 	if (fd != -1)
 		close(fd);
 	if (mp)
@@ -970,17 +970,17 @@ mbox_summary_sync_quick(CamelMboxSummary *mbs, gboolean expunge, CamelFolderChan
 	return -1;
 }
 
-static int
+static gint
 mbox_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
 	struct stat st;
 	CamelMboxSummary *mbs = (CamelMboxSummary *)cls;
 	CamelFolderSummary *s = (CamelFolderSummary *)cls;
-	int i;
-	int quick = TRUE, work=FALSE;
-	int ret;
+	gint i;
+	gint quick = TRUE, work=FALSE;
+	gint ret;
 	GPtrArray *summary = NULL;
-	
+
 	/* first, sync ourselves up, just to make sure */
 	if (camel_local_summary_check(cls, changeinfo, ex) == -1)
 		return -1;
@@ -991,28 +991,28 @@ mbox_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInf
 	summary = camel_folder_summary_get_changed ((CamelFolderSummary *)mbs);
 	for (i=0; i<summary->len; i++) {
 		CamelMboxMessageInfo *info = (CamelMboxMessageInfo *)camel_folder_summary_uid(s, summary->pdata[i]);
-		
+
 		if ((expunge && (info->info.info.flags & CAMEL_MESSAGE_DELETED)) ||
 		    (info->info.info.flags & (CAMEL_MESSAGE_FOLDER_NOXEV|CAMEL_MESSAGE_FOLDER_XEVCHANGE)))
 			quick = FALSE;
 		else
 			work |= (info->info.info.flags & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0;
-		camel_message_info_free(info);		
+		camel_message_info_free(info);
 	}
 
 	g_ptr_array_foreach (summary, (GFunc) camel_pstring_free, NULL);
 	g_ptr_array_free (summary, TRUE);
-	
+
 	if (quick && expunge) {
 		guint32 dcount =0;
 
-	
+
 		if (camel_db_count_deleted_message_info (s->folder->parent_store->cdb_w, s->folder->full_name, &dcount, ex) == -1)
 			return -1;
 		if (dcount)
 			quick = FALSE;
 	}
-	
+
 
 	/* yuck i hate this logic, but its to simplify the 'all ok, update summary' and failover cases */
 	ret = -1;
@@ -1048,22 +1048,22 @@ mbox_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInf
 	return ((CamelLocalSummaryClass *)camel_mbox_summary_parent)->sync(cls, expunge, changeinfo, ex);
 }
 
-int
-camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderChangeInfo *changeinfo, int fd, int fdout, CamelException *ex)
+gint
+camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderChangeInfo *changeinfo, gint fd, gint fdout, CamelException *ex)
 {
 	CamelMboxSummary *mbs = (CamelMboxSummary *)cls;
 	CamelFolderSummary *s = (CamelFolderSummary *)mbs;
 	CamelMimeParser *mp = NULL;
-	int i, count;
+	gint i, count;
 	CamelMboxMessageInfo *info = NULL;
-	char *buffer, *xevnew = NULL;
-	size_t len;
-	const char *fromline;
-	int lastdel = FALSE;
+	gchar *buffer, *xevnew = NULL;
+	gsize len;
+	const gchar *fromline;
+	gint lastdel = FALSE;
 	gboolean touched = FALSE;
 	GSList *del=NULL;
 #ifdef STATUS_PINE
-	char statnew[8], xstatnew[8];
+	gchar statnew[8], xstatnew[8];
 #endif
 
 	d(printf("performing full summary/sync\n"));
@@ -1084,7 +1084,7 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 
 	count = camel_folder_summary_count(s);
 	for (i = 0; i < count; i++) {
-		int pc = (i + 1) * 100 / count;
+		gint pc = (i + 1) * 100 / count;
 
 		camel_operation_progress(NULL, pc);
 
@@ -1095,12 +1095,12 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 
 		d(printf("Looking at message %s\n", camel_message_info_uid(info)));
 
-		d(printf("seeking (%s) to %d\n", ((CamelMessageInfo *) info)->uid, (int)info->frompos));
+		d(printf("seeking (%s) to %d\n", ((CamelMessageInfo *) info)->uid, (gint)info->frompos));
 		if (lastdel)
 			camel_mime_parser_seek(mp, info->frompos, SEEK_SET);
 
 		if (camel_mime_parser_step(mp, &buffer, &len) != CAMEL_MIME_PARSER_STATE_FROM) {
-			g_warning("Expected a From line here, didn't get it %d", (int)camel_mime_parser_tell(mp));
+			g_warning("Expected a From line here, didn't get it %d", (gint)camel_mime_parser_tell(mp));
 			camel_exception_setv(ex, CAMEL_EXCEPTION_SYSTEM,
 					     _("Summary and folder mismatch, even after a sync"));
 			goto error;
@@ -1108,7 +1108,7 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 
 		if (camel_mime_parser_tell_start_from(mp) != info->frompos) {
 			g_warning("Didn't get the next message where I expected (%d) got %d instead",
-				  (int)info->frompos, (int)camel_mime_parser_tell_start_from(mp));
+				  (gint)info->frompos, (gint)camel_mime_parser_tell_start_from(mp));
 			camel_exception_setv(ex, CAMEL_EXCEPTION_SYSTEM,
 					     _("Summary and folder mismatch, even after a sync"));
 			goto error;
@@ -1116,9 +1116,9 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 
 		lastdel = FALSE;
 		if ((flags&1) && info->info.info.flags & CAMEL_MESSAGE_DELETED) {
-			const char *uid = camel_message_info_uid(info);
+			const gchar *uid = camel_message_info_uid(info);
 			guint32 flags = camel_message_info_flags(info);
-			int read, junk;
+			gint read, junk;
 			d(printf("Deleting %s\n", uid));
 
 			if (((CamelLocalSummary *)cls)->index)
@@ -1128,7 +1128,7 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 			junk = flags & CAMEL_MESSAGE_JUNK;
 			read = flags & CAMEL_MESSAGE_SEEN;
 			s->saved_count--;
-			if (junk) 
+			if (junk)
 				s->junk_count--;
 			if (!read)
 				s->unread_count--;
@@ -1190,7 +1190,7 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 
 		camel_mime_parser_drop_step(mp);
 		if (info) {
-			d(printf("looking for message content to copy across from %d\n", (int)camel_mime_parser_tell(mp)));
+			d(printf("looking for message content to copy across from %d\n", (gint)camel_mime_parser_tell(mp)));
 			while (camel_mime_parser_step(mp, &buffer, &len) == CAMEL_MIME_PARSER_STATE_PRE_FROM) {
 				/*d(printf("copying mbox contents to temporary: '%.*s'\n", len, buffer));*/
 				if (write(fdout, buffer, len) != len) {
@@ -1209,8 +1209,8 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 				goto error;
 			}
 
-			d(printf("we are now at %d, from = %d\n", (int)camel_mime_parser_tell(mp),
-				 (int)camel_mime_parser_tell_start_from(mp)));
+			d(printf("we are now at %d, from = %d\n", (gint)camel_mime_parser_tell(mp),
+				 (gint)camel_mime_parser_tell_start_from(mp)));
 			camel_mime_parser_unstep(mp);
 			camel_message_info_free((CamelMessageInfo *)info);
 			info = NULL;
@@ -1242,14 +1242,14 @@ camel_mbox_summary_sync_mbox(CamelMboxSummary *cls, guint32 flags, CamelFolderCh
 			camel_message_info_free((CamelMessageInfo *)info);
 		}
 	}
-	
+
 	if (touched)
 		camel_folder_summary_header_save_to_db (s, ex);
 
 	return 0;
  error:
 	g_free(xevnew);
-	
+
 	if (mp)
 		camel_object_unref((CamelObject *)mp);
 	if (info)
@@ -1266,7 +1266,7 @@ mbox_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMessa
 
 	mi = (CamelMboxMessageInfo *)((CamelLocalSummaryClass *)camel_mbox_summary_parent)->add(cls, msg, info, ci, ex);
 	if (mi && ((CamelMboxSummary *)cls)->xstatus) {
-		char status[8];
+		gchar status[8];
 
 		/* we snoop and add status/x-status headers to suit */
 		encode_status(mi->info.info.flags & STATUS_STATUS, status);
@@ -1279,7 +1279,7 @@ mbox_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMessa
 }
 
 static struct {
-	char tag;
+	gchar tag;
 	guint32 flag;
 } status_flags[] = {
 	{ 'F', CAMEL_MESSAGE_FLAGGED },
@@ -1289,11 +1289,11 @@ static struct {
 };
 
 static void
-encode_status(guint32 flags, char status[8])
+encode_status(guint32 flags, gchar status[8])
 {
-	size_t i;
-	char *p;
-	
+	gsize i;
+	gchar *p;
+
 	p = status;
 	for (i = 0; i < G_N_ELEMENTS (status_flags); i++)
 		if (status_flags[i].flag & flags)
@@ -1303,20 +1303,20 @@ encode_status(guint32 flags, char status[8])
 }
 
 static guint32
-decode_status(const char *status)
+decode_status(const gchar *status)
 {
-	const char *p;
+	const gchar *p;
 	guint32 flags = 0;
-	size_t i;
-	char c;
-	
+	gsize i;
+	gchar c;
+
 	p = status;
 	while ((c = *p++)) {
 		for (i = 0; i < G_N_ELEMENTS (status_flags); i++)
 			if (status_flags[i].tag == c)
 				flags |= status_flags[i].flag;
 	}
-	
+
 	return flags;
 }
 
