@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Christopher Toshok <toshok@ximian.com>
- *    	    Michael Zucchi <notzed@ximian.com>
+ *	    Michael Zucchi <notzed@ximian.com>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -70,11 +70,11 @@ static CamelServiceClass *service_class = NULL;
 #define CF_CLASS(so) CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 #define CNNTPF_CLASS(so) CAMEL_NNTP_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
-static int camel_nntp_try_authenticate (CamelNNTPStore *store, CamelException *ex);
+static gint camel_nntp_try_authenticate (CamelNNTPStore *store, CamelException *ex);
 
 static void nntp_construct (CamelService *service, CamelSession *session,
-		            CamelProvider *provider, CamelURL *url,
-		            CamelException *ex);
+			    CamelProvider *provider, CamelURL *url,
+			    CamelException *ex);
 
 
 static gboolean
@@ -84,8 +84,8 @@ nntp_can_work_offline(CamelDiscoStore *store)
 }
 
 static struct {
-	const char *name;
-	int type;
+	const gchar *name;
+	gint type;
 } headers[] = {
 	{ "subject", 0 },
 	{ "from", 0 },
@@ -95,13 +95,13 @@ static struct {
 	{ "bytes", 2 },
 };
 
-static int
+static gint
 xover_setup(CamelNNTPStore *store, CamelException *ex)
 {
-	int ret, i;
-	char *line;
-	unsigned int len;
-	unsigned char c, *p;
+	gint ret, i;
+	gchar *line;
+	guint len;
+	guchar c, *p;
 	struct _xover_header *xover, *last;
 
 	/* manual override */
@@ -118,8 +118,8 @@ xover_setup(CamelNNTPStore *store, CamelException *ex)
 	last = (struct _xover_header *)&store->xover;
 
 	/* supported command */
-	while ((ret = camel_nntp_stream_line(store->stream, (unsigned char **)&line, &len)) > 0) {
-		p = (unsigned char *) line;
+	while ((ret = camel_nntp_stream_line(store->stream, (guchar **)&line, &len)) > 0) {
+		p = (guchar *) line;
 		xover = g_malloc0(sizeof(*xover));
 		last->next = xover;
 		last = xover;
@@ -129,7 +129,7 @@ xover_setup(CamelNNTPStore *store, CamelException *ex)
 				for (i=0;i<sizeof(headers)/sizeof(headers[0]);i++) {
 					if (strcmp(line, headers[i].name) == 0) {
 						xover->name = headers[i].name;
-						if (strncmp((char *) p, "full", 4) == 0)
+						if (strncmp((gchar *) p, "full", 4) == 0)
 							xover->skip = strlen(xover->name)+1;
 						else
 							xover->skip = 0;
@@ -159,16 +159,16 @@ enum {
 #endif
 
 static gboolean
-connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, CamelException *ex)
+connect_to_server (CamelService *service, struct addrinfo *ai, gint ssl_mode, CamelException *ex)
 {
 	CamelNNTPStore *store = (CamelNNTPStore *) service;
 	CamelDiscoStore *disco_store = (CamelDiscoStore*) service;
 	CamelStream *tcp_stream;
 	gboolean retval = FALSE;
-	unsigned char *buf;
-	unsigned int len;
-	char *path;
-	
+	guchar *buf;
+	guint len;
+	gchar *path;
+
 	CAMEL_SERVICE_REC_LOCK(store, connect_lock);
 
 	if (ssl_mode != MODE_CLEAR) {
@@ -182,13 +182,13 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
 				      _("Could not connect to %s: %s"),
 				      service->url->host, _("SSL unavailable"));
-		
+
 		goto fail;
 #endif /* HAVE_SSL */
 	} else {
 		tcp_stream = camel_tcp_stream_raw_new ();
 	}
-	
+
 	if (camel_tcp_stream_connect ((CamelTcpStream *) tcp_stream, ai) == -1) {
 		if (errno == EINTR)
 			camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL,
@@ -198,15 +198,15 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 					      _("Could not connect to %s: %s"),
 					      service->url->host,
 					      g_strerror (errno));
-		
+
 		camel_object_unref (tcp_stream);
-		
+
 		goto fail;
 	}
-	
+
 	store->stream = (CamelNNTPStream *) camel_nntp_stream_new (tcp_stream);
 	camel_object_unref (tcp_stream);
-	
+
 	/* Read the greeting, if any. */
 	if (camel_nntp_stream_line (store->stream, &buf, &len) == -1) {
 		if (errno == EINTR)
@@ -223,7 +223,7 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 		goto fail;
 	}
 
-	len = strtoul ((char *) buf, (char **) &buf, 10);
+	len = strtoul ((gchar *) buf, (gchar **) &buf, 10);
 	if (len != 200 && len != 201) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("NNTP server %s returned error code %d: %s"),
@@ -240,11 +240,11 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 	    && service->url->user[0]
 	    && camel_nntp_try_authenticate(store, ex) != NNTP_AUTH_ACCEPTED)
 		goto fail;
-  	
-  	/* set 'reader' mode & ignore return code, also ping the server, inn goes offline very quickly otherwise */
-	if (camel_nntp_raw_command_auth (store, ex, (char **) &buf, "mode reader") == -1
-	    || camel_nntp_raw_command_auth (store, ex, (char **) &buf, "date") == -1)
-  		goto fail;
+
+	/* set 'reader' mode & ignore return code, also ping the server, inn goes offline very quickly otherwise */
+	if (camel_nntp_raw_command_auth (store, ex, (gchar **) &buf, "mode reader") == -1
+	    || camel_nntp_raw_command_auth (store, ex, (gchar **) &buf, "date") == -1)
+		goto fail;
 
 	if (xover_setup(store, ex) == -1)
 		goto fail;
@@ -259,17 +259,17 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 
 	g_free(store->current_folder);
 	store->current_folder = NULL;
-	
+
  fail:
 	CAMEL_SERVICE_REC_UNLOCK(store, connect_lock);
 	return retval;
 }
 
 static struct {
-	char *value;
-	char *serv;
-	char *port;
-	int mode;
+	const gchar *value;
+	const gchar *serv;
+	const gchar *port;
+	gint mode;
 } ssl_options[] = {
 	{ "",              "nntps", NNTPS_PORT, MODE_SSL   },  /* really old (1.x) */
 	{ "always",        "nntps", NNTPS_PORT, MODE_SSL   },
@@ -282,30 +282,30 @@ static gboolean
 nntp_connect_online (CamelService *service, CamelException *ex)
 {
 	struct addrinfo hints, *ai;
-	const char *ssl_mode;
-	int mode, ret, i;
-	char *serv;
-	const char *port;
-	
+	const gchar *ssl_mode;
+	gint mode, ret, i;
+	gchar *serv;
+	const gchar *port;
+
 	if ((ssl_mode = camel_url_get_param (service->url, "use_ssl"))) {
 		for (i = 0; ssl_options[i].value; i++)
 			if (!strcmp (ssl_options[i].value, ssl_mode))
 				break;
 		mode = ssl_options[i].mode;
-		serv = ssl_options[i].serv;
+		serv = (gchar *) ssl_options[i].serv;
 		port = ssl_options[i].port;
 	} else {
 		mode = MODE_CLEAR;
-		serv = "nntp";
+		serv = (gchar *) "nntp";
 		port = NNTP_PORT;
 	}
-	
+
 	if (service->url->port) {
 		serv = g_alloca (16);
 		sprintf (serv, "%d", service->url->port);
 		port = NULL;
 	}
-	
+
 	memset (&hints, 0, sizeof (hints));
 	hints.ai_socktype = SOCK_STREAM;
 	hints.ai_family = PF_UNSPEC;
@@ -316,11 +316,11 @@ nntp_connect_online (CamelService *service, CamelException *ex)
 	}
 	if (ai == NULL)
 		return FALSE;
-	
+
 	ret = connect_to_server (service, ai, mode, ex);
-	
+
 	camel_freeaddrinfo (ai);
-	
+
 	return ret;
 }
 
@@ -329,21 +329,21 @@ nntp_connect_offline (CamelService *service, CamelException *ex)
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE(service);
 	CamelDiscoStore *disco_store = (CamelDiscoStore *) nntp_store;
-	char *path;
-	
+	gchar *path;
+
 	if (nntp_store->storage_path == NULL)
 		return FALSE;
-	
+
 	/* setup store-wide cache */
 	if (nntp_store->cache == NULL) {
 		nntp_store->cache = camel_data_cache_new (nntp_store->storage_path, 0, ex);
 		if (nntp_store->cache == NULL)
 			return FALSE;
-		
+
 		/* Default cache expiry - 2 weeks old, or not visited in 5 days */
 		camel_data_cache_set_expire_age (nntp_store->cache, 60*60*24*14);
 		camel_data_cache_set_expire_access (nntp_store->cache, 60*60*24*5);
-	}	
+	}
 
 	if (disco_store->diary)
 		return TRUE;
@@ -351,10 +351,10 @@ nntp_connect_offline (CamelService *service, CamelException *ex)
 	path = g_build_filename (nntp_store->storage_path, ".ev-journal", NULL);
 	disco_store->diary = camel_disco_diary_new (disco_store, path, ex);
 	g_free (path);
-	
+
 	if (!disco_store->diary)
 		return FALSE;
-	
+
 	return TRUE;
 }
 
@@ -362,27 +362,27 @@ static gboolean
 nntp_disconnect_online (CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelNNTPStore *store = CAMEL_NNTP_STORE (service);
-	char *line;
-	
+	gchar *line;
+
 	CAMEL_SERVICE_REC_LOCK(store, connect_lock);
-	
+
 	if (clean) {
 		camel_nntp_raw_command (store, ex, &line, "quit");
 		camel_exception_clear(ex);
 	}
-	
+
 	if (!service_class->disconnect (service, clean, ex)) {
 		CAMEL_SERVICE_REC_UNLOCK(store, connect_lock);
 		return FALSE;
 	}
-	
+
 	camel_object_unref (store->stream);
 	store->stream = NULL;
 	g_free(store->current_folder);
 	store->current_folder = NULL;
 
 	CAMEL_SERVICE_REC_UNLOCK(store, connect_lock);
-	
+
 	return TRUE;
 }
 
@@ -390,26 +390,26 @@ static gboolean
 nntp_disconnect_offline (CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelDiscoStore *disco = CAMEL_DISCO_STORE(service);
-	
+
 	if (!service_class->disconnect (service, clean, ex))
 		return FALSE;
-	
+
 	if (disco->diary) {
 		camel_object_unref (disco->diary);
 		disco->diary = NULL;
 	}
-	
+
 	return TRUE;
 }
 
-static char *
+static gchar *
 nntp_store_get_name (CamelService *service, gboolean brief)
 {
 	if (brief)
 		return g_strdup_printf ("%s", service->url->host);
 	else
 		return g_strdup_printf (_("USENET News via %s"), service->url->host);
-	
+
 }
 
 extern CamelServiceAuthType camel_nntp_password_authtype;
@@ -421,17 +421,17 @@ nntp_store_query_auth_types (CamelService *service, CamelException *ex)
 }
 
 static CamelFolder *
-nntp_get_folder(CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
+nntp_get_folder(CamelStore *store, const gchar *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (store);
 	CamelFolder *folder;
-	
+
 	CAMEL_SERVICE_REC_LOCK(nntp_store, connect_lock);
-	
+
 	folder = camel_nntp_folder_new(store, folder_name, ex);
-	
+
 	CAMEL_SERVICE_REC_UNLOCK(nntp_store, connect_lock);
-	
+
 	return folder;
 }
 
@@ -440,25 +440,25 @@ nntp_get_folder(CamelStore *store, const char *folder_name, guint32 flags, Camel
  * e.g. nl.comp.os.linux.programmeren becomes n.c.o.l.programmeren
  */
 
-static char *
-nntp_newsgroup_name_short (const char *name)
+static gchar *
+nntp_newsgroup_name_short (const gchar *name)
 {
-	char *resptr, *tmp;
-	const char *ptr2;
-	
+	gchar *resptr, *tmp;
+	const gchar *ptr2;
+
 	resptr = tmp = g_malloc0 (strlen (name) + 1);
-	
+
 	while ((ptr2 = strchr (name, '.'))) {
 		if (ptr2 == name) {
 			name++;
 			continue;
 		}
-		
+
 		*resptr++ = *name;
 		*resptr++ = '.';
 		name = ptr2 + 1;
 	}
-	
+
 	strcpy (resptr, name);
 	return tmp;
 }
@@ -475,7 +475,7 @@ nntp_folder_info_from_store_info (CamelNNTPStore *store, gboolean short_notation
 	CamelURL *base_url = ((CamelService *) store)->url;
 	CamelFolderInfo *fi;
 	CamelURL *url;
-	char *path;
+	gchar *path;
 
 	fi = camel_folder_info_new ();
 	fi->full_name = g_strdup (si->path);
@@ -493,46 +493,46 @@ nntp_folder_info_from_store_info (CamelNNTPStore *store, gboolean short_notation
 	url = camel_url_new_with_base (base_url, path);
 	fi->uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
 	camel_url_free (url);
-	
+
 	return fi;
 }
 
 static CamelFolderInfo *
-nntp_folder_info_from_name (CamelNNTPStore *store, gboolean short_notation, const char *name)
+nntp_folder_info_from_name (CamelNNTPStore *store, gboolean short_notation, const gchar *name)
 {
 	CamelURL *base_url = ((CamelService *)store)->url;
 	CamelFolderInfo *fi;
 	CamelURL *url;
-	char *path;
+	gchar *path;
 
 	fi = camel_folder_info_new ();
 	fi->full_name = g_strdup (name);
-	
+
 	if (short_notation)
 		fi->name = nntp_newsgroup_name_short (name);
 	else
 		fi->name = g_strdup (name);
-	
+
 	fi->unread = -1;
-	
+
 	path = alloca(strlen(fi->full_name)+2);
 	sprintf(path, "/%s", fi->full_name);
 	url = camel_url_new_with_base (base_url, path);
 	fi->uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
 	camel_url_free (url);
-	
+
 	return fi;
 }
 
 /* handle list/newgroups response */
 static CamelNNTPStoreInfo *
-nntp_store_info_update(CamelNNTPStore *store, char *line)
+nntp_store_info_update(CamelNNTPStore *store, gchar *line)
 {
 	CamelStoreSummary *summ = (CamelStoreSummary *)store->summary;
 	CamelURL *base_url = ((CamelService *)store)->url;
 	CamelNNTPStoreInfo *si, *fsi;
 	CamelURL *url;
-	char *relpath, *tmp;
+	gchar *relpath, *tmp;
 	guint32 last = 0, first = 0, new = 0;
 
 	tmp = strchr(line, ' ');
@@ -590,16 +590,16 @@ nntp_store_info_update(CamelNNTPStore *store, char *line)
 }
 
 static CamelFolderInfo *
-nntp_store_get_subscribed_folder_info (CamelNNTPStore *store, const char *top, guint flags, CamelException *ex)
+nntp_store_get_subscribed_folder_info (CamelNNTPStore *store, const gchar *top, guint flags, CamelException *ex)
 {
-	int i;
+	gint i;
 	CamelStoreInfo *si;
 	CamelFolderInfo *first = NULL, *last = NULL, *fi = NULL;
-	
+
 	/* since we do not do a tree, any request that is not for root is sure to give no results */
 	if (top != NULL && top[0] != 0)
 		return NULL;
-	
+
 	for (i=0;(si = camel_store_summary_index ((CamelStoreSummary *) store->summary, i));i++) {
 		if (si == NULL)
 			continue;
@@ -609,7 +609,7 @@ nntp_store_get_subscribed_folder_info (CamelNNTPStore *store, const char *top, g
 			   our storeinfo too; in a very round-about way */
 			if ((flags & CAMEL_STORE_FOLDER_INFO_FAST) == 0) {
 				CamelNNTPFolder *folder;
-				char *line;
+				gchar *line;
 
 				folder = (CamelNNTPFolder *)camel_store_get_folder((CamelStore *)store, si->path, 0, ex);
 				if (folder) {
@@ -640,7 +640,7 @@ nntp_store_get_subscribed_folder_info (CamelNNTPStore *store, const char *top, g
 		}
 		camel_store_summary_info_free ((CamelStoreSummary *) store->summary, si);
 	}
-	
+
 	return first;
 }
 
@@ -648,18 +648,18 @@ nntp_store_get_subscribed_folder_info (CamelNNTPStore *store, const char *top, g
  * get folder info, using the information in our StoreSummary
  */
 static CamelFolderInfo *
-nntp_store_get_cached_folder_info (CamelNNTPStore *store, const char *orig_top, guint flags, CamelException *ex)
+nntp_store_get_cached_folder_info (CamelNNTPStore *store, const gchar *orig_top, guint flags, CamelException *ex)
 {
-	int i;
-	int subscribed_or_flag = (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED) ? 0 : 1,
+	gint i;
+	gint subscribed_or_flag = (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED) ? 0 : 1,
 	    root_or_flag = (orig_top == NULL || orig_top[0] == '\0') ? 1 : 0,
 	    recursive_flag = flags & CAMEL_STORE_FOLDER_INFO_RECURSIVE;
 	CamelStoreInfo *si;
 	CamelFolderInfo *first = NULL, *last = NULL, *fi = NULL, *l;
-	char *tmpname;
-	char *top = g_strconcat(orig_top?orig_top:"", ".", NULL);
-	int toplen = strlen(top);
-	
+	gchar *tmpname;
+	gchar *top = g_strconcat(orig_top?orig_top:"", ".", NULL);
+	gint toplen = strlen(top);
+
 	for (i = 0; (si = camel_store_summary_index ((CamelStoreSummary *) store->summary, i)); i++) {
 		if ((subscribed_or_flag || (si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED))
 		    && (root_or_flag || strncmp (si->path, top, toplen) == 0)) {
@@ -677,7 +677,7 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store, const char *orig_top,
 				   the item we added last, we need to add a portion of this item to
 				   the list as a placeholder */
 				if (!last ||
-				    strncmp(si->path, last->full_name, strlen(last->full_name)) != 0 || 
+				    strncmp(si->path, last->full_name, strlen(last->full_name)) != 0 ||
 				    si->path[strlen(last->full_name)] != '.') {
 					tmpname = g_strdup(si->path);
 					*(strchr(tmpname + toplen, '.')) = '\0';
@@ -721,7 +721,7 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store, const char *orig_top,
 		}
 		camel_store_summary_info_free((CamelStoreSummary *)store->summary, si);
 	}
-	
+
 	g_free(top);
 	return first;
 }
@@ -730,14 +730,14 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store, const char *orig_top,
 static gboolean
 nntp_get_date(CamelNNTPStore *nntp_store, CamelException *ex)
 {
-	unsigned char *line;
-	int ret = camel_nntp_command(nntp_store, ex, NULL, (char **)&line, "date");
-	char *ptr;
+	guchar *line;
+	gint ret = camel_nntp_command(nntp_store, ex, NULL, (gchar **)&line, "date");
+	gchar *ptr;
 
 	nntp_store->summary->last_newslist[0] = 0;
 
 	if (ret == 111) {
-		ptr = (char *) line + 3;
+		ptr = (gchar *) line + 3;
 		while (*ptr == ' ' || *ptr == '\t')
 			ptr++;
 
@@ -750,7 +750,7 @@ nntp_get_date(CamelNNTPStore *nntp_store, CamelException *ex)
 }
 
 static void
-store_info_remove(void *key, void *value, void *data)
+store_info_remove(gpointer key, gpointer value, gpointer data)
 {
 	CamelStoreSummary *summary = data;
 	CamelStoreInfo *si = value;
@@ -765,24 +765,24 @@ store_info_sort (gconstpointer a, gconstpointer b)
 }
 
 static CamelFolderInfo *
-nntp_store_get_folder_info_all(CamelNNTPStore *nntp_store, const char *top, guint32 flags, gboolean online, CamelException *ex)
+nntp_store_get_folder_info_all(CamelNNTPStore *nntp_store, const gchar *top, guint32 flags, gboolean online, CamelException *ex)
 {
 	CamelNNTPStoreSummary *summary = nntp_store->summary;
 	CamelNNTPStoreInfo *si;
-	unsigned int len;
-	unsigned char *line;
-	int ret = -1;
+	guint len;
+	guchar *line;
+	gint ret = -1;
 	CamelFolderInfo *fi = NULL;
 
 	CAMEL_SERVICE_REC_LOCK(nntp_store, connect_lock);
-	
+
 	if (top == NULL)
 		top = "";
-	
+
 	if (online && (top == NULL || top[0] == 0)) {
 		/* we may need to update */
 		if (summary->last_newslist[0] != 0) {
-			char date[14];
+			gchar date[14];
 			memcpy(date, summary->last_newslist + 2, 6); /* YYMMDDD */
 			date[6] = ' ';
 			memcpy(date + 7, summary->last_newslist + 8, 6); /* HHMMSS */
@@ -791,8 +791,8 @@ nntp_store_get_folder_info_all(CamelNNTPStore *nntp_store, const char *top, guin
 			/* Some servers don't support date (!), so fallback if they dont */
 			if (!nntp_get_date (nntp_store, NULL))
 				goto do_complete_list_nodate;
-			
-			ret = camel_nntp_command (nntp_store, ex, NULL, (char **) &line, "newgroups %s", date);
+
+			ret = camel_nntp_command (nntp_store, ex, NULL, (gchar **) &line, "newgroups %s", date);
 			if (ret == -1)
 				goto error;
 			else if (ret != 231) {
@@ -802,17 +802,17 @@ nntp_store_get_folder_info_all(CamelNNTPStore *nntp_store, const char *top, guin
 			}
 
 			while ((ret = camel_nntp_stream_line (nntp_store->stream, &line, &len)) > 0)
-				nntp_store_info_update(nntp_store, (char *) line);
+				nntp_store_info_update(nntp_store, (gchar *) line);
 		} else {
 			GHashTable *all;
-			int i;
+			gint i;
 
 		do_complete_list:
 			/* seems we do need a complete list */
 			/* at first, we do a DATE to find out the last load occasion */
 			nntp_get_date (nntp_store, NULL);
 		do_complete_list_nodate:
-			ret = camel_nntp_command (nntp_store, ex, NULL, (char **)&line, "list");
+			ret = camel_nntp_command (nntp_store, ex, NULL, (gchar **)&line, "list");
 			if (ret == -1)
 				goto error;
 			else if (ret != 215) {
@@ -826,22 +826,22 @@ nntp_store_get_folder_info_all(CamelNNTPStore *nntp_store, const char *top, guin
 				g_hash_table_insert(all, si->info.path, si);
 
 			while ((ret = camel_nntp_stream_line(nntp_store->stream, &line, &len)) > 0) {
-				si = nntp_store_info_update(nntp_store, (char *) line);
+				si = nntp_store_info_update(nntp_store, (gchar *) line);
 				g_hash_table_remove(all, si->info.path);
 			}
 
 			g_hash_table_foreach(all, store_info_remove, nntp_store->summary);
 			g_hash_table_destroy(all);
 		}
-		
+
 		/* sort the list */
 		g_ptr_array_sort (CAMEL_STORE_SUMMARY (nntp_store->summary)->folders, store_info_sort);
 		if (ret < 0)
 			goto error;
-		
+
 		camel_store_summary_save ((CamelStoreSummary *) nntp_store->summary);
 	}
-	
+
 	fi = nntp_store_get_cached_folder_info (nntp_store, top, flags, ex);
  error:
 	CAMEL_SERVICE_REC_UNLOCK(nntp_store, connect_lock);
@@ -850,45 +850,45 @@ nntp_store_get_folder_info_all(CamelNNTPStore *nntp_store, const char *top, guin
 }
 
 static CamelFolderInfo *
-nntp_get_folder_info (CamelStore *store, const char *top, guint32 flags, gboolean online, CamelException *ex)
+nntp_get_folder_info (CamelStore *store, const gchar *top, guint32 flags, gboolean online, CamelException *ex)
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE(store);
 	CamelFolderInfo *first = NULL;
-	
+
 	dd(printf("g_f_i: fast %d subscr %d recursive %d online %d top \"%s\"\n",
 		flags & CAMEL_STORE_FOLDER_INFO_FAST,
 		flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED,
 		flags & CAMEL_STORE_FOLDER_INFO_RECURSIVE,
 		online,
 		top?top:""));
-	
+
 	if (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED)
 		first = nntp_store_get_subscribed_folder_info (nntp_store, top, flags, ex);
 	else
 		first = nntp_store_get_folder_info_all (nntp_store, top, flags, online, ex);
-	
+
 	return first;
 }
 
 static CamelFolderInfo *
-nntp_get_folder_info_online (CamelStore *store, const char *top, guint32 flags, CamelException *ex)
+nntp_get_folder_info_online (CamelStore *store, const gchar *top, guint32 flags, CamelException *ex)
 {
 	return nntp_get_folder_info (store, top, flags, TRUE, ex);
 }
 
 static CamelFolderInfo *
-nntp_get_folder_info_offline(CamelStore *store, const char *top, guint32 flags, CamelException *ex)
+nntp_get_folder_info_offline(CamelStore *store, const gchar *top, guint32 flags, CamelException *ex)
 {
 	return nntp_get_folder_info (store, top, flags, FALSE, ex);
 }
 
 static gboolean
-nntp_store_folder_subscribed (CamelStore *store, const char *folder_name)
+nntp_store_folder_subscribed (CamelStore *store, const gchar *folder_name)
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (store);
 	CamelStoreInfo *si;
-	int truth = FALSE;
-	
+	gint truth = FALSE;
+
 	si = camel_store_summary_path ((CamelStoreSummary *) nntp_store->summary, folder_name);
 	if (si) {
 		truth = (si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) != 0;
@@ -899,20 +899,20 @@ nntp_store_folder_subscribed (CamelStore *store, const char *folder_name)
 }
 
 static void
-nntp_store_subscribe_folder (CamelStore *store, const char *folder_name,
+nntp_store_subscribe_folder (CamelStore *store, const gchar *folder_name,
 			     CamelException *ex)
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE(store);
 	CamelStoreInfo *si;
 	CamelFolderInfo *fi;
-	
+
 	CAMEL_SERVICE_REC_LOCK(nntp_store, connect_lock);
-	
+
 	si = camel_store_summary_path(CAMEL_STORE_SUMMARY(nntp_store->summary), folder_name);
 	if (!si) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
 				      _("You cannot subscribe to this newsgroup:\n\n"
-				        "No such newsgroup. The selected item is a probably a parent folder."));
+					"No such newsgroup. The selected item is a probably a parent folder."));
 	} else {
 		if (!(si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED)) {
 			si->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
@@ -926,25 +926,25 @@ nntp_store_subscribe_folder (CamelStore *store, const char *folder_name,
 			return;
 		}
 	}
-	
+
 	CAMEL_SERVICE_REC_UNLOCK(nntp_store, connect_lock);
 }
 
 static void
-nntp_store_unsubscribe_folder (CamelStore *store, const char *folder_name,
+nntp_store_unsubscribe_folder (CamelStore *store, const gchar *folder_name,
 			       CamelException *ex)
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE(store);
 	CamelFolderInfo *fi;
 	CamelStoreInfo *fitem;
 	CAMEL_SERVICE_REC_LOCK(nntp_store, connect_lock);
-	
+
 	fitem = camel_store_summary_path(CAMEL_STORE_SUMMARY(nntp_store->summary), folder_name);
-	
+
 	if (!fitem) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
 				      _("You cannot unsubscribe to this newsgroup:\n\n"
-				        "newsgroup does not exist!"));
+					"newsgroup does not exist!"));
 	} else {
 		if (fitem->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) {
 			fitem->flags &= ~CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
@@ -957,34 +957,34 @@ nntp_store_unsubscribe_folder (CamelStore *store, const char *folder_name,
 			return;
 		}
 	}
-	
+
 	CAMEL_SERVICE_REC_UNLOCK(nntp_store, connect_lock);
 }
 
 /* stubs for various folder operations we're not implementing */
 
 static CamelFolderInfo *
-nntp_create_folder (CamelStore *store, const char *parent_name,
-                    const char *folder_name, CamelException *ex)
+nntp_create_folder (CamelStore *store, const gchar *parent_name,
+                    const gchar *folder_name, CamelException *ex)
 {
 	camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
-	            _("You cannot create a folder in a News store: subscribe instead."));
+		    _("You cannot create a folder in a News store: subscribe instead."));
 	return NULL;
 }
 
 static void
-nntp_rename_folder (CamelStore *store, const char *old_name, const char *new_name_in, CamelException *ex)
+nntp_rename_folder (CamelStore *store, const gchar *old_name, const gchar *new_name_in, CamelException *ex)
 {
 	camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
-	          _("You cannot rename a folder in a News store."));
+		  _("You cannot rename a folder in a News store."));
 }
 
 static void
-nntp_delete_folder (CamelStore *store, const char *folder_name, CamelException *ex)
+nntp_delete_folder (CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	nntp_store_unsubscribe_folder (store, folder_name, ex);
 	camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
-	          _("You cannot remove a folder in a News store: unsubscribe instead."));
+		  _("You cannot remove a folder in a News store: unsubscribe instead."));
 	return;
 }
 
@@ -996,19 +996,19 @@ nntp_store_finalize (CamelObject *object)
 	CamelDiscoStore *disco_store = (CamelDiscoStore *) nntp_store;
 	struct _CamelNNTPStorePrivate *p = nntp_store->priv;
 	struct _xover_header *xover, *xn;
-	
+
 	camel_service_disconnect ((CamelService *)object, TRUE, NULL);
-	
+
 	if (nntp_store->summary) {
 		camel_store_summary_save ((CamelStoreSummary *) nntp_store->summary);
 		camel_object_unref (nntp_store->summary);
-	}	
+	}
 
 	camel_object_unref (nntp_store->mem);
 	nntp_store->mem = NULL;
 	if (nntp_store->stream)
 		camel_object_unref (nntp_store->stream);
-	
+
 	if (nntp_store->base_url)
 		g_free (nntp_store->base_url);
 	if (nntp_store->storage_path)
@@ -1032,7 +1032,7 @@ nntp_store_finalize (CamelObject *object)
 	g_free(p);
 }
 
-static gboolean 
+static gboolean
 nntp_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex)
 {
 	/* any nntp folder can be refreshed */
@@ -1048,12 +1048,12 @@ nntp_store_class_init (CamelNNTPStoreClass *camel_nntp_store_class)
 
 	parent_class = CAMEL_DISCO_STORE_CLASS (camel_type_get_global_classfuncs (camel_disco_store_get_type ()));
 	service_class = CAMEL_SERVICE_CLASS (camel_type_get_global_classfuncs (camel_service_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_service_class->construct = nntp_construct;
 	camel_service_class->query_auth_types = nntp_store_query_auth_types;
 	camel_service_class->get_name = nntp_store_get_name;
-	
+
 	camel_disco_store_class->can_work_offline = nntp_can_work_offline;
 	camel_disco_store_class->connect_online = nntp_connect_online;
 	camel_disco_store_class->connect_offline = nntp_connect_offline;
@@ -1062,13 +1062,13 @@ nntp_store_class_init (CamelNNTPStoreClass *camel_nntp_store_class)
 	camel_disco_store_class->get_folder_online = nntp_get_folder;
 	camel_disco_store_class->get_folder_resyncing = nntp_get_folder;
 	camel_disco_store_class->get_folder_offline = nntp_get_folder;
-	
+
 	camel_disco_store_class->get_folder_info_online = nntp_get_folder_info_online;
 	camel_disco_store_class->get_folder_info_resyncing = nntp_get_folder_info_online;
 	camel_disco_store_class->get_folder_info_offline = nntp_get_folder_info_offline;
-	
+
 	camel_store_class->free_folder_info = camel_store_free_folder_info_full;
-	
+
 	camel_store_class->folder_subscribed = nntp_store_folder_subscribed;
 	camel_store_class->subscribe_folder = nntp_store_subscribe_folder;
 	camel_store_class->unsubscribe_folder = nntp_store_unsubscribe_folder;
@@ -1087,34 +1087,33 @@ nntp_construct (CamelService *service, CamelSession *session,
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE(service);
 	CamelURL *summary_url;
-	char *tmp;
-	
+	gchar *tmp;
+
 	/* construct the parent first */
 	CAMEL_SERVICE_CLASS (parent_class)->construct (service, session, provider, url, ex);
 	if (camel_exception_is_set (ex))
 		return;
-	
+
 	/* find out the storage path, base url */
 	nntp_store->storage_path = camel_session_get_storage_path (session, service, ex);
 	if (!nntp_store->storage_path)
 		return;
-	
+
 	/* FIXME */
 	nntp_store->base_url = camel_url_to_string (service->url, (CAMEL_URL_HIDE_PASSWORD |
 								   CAMEL_URL_HIDE_PARAMS |
 								   CAMEL_URL_HIDE_AUTH));
-	
+
 	tmp = g_build_filename (nntp_store->storage_path, ".ev-store-summary", NULL);
 	nntp_store->summary = camel_nntp_store_summary_new ();
-	camel_store_summary_set_filename ((CamelStoreSummary *) nntp_store->summary, tmp);	
+	camel_store_summary_set_filename ((CamelStoreSummary *) nntp_store->summary, tmp);
 	summary_url = camel_url_new (nntp_store->base_url, NULL);
 	camel_store_summary_set_uri_base ((CamelStoreSummary *) nntp_store->summary, summary_url);
 	g_free (tmp);
-	
+
 	camel_url_free (summary_url);
-	if (camel_store_summary_load ((CamelStoreSummary *)nntp_store->summary) == 0)
-		;
-	
+	camel_store_summary_load ((CamelStoreSummary *)nntp_store->summary);
+
 	/* get options */
 	if (camel_url_get_param (url, "show_short_notation"))
 		nntp_store->do_short_folder_notation = TRUE;
@@ -1129,7 +1128,7 @@ nntp_construct (CamelService *service, CamelSession *session,
 	nntp_store->cache = camel_data_cache_new(nntp_store->storage_path, 0, ex);
 	if (nntp_store->cache == NULL)
 		return;
-		
+
 	/* Default cache expiry - 2 weeks old, or not visited in 5 days */
 	camel_data_cache_set_expire_age(nntp_store->cache, 60*60*24*14);
 	camel_data_cache_set_expire_access(nntp_store->cache, 60*60*24*5);
@@ -1141,11 +1140,11 @@ nntp_store_init (gpointer object, gpointer klass)
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE(object);
 	CamelStore *store = CAMEL_STORE (object);
 	struct _CamelNNTPStorePrivate *p;
-	
+
 	store->flags = CAMEL_STORE_SUBSCRIPTIONS;
-	
+
 	nntp_store->mem = (CamelStreamMem *)camel_stream_mem_new();
-	
+
 	p = nntp_store->priv = g_malloc0(sizeof(*p));
 }
 
@@ -1153,7 +1152,7 @@ CamelType
 camel_nntp_store_get_type (void)
 {
 	static CamelType camel_nntp_store_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_nntp_store_type == CAMEL_INVALID_TYPE) {
 		camel_nntp_store_type =
 			camel_type_register (CAMEL_DISCO_STORE_TYPE,
@@ -1165,18 +1164,18 @@ camel_nntp_store_get_type (void)
 					     (CamelObjectInitFunc) nntp_store_init,
 					     (CamelObjectFinalizeFunc) nntp_store_finalize);
 	}
-	
+
 	return camel_nntp_store_type;
 }
 
-static int
+static gint
 camel_nntp_try_authenticate (CamelNNTPStore *store, CamelException *ex)
 {
 	CamelService *service = (CamelService *) store;
 	CamelSession *session = camel_service_get_session (service);
-	int ret;
-	char *line = NULL;
-	
+	gint ret;
+	gchar *line = NULL;
+
 	if (!service->url->user) {
 		camel_exception_setv(ex, CAMEL_EXCEPTION_INVALID_PARAM,
 				     _("Authentication requested but no username provided"));
@@ -1185,12 +1184,12 @@ camel_nntp_try_authenticate (CamelNNTPStore *store, CamelException *ex)
 
 	/* if nessecary, prompt for the password */
 	if (!service->url->passwd) {
-		char *prompt, *base;
+		gchar *prompt, *base;
 	retry:
 		base = camel_session_build_password_prompt (
 			"NNTP", service->url->user, service->url->host);
 		if (line) {
-			char *top = g_markup_printf_escaped (
+			gchar *top = g_markup_printf_escaped (
 				_("Cannot authenticate to server: %s"), line);
 
 			prompt = g_strdup_printf("%s\n\n%s", top, base);
@@ -1205,7 +1204,7 @@ camel_nntp_try_authenticate (CamelNNTPStore *store, CamelException *ex)
 						    prompt, "password", CAMEL_SESSION_PASSWORD_SECRET, ex);
 		g_free(prompt);
 		g_free(base);
-		
+
 		if (!service->url->passwd)
 			return -1;
 	}
@@ -1234,48 +1233,48 @@ camel_nntp_try_authenticate (CamelNNTPStore *store, CamelException *ex)
 }
 
 /* Enter owning lock */
-int
-camel_nntp_raw_commandv (CamelNNTPStore *store, CamelException *ex, char **line, const char *fmt, va_list ap)
+gint
+camel_nntp_raw_commandv (CamelNNTPStore *store, CamelException *ex, gchar **line, const gchar *fmt, va_list ap)
 {
-	const unsigned char *p, *ps;
-	unsigned char c;
-	char *s;
-	int d;
-	unsigned int u, u2;
+	const guchar *p, *ps;
+	guchar c;
+	gchar *s;
+	gint d;
+	guint u, u2;
 
 	g_assert(store->stream->mode != CAMEL_NNTP_STREAM_DATA);
 
 	camel_nntp_stream_set_mode(store->stream, CAMEL_NNTP_STREAM_LINE);
 
-	p = (const unsigned char *) fmt;
-	ps = (const unsigned char *) p;
+	p = (const guchar *) fmt;
+	ps = (const guchar *) p;
 
 	while ((c = *p++)) {
 		switch (c) {
 		case '%':
 			c = *p++;
-			camel_stream_write ((CamelStream *) store->mem, (const char *) ps, p - ps - (c == '%' ? 1 : 2));
+			camel_stream_write ((CamelStream *) store->mem, (const gchar *) ps, p - ps - (c == '%' ? 1 : 2));
 			ps = p;
 			switch (c) {
 			case 's':
-				s = va_arg(ap, char *);
+				s = va_arg(ap, gchar *);
 				camel_stream_write((CamelStream *)store->mem, s, strlen(s));
 				break;
 			case 'd':
-				d = va_arg(ap, int);
+				d = va_arg(ap, gint);
 				camel_stream_printf((CamelStream *)store->mem, "%d", d);
 				break;
 			case 'u':
-				u = va_arg(ap, unsigned int);
+				u = va_arg(ap, guint);
 				camel_stream_printf((CamelStream *)store->mem, "%u", u);
 				break;
 			case 'm':
-				s = va_arg(ap, char *);
+				s = va_arg(ap, gchar *);
 				camel_stream_printf((CamelStream *)store->mem, "<%s>", s);
 				break;
 			case 'r':
-				u = va_arg(ap, unsigned int);
-				u2 = va_arg(ap, unsigned int);
+				u = va_arg(ap, guint);
+				u2 = va_arg(ap, guint);
 				if (u == u2)
 					camel_stream_printf((CamelStream *)store->mem, "%u", u);
 				else
@@ -1288,18 +1287,18 @@ camel_nntp_raw_commandv (CamelNNTPStore *store, CamelException *ex, char **line,
 		}
 	}
 
-	camel_stream_write ((CamelStream *) store->mem, (const char *) ps, p-ps-1);
-	dd(printf("NNTP_COMMAND: '%.*s'\n", (int)store->mem->buffer->len, store->mem->buffer->data));
+	camel_stream_write ((CamelStream *) store->mem, (const gchar *) ps, p-ps-1);
+	dd(printf("NNTP_COMMAND: '%.*s'\n", (gint)store->mem->buffer->len, store->mem->buffer->data));
 	camel_stream_write ((CamelStream *) store->mem, "\r\n", 2);
 
-	if (camel_stream_write((CamelStream *) store->stream, (const char *) store->mem->buffer->data, store->mem->buffer->len) == -1)
+	if (camel_stream_write((CamelStream *) store->stream, (const gchar *) store->mem->buffer->data, store->mem->buffer->len) == -1)
 		goto ioerror;
 
 	/* FIXME: hack */
 	camel_stream_reset ((CamelStream *) store->mem);
 	g_byte_array_set_size (store->mem->buffer, 0);
 
-	if (camel_nntp_stream_line (store->stream, (unsigned char **) line, &u) == -1)
+	if (camel_nntp_stream_line (store->stream, (guchar **) line, &u) == -1)
 		goto ioerror;
 
 	u = strtoul (*line, NULL, 10);
@@ -1318,10 +1317,10 @@ ioerror:
 	return -1;
 }
 
-int
-camel_nntp_raw_command(CamelNNTPStore *store, CamelException *ex, char **line, const char *fmt, ...)
+gint
+camel_nntp_raw_command(CamelNNTPStore *store, CamelException *ex, gchar **line, const gchar *fmt, ...)
 {
-	int ret;
+	gint ret;
 	va_list ap;
 
 	va_start(ap, fmt);
@@ -1332,10 +1331,10 @@ camel_nntp_raw_command(CamelNNTPStore *store, CamelException *ex, char **line, c
 }
 
 /* use this where you also need auth to be handled, i.e. most cases where you'd try raw command */
-int
-camel_nntp_raw_command_auth(CamelNNTPStore *store, CamelException *ex, char **line, const char *fmt, ...)
+gint
+camel_nntp_raw_command_auth(CamelNNTPStore *store, CamelException *ex, gchar **line, const gchar *fmt, ...)
 {
-	int ret, retry, go;
+	gint ret, retry, go;
 	va_list ap;
 
 	retry = 0;
@@ -1358,20 +1357,20 @@ camel_nntp_raw_command_auth(CamelNNTPStore *store, CamelException *ex, char **li
 	return ret;
 }
 
-int
-camel_nntp_command (CamelNNTPStore *store, CamelException *ex, CamelNNTPFolder *folder, char **line, const char *fmt, ...)
+gint
+camel_nntp_command (CamelNNTPStore *store, CamelException *ex, CamelNNTPFolder *folder, gchar **line, const gchar *fmt, ...)
 {
-	const unsigned char *p;
+	const guchar *p;
 	va_list ap;
-	int ret, retry;
-	unsigned int u;
-	
+	gint ret, retry;
+	guint u;
+
 	if (((CamelDiscoStore *)store)->status == CAMEL_DISCO_STORE_OFFLINE) {
 		camel_exception_setv(ex, CAMEL_EXCEPTION_SERVICE_NOT_CONNECTED,
 				     _("Not connected."));
 		return -1;
 	}
-	
+
 	retry = 0;
 	do {
 		retry ++;
@@ -1383,7 +1382,7 @@ camel_nntp_command (CamelNNTPStore *store, CamelException *ex, CamelNNTPFolder *
 		/* Check for unprocessed data, ! */
 		if (store->stream->mode == CAMEL_NNTP_STREAM_DATA) {
 			g_warning("Unprocessed data left in stream, flushing");
-			while (camel_nntp_stream_getd(store->stream, (unsigned char **)&p, &u) > 0)
+			while (camel_nntp_stream_getd(store->stream, (guchar **)&p, &u) > 0)
 				;
 		}
 		camel_nntp_stream_set_mode(store->stream, CAMEL_NNTP_STREAM_LINE);
