@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-pop3-store.c : class for a pop3 store */
 
-/* 
+/*
  * Authors:
  *   Dan Winship <danw@ximian.com>
  *   Michael Zucchi <notzed@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -50,6 +50,7 @@
 #include "camel-tcp-stream-raw.h"
 #include "camel-tcp-stream.h"
 #include "camel-url.h"
+#include "camel-utf8.h"
 
 #ifdef HAVE_SSL
 #include "camel-tcp-stream-ssl.h"
@@ -67,7 +68,7 @@ static gboolean pop3_connect (CamelService *service, CamelException *ex);
 static gboolean pop3_disconnect (CamelService *service, gboolean clean, CamelException *ex);
 static GList *query_auth_types (CamelService *service, CamelException *ex);
 
-static CamelFolder *get_folder (CamelStore *store, const char *folder_name, 
+static CamelFolder *get_folder (CamelStore *store, const gchar *folder_name,
 				guint32 flags, CamelException *ex);
 
 static CamelFolder *get_trash  (CamelStore *store, CamelException *ex);
@@ -83,7 +84,7 @@ camel_pop3_store_class_init (CamelPOP3StoreClass *camel_pop3_store_class)
 		CAMEL_STORE_CLASS (camel_pop3_store_class);
 
 	parent_class = CAMEL_STORE_CLASS (camel_type_get_global_classfuncs (camel_store_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_service_class->query_auth_types = query_auth_types;
 	camel_service_class->connect = pop3_connect;
@@ -149,16 +150,16 @@ enum {
 #endif
 
 static gboolean
-connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, CamelException *ex)
+connect_to_server (CamelService *service, struct addrinfo *ai, gint ssl_mode, CamelException *ex)
 {
 	CamelPOP3Store *store = CAMEL_POP3_STORE (service);
 	CamelStream *tcp_stream;
 	CamelPOP3Command *pc;
 	guint32 flags = 0;
-	int clean_quit = TRUE;
-	int ret;
+	gint clean_quit = TRUE;
+	gint ret;
 	const gchar *delete_days;
-	
+
 	if (ssl_mode != MODE_CLEAR) {
 #ifdef HAVE_SSL
 		if (ssl_mode == MODE_TLS) {
@@ -210,12 +211,12 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 		camel_object_unref (tcp_stream);
 		return FALSE;
 	}
-	
+
 	if (ssl_mode != MODE_TLS) {
 		camel_object_unref (tcp_stream);
 		return TRUE;
 	}
-	
+
 #ifdef HAVE_SSL
 	/* as soon as we send a STLS command, all hope is lost of a clean QUIT if problems arise */
 	clean_quit = FALSE;
@@ -273,19 +274,19 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 			;
 		camel_pop3_engine_command_free (store->engine, pc);
 	}
-	
+
 	camel_object_unref (CAMEL_OBJECT (store->engine));
 	camel_object_unref (CAMEL_OBJECT (tcp_stream));
 	store->engine = NULL;
-	
+
 	return FALSE;
 }
 
 static struct {
-	char *value;
-	char *serv;
-	char *port;
-	int mode;
+	const gchar *value;
+	const gchar *serv;
+	const gchar *port;
+	gint mode;
 } ssl_options[] = {
 	{ "",              "pop3s", POP3S_PORT, MODE_SSL   },  /* really old (1.x) */
 	{ "always",        "pop3s", POP3S_PORT, MODE_SSL   },
@@ -298,30 +299,30 @@ static gboolean
 connect_to_server_wrapper (CamelService *service, CamelException *ex)
 {
 	struct addrinfo hints, *ai;
-	const char *ssl_mode;
-	int mode, ret, i;
-	char *serv;
-	const char *port;
+	const gchar *ssl_mode;
+	gint mode, ret, i;
+	gchar *serv;
+	const gchar *port;
 
 	if ((ssl_mode = camel_url_get_param (service->url, "use_ssl"))) {
 		for (i = 0; ssl_options[i].value; i++)
 			if (!strcmp (ssl_options[i].value, ssl_mode))
 				break;
 		mode = ssl_options[i].mode;
-		serv = ssl_options[i].serv;
+		serv = (gchar *) ssl_options[i].serv;
 		port = ssl_options[i].port;
 	} else {
 		mode = MODE_CLEAR;
-		serv = "pop3";
+		serv = (gchar *) "pop3";
 		port = POP3S_PORT;
 	}
-	
+
 	if (service->url->port) {
 		serv = g_alloca (16);
 		sprintf (serv, "%d", service->url->port);
 		port = NULL;
 	}
-	
+
 	memset (&hints, 0, sizeof (hints));
 	hints.ai_socktype = SOCK_STREAM;
 	hints.ai_family = PF_UNSPEC;
@@ -330,14 +331,14 @@ connect_to_server_wrapper (CamelService *service, CamelException *ex)
 		camel_exception_clear (ex);
 		ai = camel_getaddrinfo(service->url->host, port, &hints, ex);
 	}
-	
+
 	if (ai == NULL)
 		return FALSE;
-	
+
 	ret = connect_to_server (service, ai, mode, ex);
-	
+
 	camel_freeaddrinfo (ai);
-	
+
 	return ret;
 }
 
@@ -388,14 +389,14 @@ camel_pop3_store_expunge (CamelPOP3Store *store, CamelException *ex)
 	camel_service_disconnect (CAMEL_SERVICE (store), FALSE, ex);
 }
 
-static int
-try_sasl(CamelPOP3Store *store, const char *mech, CamelException *ex)
+static gint
+try_sasl(CamelPOP3Store *store, const gchar *mech, CamelException *ex)
 {
 	CamelPOP3Stream *stream = store->engine->stream;
-	unsigned char *line, *resp;
+	guchar *line, *resp;
 	CamelSasl *sasl;
-	unsigned int len;
-	int ret;
+	guint len;
+	gint ret;
 
 	sasl = camel_sasl_new("pop", mech, (CamelService *)store);
 	if (sasl == NULL) {
@@ -412,9 +413,9 @@ try_sasl(CamelPOP3Store *store, const char *mech, CamelException *ex)
 	while (1) {
 		if (camel_pop3_stream_line(stream, &line, &len) == -1)
 			goto ioerror;
-		if (strncmp((char *) line, "+OK", 3) == 0)
+		if (strncmp((gchar *) line, "+OK", 3) == 0)
 			break;
-		if (strncmp((char *) line, "-ERR", 4) == 0) {
+		if (strncmp((gchar *) line, "-ERR", 4) == 0) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
 					      _("SASL '%s' Login failed for POP server %s: %s"),
 					      mech, CAMEL_SERVICE (store)->url->host, line);
@@ -422,9 +423,9 @@ try_sasl(CamelPOP3Store *store, const char *mech, CamelException *ex)
 		}
 		/* If we dont get continuation, or the sasl object's run out of work, or we dont get a challenge,
 		   its a protocol error, so fail, and try reset the server */
-		if (strncmp((char *) line, "+ ", 2) != 0
+		if (strncmp((gchar *) line, "+ ", 2) != 0
 		    || camel_sasl_authenticated(sasl)
-		    || (resp = (unsigned char *) camel_sasl_challenge_base64(sasl, (const char *) line+2, ex)) == NULL) {
+		    || (resp = (guchar *) camel_sasl_challenge_base64(sasl, (const gchar *) line+2, ex)) == NULL) {
 			camel_stream_printf((CamelStream *)stream, "*\r\n");
 			camel_pop3_stream_line(stream, &line, &len);
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
@@ -441,7 +442,7 @@ try_sasl(CamelPOP3Store *store, const char *mech, CamelException *ex)
 	}
 	camel_object_unref((CamelObject *)sasl);
 	return 0;
-	
+
  ioerror:
 	if (errno == EINTR) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
@@ -455,20 +456,20 @@ try_sasl(CamelPOP3Store *store, const char *mech, CamelException *ex)
 	return -1;
 }
 
-static int
-pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *errmsg, CamelException *ex)
+static gint
+pop3_try_authenticate (CamelService *service, gboolean reprompt, const gchar *errmsg, CamelException *ex)
 {
 	CamelPOP3Store *store = (CamelPOP3Store *)service;
 	CamelPOP3Command *pcu = NULL, *pcp = NULL;
-	int status;
+	gint status;
 
 	/* override, testing only */
 	/*printf("Forcing authmech to 'login'\n");
 	service->url->authmech = g_strdup("LOGIN");*/
 
 	if (!service->url->passwd) {
-		char *base_prompt;
-		char *full_prompt;
+		gchar *base_prompt;
+		gchar *full_prompt;
 		guint32 flags = CAMEL_SESSION_PASSWORD_SECRET;
 
 		if (reprompt)
@@ -489,7 +490,7 @@ pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *err
 		g_free (base_prompt);
 		g_free (full_prompt);
 		if (!service->url->passwd)
-			return 0;
+			return -1;
 	}
 
 	if (!service->url->authmech) {
@@ -497,12 +498,12 @@ pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *err
 		pcu = camel_pop3_engine_command_new(store->engine, 0, NULL, NULL, "USER %s\r\n", service->url->user);
 		pcp = camel_pop3_engine_command_new(store->engine, 0, NULL, NULL, "PASS %s\r\n", service->url->passwd);
 	} else if (strcmp(service->url->authmech, "+APOP") == 0 && store->engine->apop) {
-		char *secret, *md5asc, *d;
+		gchar *secret, *md5asc, *d;
 
 		d = store->engine->apop;
 
 		while (*d != '\0') {
-			if (!isascii((int)*d)) {
+			if (!isascii((gint)*d)) {
 
 				/* README for Translators: The string APOP should not be translated */
 				camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_URL_INVALID,
@@ -531,17 +532,17 @@ pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *err
 				return try_sasl (store, service->url->authmech, ex);
 			l = l->next;
 		}
-		
+
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_URL_INVALID,
 				      _("Unable to connect to POP server %s: "
 					"No support for requested authentication mechanism."),
 				      CAMEL_SERVICE (store)->url->host);
 		return 0;
 	}
-	
+
 	while ((status = camel_pop3_engine_iterate(store->engine, pcp)) > 0)
 		;
-	
+
 	if (status == -1) {
 		if (errno == EINTR) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
@@ -557,13 +558,14 @@ pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *err
 				      _("Unable to connect to POP server %s.\n"
 					"Error sending username: %s"),
 				      CAMEL_SERVICE (store)->url->host,
-				      store->engine->line ? (char *)store->engine->line : _("Unknown error"));
-	} else if (pcp->state != CAMEL_POP3_COMMAND_OK)
+				      store->engine->line ? (gchar *)store->engine->line : _("Unknown error"));
+	} else if (pcp->state != CAMEL_POP3_COMMAND_OK) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
 				      _("Unable to connect to POP server %s.\n"
 					"Error sending password: %s"),
 				      CAMEL_SERVICE (store)->url->host,
-				      store->engine->line ? (char *)store->engine->line : _("Unknown error"));
+				      store->engine->line ? (gchar *)store->engine->line : _("Unknown error"));
+	}
 
 	camel_pop3_engine_command_free (store->engine, pcp);
 
@@ -573,38 +575,19 @@ pop3_try_authenticate (CamelService *service, gboolean reprompt, const char *err
 	return status;
 }
 
-/* ensures the returned text will be valid UTF-8 text, thus gtk functions expecting
-   only valid UTF-8 texts will not crash. Returned pointer should be freed with g_free. */
-static gchar *
-ensure_utf8 (const char *text)
-{
-	gchar *res = g_strdup (text), *p;
-
-	if (!text)
-		return res;
-
-	p = res;
-	while (!g_utf8_validate (p, -1, (const gchar **) &p)) {
-		/* make all invalid characters appear as question marks */
-		*p = '?';
-	}
-
-	return res;
-}
-
 static gboolean
 pop3_connect (CamelService *service, CamelException *ex)
 {
 	CamelPOP3Store *store = (CamelPOP3Store *)service;
 	gboolean reprompt = FALSE;
 	CamelSession *session;
-	char *errbuf = NULL;
-	int status;
-	
+	gchar *errbuf = NULL;
+	gint status;
+
 	session = camel_service_get_session (service);
-	
+
 	if (store->cache == NULL) {
-		char *root;
+		gchar *root;
 
 		root = camel_session_get_storage_path (session, service, ex);
 		if (root) {
@@ -617,18 +600,18 @@ pop3_connect (CamelService *service, CamelException *ex)
 			}
 		}
 	}
-	
+
 	if (!connect_to_server_wrapper (service, ex))
 		return FALSE;
-	
+
 	while (1) {
 		status = pop3_try_authenticate (service, reprompt, errbuf, ex);
 		g_free (errbuf);
 		errbuf = NULL;
-		
+
 		/* we only re-prompt if we failed to authenticate, any other error and we just abort */
 		if (status == 0 && camel_exception_get_id (ex) == CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE) {
-			char *tmp = ensure_utf8 (camel_exception_get_description (ex));
+			gchar *tmp = camel_utf8_make_valid (camel_exception_get_description (ex));
 			errbuf = g_markup_printf_escaped ("%s\n\n", tmp);
 			g_free (tmp);
 			camel_exception_clear (ex);
@@ -642,18 +625,18 @@ pop3_connect (CamelService *service, CamelException *ex)
 		} else
 			break;
 	}
-	
+
 	g_free (errbuf);
-	
+
 	if (status == -1 || camel_exception_is_set(ex)) {
 		camel_service_disconnect(service, TRUE, ex);
 		return FALSE;
 	}
-	
+
 	/* Now that we are in the TRANSACTION state, try regetting the capabilities */
 	store->engine->state = CAMEL_POP3_ENGINE_TRANSACTION;
 	camel_pop3_engine_reget_capabilities (store->engine);
-	
+
 	return TRUE;
 }
 
@@ -661,27 +644,27 @@ static gboolean
 pop3_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelPOP3Store *store = CAMEL_POP3_STORE (service);
-	
+
 	if (clean) {
 		CamelPOP3Command *pc;
-		
+
 		pc = camel_pop3_engine_command_new(store->engine, 0, NULL, NULL, "QUIT\r\n");
 		while (camel_pop3_engine_iterate(store->engine, NULL) > 0)
 			;
 		camel_pop3_engine_command_free(store->engine, pc);
 	}
-	
+
 	if (!CAMEL_SERVICE_CLASS (parent_class)->disconnect (service, clean, ex))
 		return FALSE;
-	
+
 	camel_object_unref((CamelObject *)store->engine);
 	store->engine = NULL;
-	
+
 	return TRUE;
 }
 
 static CamelFolder *
-get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
+get_folder (CamelStore *store, const gchar *folder_name, guint32 flags, CamelException *ex)
 {
 	if (g_ascii_strcasecmp (folder_name, "inbox") != 0) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
