@@ -3,7 +3,7 @@
  * Author:
  *  Michael Zucchi <notzed@ximian.com>
  *
- * Copyright 2002 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -36,7 +36,7 @@
 
 #include "camel-pop3-stream.h"
 
-extern int camel_verbose_debug;
+extern gint camel_verbose_debug;
 #define dd(x) (camel_verbose_debug?(x):0)
 
 static CamelObjectClass *parent_class = NULL;
@@ -47,23 +47,23 @@ static CamelObjectClass *parent_class = NULL;
 #define CAMEL_POP3_STREAM_SIZE (4096)
 #define CAMEL_POP3_STREAM_LINE (1024) /* maximum line size */
 
-static int
+static gint
 stream_fill(CamelPOP3Stream *is)
 {
-	int left = 0;
+	gint left = 0;
 
 	if (is->source) {
 		left = is->end - is->ptr;
-		memcpy(is->buf, is->ptr, left);
+		memmove(is->buf, is->ptr, left);
 		is->end = is->buf + left;
 		is->ptr = is->buf;
-		left = camel_stream_read(is->source, (char *) is->end, CAMEL_POP3_STREAM_SIZE - (is->end - is->buf));
+		left = camel_stream_read(is->source, (gchar *) is->end, CAMEL_POP3_STREAM_SIZE - (is->end - is->buf));
 		if (left > 0) {
 			is->end += left;
 			is->end[0] = '\n';
 			return is->end - is->ptr;
 		} else {
-			dd(printf("POP3_STREAM_FILL(ERROR): '%s'\n", strerror (errno)));
+			dd(printf("POP3_STREAM_FILL(ERROR): '%s'\n", g_strerror (errno)));
 			return -1;
 		}
 	}
@@ -71,13 +71,13 @@ stream_fill(CamelPOP3Stream *is)
 	return 0;
 }
 
-static ssize_t
-stream_read(CamelStream *stream, char *buffer, size_t n)
+static gssize
+stream_read(CamelStream *stream, gchar *buffer, gsize n)
 {
 	CamelPOP3Stream *is = (CamelPOP3Stream *)stream;
-	char *o, *oe;
-	unsigned char *p, *e, c;
-	int state;
+	gchar *o, *oe;
+	guchar *p, *e, c;
+	gint state;
 
 	if (is->mode != CAMEL_POP3_STREAM_DATA || n == 0)
 		return 0;
@@ -105,7 +105,7 @@ stream_read(CamelStream *stream, char *buffer, size_t n)
 				is->ptr = p+3;
 				is->mode = CAMEL_POP3_STREAM_EOD;
 				is->state = 0;
-				dd(printf("POP3_STREAM_READ(%d):\n%.*s\n", (int)(o-buffer), (int)(o-buffer), buffer));
+				dd(printf("POP3_STREAM_READ(%d):\n%.*s\n", (gint)(o-buffer), (gint)(o-buffer), buffer));
 				return o-buffer;
 			}
 			p++;
@@ -138,32 +138,32 @@ stream_read(CamelStream *stream, char *buffer, size_t n)
 	is->ptr = p;
 	is->state = state;
 
-	dd(printf("POP3_STREAM_READ(%d):\n%.*s\n", (int)(o-buffer), (int)(o-buffer), buffer));
+	dd(printf("POP3_STREAM_READ(%d):\n%.*s\n", (gint)(o-buffer), (gint)(o-buffer), buffer));
 
 	return o-buffer;
 }
 
-static ssize_t
-stream_write(CamelStream *stream, const char *buffer, size_t n)
+static gssize
+stream_write(CamelStream *stream, const gchar *buffer, gsize n)
 {
 	CamelPOP3Stream *is = (CamelPOP3Stream *)stream;
 
 	if (strncmp (buffer, "PASS ", 5) != 0)
-		dd(printf("POP3_STREAM_WRITE(%d):\n%.*s\n", (int)n, (int)n, buffer));
+		dd(printf("POP3_STREAM_WRITE(%d):\n%.*s\n", (gint)n, (gint)n, buffer));
 	else
-		dd(printf("POP3_STREAM_WRITE(%d):\nPASS xxxxxxxx\n", (int)n));
+		dd(printf("POP3_STREAM_WRITE(%d):\nPASS xxxxxxxx\n", (gint)n));
 
 	return camel_stream_write(is->source, buffer, n);
 }
 
-static int
+static gint
 stream_close(CamelStream *stream)
 {
 	/* nop? */
 	return 0;
 }
 
-static int
+static gint
 stream_flush(CamelStream *stream)
 {
 	/* nop? */
@@ -178,7 +178,7 @@ stream_eos(CamelStream *stream)
 	return is->mode != CAMEL_POP3_STREAM_DATA;
 }
 
-static int
+static gint
 stream_reset(CamelStream *stream)
 {
 	/* nop?  reset literal mode? */
@@ -265,12 +265,12 @@ camel_pop3_stream_new(CamelStream *source)
 }
 
 /* Get one line from the pop3 stream */
-int
-camel_pop3_stream_line(CamelPOP3Stream *is, unsigned char **data, unsigned int *len)
+gint
+camel_pop3_stream_line(CamelPOP3Stream *is, guchar **data, guint *len)
 {
-	register unsigned char c, *p, *o, *oe;
-	int newlen, oldlen;
-	unsigned char *e;
+	register guchar c, *p, *o, *oe;
+	gint newlen, oldlen;
+	guchar *e;
 
 	if (is->mode == CAMEL_POP3_STREAM_EOD) {
 		*data = is->linebuf;
@@ -350,10 +350,10 @@ camel_pop3_stream_line(CamelPOP3Stream *is, unsigned char **data, unsigned int *
 }
 
 /* returns -1 on error, 0 if last lot of data, >0 if more remaining */
-int camel_pop3_stream_gets(CamelPOP3Stream *is, unsigned char **start, unsigned int *len)
+gint camel_pop3_stream_gets(CamelPOP3Stream *is, guchar **start, guint *len)
 {
-	int max;
-	unsigned char *end;
+	gint max;
+	guchar *end;
 
 	*len = 0;
 
@@ -372,7 +372,7 @@ int camel_pop3_stream_gets(CamelPOP3Stream *is, unsigned char **start, unsigned
 	*len = max;
 	is->ptr += max;
 
-	dd(printf("POP3_STREAM_GETS(%s,%d): '%.*s'\n", end==NULL?"more":"last", *len, (int)*len, *start));
+	dd(printf("POP3_STREAM_GETS(%s,%d): '%.*s'\n", end==NULL?"more":"last", *len, (gint)*len, *start));
 
 	return end == NULL?1:0;
 }
@@ -383,10 +383,10 @@ void camel_pop3_stream_set_mode(CamelPOP3Stream *is, camel_pop3_stream_mode_t mo
 }
 
 /* returns -1 on erorr, 0 if last data, >0 if more data left */
-int camel_pop3_stream_getd(CamelPOP3Stream *is, unsigned char **start, unsigned int *len)
+gint camel_pop3_stream_getd(CamelPOP3Stream *is, guchar **start, guint *len)
 {
-	unsigned char *p, *e, *s;
-	int state;
+	guchar *p, *e, *s;
+	gint state;
 
 	*len = 0;
 
@@ -424,7 +424,7 @@ int camel_pop3_stream_getd(CamelPOP3Stream *is, unsigned char **start, unsigned
 					is->mode = CAMEL_POP3_STREAM_EOD;
 					is->state = 0;
 
-					dd(printf("POP3_STREAM_GETD(%s,%d): '%.*s'\n", "last", *len, (int)*len, *start));
+					dd(printf("POP3_STREAM_GETD(%s,%d): '%.*s'\n", "last", *len, (gint)*len, *start));
 
 					return 0;
 				}
@@ -439,7 +439,7 @@ int camel_pop3_stream_getd(CamelPOP3Stream *is, unsigned char **start, unsigned
 					*start = s;
 					is->state = 1;
 
-					dd(printf("POP3_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (int)*len, *start));
+					dd(printf("POP3_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (gint)*len, *start));
 
 					return 1;
 				}
@@ -464,7 +464,7 @@ int camel_pop3_stream_getd(CamelPOP3Stream *is, unsigned char **start, unsigned
 	*len = p-s;
 	*start = s;
 
-	dd(printf("POP3_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (int)*len, *start));
+	dd(printf("POP3_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (gint)*len, *start));
 
 	return 1;
 }
