@@ -34,6 +34,9 @@
 #include "camel-smtp-transport.h"
 #include "camel-url.h"
 
+static guint smtp_url_hash (gconstpointer key);
+static gint smtp_url_equal (gconstpointer a, gconstpointer b);
+
 static CamelProvider smtp_provider = {
 	"smtp",
 	N_("SMTP"),
@@ -56,12 +59,56 @@ camel_provider_module_init(void)
 	smtp_provider.object_types[CAMEL_PROVIDER_TRANSPORT] = camel_smtp_transport_get_type ();
 	smtp_provider.authtypes = g_list_append (camel_sasl_authtype_list (TRUE), camel_sasl_authtype ("LOGIN"));
 	smtp_provider.authtypes = g_list_append (smtp_provider.authtypes, camel_sasl_authtype ("POPB4SMTP"));
-	smtp_provider.url_hash = camel_url_hash;
-	smtp_provider.url_equal = camel_url_equal;
+	smtp_provider.url_hash = smtp_url_hash;
+	smtp_provider.url_equal = smtp_url_equal;
 	smtp_provider.translation_domain = GETTEXT_PACKAGE;
-	
+
 	camel_provider_register(&smtp_provider);
 }
 
+static void
+add_hash (guint *hash, gchar *s)
+{
+	if (s)
+		*hash ^= g_str_hash(s);
+}
 
+static guint
+smtp_url_hash (gconstpointer key)
+{
+	const CamelURL *u = (CamelURL *)key;
+	guint hash = 0;
 
+	add_hash (&hash, u->user);
+	add_hash (&hash, u->host);
+	hash ^= u->port;
+
+	return hash;
+}
+
+static gint
+check_equal (gchar *s1, gchar *s2)
+{
+	if (s1 == NULL) {
+		if (s2 == NULL)
+			return TRUE;
+		else
+			return FALSE;
+	}
+
+	if (s2 == NULL)
+		return FALSE;
+
+	return strcmp (s1, s2) == 0;
+}
+
+static gint
+smtp_url_equal (gconstpointer a, gconstpointer b)
+{
+	const CamelURL *u1 = a, *u2 = b;
+
+	return check_equal (u1->protocol, u2->protocol)
+		&& check_equal (u1->user, u2->user)
+		&& check_equal (u1->host, u2->host)
+		&& u1->port == u2->port;
+}
