@@ -44,18 +44,18 @@
 
 typedef struct _CamelPgpSession {
 	CamelSession parent_object;
-	
+
 } CamelPgpSession;
 
 typedef struct _CamelPgpSessionClass {
 	CamelSessionClass parent_class;
-	
+
 } CamelPgpSessionClass;
 
 
-static char *get_password (CamelSession *session, const char *prompt,
+static gchar *get_password (CamelSession *session, const gchar *prompt,
 			   guint32 flags,
-			   CamelService *service, const char *item,
+			   CamelService *service, const gchar *item,
 			   CamelException *ex);
 
 static void
@@ -69,7 +69,7 @@ class_init (CamelPgpSessionClass *camel_pgp_session_class)
 {
 	CamelSessionClass *camel_session_class =
 		CAMEL_SESSION_CLASS (camel_pgp_session_class);
-	
+
 	/* virtual method override */
 	camel_session_class->get_password = get_password;
 }
@@ -78,7 +78,7 @@ static CamelType
 camel_pgp_session_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (
 			camel_test_session_get_type (),
@@ -90,31 +90,31 @@ camel_pgp_session_get_type (void)
 			(CamelObjectInitFunc) init,
 			NULL);
 	}
-	
+
 	return type;
 }
 
-static char *
-get_password (CamelSession *session, const char *prompt, guint32 flags,
-	      CamelService *service, const char *item, CamelException *ex)
+static gchar *
+get_password (CamelSession *session, const gchar *prompt, guint32 flags,
+	      CamelService *service, const gchar *item, CamelException *ex)
 {
 	return g_strdup ("no.secret");
 }
 
 static CamelSession *
-camel_pgp_session_new (const char *path)
+camel_pgp_session_new (const gchar *path)
 {
 	CamelSession *session;
-	
+
 	session = CAMEL_SESSION (camel_object_new (CAMEL_PGP_SESSION_TYPE));
-	
+
 	camel_session_construct (session, path);
-	
+
 	return session;
 }
 
 
-int main (int argc, char **argv)
+gint main (gint argc, gchar **argv)
 {
 	CamelSession *session;
 	CamelCipherContext *ctx;
@@ -125,19 +125,19 @@ int main (int argc, char **argv)
 	CamelDataWrapper *dw;
 	GPtrArray *recipients;
 	GByteArray *buf;
-	char *before, *after;
-	int ret;
+	gchar *before, *after;
+	gint ret;
 
 	if (getenv("CAMEL_TEST_GPG") == NULL)
 		return 77;
-	
+
 	camel_test_init (argc, argv);
-	
+
 	/* clear out any camel-test data */
 	system ("/bin/rm -rf /tmp/camel-test");
 	system ("/bin/mkdir /tmp/camel-test");
 	setenv ("GNUPGHOME", "/tmp/camel-test/.gnupg", 1);
-	
+
 	/* import the gpg keys */
 	if ((ret = system ("gpg < /dev/null > /dev/null 2>&1")) == -1)
 		return 77;
@@ -150,12 +150,12 @@ int main (int argc, char **argv)
 	system ("gpg --import " TEST_DATA_DIR "/camel-test.gpg.sec > /dev/null 2>&1");
 
 	session = camel_pgp_session_new ("/tmp/camel-test");
-	
+
 	ex = camel_exception_new ();
-	
+
 	ctx = camel_gpg_context_new (session);
 	camel_gpg_context_set_always_trust (CAMEL_GPG_CONTEXT (ctx), TRUE);
-	
+
 	camel_test_start ("Test of PGP functions");
 
 	stream1 = camel_stream_mem_new ();
@@ -179,19 +179,19 @@ int main (int argc, char **argv)
 		return 77;
 	}
 	camel_test_pull ();
-	
+
 	camel_exception_clear (ex);
-	
+
 	camel_test_push ("PGP verify");
 	valid = camel_cipher_verify (ctx, sigpart, ex);
 	check_msg (!camel_exception_is_set (ex), "%s", camel_exception_get_description (ex));
 	check_msg (camel_cipher_validity_get_valid (valid), "%s", camel_cipher_validity_get_description (valid));
 	camel_cipher_validity_free (valid);
 	camel_test_pull ();
-	
+
 	camel_object_unref(conpart);
 	camel_object_unref(sigpart);
-	
+
 	stream1 = camel_stream_mem_new ();
 	camel_stream_write (stream1, "Hello, I am a test of encryption/decryption.", 44);
 	camel_stream_reset (stream1);
@@ -205,9 +205,9 @@ int main (int argc, char **argv)
 	camel_object_unref(dw);
 
 	encpart = camel_mime_part_new();
-	
+
 	camel_exception_clear (ex);
-	
+
 	camel_test_push ("PGP encrypt");
 	recipients = g_ptr_array_new ();
 	g_ptr_array_add (recipients, "no.user@no.domain");
@@ -217,7 +217,7 @@ int main (int argc, char **argv)
 	camel_test_pull ();
 
 	camel_exception_clear (ex);
-	
+
 	camel_test_push ("PGP decrypt");
 	outpart = camel_mime_part_new();
 	valid = camel_cipher_decrypt (ctx, encpart, outpart, ex);
@@ -245,11 +245,11 @@ int main (int argc, char **argv)
 	camel_object_unref(outpart);
 
 	camel_test_pull ();
-	
+
 	camel_object_unref (CAMEL_OBJECT (ctx));
 	camel_object_unref (CAMEL_OBJECT (session));
-	
+
 	camel_test_end ();
-	
+
 	return 0;
 }
