@@ -36,7 +36,7 @@
   bool = (or bool*)
 	perform a boolean OR of boolean values.
 
-  int = (+ int*)
+  gint = (+ int*)
 	Add integers.
 
   string = (+ string*)
@@ -45,13 +45,13 @@
   time_t = (+ time_t*)
 	Add time_t values.
 
-  int = (- int int*)
+  gint = (- gint int*)
 	Subtract integers from the first.
 
   time_t = (- time_t*)
 	Subtract time_t values from the first.
 
-  int = (cast-int string|int|bool)
+  gint = (cast-int string|int|bool)
         Cast to an integer value.
 
   string = (cast-string string|int|bool)
@@ -59,9 +59,9 @@
 
   Comparison operators:
 
-  bool = (< int int)
-  bool = (> int int)
-  bool = (= int int)
+  bool = (< gint gint)
+  bool = (> gint gint)
+  bool = (= gint gint)
 
   bool = (< string string)
   bool = (> string string)
@@ -76,7 +76,7 @@
 
   type = (if bool function)
   type = (if bool function function)
-  	Choose a flow path based on a boolean value
+	Choose a flow path based on a boolean value
 
   type = (begin  func func func)
         Execute a sequence.  The last function return is the return type.
@@ -100,10 +100,12 @@
 #define d(x)			/* general debug */
 
 
-static struct _ESExpTerm * parse_list(ESExp *f, int gotbrace);
+static struct _ESExpTerm * parse_list(ESExp *f, gint gotbrace);
 static struct _ESExpTerm * parse_value(ESExp *f);
 
-static void parse_dump_term(struct _ESExpTerm *t, int depth);
+#ifdef TESTER
+static void parse_dump_term(struct _ESExpTerm *t, gint depth);
+#endif
 
 #ifdef E_SEXP_IS_G_OBJECT
 static GObjectClass *parent_class;
@@ -111,44 +113,44 @@ static GObjectClass *parent_class;
 
 static const GScannerConfig scanner_config =
 {
-	( " \t\r\n")		/* cset_skip_characters */,
-	( G_CSET_a_2_z
+	( (gchar *) " \t\r\n")		/* cset_skip_characters */,
+	( (gchar *) G_CSET_a_2_z
 	  "_+-<=>?"
-	  G_CSET_A_2_Z)		/* cset_identifier_first */,
-	( G_CSET_a_2_z
+	  G_CSET_A_2_Z)			/* cset_identifier_first */,
+	( (gchar *) G_CSET_a_2_z
 	  "_0123456789-<>?"
 	  G_CSET_A_2_Z
 	  G_CSET_LATINS
-	  G_CSET_LATINC	)	/* cset_identifier_nth */,
-	( ";\n" )		/* cpair_comment_single */,
+	  G_CSET_LATINC	)		/* cset_identifier_nth */,
+	( (gchar *) ";\n" )		/* cpair_comment_single */,
 
-	FALSE			/* case_sensitive */,
+	FALSE				/* case_sensitive */,
 
-	TRUE			/* skip_comment_multi */,
-	TRUE			/* skip_comment_single */,
-	TRUE			/* scan_comment_multi */,
-	TRUE			/* scan_identifier */,
-	TRUE			/* scan_identifier_1char */,
-	FALSE			/* scan_identifier_NULL */,
-	TRUE			/* scan_symbols */,
-	FALSE			/* scan_binary */,
-	TRUE			/* scan_octal */,
-	TRUE			/* scan_float */,
-	TRUE			/* scan_hex */,
-	FALSE			/* scan_hex_dollar */,
-	TRUE			/* scan_string_sq */,
-	TRUE			/* scan_string_dq */,
-	TRUE			/* numbers_2_int */,
-	FALSE			/* int_2_float */,
-	FALSE			/* identifier_2_string */,
-	TRUE			/* char_2_token */,
-	FALSE			/* symbol_2_token */,
-	FALSE			/* scope_0_fallback */,
+	TRUE				/* skip_comment_multi */,
+	TRUE				/* skip_comment_single */,
+	TRUE				/* scan_comment_multi */,
+	TRUE				/* scan_identifier */,
+	TRUE				/* scan_identifier_1char */,
+	FALSE				/* scan_identifier_NULL */,
+	TRUE				/* scan_symbols */,
+	FALSE				/* scan_binary */,
+	TRUE				/* scan_octal */,
+	TRUE				/* scan_float */,
+	TRUE				/* scan_hex */,
+	FALSE				/* scan_hex_dollar */,
+	TRUE				/* scan_string_sq */,
+	TRUE				/* scan_string_dq */,
+	TRUE				/* numbers_2_int */,
+	FALSE				/* int_2_float */,
+	FALSE				/* identifier_2_string */,
+	TRUE				/* char_2_token */,
+	FALSE				/* symbol_2_token */,
+	FALSE				/* scope_0_fallback */,
 };
 
 /* jumps back to the caller of f->failenv, only to be called from inside a callback */
 void
-e_sexp_fatal_error(struct _ESExp *f, char *why, ...)
+e_sexp_fatal_error(struct _ESExp *f, const gchar *why, ...)
 {
 	va_list args;
 
@@ -162,14 +164,14 @@ e_sexp_fatal_error(struct _ESExp *f, char *why, ...)
 	longjmp(f->failenv, 1);
 }
 
-const char *
+const gchar *
 e_sexp_error(struct _ESExp *f)
 {
 	return f->error;
 }
 
 struct _ESExpResult *
-e_sexp_result_new(struct _ESExp *f, int type)
+e_sexp_result_new(struct _ESExp *f, gint type)
 {
 	struct _ESExpResult *r = e_memchunk_alloc0(f->result_chunks);
 	r->type = type;
@@ -203,9 +205,9 @@ e_sexp_result_free(struct _ESExp *f, struct _ESExpResult *t)
 
 /* used in normal functions if they have to abort, and free their arguments */
 void
-e_sexp_resultv_free(struct _ESExp *f, int argc, struct _ESExpResult **argv)
+e_sexp_resultv_free(struct _ESExp *f, gint argc, struct _ESExpResult **argv)
 {
-	int i;
+	gint i;
 
 	for (i=0;i<argc;i++) {
 		e_sexp_result_free(f, argv[i]);
@@ -214,46 +216,45 @@ e_sexp_resultv_free(struct _ESExp *f, int argc, struct _ESExpResult **argv)
 
 /* implementations for the builtin functions */
 
-/* can you tell, i dont like glib? */
 /* we can only itereate a hashtable from a called function */
-struct _glib_sux_donkeys {
-	int count;
+struct IterData {
+	gint count;
 	GPtrArray *uids;
 };
 
 /* ok, store any values that are in all sets */
 static void
-g_lib_sux_htand(char *key, int value, struct _glib_sux_donkeys *fuckup)
+htand(gchar *key, gint value, struct IterData *iter_data)
 {
-	if (value == fuckup->count) {
-		g_ptr_array_add(fuckup->uids, key);
+	if (value == iter_data->count) {
+		g_ptr_array_add(iter_data->uids, key);
 	}
 }
 
 /* or, store all unique values */
 static void
-g_lib_sux_htor(char *key, int value, struct _glib_sux_donkeys *fuckup)
+htor(gchar *key, gint value, struct IterData *iter_data)
 {
-	g_ptr_array_add(fuckup->uids, key);
+	g_ptr_array_add(iter_data->uids, key);
 }
 
 static ESExpResult *
-term_eval_and(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
+term_eval_and(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
 {
 	struct _ESExpResult *r, *r1;
 	GHashTable *ht = g_hash_table_new(g_str_hash, g_str_equal);
-	struct _glib_sux_donkeys lambdafoo;
-	int type=-1;
-	int bool = TRUE;
-	int i;
-	char *oper;
+	struct IterData lambdafoo;
+	gint type=-1;
+	gint bool = TRUE;
+	gint i;
+	const gchar *oper;
 
 	r(printf("( and\n"));
 
 	r = e_sexp_result_new(f, ESEXP_RES_UNDEFINED);
 
 	oper = "AND";
-	f->operators = g_slist_prepend (f->operators, oper);
+	f->operators = g_slist_prepend (f->operators, (gpointer) oper);
 
 	for (i=0;bool && i<argc;i++) {
 		r1 = e_sexp_term_eval(f, argv[i]);
@@ -265,14 +266,14 @@ term_eval_and(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 			g_hash_table_destroy(ht);
 			e_sexp_fatal_error(f, "Invalid types in AND");
 		} else if (r1->type == ESEXP_RES_ARRAY_PTR) {
-			char **a1;
-			int l1, j;
+			gchar **a1;
+			gint l1, j;
 
-			a1 = (char **)r1->value.ptrarray->pdata;
+			a1 = (gchar **)r1->value.ptrarray->pdata;
 			l1 = r1->value.ptrarray->len;
 			for (j=0;j<l1;j++) {
-			        gpointer ptr;
-				int n;
+				gpointer ptr;
+				gint n;
 				ptr = g_hash_table_lookup(ht, a1[j]);
 				n = GPOINTER_TO_INT(ptr);
 				g_hash_table_insert(ht, a1[j], GINT_TO_POINTER(n+1));
@@ -286,7 +287,7 @@ term_eval_and(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 	if (type == ESEXP_RES_ARRAY_PTR) {
 		lambdafoo.count = argc;
 		lambdafoo.uids = g_ptr_array_new();
-		g_hash_table_foreach(ht, (GHFunc)g_lib_sux_htand, &lambdafoo);
+		g_hash_table_foreach(ht, (GHFunc)htand, &lambdafoo);
 		r->type = ESEXP_RES_ARRAY_PTR;
 		r->value.ptrarray = lambdafoo.uids;
 	} else if (type == ESEXP_RES_BOOL) {
@@ -301,20 +302,20 @@ term_eval_and(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 }
 
 static ESExpResult *
-term_eval_or(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
+term_eval_or(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
 {
 	struct _ESExpResult *r, *r1;
 	GHashTable *ht = g_hash_table_new(g_str_hash, g_str_equal);
-	struct _glib_sux_donkeys lambdafoo;
-	int type = -1;
-	int bool = FALSE;
-	int i;
-	char *oper;
+	struct IterData lambdafoo;
+	gint type = -1;
+	gint bool = FALSE;
+	gint i;
+	const gchar *oper;
 
 	r(printf("(or \n"));
 
 	oper = "OR";
-	f->operators = g_slist_prepend (f->operators, oper);
+	f->operators = g_slist_prepend (f->operators, (gpointer) oper);
 
 	r = e_sexp_result_new(f, ESEXP_RES_UNDEFINED);
 
@@ -328,13 +329,13 @@ term_eval_or(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 			g_hash_table_destroy(ht);
 			e_sexp_fatal_error(f, "Invalid types in OR");
 		} else if (r1->type == ESEXP_RES_ARRAY_PTR) {
-			char **a1;
-			int l1, j;
+			gchar **a1;
+			gint l1, j;
 
-			a1 = (char **)r1->value.ptrarray->pdata;
+			a1 = (gchar **)r1->value.ptrarray->pdata;
 			l1 = r1->value.ptrarray->len;
 			for (j=0;j<l1;j++) {
-				g_hash_table_insert(ht, a1[j], (void *)1);
+				g_hash_table_insert(ht, a1[j], (gpointer)1);
 			}
 		} else if (r1->type == ESEXP_RES_BOOL) {
 			bool |= r1->value.bool;
@@ -345,7 +346,7 @@ term_eval_or(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 	if (type == ESEXP_RES_ARRAY_PTR) {
 		lambdafoo.count = argc;
 		lambdafoo.uids = g_ptr_array_new();
-		g_hash_table_foreach(ht, (GHFunc)g_lib_sux_htor, &lambdafoo);
+		g_hash_table_foreach(ht, (GHFunc)htor, &lambdafoo);
 		r->type = ESEXP_RES_ARRAY_PTR;
 		r->value.ptrarray = lambdafoo.uids;
 	} else if (type == ESEXP_RES_BOOL) {
@@ -359,9 +360,9 @@ term_eval_or(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 }
 
 static ESExpResult *
-term_eval_not(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+term_eval_not(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
-	int res = TRUE;
+	gint res = TRUE;
 	ESExpResult *r;
 
 	if (argc>0) {
@@ -376,7 +377,7 @@ term_eval_not(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data
 
 /* this should support all arguments ...? */
 static ESExpResult *
-term_eval_lt(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
+term_eval_lt(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
 {
 	struct _ESExpResult *r, *r1, *r2;
 
@@ -408,7 +409,7 @@ term_eval_lt(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 
 /* this should support all arguments ...? */
 static ESExpResult *
-term_eval_gt(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
+term_eval_gt(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
 {
 	struct _ESExpResult *r, *r1, *r2;
 
@@ -440,7 +441,7 @@ term_eval_gt(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 
 /* this should support all arguments ...? */
 static ESExpResult *
-term_eval_eq(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
+term_eval_eq(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
 {
 	struct _ESExpResult *r, *r1, *r2;
 
@@ -467,17 +468,17 @@ term_eval_eq(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 }
 
 static ESExpResult *
-term_eval_plus(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+term_eval_plus(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	struct _ESExpResult *r=NULL;
-	int type;
-	int i;
+	gint type;
+	gint i;
 
 	if (argc>0) {
 		type = argv[0]->type;
 		switch(type) {
 		case ESEXP_RES_INT: {
-			int total = argv[0]->value.number;
+			gint total = argv[0]->value.number;
 			for (i=1;i<argc && argv[i]->type == ESEXP_RES_INT;i++) {
 				total += argv[i]->value.number;
 			}
@@ -528,17 +529,17 @@ term_eval_plus(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *dat
 }
 
 static ESExpResult *
-term_eval_sub(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+term_eval_sub(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	struct _ESExpResult *r=NULL;
-	int type;
-	int i;
+	gint type;
+	gint i;
 
 	if (argc>0) {
 		type = argv[0]->type;
 		switch(type) {
 		case ESEXP_RES_INT: {
-			int total = argv[0]->value.number;
+			gint total = argv[0]->value.number;
 			for (i=1;i<argc && argv[i]->type == ESEXP_RES_INT;i++) {
 				total -= argv[i]->value.number;
 			}
@@ -575,14 +576,14 @@ term_eval_sub(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data
 	return r;
 }
 
-/* cast to int */
+/* cast to gint */
 static ESExpResult *
-term_eval_castint(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+term_eval_castint(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	struct _ESExpResult *r;
 
 	if (argc != 1)
-		e_sexp_fatal_error(f, "Incorrect argument count to (int )");
+		e_sexp_fatal_error(f, "Incorrect argument count to (gint )");
 
 	r = e_sexp_result_new(f, ESEXP_RES_INT);
 	switch (argv[0]->type) {
@@ -605,7 +606,7 @@ term_eval_castint(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *
 
 /* cast to string */
 static ESExpResult *
-term_eval_caststring(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+term_eval_caststring(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	struct _ESExpResult *r;
 
@@ -625,7 +626,7 @@ term_eval_caststring(struct _ESExp *f, int argc, struct _ESExpResult **argv, voi
 		break;
 	default:
 		e_sexp_result_free(f, r);
-		e_sexp_fatal_error(f, "Invalid type in (int )");
+		e_sexp_fatal_error(f, "Invalid type in (gint )");
 	}
 
 	return r;
@@ -633,10 +634,10 @@ term_eval_caststring(struct _ESExp *f, int argc, struct _ESExpResult **argv, voi
 
 /* implements 'if' function */
 static ESExpResult *
-term_eval_if(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
+term_eval_if(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
 {
 	struct _ESExpResult *r;
-	int doit;
+	gint doit;
 
 	if (argc >=2 && argc<=3) {
 		r = e_sexp_term_eval(f, argv[0]);
@@ -653,10 +654,10 @@ term_eval_if(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
 
 /* implements 'begin' statement */
 static ESExpResult *
-term_eval_begin(struct _ESExp *f, int argc, struct _ESExpTerm **argv, void *data)
+term_eval_begin(struct _ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
 {
 	struct _ESExpResult *r=NULL;
-	int i;
+	gint i;
 
 	for (i=0;i<argc;i++) {
 		if (r)
@@ -675,7 +676,7 @@ struct _ESExpResult *
 e_sexp_term_eval(struct _ESExp *f, struct _ESExpTerm *t)
 {
 	struct _ESExpResult *r = NULL;
-	int i;
+	gint i;
 	struct _ESExpResult **argv;
 
 	g_return_val_if_fail(t != NULL, NULL);
@@ -691,12 +692,12 @@ e_sexp_term_eval(struct _ESExp *f, struct _ESExpTerm *t)
 		r->value.string = g_strdup(t->value.string);
 		break;
 	case ESEXP_TERM_INT:
-		r(printf(" (int %d)\n", t->value.number));
+		r(printf(" (gint %d)\n", t->value.number));
 		r = e_sexp_result_new(f, ESEXP_RES_INT);
 		r->value.number = t->value.number;
 		break;
 	case ESEXP_TERM_BOOL:
-		r(printf(" (int %d)\n", t->value.number));
+		r(printf(" (gint %d)\n", t->value.number));
 		r = e_sexp_result_new(f, ESEXP_RES_BOOL);
 		r->value.bool = t->value.bool;
 		break;
@@ -733,9 +734,9 @@ e_sexp_term_eval(struct _ESExp *f, struct _ESExpTerm *t)
 
 #ifdef TESTER
 static void
-eval_dump_result(ESExpResult *r, int depth)
+eval_dump_result(ESExpResult *r, gint depth)
 {
-	int i;
+	gint i;
 
 	if (r==NULL) {
 		printf("null result???\n");
@@ -759,7 +760,7 @@ eval_dump_result(ESExpResult *r, int depth)
 		printf("bool: %c\n", r->value.bool?'t':'f');
 		break;
 	case ESEXP_RES_TIME:
-		printf("time_t: %ld\n", (long) r->value.time);
+		printf("time_t: %ld\n", (glong) r->value.time);
 		break;
 	case ESEXP_RES_UNDEFINED:
 		printf(" <undefined>\n");
@@ -769,10 +770,11 @@ eval_dump_result(ESExpResult *r, int depth)
 }
 #endif
 
+#ifdef TESTER
 static void
-parse_dump_term(struct _ESExpTerm *t, int depth)
+parse_dump_term(struct _ESExpTerm *t, gint depth)
 {
-	int i;
+	gint i;
 
 	if (t==NULL) {
 		printf("null term??\n");
@@ -793,7 +795,7 @@ parse_dump_term(struct _ESExpTerm *t, int depth)
 		printf(" #%c", t->value.bool?'t':'f');
 		break;
 	case ESEXP_TERM_TIME:
-		printf(" %ld", (long) t->value.time);
+		printf(" %ld", (glong) t->value.time);
 		break;
 	case ESEXP_TERM_IFUNC:
 	case ESEXP_TERM_FUNC:
@@ -815,13 +817,14 @@ parse_dump_term(struct _ESExpTerm *t, int depth)
 
 	printf("\n");
 }
+#endif
 
 /*
   PARSER
 */
 
 static struct _ESExpTerm *
-parse_term_new(struct _ESExp *f, int type)
+parse_term_new(struct _ESExp *f, gint type)
 {
 	struct _ESExpTerm *s = e_memchunk_alloc0(f->term_chunks);
 	s->type = type;
@@ -831,7 +834,7 @@ parse_term_new(struct _ESExp *f, int type)
 static void
 parse_term_free(struct _ESExp *f, struct _ESExpTerm *t)
 {
-	int i;
+	gint i;
 
 	if (t==NULL) {
 		return;
@@ -863,11 +866,11 @@ parse_term_free(struct _ESExp *f, struct _ESExpTerm *t)
 }
 
 static struct _ESExpTerm **
-parse_values(ESExp *f, int *len)
+parse_values(ESExp *f, gint *len)
 {
-	int token;
+	gint token;
 	struct _ESExpTerm **terms;
-	int i, size = 0;
+	gint i, size = 0;
 	GScanner *gs = f->scanner;
 	GSList *list = NULL, *l;
 
@@ -897,7 +900,7 @@ parse_values(ESExp *f, int *len)
 	return terms;
 }
 
-ESExpTerm * e_sexp_parse_value (ESExp *f) 
+ESExpTerm * e_sexp_parse_value (ESExp *f)
 {
 	return parse_value (f);
 }
@@ -906,7 +909,7 @@ ESExpTerm * e_sexp_parse_value (ESExp *f)
 static struct _ESExpTerm *
 parse_value(ESExp *f)
 {
-	int token, negative = FALSE;
+	gint token, negative = FALSE;
 	struct _ESExpTerm *t = NULL;
 	GScanner *gs = f->scanner;
 	struct _ESExpSymbol *s;
@@ -940,10 +943,10 @@ parse_value(ESExp *f)
 		t->value.number = g_scanner_cur_value(gs).v_int;
 		if (negative)
 			t->value.number = -t->value.number;
-		p(printf("got int %d\n", t->value.number));
+		p(printf("got gint %d\n", t->value.number));
 		break;
 	case '#': {
-		char *str;
+		gchar *str;
 
 		p(printf("got bool?\n"));
 		token = g_scanner_get_next_token(gs);
@@ -996,9 +999,9 @@ parse_value(ESExp *f)
 
 /* FIXME: this needs some robustification */
 static struct _ESExpTerm *
-parse_list(ESExp *f, int gotbrace)
+parse_list(ESExp *f, gint gotbrace)
 {
-	int token;
+	gint token;
 	struct _ESExpTerm *t = NULL;
 	GScanner *gs = f->scanner;
 
@@ -1050,7 +1053,7 @@ parse_list(ESExp *f, int gotbrace)
 	return t;
 }
 
-static void e_sexp_finalise(void *);
+static void e_sexp_finalise(gpointer);
 
 #ifdef E_SEXP_IS_G_OBJECT
 static void
@@ -1066,9 +1069,9 @@ e_sexp_class_init (ESExpClass *klass)
 
 /* 'builtin' functions */
 static const struct {
-	char *name;
+	const gchar *name;
 	ESExpFunc *func;
-	int type;		/* set to 1 if a function can perform shortcut evaluation, or
+	gint type;		/* set to 1 if a function can perform shortcut evaluation, or
 				   doesn't execute everything, 0 otherwise */
 } symbols[] = {
 	{ "and", (ESExpFunc *)term_eval_and, 1 },
@@ -1086,7 +1089,7 @@ static const struct {
 };
 
 static void
-free_symbol(void *key, void *value, void *data)
+free_symbol(gpointer key, gpointer value, gpointer data)
 {
 	struct _ESExpSymbol *s = value;
 
@@ -1095,7 +1098,7 @@ free_symbol(void *key, void *value, void *data)
 }
 
 static void
-e_sexp_finalise(void *o)
+e_sexp_finalise(gpointer o)
 {
 	ESExp *s = (ESExp *)o;
 
@@ -1118,7 +1121,7 @@ e_sexp_finalise(void *o)
 static void
 e_sexp_init (ESExp *s)
 {
-	int i;
+	gint i;
 
 	s->scanner = g_scanner_new(&scanner_config);
 	s->term_chunks = e_memchunk_new(16, sizeof(struct _ESExpTerm));
@@ -1127,9 +1130,9 @@ e_sexp_init (ESExp *s)
 	/* load in builtin symbols? */
 	for(i=0;i<sizeof(symbols)/sizeof(symbols[0]);i++) {
 		if (symbols[i].type == 1) {
-			e_sexp_add_ifunction(s, 0, symbols[i].name, (ESExpIFunc *)symbols[i].func, (void *)&symbols[i]);
+			e_sexp_add_ifunction(s, 0, symbols[i].name, (ESExpIFunc *)symbols[i].func, (gpointer)&symbols[i]);
 		} else {
-			e_sexp_add_function(s, 0, symbols[i].name, symbols[i].func, (void *)&symbols[i]);
+			e_sexp_add_function(s, 0, symbols[i].name, symbols[i].func, (gpointer)&symbols[i]);
 		}
 	}
 
@@ -1196,7 +1199,7 @@ e_sexp_unref (ESExp *f)
 #endif
 
 void
-e_sexp_add_function(ESExp *f, int scope, char *name, ESExpFunc *func, void *data)
+e_sexp_add_function(ESExp *f, gint scope, const gchar *name, ESExpFunc *func, gpointer data)
 {
 	struct _ESExpSymbol *s;
 
@@ -1214,7 +1217,7 @@ e_sexp_add_function(ESExp *f, int scope, char *name, ESExpFunc *func, void *data
 }
 
 void
-e_sexp_add_ifunction(ESExp *f, int scope, char *name, ESExpIFunc *ifunc, void *data)
+e_sexp_add_ifunction(ESExp *f, gint scope, const gchar *name, ESExpIFunc *ifunc, gpointer data)
 {
 	struct _ESExpSymbol *s;
 
@@ -1232,7 +1235,7 @@ e_sexp_add_ifunction(ESExp *f, int scope, char *name, ESExpIFunc *ifunc, void *d
 }
 
 void
-e_sexp_add_variable(ESExp *f, int scope, char *name, ESExpTerm *value)
+e_sexp_add_variable(ESExp *f, gint scope, gchar *name, ESExpTerm *value)
 {
 	struct _ESExpSymbol *s;
 
@@ -1247,9 +1250,9 @@ e_sexp_add_variable(ESExp *f, int scope, char *name, ESExpTerm *value)
 }
 
 void
-e_sexp_remove_symbol(ESExp *f, int scope, char *name)
+e_sexp_remove_symbol(ESExp *f, gint scope, const gchar *name)
 {
-	int oldscope;
+	gint oldscope;
 	struct _ESExpSymbol *s;
 
 	g_return_if_fail (IS_E_SEXP (f));
@@ -1265,8 +1268,8 @@ e_sexp_remove_symbol(ESExp *f, int scope, char *name)
 	}
 }
 
-int
-e_sexp_set_scope(ESExp *f, int scope)
+gint
+e_sexp_set_scope(ESExp *f, gint scope)
 {
 	g_return_val_if_fail (IS_E_SEXP (f), 0);
 
@@ -1274,7 +1277,7 @@ e_sexp_set_scope(ESExp *f, int scope)
 }
 
 void
-e_sexp_input_text(ESExp *f, const char *text, int len)
+e_sexp_input_text(ESExp *f, const gchar *text, gint len)
 {
 	g_return_if_fail (IS_E_SEXP (f));
 	g_return_if_fail (text != NULL);
@@ -1283,7 +1286,7 @@ e_sexp_input_text(ESExp *f, const char *text, int len)
 }
 
 void
-e_sexp_input_file (ESExp *f, int fd)
+e_sexp_input_file (ESExp *f, gint fd)
 {
 	g_return_if_fail (IS_E_SEXP (f));
 
@@ -1291,7 +1294,7 @@ e_sexp_input_file (ESExp *f, int fd)
 }
 
 /* returns -1 on error */
-int
+gint
 e_sexp_parse(ESExp *f)
 {
 	g_return_val_if_fail (IS_E_SEXP (f), -1);
@@ -1351,10 +1354,10 @@ e_sexp_encode_bool(GString *s, gboolean state)
  * are escaped appropriately.
  **/
 void
-e_sexp_encode_string(GString *s, const char *string)
+e_sexp_encode_string(GString *s, const gchar *string)
 {
-	char c;
-	const char *p;
+	gchar c;
+	const gchar *p;
 
 	if (string == NULL)
 		p = "";
@@ -1370,10 +1373,10 @@ e_sexp_encode_string(GString *s, const char *string)
 }
 
 #ifdef TESTER
-int main(int argc, char **argv)
+gint main(gint argc, gchar **argv)
 {
 	ESExp *f;
-	char *t = "(+ \"foo\" \"\\\"\" \"bar\" \"\\\\ blah \\x \")";
+	gchar *t = "(+ \"foo\" \"\\\"\" \"bar\" \"\\\\ blah \\x \")";
 	ESExpResult *r;
 
 	g_type_init();
