@@ -29,14 +29,14 @@
 
 struct _ESourceListPrivate {
 	GConfClient *gconf_client;
-	char *gconf_path;
+	gchar *gconf_path;
 
-	int gconf_notify_id;
+	gint gconf_notify_id;
 
 	GSList *groups;
 
 	gboolean ignore_group_changed;
-	int sync_idle_id;
+	gint sync_idle_id;
 };
 
 
@@ -48,7 +48,7 @@ enum {
 	GROUP_ADDED,
 	LAST_SIGNAL
 };
-static unsigned int signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 
 
 /* Forward declarations.  */
@@ -57,7 +57,7 @@ static gboolean  sync_idle_callback      (ESourceList  *list);
 static void      group_changed_callback  (ESourceGroup *group,
 					  ESourceList  *list);
 static void      conf_changed_callback   (GConfClient  *client,
-					  unsigned int  connection_id,
+					  guint  connection_id,
 					  GConfEntry   *entry,
 					  ESourceList  *list);
 
@@ -71,7 +71,7 @@ load_from_gconf (ESourceList *list)
 	GSList *new_groups_list;
 	GHashTable *new_groups_hash;
 	gboolean changed = FALSE;
-	int pos;
+	gint pos;
 
 	conf_list = gconf_client_get_list (list->priv->gconf_client,
 					   list->priv->gconf_path,
@@ -83,7 +83,7 @@ load_from_gconf (ESourceList *list)
 	for (p = conf_list, pos = 0; p != NULL; p = p->next, pos++) {
 		const xmlChar *xml = p->data;
 		xmlDocPtr xmldoc;
-		char *group_uid;
+		gchar *group_uid;
 		ESourceGroup *existing_group;
 
 		xmldoc = xmlParseDoc (xml);
@@ -218,7 +218,7 @@ group_changed_callback (ESourceGroup *group,
 
 static void
 conf_changed_callback (GConfClient *client,
-		       unsigned int connection_id,
+		       guint connection_id,
 		       GConfEntry *entry,
 		       ESourceList *list)
 {
@@ -228,7 +228,7 @@ conf_changed_callback (GConfClient *client,
 
 /* GObject methods.  */
 
-G_DEFINE_TYPE (ESourceList, e_source_list, G_TYPE_OBJECT);
+G_DEFINE_TYPE (ESourceList, e_source_list, G_TYPE_OBJECT)
 
 static void
 impl_dispose (GObject *object)
@@ -366,7 +366,7 @@ e_source_list_new (void)
 
 ESourceList *
 e_source_list_new_for_gconf (GConfClient *client,
-			     const char *path)
+			     const gchar *path)
 {
 	ESourceList *list;
 
@@ -391,7 +391,7 @@ e_source_list_new_for_gconf (GConfClient *client,
 }
 
 ESourceList *
-e_source_list_new_for_gconf_default (const char  *path)
+e_source_list_new_for_gconf_default (const gchar  *path)
 {
 	ESourceList *list;
 
@@ -423,7 +423,7 @@ e_source_list_peek_groups (ESourceList *list)
 
 ESourceGroup *
 e_source_list_peek_group_by_uid (ESourceList *list,
-				 const char *uid)
+				 const gchar *uid)
 {
 	GSList *p;
 
@@ -440,9 +440,14 @@ e_source_list_peek_group_by_uid (ESourceList *list,
 	return NULL;
 }
 
+#ifndef EDS_DISABLE_DEPRECATED
+/**
+ * Note: This function isn't safe with respect of localized names,
+ * use e_source_list_peek_group_by_base_uri instead.
+ **/
 ESourceGroup *
 e_source_list_peek_group_by_name (ESourceList *list,
-				  const char *name)
+				  const gchar *name)
 {
 	GSList *p;
 
@@ -458,10 +463,107 @@ e_source_list_peek_group_by_name (ESourceList *list,
 
 	return NULL;
 }
+#endif
+
+/**
+ * e_source_list_peek_group_by_base_uri:
+ * Returns the first group which base uri begins with a base_uri.
+ **/
+ESourceGroup *
+e_source_list_peek_group_by_base_uri (ESourceList *list, const gchar *base_uri)
+{
+	GSList *p;
+	gint len;
+
+	g_return_val_if_fail (E_IS_SOURCE_LIST (list), NULL);
+	g_return_val_if_fail (base_uri != NULL, NULL);
+
+	len = strlen (base_uri);
+
+	for (p = list->priv->groups; p != NULL; p = p->next) {
+		ESourceGroup *group = E_SOURCE_GROUP (p->data);
+		const gchar *buri = e_source_group_peek_base_uri (group);
+
+		if (buri && g_ascii_strncasecmp (buri, base_uri, len) == 0)
+			return group;
+	}
+
+	return NULL;
+}
+
+struct property_check_struct {
+	ESourceGroup *group;
+	gboolean same;
+};
+
+static void
+check_group_property (const gchar *property_name, const gchar *property_value, struct property_check_struct *pcs)
+{
+	gchar *value;
+
+	g_return_if_fail (property_name != NULL);
+	g_return_if_fail (property_value != NULL);
+	g_return_if_fail (pcs != NULL);
+	g_return_if_fail (pcs->group != NULL);
+
+	value = e_source_group_get_property (pcs->group, property_name);
+	pcs->same = pcs->same && value && g_ascii_strcasecmp (property_value, value) == 0;
+	g_free (value);
+}
+
+/**
+ * e_source_list_peek_group_by_properties:
+ * Peeks group by its properties. Parameters are pairs of strings
+ * property_name, property_value, terminated by NULL! ESourceGroup
+ * is returned only if matches all the properties. Values are compared
+ * case insensitively.
+ **/
+ESourceGroup *
+e_source_list_peek_group_by_properties (ESourceList *list, const gchar *property_name, ...)
+{
+	GSList *p;
+	va_list ap;
+	GHashTable *props;
+
+	g_return_val_if_fail (E_IS_SOURCE_LIST (list), NULL);
+	g_return_val_if_fail (property_name != NULL, NULL);
+
+	props = g_hash_table_new (g_str_hash, g_str_equal);
+
+	va_start (ap, property_name);
+	while (property_name) {
+		const gchar *value = va_arg (ap, const gchar *);
+
+		if (!value)
+			break;
+
+		g_hash_table_insert (props, (gpointer)property_name, (gpointer)value);
+		property_name = va_arg (ap, const gchar *);
+	}
+	va_end (ap);
+
+	for (p = list->priv->groups; p != NULL; p = p->next) {
+		struct property_check_struct pcs;
+
+		pcs.group = E_SOURCE_GROUP (p->data);
+		pcs.same = TRUE;
+
+		g_hash_table_foreach (props, (GHFunc) check_group_property, &pcs);
+
+		if (pcs.same) {
+			g_hash_table_unref (props);
+			return pcs.group;
+		}
+	}
+
+	g_hash_table_unref (props);
+
+	return NULL;
+}
 
 ESource *
 e_source_list_peek_source_by_uid (ESourceList *list,
-				  const char *uid)
+				  const gchar *uid)
 {
 	GSList *p;
 
@@ -502,7 +604,7 @@ e_source_list_peek_source_any (ESourceList *list)
 gboolean
 e_source_list_add_group (ESourceList *list,
 			 ESourceGroup *group,
-			 int position)
+			 gint position)
 {
 	g_return_val_if_fail (E_IS_SOURCE_LIST (list), FALSE);
 	g_return_val_if_fail (E_IS_SOURCE_GROUP (group), FALSE);
@@ -537,7 +639,7 @@ e_source_list_remove_group (ESourceList *list,
 
 gboolean
 e_source_list_remove_group_by_uid (ESourceList *list,
-				    const char *uid)
+				    const gchar *uid)
 {
 	ESourceGroup *group;
 
@@ -552,9 +654,73 @@ e_source_list_remove_group_by_uid (ESourceList *list,
 	return TRUE;
 }
 
+/**
+ * e_source_list_ensure_group:
+ * Ensures group with the @base_uri will exists in the @list and its name will be @name.
+ * If ret_it will be TRUE the group will be also returned, in that case caller should
+ * g_object_unref the group. Otherwise it returns NULL.
+ **/
+ESourceGroup *
+e_source_list_ensure_group (ESourceList *list, const gchar *name, const gchar *base_uri, gboolean ret_it)
+{
+	ESourceGroup *group;
+
+	g_return_val_if_fail (E_IS_SOURCE_LIST (list), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (base_uri != NULL, NULL);
+
+	group = e_source_list_peek_group_by_base_uri (list, base_uri);
+	if (group) {
+		e_source_group_set_name (group, name);
+		if (ret_it)
+			g_object_ref (group);
+		else
+			group = NULL;
+	} else {
+		group = e_source_group_new (name, base_uri);
+
+		if (!e_source_list_add_group (list, group, -1)) {
+			g_warning ("Could not add source group %s with base uri %s to a source list", name, base_uri);
+			g_object_unref (group);
+			group = NULL;
+		} else {
+			/* save it now */
+			e_source_list_sync (list, NULL);
+
+			if (!ret_it) {
+				g_object_unref (group);
+				group = NULL;
+			}
+		}
+	}
+
+	return group;
+}
+
+/**
+ * e_source_list_remove_group_by_base_uri:
+ * Removes group with given base_uri.
+ * Returns TRUE if group was found.
+ **/
+gboolean
+e_source_list_remove_group_by_base_uri (ESourceList *list, const gchar *base_uri)
+{
+	ESourceGroup *group;
+
+	g_return_val_if_fail (E_IS_SOURCE_LIST (list), FALSE);
+	g_return_val_if_fail (base_uri != NULL, FALSE);
+
+	group = e_source_list_peek_group_by_base_uri (list, base_uri);
+	if (group == NULL)
+		return FALSE;
+
+	remove_group (list, group);
+	return TRUE;
+}
+
 gboolean
 e_source_list_remove_source_by_uid (ESourceList *list,
-				     const char *uid)
+				     const gchar *uid)
 {
 	GSList *p;
 
@@ -607,9 +773,9 @@ e_source_list_sync (ESourceList *list,
 gboolean
 e_source_list_is_gconf_updated (ESourceList *list)
 {
-	char *source_group_xml = NULL;
-	char *gconf_xml = NULL;
-	char *group_uid = NULL;
+	gchar *source_group_xml = NULL;
+	gchar *gconf_xml = NULL;
+	gchar *group_uid = NULL;
 	GSList *conf_list = NULL, *temp = NULL, *p = NULL;
 	xmlDocPtr xmldoc;
 	ESourceGroup *group = NULL;
@@ -625,7 +791,7 @@ e_source_list_is_gconf_updated (ESourceList *list)
 	/* From conf to list */
 
 	for (temp = conf_list; temp != NULL; temp = temp->next) {
-		gconf_xml = (char *)temp->data;
+		gconf_xml = (gchar *)temp->data;
 		xmldoc = xmlParseDoc ((const xmlChar *)gconf_xml);
 
 		if (xmldoc == NULL)
@@ -656,8 +822,8 @@ e_source_list_is_gconf_updated (ESourceList *list)
 
 	/* If there is mismatch, free the conf_list and return FALSE */
 	if (!conf_to_list) {
-		for (p = conf_list; p != NULL ; p = p->next) {
-			gconf_xml = (char *) p->data;
+		for (p = conf_list; p != NULL; p = p->next) {
+			gconf_xml = (gchar *) p->data;
 			g_free (gconf_xml);
 		}
 		g_slist_free (conf_list);
@@ -668,12 +834,12 @@ e_source_list_is_gconf_updated (ESourceList *list)
 
 	/* From list to conf */
 
-	for (p = groups ; p != NULL; p = p->next) {
+	for (p = groups; p != NULL; p = p->next) {
 		group = E_SOURCE_GROUP (p->data);
 		source_group_xml = e_source_group_to_xml (group);
 
 		for (temp = conf_list; temp != NULL; temp = temp->next) {
-			gconf_xml = (char *)temp->data;
+			gconf_xml = (gchar *)temp->data;
 			if (!e_source_group_xmlstr_equal (gconf_xml, source_group_xml))
 				continue;
 			else
@@ -688,8 +854,8 @@ e_source_list_is_gconf_updated (ESourceList *list)
 
 	}
 
-	for (p = conf_list; p != NULL ; p = p->next) {
-		gconf_xml = (char *) p->data;
+	for (p = conf_list; p != NULL; p = p->next) {
+		gconf_xml = (gchar *) p->data;
 		g_free (gconf_xml);
 	}
 	g_slist_free (conf_list);
