@@ -57,12 +57,12 @@ struct _ESourceClass {
 
 GType    e_source_get_type (void);
 
-ESource *e_source_new                (const char   *name,
-				      const char   *relative_uri);
-ESource *e_source_new_with_absolute_uri(const char   *name,
-					const char   *absolute_uri);
+ESource *e_source_new                (const gchar   *name,
+				      const gchar   *relative_uri);
+ESource *e_source_new_with_absolute_uri(const gchar   *name,
+					const gchar   *absolute_uri);
 ESource *e_source_new_from_xml_node  (xmlNodePtr    node);
-ESource *e_source_new_from_standalone_xml (const char *xml);
+ESource *e_source_new_from_standalone_xml (const gchar *xml);
 
 ESource *e_source_copy (ESource *source);
 
@@ -70,16 +70,16 @@ gboolean  e_source_update_from_xml_node  (ESource    *source,
 					  xmlNodePtr  node,
 					  gboolean   *changed_return);
 
-char *e_source_uid_from_xml_node  (xmlNodePtr node);
+gchar *e_source_uid_from_xml_node  (xmlNodePtr node);
 
 void  e_source_set_group         (ESource      *source,
 				  ESourceGroup *group);
 void  e_source_set_name          (ESource      *source,
-				  const char   *name);
+				  const gchar   *name);
 void  e_source_set_relative_uri  (ESource      *source,
-				  const char   *relative_uri);
+				  const gchar   *relative_uri);
 void  e_source_set_absolute_uri  (ESource      *source,
-				  const char   *absolute_uri);
+				  const gchar   *absolute_uri);
 void  e_source_set_color_spec    (ESource      *source,
 				  const gchar  *color_spec);
 void  e_source_set_readonly      (ESource      *source,
@@ -91,22 +91,22 @@ void  e_source_unset_color       (ESource      *source);
 #endif
 
 ESourceGroup *e_source_peek_group         (ESource *source);
-const char   *e_source_peek_uid           (ESource *source);
-const char   *e_source_peek_name          (ESource *source);
-const char   *e_source_peek_relative_uri  (ESource *source);
-const char   *e_source_peek_absolute_uri  (ESource *source);
-const char   *e_source_peek_color_spec    (ESource *source);
+const gchar   *e_source_peek_uid           (ESource *source);
+const gchar   *e_source_peek_name          (ESource *source);
+const gchar   *e_source_peek_relative_uri  (ESource *source);
+const gchar   *e_source_peek_absolute_uri  (ESource *source);
+const gchar   *e_source_peek_color_spec    (ESource *source);
 gboolean      e_source_get_readonly       (ESource *source);
 #ifndef EDS_DISABLE_DEPRECATED
 gboolean      e_source_get_color          (ESource *source,
 					   guint32 *color_return);
 #endif
 
-char *e_source_get_uri  (ESource *source);
+gchar *e_source_get_uri  (ESource *source);
 
 void  e_source_dump_to_xml_node  (ESource    *source,
 				  xmlNodePtr  parent_node);
-char *e_source_to_standalone_xml (ESource *source);
+gchar *e_source_to_standalone_xml (ESource *source);
 
 const gchar *e_source_get_property     (ESource *source,
 					const gchar *property);
@@ -117,10 +117,10 @@ void         e_source_foreach_property (ESource *source,
 					GHFunc func,
 					gpointer data);
 
-char *e_source_get_duped_property (ESource *source, const char *property);
-char *e_source_build_absolute_uri (ESource *source);
+gchar *e_source_get_duped_property (ESource *source, const gchar *property);
+gchar *e_source_build_absolute_uri (ESource *source);
 
-gboolean e_source_equal (ESource *a, ESource *b); 
+gboolean e_source_equal (ESource *a, ESource *b);
 gboolean e_source_xmlstr_equal (const gchar *a, const gchar *b);
 
 G_END_DECLS
