@@ -42,12 +42,13 @@ static guint COMPLETION_CUE_MIN_LEN = 0;
 static gboolean COMPLETION_FORCE_SHOW_ADDRESS = FALSE;
 #define ENS_DEBUG(x)
 
-G_DEFINE_TYPE (ENameSelectorEntry, e_name_selector_entry, GTK_TYPE_ENTRY);
+G_DEFINE_TYPE (ENameSelectorEntry, e_name_selector_entry, GTK_TYPE_ENTRY)
 
 typedef struct _ENameSelectorEntryPrivate	ENameSelectorEntryPrivate;
 struct _ENameSelectorEntryPrivate
 {
 	gboolean is_completing;
+	GSList *user_query_fields;
 };
 
 #define E_NAME_SELECTOR_ENTRY_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), E_TYPE_NAME_SELECTOR_ENTRY, ENameSelectorEntryPrivate))
@@ -55,14 +56,12 @@ struct _ENameSelectorEntryPrivate
 /* 1/3 of the second to wait until invoking autocomplete lookup */
 #define AUTOCOMPLETE_TIMEOUT 333
 
-#define re_set_timeout(id,func,ptr) 			\
+#define re_set_timeout(id,func,ptr)			\
 	if (id)						\
 		g_source_remove (id);			\
 	id = g_timeout_add (AUTOCOMPLETE_TIMEOUT,	\
 			    (GSourceFunc) func, ptr);
 
-static void e_name_selector_entry_class_init (ENameSelectorEntryClass *name_selector_entry_class);
-static void e_name_selector_entry_init       (ENameSelectorEntry *name_selector_entry);
 static void e_name_selector_entry_dispose    (GObject *object);
 static void e_name_selector_entry_finalize   (GObject *object);
 
@@ -105,6 +104,9 @@ static void
 e_name_selector_entry_dispose (GObject *object)
 {
 	ENameSelectorEntry *name_selector_entry = E_NAME_SELECTOR_ENTRY (object);
+	ENameSelectorEntryPrivate *priv;
+
+	priv = E_NAME_SELECTOR_ENTRY_GET_PRIVATE (name_selector_entry);
 
 	if (name_selector_entry->entry_completion) {
 		g_object_unref (name_selector_entry->entry_completion);
@@ -116,6 +118,12 @@ e_name_selector_entry_dispose (GObject *object)
 		name_selector_entry->destination_store = NULL;
 	}
 
+	if (priv && priv->user_query_fields) {
+		g_slist_foreach (priv->user_query_fields, (GFunc)g_free, NULL);
+		g_slist_free (priv->user_query_fields);
+		priv->user_query_fields = NULL;
+	}
+
 	if (G_OBJECT_CLASS (e_name_selector_entry_parent_class)->dispose)
 		G_OBJECT_CLASS (e_name_selector_entry_parent_class)->dispose (object);
 }
@@ -129,7 +137,7 @@ e_name_selector_entry_finalize (GObject *object)
 }
 
 static void
-e_name_selector_entry_updated (ENameSelectorEntry *entry, char *email)
+e_name_selector_entry_updated (ENameSelectorEntry *entry, gchar *email)
 {
 	g_return_if_fail (E_IS_NAME_SELECTOR_ENTRY (entry));
 }
@@ -468,14 +476,58 @@ escape_sexp_string (const gchar *string)
 	return encoded_string;
 }
 
+/**
+ * ens_util_populate_user_query_fields:
+ * Populates list of user query fields to string usable in query string.
+ * Returned pointer is either newly allocated string, supposed to be freed with g_free,
+ * or NULL if no fields defined.
+ **/
+gchar *
+ens_util_populate_user_query_fields (GSList *user_query_fields, const gchar *cue_str, const gchar *encoded_cue_str)
+{
+	GString *user_fields;
+	GSList *s;
+
+	g_return_val_if_fail (cue_str != NULL, NULL);
+	g_return_val_if_fail (encoded_cue_str != NULL, NULL);
+
+	user_fields = g_string_new ("");
+
+	for (s = user_query_fields; s; s = s->next) {
+		const gchar *field = s->data;
+
+		if (!field || !*field)
+			continue;
+
+		if (*field == '$') {
+			g_string_append_printf (user_fields, " (beginswith \"%s\" %s) ", field + 1, encoded_cue_str);
+		} else if (*field == '@') {
+			g_string_append_printf (user_fields, " (is \"%s\" %s) ", field + 1, encoded_cue_str);
+		} else {
+			gchar *tmp = name_style_query (field, cue_str);
+
+			g_string_append (user_fields, " ");
+			g_string_append (user_fields, tmp);
+			g_string_append (user_fields, " ");
+			g_free (tmp);
+		}
+	}
+
+	return g_string_free (user_fields, !user_fields->str || !*user_fields->str);
+}
+
 static void
 set_completion_query (ENameSelectorEntry *name_selector_entry, const gchar *cue_str)
 {
+	ENameSelectorEntryPrivate *priv;
 	EBookQuery *book_query;
 	gchar      *query_str;
 	gchar      *encoded_cue_str;
 	gchar      *full_name_query_str;
 	gchar      *file_as_query_str;
+	gchar      *user_fields_str;
+
+	priv = E_NAME_SELECTOR_ENTRY_GET_PRIVATE (name_selector_entry);
 
 	if (!name_selector_entry->contact_store)
 		return;
@@ -489,16 +541,20 @@ set_completion_query (ENameSelectorEntry *name_selector_entry, const gchar *cue_
 	encoded_cue_str     = escape_sexp_string (cue_str);
 	full_name_query_str = name_style_query ("full_name", cue_str);
 	file_as_query_str   = name_style_query ("file_as",   cue_str);
+	user_fields_str     = ens_util_populate_user_query_fields (priv->user_query_fields, cue_str, encoded_cue_str);
 
 	query_str = g_strdup_printf ("(or "
 				     " (beginswith \"nickname\"  %s) "
 				     " (beginswith \"email\"     %s) "
 				     " %s "
 				     " %s "
+				     " %s "
 				     ")",
 				     encoded_cue_str, encoded_cue_str,
-				     full_name_query_str, file_as_query_str);
+				     full_name_query_str, file_as_query_str,
+				     user_fields_str ? user_fields_str : "");
 
+	g_free (user_fields_str);
 	g_free (file_as_query_str);
 	g_free (full_name_query_str);
 	g_free (encoded_cue_str);
@@ -531,7 +587,7 @@ utf8_casefold_collate_len (const gchar *str1, const gchar *str2, gint len)
 {
 	gchar *s1 = g_utf8_casefold(str1, len);
 	gchar *s2 = g_utf8_casefold(str2, len);
-	int rv;
+	gint rv;
 
 	rv = g_utf8_collate (s1, s2);
 
@@ -807,7 +863,7 @@ type_ahead_complete (ENameSelectorEntry *name_selector_entry)
 					 destination_row_changed, name_selector_entry);
 
 	if (textrep_len > range_len) {
-		int i;
+		gint i;
 
 		/* keep character's case as user types */
 		for (i = 0; textrep [i] && cue_str [i]; i++)
@@ -1210,9 +1266,9 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 	 * Here, we let the model know about removals. */
 	for (i = index_end; i > index_start; i--) {
 		EDestination *destination = find_destination_by_index (name_selector_entry, i);
-		int range_start, range_end;
-		char *ttext;
-		const char *email=NULL;
+		gint range_start, range_end;
+		gchar *ttext;
+		const gchar *email=NULL;
 		gboolean sel=FALSE;
 
 		if (destination)
@@ -1252,7 +1308,7 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 
 	if (end_pos == start_pos +1 &&  index_end == index_start) {
 		/* We could be just deleting the empty text */
-		char *c;
+		gchar *c;
 
 		/* Get the actual deleted text */
 		c = gtk_editable_get_chars (GTK_EDITABLE (name_selector_entry), start_pos, start_pos+1);
@@ -1261,9 +1317,9 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 			/* If we are at the beginning or removing junk space, let us ignore it */
 			del_space = TRUE;
 		}
-	} else 	if (end_pos == start_pos +1 &&  index_end == index_start+1) {
+	} else	if (end_pos == start_pos +1 &&  index_end == index_start+1) {
 		/* We could be just deleting the empty text */
-		char *c;
+		gchar *c;
 
 		/* Get the actual deleted text */
 		c = gtk_editable_get_chars (GTK_EDITABLE (name_selector_entry), start_pos, start_pos+1);
@@ -1275,7 +1331,7 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 	}
 
 	if (del_comma) {
-		int range_start=-1, range_end;
+		gint range_start=-1, range_end;
 		EDestination *dest = find_destination_by_index (name_selector_entry, index_end);
 		/* If we have deleted the last comma, let us autocomplete normally
 		 */
@@ -1283,8 +1339,8 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 		if (dest && len - end_pos  != 0) {
 
 			EDestination *destination1  = find_destination_by_index (name_selector_entry, index_start);
-			char *ttext;
-			const char *email=NULL;
+			gchar *ttext;
+			const gchar *email=NULL;
 
 			if (destination1)
 				email = e_destination_get_address (destination1);
@@ -1441,7 +1497,7 @@ entry_activate (ENameSelectorEntry *name_selector_entry)
 	get_range_at_position (text, cursor_pos, &range_start, &range_end);
 
 	if (priv->is_completing) {
-		char *str_context=NULL;
+		gchar *str_context=NULL;
 
 		str_context = gtk_editable_get_chars (GTK_EDITABLE (name_selector_entry), range_end, range_end+1);
 
@@ -1450,7 +1506,7 @@ entry_activate (ENameSelectorEntry *name_selector_entry)
 			gtk_editable_insert_text (GTK_EDITABLE (name_selector_entry), ", ", -1, &range_end);
 		} else {
 			/* In the middle */
-			int newpos = strlen (text);
+			gint newpos = strlen (text);
 
                         /* Doing this we can make sure that It wont ask for completion again. */
 			gtk_editable_insert_text (GTK_EDITABLE (name_selector_entry), ", ", -1, &newpos);
@@ -1473,7 +1529,7 @@ entry_activate (ENameSelectorEntry *name_selector_entry)
 static void
 sanitize_entry (ENameSelectorEntry *name_selector_entry)
 {
-	int n;
+	gint n;
 	GList *l, *known, *del = NULL;
 	GString *str = g_string_new ("");
 
@@ -1487,7 +1543,7 @@ sanitize_entry (ENameSelectorEntry *name_selector_entry)
 		if (!dest || !e_destination_get_address (dest))
 			del = g_list_prepend (del, GINT_TO_POINTER (n));
 		else {
-			char *text;
+			gchar *text;
 
 			text = get_destination_textrep (dest);
 			if (text) {
@@ -1567,6 +1623,93 @@ deep_free_list (GList *list)
 	g_list_free (list);
 }
 
+/* Given a widget, determines the height that text will normally be drawn. */
+static guint
+entry_height (GtkWidget *widget)
+{
+	PangoLayout *layout;
+	gint bound;
+
+	g_return_val_if_fail (widget != NULL, 0);
+
+	layout = gtk_widget_create_pango_layout (widget, NULL);
+
+	pango_layout_get_pixel_size (layout, NULL, &bound);
+
+	return bound;
+}
+
+static void
+contact_layout_pixbuffer (GtkCellLayout *cell_layout, GtkCellRenderer *cell, GtkTreeModel *model,
+			  GtkTreeIter *iter, ENameSelectorEntry *name_selector_entry)
+{
+	EContact      *contact;
+	GtkTreeIter    generator_iter;
+	GtkTreeIter    contact_store_iter;
+	gint           email_n;
+	EContactPhoto *photo;
+	GdkPixbuf *pixbuf = NULL;
+
+	if (!name_selector_entry->contact_store)
+		return;
+
+	gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model),
+							  &generator_iter, iter);
+	e_tree_model_generator_convert_iter_to_child_iter (name_selector_entry->email_generator,
+							   &contact_store_iter, &email_n,
+							   &generator_iter);
+
+	contact = e_contact_store_get_contact (name_selector_entry->contact_store, &contact_store_iter);
+	if (!contact) {
+		g_object_set (cell, "pixbuf", pixbuf, NULL);
+		return;
+	}
+
+	photo =  e_contact_get (contact, E_CONTACT_PHOTO);
+	if (photo && photo->type == E_CONTACT_PHOTO_TYPE_INLINED) {
+		guint max_height = entry_height (GTK_WIDGET (name_selector_entry));
+		GdkPixbufLoader *loader;
+
+		loader = gdk_pixbuf_loader_new ();
+		if (gdk_pixbuf_loader_write (loader, (guchar *)photo->data.inlined.data, photo->data.inlined.length, NULL) &&
+		    gdk_pixbuf_loader_close (loader, NULL)) {
+			pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
+			if (pixbuf)
+				g_object_ref (pixbuf);
+		}
+		g_object_unref (loader);
+
+		if (pixbuf) {
+			gint w, h;
+			gdouble scale = 1.0;
+
+			w = gdk_pixbuf_get_width (pixbuf);
+			h = gdk_pixbuf_get_height (pixbuf);
+
+			if (h > w)
+				scale = max_height / (double) h;
+			else
+				scale = max_height / (double) w;
+
+			if (scale < 1.0) {
+				GdkPixbuf *tmp;
+
+				tmp = gdk_pixbuf_scale_simple (pixbuf, w * scale, h * scale, GDK_INTERP_BILINEAR);
+				g_object_unref (pixbuf);
+				pixbuf = tmp;
+			}
+
+		}
+	}
+
+	e_contact_photo_free (photo);
+
+	g_object_set (cell, "pixbuf", pixbuf, NULL);
+
+	if (pixbuf)
+		g_object_unref (pixbuf);
+}
+
 static void
 contact_layout_formatter (GtkCellLayout *cell_layout, GtkCellRenderer *cell, GtkTreeModel *model,
 			  GtkTreeIter *iter, ENameSelectorEntry *name_selector_entry)
@@ -2008,16 +2151,16 @@ editor_closed_cb (GtkObject *editor, gpointer data)
 static void
 popup_activate_inline_expand (ENameSelectorEntry *name_selector_entry, GtkWidget *menu_item)
 {
-	const char *email_list, *text;
+	const gchar *email_list, *text;
 	gchar *sanitized_text;
 	EDestination *destination = name_selector_entry->popup_destination;
-	int position, start, end;
+	gint position, start, end;
 
- 	position = GPOINTER_TO_INT(g_object_get_data ((GObject *)name_selector_entry, "index"));
+	position = GPOINTER_TO_INT(g_object_get_data ((GObject *)name_selector_entry, "index"));
 
 	email_list = e_destination_get_address(destination);
- 	text = gtk_entry_get_text (GTK_ENTRY (name_selector_entry));
- 	get_range_at_position (text, position, &start, &end);
+	text = gtk_entry_get_text (GTK_ENTRY (name_selector_entry));
+	get_range_at_position (text, position, &start, &end);
 
 	g_signal_handlers_block_by_func (name_selector_entry, user_delete_text, name_selector_entry);
 
@@ -2121,8 +2264,8 @@ static void
 popup_activate_cut (ENameSelectorEntry *name_selector_entry, GtkWidget *menu_item)
 {
 	EDestination *destination;
-	const char *contact_email;
-	char *pemail = NULL;
+	const gchar *contact_email;
+	gchar *pemail = NULL;
 	GtkClipboard *clipboard;
 
 	destination = name_selector_entry->popup_destination;
@@ -2150,8 +2293,8 @@ static void
 popup_activate_copy (ENameSelectorEntry *name_selector_entry, GtkWidget *menu_item)
 {
 	EDestination *destination;
-	const char *contact_email;
-	char *pemail;
+	const gchar *contact_email;
+	gchar *pemail;
 	GtkClipboard *clipboard;
 
 	destination = name_selector_entry->popup_destination;
@@ -2187,10 +2330,10 @@ destination_set_list (GtkWidget *item, EDestination *destination)
 static void
 destination_set_email (GtkWidget *item, EDestination *destination)
 {
-	int email_num;
+	gint email_num;
 	EContact *contact;
 
- 	if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
+	if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
 		return;
 	contact = e_destination_get_contact (destination);
 	if (!contact)
@@ -2209,11 +2352,11 @@ populate_popup (ENameSelectorEntry *name_selector_entry, GtkMenu *menu)
 	GList        *email_list=NULL;
 	GList        *l;
 	gint          i;
-	char 	     *edit_label;
-	char 	     *cut_label;
-	char         *copy_label;
-	int 	      email_num, len;
-	GSList 	     *group = NULL;
+	gchar	     *edit_label;
+	gchar	     *cut_label;
+	gchar         *copy_label;
+	gint	      email_num, len;
+	GSList	     *group = NULL;
 	gboolean      is_list;
 	gboolean      show_menu = FALSE;
 
@@ -2239,11 +2382,11 @@ populate_popup (ENameSelectorEntry *name_selector_entry, GtkMenu *menu)
 	if (is_list) {
 		const GList *dests = e_destination_list_get_dests (destination);
 		GList *iter;
-		int length = g_list_length ((GList *)dests);
+		gint length = g_list_length ((GList *)dests);
 
 		for (iter = (GList *)dests; iter; iter = iter->next) {
 			EDestination *dest = (EDestination *) iter->data;
-			const char *email = e_destination_get_email (dest);
+			const gchar *email = e_destination_get_email (dest);
 
 			if (!email || *email == '\0')
 				continue;
@@ -2308,7 +2451,7 @@ populate_popup (ENameSelectorEntry *name_selector_entry, GtkMenu *menu)
 	/* Expand a list inline */
 	if (is_list) {
 		/* To Translators: This would be similiar to "Expand MyList Inline" where MyList is a Contact List*/
-		edit_label = g_strdup_printf (_("E_xpand %s Inline"), (char *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
+		edit_label = g_strdup_printf (_("E_xpand %s Inline"), (gchar *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
 		menu_item = gtk_menu_item_new_with_mnemonic (edit_label);
 		g_free (edit_label);
 		gtk_widget_show (menu_item);
@@ -2323,7 +2466,7 @@ populate_popup (ENameSelectorEntry *name_selector_entry, GtkMenu *menu)
 	}
 
 	/* Copy Contact Item */
-	copy_label = g_strdup_printf (_("Cop_y %s"), (char *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
+	copy_label = g_strdup_printf (_("Cop_y %s"), (gchar *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
 	menu_item = gtk_menu_item_new_with_mnemonic (copy_label);
 	g_free (copy_label);
 	gtk_widget_show (menu_item);
@@ -2333,7 +2476,7 @@ populate_popup (ENameSelectorEntry *name_selector_entry, GtkMenu *menu)
 				  name_selector_entry);
 
 	/* Cut Contact Item */
-	cut_label = g_strdup_printf (_("C_ut %s"), (char *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
+	cut_label = g_strdup_printf (_("C_ut %s"), (gchar *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
 	menu_item = gtk_menu_item_new_with_mnemonic (cut_label);
 	g_free (cut_label);
 	gtk_widget_show (menu_item);
@@ -2350,7 +2493,7 @@ populate_popup (ENameSelectorEntry *name_selector_entry, GtkMenu *menu)
 
 	/* Edit Contact item */
 
-	edit_label = g_strdup_printf (_("_Edit %s"), (char *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
+	edit_label = g_strdup_printf (_("_Edit %s"), (gchar *)e_contact_get_const (contact, E_CONTACT_FILE_AS));
 	menu_item = gtk_menu_item_new_with_mnemonic (edit_label);
 	g_free (edit_label);
 	gtk_widget_show (menu_item);
@@ -2385,7 +2528,7 @@ copy_or_cut_clipboard (ENameSelectorEntry *name_selector_entry, gboolean is_cut)
 
 	hash = g_hash_table_new (g_direct_hash, g_direct_equal);
 	for (i = start; i <= end; i++) {
-		int index = get_index_at_position (text, i);
+		gint index = get_index_at_position (text, i);
 
 		g_hash_table_insert (hash, GINT_TO_POINTER (index), NULL);
 	}
@@ -2394,7 +2537,7 @@ copy_or_cut_clipboard (ENameSelectorEntry *name_selector_entry, gboolean is_cut)
 
 	g_hash_table_iter_init (&iter, hash);
 	while (g_hash_table_iter_next (&iter, &key, &value)) {
-		int index = GPOINTER_TO_INT (key);
+		gint index = GPOINTER_TO_INT (key);
 		EDestination *dest;
 		gint rstart, rend;
 
@@ -2475,6 +2618,7 @@ e_name_selector_entry_init (ENameSelectorEntry *name_selector_entry)
 	  else COMPLETION_CUE_MIN_LEN = 3;
   }
   COMPLETION_FORCE_SHOW_ADDRESS = gconf_client_get_bool (gconf, FORCE_SHOW_ADDRESS, NULL);
+	priv->user_query_fields = gconf_client_get_list (gconf, USER_QUERY_FIELDS, GCONF_VALUE_STRING, NULL);
   g_object_unref (G_OBJECT (gconf));
 
   /* Edit signals */
@@ -2496,7 +2640,7 @@ e_name_selector_entry_init (ENameSelectorEntry *name_selector_entry)
 
   g_signal_connect (name_selector_entry, "button-press-event", G_CALLBACK (prepare_popup_destination), name_selector_entry);
   g_signal_connect (name_selector_entry, "populate-popup", G_CALLBACK (populate_popup), name_selector_entry);
-  
+
 	/* Clipboard signals */
 	g_signal_connect (name_selector_entry, "copy-clipboard", G_CALLBACK (copy_clipboard), name_selector_entry);
 	g_signal_connect (name_selector_entry, "cut-clipboard", G_CALLBACK (cut_clipboard), name_selector_entry);
@@ -2513,8 +2657,14 @@ e_name_selector_entry_init (ENameSelectorEntry *name_selector_entry)
 
   gtk_entry_set_completion (GTK_ENTRY (name_selector_entry), name_selector_entry->entry_completion);
 
-  /* Completion list name renderer */
+	renderer = gtk_cell_renderer_pixbuf_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (name_selector_entry->entry_completion), renderer, FALSE);
+	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (name_selector_entry->entry_completion),
+		GTK_CELL_RENDERER (renderer),
+		(GtkCellLayoutDataFunc) contact_layout_pixbuffer,
+		name_selector_entry, NULL);
 
+  /* Completion list name renderer */
   renderer = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (name_selector_entry->entry_completion),
 			      renderer, TRUE);
