@@ -92,14 +92,14 @@ static gint idle_id;
 static gint ep_online_state = TRUE;
 
 #ifdef WITH_GNOME_KEYRING
-static char *default_keyring = NULL;
+static gchar *default_keyring = NULL;
 #endif
 
 #define KEY_FILE_GROUP_PREFIX "Passwords-"
 static GKeyFile *key_file = NULL;
 
 static gboolean
-check_key_file (const char *funcname)
+check_key_file (const gchar *funcname)
 {
 	if (!key_file)
 		g_message ("%s: Failed to create key file!", funcname);
@@ -451,7 +451,7 @@ ep_password_decode (const gchar *encoded_password)
 }
 
 static gboolean
-ep_idle_dispatch (void *data)
+ep_idle_dispatch (gpointer data)
 {
 	EPassMsg *msg;
 
@@ -849,9 +849,9 @@ ep_get_password_keyring (EPassMsg *msg)
 			if (default_keyring && strcmp(default_keyring, found->keyring) != 0) {
 				g_message ("Received a password from keyring '%s'. But looking for the password from '%s' keyring\n", found->keyring, default_keyring);
 				iter = g_list_next (iter);
-				continue;			
+				continue;
 			}
-				
+
 
 			if (ep_keyring_validate (uri->user, uri->host, uri->protocol, found->attributes)) {
 				msg->password = g_strdup (found->secret);
@@ -885,7 +885,7 @@ ep_get_password_keyring (EPassMsg *msg)
 			if (default_keyring && strcmp(default_keyring, found->keyring) != 0) {
 				g_message ("Received a password from keyring '%s'. But looking for the password from '%s' keyring\n", found->keyring, default_keyring);
 				iter = g_list_next (iter);
-				continue;			
+				continue;
 			}
 			if (ep_keyring_validate (uri->user, uri->host, NULL, found->attributes)) {
 				msg->password = g_strdup (found->secret);
@@ -1014,7 +1014,7 @@ ep_add_password (EPassMsg *msg)
 static void ep_ask_password (EPassMsg *msg);
 
 static void
-pass_response (GtkDialog *dialog, gint response, void *data)
+pass_response (GtkDialog *dialog, gint response, gpointer data)
 {
 	EPassMsg *msg = data;
 	gint type = msg->flags & E_PASSWORDS_REMEMBER_MASK;
@@ -1091,7 +1091,7 @@ update_capslock_state (gpointer widget, gpointer event, GtkWidget *label)
 	/* The space acts as a vertical placeholder. */
 	markup = g_markup_printf_escaped (
 		"<small>%s</small>", (mask & GDK_LOCK_MASK) ?
-	 	 _("You have the Caps Lock key on.") : " ");
+		 _("You have the Caps Lock key on.") : " ");
 	gtk_label_set_markup (GTK_LABEL (label), markup);
 	g_free (markup);
 
@@ -1274,7 +1274,7 @@ e_passwords_init (void)
 
 #ifdef WITH_GNOME_KEYRING
 	if (gnome_keyring_is_available ())
-		gnome_keyring_get_default_keyring_sync (&default_keyring); 
+		gnome_keyring_get_default_keyring_sync (&default_keyring);
 #endif
 	G_UNLOCK (passwords);
 }
@@ -1315,7 +1315,7 @@ e_passwords_shutdown (void)
 	}
 #ifdef WITH_GNOME_KEYRING
 	g_free (default_keyring);
-#endif	
+#endif
 }
 
 /**
@@ -1415,7 +1415,7 @@ e_passwords_forget_password (const gchar *component_name, const gchar *key)
  * Return value: the password associated with @key, or %NULL.  Caller
  * must free the returned password.
  **/
-char *
+gchar *
 e_passwords_get_password (const gchar *component_name, const gchar *key)
 {
 	EPassMsg *msg;
@@ -1481,7 +1481,7 @@ e_passwords_add_password (const gchar *key, const gchar *passwd)
  * return value is non-%NULL and @remember_type is not
  * E_PASSWORDS_DO_NOT_REMEMBER.
  **/
-char *
+gchar *
 e_passwords_ask_password (const gchar *title, const gchar *component_name,
 			  const gchar *key,
 			  const gchar *prompt,
