@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* test-source-combo-box.c - Test for ESourceComboBox.
  *
- * Copyright (C) 2003 Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -38,8 +38,8 @@ source_changed_cb (ESourceComboBox *combo_box)
 }
 
 
-static int
-on_idle_create_widget (const char *gconf_path)
+static gint
+on_idle_create_widget (const gchar *gconf_path)
 {
 	GtkWidget *window;
 	GtkWidget *combo_box;
@@ -65,10 +65,10 @@ on_idle_create_widget (const char *gconf_path)
 }
 
 
-int
-main (int argc, char **argv)
+gint
+main (gint argc, gchar **argv)
 {
-	const char *gconf_path;
+	const gchar *gconf_path;
 
 	gtk_init (&argc, &argv);
 
@@ -77,7 +77,7 @@ main (int argc, char **argv)
 	else
 		gconf_path = argv [1];
 
-	g_idle_add ((GSourceFunc) on_idle_create_widget, (void *) gconf_path);
+	g_idle_add ((GSourceFunc) on_idle_create_widget, (gpointer) gconf_path);
 
 	gtk_main ();
 
