@@ -37,136 +37,136 @@ struct _E2kContextClass {
 
 	/* signals */
 	void (*redirect) (E2kContext *ctx, E2kHTTPStatus status,
-			  const char *old_uri, const char *new_uri);
+			  const gchar *old_uri, const gchar *new_uri);
 };
 
 GType          e2k_context_get_type         (void);
 
-E2kContext    *e2k_context_new              (const char  *uri);
+E2kContext    *e2k_context_new              (const gchar  *uri);
 void           e2k_context_set_auth         (E2kContext  *ctx,
-					     const char  *username,
-					     const char  *domain,
-					     const char  *authmech,
-					     const char  *password);
+					     const gchar  *username,
+					     const gchar  *domain,
+					     const gchar  *authmech,
+					     const gchar  *password);
 gboolean       e2k_context_fba              (E2kContext  *ctx,
 					     SoupMessage *failed_msg);
 
 time_t        e2k_context_get_last_timestamp    (E2kContext *ctx);
 
 typedef gboolean (*E2kContextTestCallback)     (E2kContext *ctx,
-						const char *test_name,
+						const gchar *test_name,
 						gpointer user_data);
 
 E2kHTTPStatus  e2k_context_get               (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      char **content_type,
+					      const gchar *uri,
+					      gchar **content_type,
 					      SoupBuffer **response);
 E2kHTTPStatus  e2k_context_get_owa           (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
+					      const gchar *uri,
 					      gboolean claim_ie,
 					      SoupBuffer **response);
 
 E2kHTTPStatus  e2k_context_put               (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      const char *content_type,
-					      const char *body, int length,
-					      char **repl_uid);
+					      const gchar *uri,
+					      const gchar *content_type,
+					      const gchar *body, gint length,
+					      gchar **repl_uid);
 E2kHTTPStatus  e2k_context_put_new           (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *folder_uri,
-					      const char *object_name,
+					      const gchar *folder_uri,
+					      const gchar *object_name,
 					      E2kContextTestCallback test_callback,
 					      gpointer user_data,
-					      const char *content_type,
-					      const char *body, int length,
-					      char **location,
-					      char **repl_uid);
+					      const gchar *content_type,
+					      const gchar *body, gint length,
+					      gchar **location,
+					      gchar **repl_uid);
 E2kHTTPStatus  e2k_context_post              (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      const char *content_type,
-					      const char *body, int length,
-					      char **location,
-					      char **repl_uid);
+					      const gchar *uri,
+					      const gchar *content_type,
+					      const gchar *body, gint length,
+					      gchar **location,
+					      gchar **repl_uid);
 
 E2kHTTPStatus  e2k_context_proppatch         (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
+					      const gchar *uri,
 					      E2kProperties *props,
 					      gboolean create,
-					      char **repl_uid);
+					      gchar **repl_uid);
 E2kHTTPStatus  e2k_context_proppatch_new     (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *folder_uri,
-					      const char *object_name,
+					      const gchar *folder_uri,
+					      const gchar *object_name,
 					      E2kContextTestCallback test_callback,
 					      gpointer user_data,
 					      E2kProperties *props,
-					      char **location,
-					      char **repl_uid);
+					      gchar **location,
+					      gchar **repl_uid);
 E2kResultIter *e2k_context_bproppatch_start  (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      const char **hrefs,
-					      int nhrefs,
+					      const gchar *uri,
+					      const gchar **hrefs,
+					      gint nhrefs,
 					      E2kProperties *props,
 					      gboolean create);
 
 E2kHTTPStatus  e2k_context_propfind          (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      const char **props,
-					      int nprops,
+					      const gchar *uri,
+					      const gchar **props,
+					      gint nprops,
 					      E2kResult **results,
-					      int *nresults);
+					      gint *nresults);
 E2kResultIter *e2k_context_bpropfind_start   (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      const char **hrefs,
-					      int nhrefs,
-					      const char **props,
-					      int nprops);
+					      const gchar *uri,
+					      const gchar **hrefs,
+					      gint nhrefs,
+					      const gchar **props,
+					      gint nprops);
 
 E2kResultIter *e2k_context_search_start      (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      const char **props,
-					      int nprops,
+					      const gchar *uri,
+					      const gchar **props,
+					      gint nprops,
 					      E2kRestriction *rn,
-					      const char *orderby,
+					      const gchar *orderby,
 					      gboolean ascending);
 
 E2kHTTPStatus  e2k_context_delete            (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri);
+					      const gchar *uri);
 
 E2kResultIter *e2k_context_bdelete_start     (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
-					      const char **hrefs,
-					      int nhrefs);
+					      const gchar *uri,
+					      const gchar **hrefs,
+					      gint nhrefs);
 
 E2kHTTPStatus  e2k_context_mkcol             (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *uri,
+					      const gchar *uri,
 					      E2kProperties *props,
-					      char **permanent_url);
+					      gchar **permanent_url);
 
 E2kResultIter *e2k_context_transfer_start    (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *source_folder,
-					      const char *dest_folder,
+					      const gchar *source_folder,
+					      const gchar *dest_folder,
 					      GPtrArray *source_hrefs,
 					      gboolean delete_originals);
 E2kHTTPStatus  e2k_context_transfer_dir      (E2kContext *ctx,
 					      E2kOperation *op,
-					      const char *source_href,
-					      const char *dest_href,
+					      const gchar *source_href,
+					      const gchar *dest_href,
 					      gboolean delete_original,
-					      char **permanent_url);
+					      gchar **permanent_url);
 
 /* Subscriptions */
 typedef enum {
@@ -177,32 +177,32 @@ typedef enum {
 } E2kContextChangeType;
 
 typedef void (*E2kContextChangeCallback)     (E2kContext *ctx,
-					      const char *uri,
+					      const gchar *uri,
 					      E2kContextChangeType type,
 					      gpointer user_data);
 
 void          e2k_context_subscribe          (E2kContext *ctx,
-					      const char *uri,
+					      const gchar *uri,
 					      E2kContextChangeType type,
-					      int min_interval,
+					      gint min_interval,
 					      E2kContextChangeCallback callback,
 					      gpointer user_data);
 void          e2k_context_unsubscribe        (E2kContext *ctx,
-					      const char *uri);
+					      const gchar *uri);
 
 
 /*
  * Utility functions
  */
 SoupMessage   *e2k_soup_message_new      (E2kContext *ctx,
-					  const char *uri,
-					  const char *method);
+					  const gchar *uri,
+					  const gchar *method);
 SoupMessage   *e2k_soup_message_new_full (E2kContext *ctx,
-					  const char *uri,
-					  const char *method,
-					  const char *content_type,
+					  const gchar *uri,
+					  const gchar *method,
+					  const gchar *content_type,
 					  SoupMemoryUse use,
-					  const char *body,
+					  const gchar *body,
 					  gsize length);
 void           e2k_context_queue_message (E2kContext *ctx,
 					  SoupMessage *msg,
