@@ -41,56 +41,56 @@ typedef enum {
 
 #define E2K_FL_MATCH_TYPE(fl) ((fl) & 0x3)
 
-E2kRestriction *e2k_restriction_and         (int                   nrns,
+E2kRestriction *e2k_restriction_and         (gint                   nrns,
 					     E2kRestriction      **rns,
 					     gboolean              unref);
 E2kRestriction *e2k_restriction_andv        (E2kRestriction       *rn, ...);
-E2kRestriction *e2k_restriction_or          (int                   nrns,
+E2kRestriction *e2k_restriction_or          (gint                   nrns,
 					     E2kRestriction      **rns,
 					     gboolean              unref);
 E2kRestriction *e2k_restriction_orv         (E2kRestriction       *rn, ...);
 E2kRestriction *e2k_restriction_not         (E2kRestriction       *rn,
 					     gboolean              unref);
-E2kRestriction *e2k_restriction_content     (const char           *propname,
+E2kRestriction *e2k_restriction_content     (const gchar           *propname,
 					     E2kRestrictionFuzzyLevel fuzzy_level,
-					     const char           *value);
-E2kRestriction *e2k_restriction_prop_bool   (const char           *propname,
+					     const gchar           *value);
+E2kRestriction *e2k_restriction_prop_bool   (const gchar           *propname,
 					     E2kRestrictionRelop   relop,
 					     gboolean              value);
-E2kRestriction *e2k_restriction_prop_int    (const char           *propname,
+E2kRestriction *e2k_restriction_prop_int    (const gchar           *propname,
 					     E2kRestrictionRelop   relop,
-					     int                   value);
-E2kRestriction *e2k_restriction_prop_date   (const char           *propname,
+					     gint                   value);
+E2kRestriction *e2k_restriction_prop_date   (const gchar           *propname,
 					     E2kRestrictionRelop   relop,
-					     const char           *value);
-E2kRestriction *e2k_restriction_prop_string (const char           *propname,
+					     const gchar           *value);
+E2kRestriction *e2k_restriction_prop_string (const gchar           *propname,
 					     E2kRestrictionRelop   relop,
-					     const char           *value);
-E2kRestriction *e2k_restriction_prop_binary (const char           *propname,
+					     const gchar           *value);
+E2kRestriction *e2k_restriction_prop_binary (const gchar           *propname,
 					     E2kRestrictionRelop   relop,
 					     gconstpointer         data,
-					     int                   len);
-E2kRestriction *e2k_restriction_compare     (const char           *propname1,
+					     gint                   len);
+E2kRestriction *e2k_restriction_compare     (const gchar           *propname1,
 					     E2kRestrictionRelop   relop,
-					     const char           *propname2);
-E2kRestriction *e2k_restriction_bitmask     (const char           *propname,
+					     const gchar           *propname2);
+E2kRestriction *e2k_restriction_bitmask     (const gchar           *propname,
 					     E2kRestrictionBitop   bitop,
 					     guint32               mask);
-E2kRestriction *e2k_restriction_size        (const char           *propname,
+E2kRestriction *e2k_restriction_size        (const gchar           *propname,
 					     E2kRestrictionRelop   relop,
 					     guint32               size);
-E2kRestriction *e2k_restriction_exist       (const char           *propname);
-E2kRestriction *e2k_restriction_sub         (const char           *subtable,
+E2kRestriction *e2k_restriction_exist       (const gchar           *propname);
+E2kRestriction *e2k_restriction_sub         (const gchar           *subtable,
 					     E2kRestriction       *rn,
 					     gboolean              unref);
 
 void            e2k_restriction_ref         (E2kRestriction       *rn);
 void            e2k_restriction_unref       (E2kRestriction       *rn);
 
-char           *e2k_restriction_to_sql      (E2kRestriction       *rn);
+gchar           *e2k_restriction_to_sql      (E2kRestriction       *rn);
 
 gboolean        e2k_restriction_extract     (guint8              **data,
-					     int                  *len,
+					     gint                  *len,
 					     E2kRestriction      **rn);
 void            e2k_restriction_append      (GByteArray           *ba,
 					     E2kRestriction       *rn);
