@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* server-interface-check.h
  *
- * Copyright (C) 2004  Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Sivaiah Nallagatla <snallagatla@novell.com>
  */
@@ -26,7 +26,9 @@
 
 #include "offline-listener.h"
 #include <libedata-book/e-data-book-factory.h>
+#if ENABLE_CALENDAR
 #include <libedata-cal/e-data-cal-factory.h>
+#endif
 #include <gconf/gconf-client.h>
 
 enum {
@@ -37,34 +39,35 @@ enum {
 
 static GObjectClass *parent_class = NULL;
 
-struct _OfflineListenerPrivate 
+struct _OfflineListenerPrivate
 {
 	GConfClient *default_client;
+
+#if ENABLE_CALENDAR
 	EDataCalFactory *cal_factory;
+#endif
 	EDataBookFactory *book_factory;
 	gboolean is_offline_now;
 };
 
 
-static void 
+static void
 set_online_status (OfflineListener *offline_listener, gboolean is_offline)
 {
 	OfflineListenerPrivate *priv;
-	
+
 	priv = offline_listener->priv;
-	
-	if (is_offline) {
-		e_data_cal_factory_set_backend_mode (priv->cal_factory, OFFLINE_MODE);
-		e_data_book_factory_set_backend_mode (priv->book_factory, OFFLINE_MODE);
-
-	} else {
-		e_data_cal_factory_set_backend_mode (priv->cal_factory, ONLINE_MODE);
-		e_data_book_factory_set_backend_mode (priv->book_factory, ONLINE_MODE);
-	}
 
+#if ENABLE_CALENDAR
+	e_data_cal_factory_set_backend_mode
+		(priv->cal_factory, is_offline ? OFFLINE_MODE : ONLINE_MODE);
+#endif
+	e_data_book_factory_set_backend_mode
+		(priv->book_factory, is_offline ? OFFLINE_MODE : ONLINE_MODE);
 }
-static void 
-online_status_changed (GConfClient *client, int cnxn_id, GConfEntry *entry, gpointer data)
+
+static void
+online_status_changed (GConfClient *client, gint cnxn_id, GConfEntry *entry, gpointer data)
 {
 	GConfValue *value;
 	gboolean offline;
@@ -81,30 +84,37 @@ online_status_changed (GConfClient *client, int cnxn_id, GConfEntry *entry, gpoi
 		priv->is_offline_now = offline;
 		set_online_status (offline_listener ,offline);
 	}
-	
+
 }
 
 
-static void 
+static void
 setup_offline_listener (OfflineListener *offline_listener)
 {
 	OfflineListenerPrivate *priv = offline_listener->priv;
-	
+
 	priv->default_client = gconf_client_get_default ();
 	gconf_client_add_dir (priv->default_client, "/apps/evolution/shell", GCONF_CLIENT_PRELOAD_RECURSIVE,NULL);
 	gconf_client_notify_add (priv->default_client, "/apps/evolution/shell/start_offline", (GConfClientNotifyFunc)online_status_changed, offline_listener, NULL, NULL);
 	priv->is_offline_now = gconf_client_get_bool (priv->default_client, "/apps/evolution/shell/start_offline", NULL);
-	set_online_status (offline_listener, priv->is_offline_now); 
+	set_online_status (offline_listener, priv->is_offline_now);
 }
 
+#if ENABLE_CALENDAR
 OfflineListener*
 offline_listener_new (EDataBookFactory *book_factory, EDataCalFactory *cal_factory)
+#else
+OfflineListener*
+offline_listener_new (EDataBookFactory *book_factory)
+#endif
 {
 	OfflineListener *offline_listener = g_object_new (OFFLINE_TYPE_LISTENER, NULL);
 	OfflineListenerPrivate *priv = offline_listener->priv;
-	
+
 	priv->book_factory = book_factory;
+#if ENABLE_CALENDAR
 	priv->cal_factory = cal_factory;
+#endif
 	setup_offline_listener (offline_listener);
 	return offline_listener;
 
@@ -130,10 +140,10 @@ offline_listener_finalize (GObject *object)
 
 	offline_listener = OFFLINE_LISTENER (object);
 	priv = offline_listener->priv;
-	
+
 	g_free (priv);
 	offline_listener->priv = NULL;
-	
+
 	parent_class->finalize (object);
 }
 
@@ -141,10 +151,10 @@ static void
 offline_listener_init (OfflineListener *listener)
 {
 	OfflineListenerPrivate *priv;
-	
+
 	priv =g_new0 (OfflineListenerPrivate, 1);
 	listener->priv = priv;
-	
+
 }
 
 
@@ -159,8 +169,8 @@ offline_listener_class_init (OfflineListener *klass)
 	object_class = G_OBJECT_CLASS (klass);
 	object_class->dispose = offline_listener_dispose;
 	object_class->finalize = offline_listener_finalize;
-	
-	
+
+
 
 }
 
